\qt@newcmd\qurantrans@en@i{%
In the Name of Allah, the Most Beneficent, the Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
All the praises and thanks be to Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
The Most Beneficent, the Most Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
The Only Owner (and the Only Ruling Judge) of the Day of Recompense (i.e. the Day of Resurrection)\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
You (Alone) we worship, and you (Alone) we ask for help (for each and everything).\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us to the Straight Way\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The Way of those on whom You have bestowed Your Grace, not (the way) of those who earned Your Anger, nor of those who went astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Book (the Quran), whereof there is no doubt, a guidance to those who are Al-Muttaqun [the pious and righteous persons who fear Allah much (abstain from all kinds of sins and evil deeds which He has forbidden) and love Allah much (perform all kinds of good deeds which He has ordained)].\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the Ghaib and perform As-Salat (Iqamat-as-Salat), and spend out of what we have provided for them [i.e. give Zakat, spend on themselves, their parents, their children, their wives, etc., and also give charity to the poor and also in Allah's Cause - Jihad, etc.].\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in (the Quran and the Sunnah) which has been sent down (revealed) to you (Muhammad Peace be upon him) and in [the Taurat (Torah) and the Injeel (Gospel), etc.] which were sent down before you and they believe with certainty in the Hereafter. (Resurrection, recompense of their good and bad deeds, Paradise and Hell, etc.).\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
They are on (true) guidance from their Lord, and they are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
Verily, those who disbelieve, it is the same to them whether you (O Muhammad Peace be upon him) warn them or do not warn them, they will not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has set a seal on their hearts and on their hearings, (i.e. they are closed from accepting Allah's Guidance), and on their eyes there is a covering. Theirs will be a great torment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And of mankind, there are some (hypocrites) who say: ``We believe in Allah and the Last Day" while in fact they believe not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They (think to) deceive Allah and those who believe, while they only deceive themselves, and perceive (it) not!\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease (of doubt and hypocrisy) and Allah has increased their disease. A painful torment is theirs because they used to tell lies.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said to them: ``Make not mischief on the earth," they say: ``We are only peacemakers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Verily! They are the ones who make mischief, but they perceive not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them (hypocrites): ``Believe as the people (followers of Muhammad Peace be upon him, Al-Ansar and Al-Muhajirun) have believed," they say: ``Shall we believe as the fools have believed?" Verily, they are the fools, but they know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they meet those who believe, they say: ``We believe," but when they are alone with their Shayatin (devils - polytheists, hypocrites, etc.), they say: ``Truly, we are with you; verily, we were but mocking."\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah mocks at them and gives them increase in their wrong-doings to wander blindly.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are they who have purchased error for guidance, so their commerce was profitless. And they were not guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their likeness is as the likeness of one who kindled a fire; then, when it lighted all around him, Allah took away their light and left them in darkness. (So) they could not see.\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
They are deaf, dumb, and blind, so they return not (to the Right Path).\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or like a rainstorm from the sky, wherein is darkness, thunder, and lightning. They thrust their fingers in their ears to keep out the stunning thunderclap for fear of death. But Allah ever encompasses the disbelievers (i.e. Allah will gather them all together).\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatches away their sight, whenever it flashes for them, they walk therein, and when darkness covers them, they stand still. And if Allah willed, He could have taken away their hearing and their sight. Certainly, Allah has power over all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O mankind! Worship your Lord (Allah), Who created you and those who were before you so that you may become Al-Muttaqun (the pious - see V. 2:2).\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
Who has made the earth a resting place for you, and the sky as a canopy, and sent down water (rain) from the sky and brought forth therewith fruits as a provision for you. Then do not set up rivals unto Allah (in worship) while you know (that He Alone has the right to be worshipped).\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you (Arab pagans, Jews, and Christians) are in doubt concerning that which We have sent down (i.e. the Quran) to Our slave (Muhammad Peace be upon him), then produce a Surah (chapter) of the like thereof and call your witnesses (supporters and helpers) besides Allah, if you are truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you do it not, and you can never do it, then fear the Fire (Hell) whose fuel is men and stones, prepared for the disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give glad tidings to those who believe and do righteous good deeds, that for them will be Gardens under which rivers flow (Paradise). Every time they will be provided with a fruit therefrom, they will say: ``This is what we were provided with before," and they will be given things in resemblance (i.e. in the same form but different in taste) and they shall have therein Azwajun Mutahharatun (purified mates or wives), (having no menses, stools, urine, etc.) and they will abide therein forever.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Verily, Allah is not ashamed to set forth a parable even of a mosquito or so much more when it is bigger (or less when it is smaller) than it. And as for those who believe, they know that it is the Truth from their Lord, but as for those who disbelieve, they say: ``What did Allah intend by this parable?" By it He misleads many, and many He guides thereby. And He misleads thereby only those who are Al-Fasiqun (the rebellious, disobedient to Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who break Allah's Covenant after ratifying it, and sever what Allah has ordered to be joined (as regards Allah's Religion of Islamic Monotheism, and to practise its legal laws on the earth and also as regards keeping good relations with kith and kin), and do mischief on earth, it is they who are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can you disbelieve in Allah? Seeing that you were dead and He gave you life. Then He will give you death, then again will bring you to life (on the Day of Resurrection) and then unto Him you will return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He it is Who created for you all that is on earth. Then He Istawa (rose over) towards the heaven and made them seven heavens and He is the All-Knower of everything.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And (remember) when your Lord said to the angels: ``Verily, I am going to place (mankind) generations after generations on earth." They said: ``Will You place therein those who will make mischief therein and shed blood, - while we glorify You with praises and thanks (Exalted be You above all that they associate with You as partners) and sanctify You." He (Allah) said: ``I know that which you do not know."\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam all the names (of everything), then He showed them to the angels and said, ``Tell Me the names of these if you are truthful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They (angels) said: ``Glory be to You, we have no knowledge except what you have taught us. Verily, it is You, the All-Knower, the All-Wise."\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said: ``O Adam! Inform them of their names," and when he had informed them of their names, He said: ``Did I not tell you that I know the Ghaib (unseen) in the heavens and the earth, and I know what you reveal and what you have been concealing?"\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And (remember) when We said to the angels: ``Prostrate yourselves before Adam.". And they prostrated except Iblis (Satan), he refused and was proud and was one of the disbelievers (disobedient to Allah).\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said: ``O Adam! Dwell you and your wife in the Paradise and eat both of you freely with pleasure and delight of things therein as wherever you will, but come not near this tree or you both will be of the Zalimun (wrong-doers)."\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
Then the Shaitan (Satan) made them slip therefrom (the Paradise), and got them out from that in which they were. We said: ``Get you down, all, with enmity between yourselves. On earth will be a dwelling place for you and an enjoyment for a time."\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received from his Lord Words. And his Lord pardoned him (accepted his repentance). Verily, He is the One Who forgives (accepts repentance), the Most Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said: ``Get down all of you from this place (the Paradise), then whenever there comes to you Guidance from Me, and whoever follows My Guidance, there shall be no fear on them, nor shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
But those who disbelieve and belie Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) such are the dwellers of the Fire, they shall abide therein forever.\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel! Remember My Favour which I bestowed upon you, and fulfill (your obligations to) My Covenant (with you) so that I fulfill (My Obligations to) your covenant (with Me), and fear none but Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I have sent down (this Quran), confirming that which is with you, [the Taurat (Torah) and the Injeel (Gospel)], and be not the first to disbelieve therein, and buy not with My Verses [the Taurat (Torah) and the Injeel (Gospel)] a small price (i.e. getting a small gain by selling My Verses), and fear Me and Me Alone. (Tafsir At-Tabari, Vol. I, Page 253).\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And mix not truth with falsehood, nor conceal the truth [i.e. Muhammad Peace be upon him is Allah's Messenger and his qualities are written in your Scriptures, the Taurat (Torah) and the Injeel (Gospel)] while you know (the truth).\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And perform As-Salat (Iqamat-as-Salat), and give Zakat, and Irka' (i.e. bow down or submit yourselves with obedience to Allah) along with Ar-Raki'un.\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Enjoin you Al-Birr (piety and righteousness and each and every act of obedience to Allah) on the people and you forget (to practise it) yourselves, while you recite the Scripture [the Taurat (Torah)]! Have you then no sense?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help in patience and As-Salat (the prayer) and truly it is extremely heavy and hard except for Al-Khashi'un [i.e. the true believers in Allah - those who obey Allah with full submission, fear much from His Punishment, and believe in His Promise (Paradise, etc.) and in His Warnings (Hell, etc.)].\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
(They are those) who are certain that they are going to meet their Lord, and that unto Him they are going to return.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel! Remember My Favour which I bestowed upon you and that I preferred you to the 'Alamin (mankind and jinns) (of your time period, in the past).\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And fear a Day (of Judgement) when a person shall not avail another, nor will intercession be accepted from him nor will compensation be taken from him nor will they be helped.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And (remember) when We delivered you from Fir'aun's (Pharaoh) people, who were afflicting you with a horrible torment, killing your sons and sparing your women, and therein was a mighty trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And (remember) when We separated the sea for you and saved you and drowned Fir'aun's (Pharaoh) people while you were looking (at them, when the sea-water covered them).\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And (remember) when We appointed for Musa (Moses) forty nights, and (in his absence) you took the calf (for worship), and you were Zalimun (polytheists and wrong-doers, etc.).\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then after that We forgave you so that you might be grateful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And (remember) when We gave Musa (Moses) the Scripture [the Taurat (Torah)] and the criterion (of right and wrong) so that you may be guided aright.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And (remember) when Musa (Moses) said to his people: ``O my people! Verily, you have wronged yourselves by worshipping the calf. So turn in repentance to your Creator and kill yourselves (the innocent kill the wrongdoers among you), that will be better for you with your Lord." Then He accepted your repentance. Truly, He is the One Who accepts repentance, the Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And (remember) when you said: ``O Musa (Moses)! We shall never believe in you till we see Allah plainly." But you were seized with a thunderbolt (lightning) while you were looking.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you up after your death, so that you might be grateful.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We shaded you with clouds and sent down on you Al-Manna and the quails, (saying): ``Eat of the good lawful things We have provided for you," (but they rebelled). And they did not wrong Us but they wronged themselves.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And (remember) when We said: ``Enter this town (Jerusalem) and eat bountifully therein with pleasure and delight wherever you wish, and enter the gate in prostration (or bowing with humility) and say: 'Forgive us,' and We shall forgive you your sins and shall increase (reward) for the good-doers."\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But those who did wrong changed the word from that which had been told to them for another, so We sent upon the wrong-doers Rijzan (a punishment) from the heaven because of their rebelling against Allah's Obedience. (Tafsir At-Tabari, Vol. I, Page 305).\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And (remember) when Musa (Moses) asked for water for his people, We said: ``Strike the stone with your stick." Then gushed forth therefrom twelve springs. Each (group of) people knew its own place for water. ``Eat and drink of that which Allah has provided and do not act corruptly, making mischief on the earth."\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And (remember) when you said, ``O Musa (Moses)! We cannot endure one kind of food. So invoke your Lord for us to bring forth for us of what the earth grows, its herbs, its cucumbers, its Fum (wheat or garlic), its lentils and its onions." He said, ``Would you exchange that which is better for that which is lower? Go you down to any town and you shall find what you want!" And they were covered with humiliation and misery, and they drew on themselves the Wrath of Allah. That was because they used to disbelieve the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah and killed the Prophets wrongfully. That was because they disobeyed and used to transgress the bounds (in their disobedience to Allah, i.e. commit crimes and sins).\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Verily! Those who believe and those who are Jews and Christians, and Sabians, whoever believes in Allah and the Last Day and do righteous good deeds shall have their reward with their Lord, on them shall be no fear, nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And (O Children of Israel, remember) when We took your covenant and We raised above you the Mount (saying): ``Hold fast to that which We have given you, and remember that which is therein so that you may become Al-Muttaqun (the pious - see V. 2:2).\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then after that you turned away. Had it not been for the Grace and Mercy of Allah upon you, indeed you would have been among the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And indeed you knew those amongst you who transgressed in the matter of the Sabbath (i.e. Saturday). We said to them: ``Be you monkeys, despised and rejected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
So We made this punishment an example to their own and to succeeding generations and a lesson to those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And (remember) when Musa (Moses) said to his people: ``Verily, Allah commands you that you slaughter a cow." They said, ``Do you make fun of us?" He said, ``I take Allah's Refuge from being among Al-Jahilun (the ignorants or the foolish)."\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, ``Call upon your Lord for us that He may make plain to us what it is!" He said, ``He says, 'Verily, it is a cow neither too old nor too young, but (it is) between the two conditions', so do what you are commanded."\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, ``Call upon your Lord for us to make plain to us its colour." He said, ``He says, 'It is a yellow cow, bright in its colour, pleasing to the beholders.' ``\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, ``Call upon your Lord for us to make plain to us what it is. Verily to us all cows are alike, And surely, if Allah wills, we will be guided."\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He [Musa (Moses)] said, ``He says, 'It is a cow neither trained to till the soil nor water the fields, sound, having no other colour except bright yellow.' `` They said, ``Now you have brought the truth." So they slaughtered it though they were near to not doing it.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And (remember) when you killed a man and fell into dispute among yourselves as to the crime. But Allah brought forth that which you were hiding.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
So We said: ``Strike him (the dead man) with a piece of it (the cow)." Thus Allah brings the dead to life and shows you His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) so that you may understand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then, after that, your hearts were hardened and became as stones or even worse in hardness. And indeed, there are stones out of which rivers gush forth, and indeed, there are of them (stones) which split asunder so that water flows from them, and indeed, there are of them (stones) which fall down for fear of Allah. And Allah is not unaware of what you do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Do you (faithful believers) covet that they will believe in your religion inspite of the fact that a party of them (Jewish rabbis) used to hear the Word of Allah [the Taurat (Torah)], then they used to change it knowingly after they understood it?\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they (Jews) meet those who believe (Muslims), they say, ``We believe", but when they meet one another in private, they say, ``Shall you (Jews) tell them (Muslims) what Allah has revealed to you [Jews, about the description and the qualities of Prophet Muhammad Peace be upon him, that which are written in the Taurat (Torah)], that they (Muslims) may argue with you (Jews) about it before your Lord?" Have you (Jews) then no understanding?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Know they (Jews) not that Allah knows what they conceal and what they reveal?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And there are among them (Jews) unlettered people, who know not the Book, but they trust upon false desires and they but guess.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Then woe to those who write the Book with their own hands and then say, ``This is from Allah," to purchase with it a little price! Woe to them for what their hands have written and woe to them for that they earn thereby.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they (Jews) say, ``The Fire (i.e. Hell-fire on the Day of Resurrection) shall not touch us but for a few numbered days." Say (O Muhammad Peace be upon him to them): ``Have you taken a covenant from Allah, so that Allah will not break His Covenant? Or is it that you say of Allah what you know not?"\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Yes! Whosoever earns evil and his sin has surrounded him, they are dwellers of the Fire (i.e. Hell); they will dwell therein forever.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those who believe (in the Oneness of Allah - Islamic Monotheism) and do righteous good deeds, they are dwellers of Paradise, they will dwell therein forever.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And (remember) when We took a covenant from the Children of Israel, (saying): Worship none but Allah (Alone) and be dutiful and good to parents, and to kindred, and to orphans and Al-Masakin (the poor), [Tafsir At-Tabari, Vol. 10, Page 158 (Verse 9:60)] and speak good to people [i.e. enjoin righteousness and forbid evil, and say the truth about Muhammad Peace be upon him], and perform As-Salat (Iqamat-as-Salat), and give Zakat. Then you slid back, except a few of you, while you are backsliders. (Tafsir Al-Qurtubi, Vol. 2, Page 392).\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And (remember) when We took your covenant (saying): Shed not the blood of your people, nor turn out your own people from their dwellings. Then, (this) you ratified and (to this) you bear witness.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
After this, it is you who kill one another and drive out a party of you from their homes, assist (their enemies) against them, in sin and transgression. And if they come to you as captives, you ransom them, although their expulsion was forbidden to you. Then do you believe in a part of the Scripture and reject the rest? Then what is the recompense of those who do so among you, except disgrace in the life of this world, and on the Day of Resurrection they shall be consigned to the most grievous torment. And Allah is not unaware of what you do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Those are they who have bought the life of this world at the price of the Hereafter. Their torment shall not be lightened nor shall they be helped.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And indeed, We gave Musa (Moses) the Book and followed him up with a succession of Messengers. And We gave 'Iesa (Jesus), the son of Maryam (Mary), clear signs and supported him with Ruh-ul-Qudus [Jibrael (Gabriel)]. Is it that whenever there came to you a Messenger with what you yourselves desired not, you grew arrogant? Some, you disbelieved and some, you killed.\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they say, ``Our hearts are wrapped (i.e. do not hear or understand Allah's Word)." Nay, Allah has cursed them for their disbelief, so little is that which they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there came to them (the Jews), a Book (this Quran) from Allah confirming what is with them [the Taurat (Torah) and the Injeel (Gospel)], although aforetime they had invoked Allah (for coming of Muhammad Peace be upon him) in order to gain victory over those who disbelieved, then when there came to them that which they had recognised, they disbelieved in it. So let the Curse of Allah be on the disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
How bad is that for which they have sold their ownselves, that they should disbelieve in that which Allah has revealed (the Quran), grudging that Allah should reveal of His Grace unto whom He will of His slaves. So they have drawn on themselves wrath upon wrath. And for the disbelievers, there is disgracing torment.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said to them (the Jews), ``Believe in what Allah has sent down," they say, ``We believe in what was sent down to us." And they disbelieve in that which came after it, while it is the truth confirming what is with them. Say (O Muhammad Peace be upon him to them): ``Why then have you killed the Prophets of Allah aforetime, if you indeed have been believers?"\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And indeed Musa (Moses) came to you with clear proofs, yet you worshipped the calf after he left, and you were Zalimun (polytheists and wrong-doers).\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And (remember) when We took your covenant and We raised above you the Mount (saying), ``Hold firmly to what We have given you and hear (Our Word). They said, ``We have heard and disobeyed." And their hearts absorbed (the worship of) the calf because of their disbelief. Say: ``Worst indeed is that which your faith enjoins on you if you are believers."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say to (them): ``If the home of the Hereafter with Allah is indeed for you specially and not for others, of mankind, then long for death if you are truthful."\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never long for it because of what their hands have sent before them (i.e. what they have done). And Allah is All-Aware of the Zalimun (polytheists and wrong-doers).\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
And verily, you will find them (the Jews) the greediest of mankind for life and (even greedier) than those who - ascribe partners to Allah (and do not believe in Resurrection - Magians, pagans, and idolaters, etc.). Everyone of them wishes that he could be given a life of a thousand years. But the grant of such life will not save him even a little from (due) punishment. And Allah is All-Seer of what they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say (O Muhammad Peace be upon him): ``Whoever is an enemy to Jibrael (Gabriel) (let him die in his fury), for indeed he has brought it (this Quran) down to your heart by Allah's Permission, confirming what came before it [i.e. the Taurat (Torah) and the Injeel (Gospel)] and guidance and glad tidings for the believers.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
``Whoever is an enemy to Allah, His Angels, His Messengers, Jibrael (Gabriel) and Mikael (Michael), then verily, Allah is an enemy to the disbelievers."\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
And indeed We have sent down to you manifest Ayat (these Verses of the Quran which inform in detail about the news of the Jews and their secret intentions, etc.), and none disbelieve in them but Fasiqun (those who rebel against Allah's Command).\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it not (the case) that every time they make a covenant, some party among them throw it aside? Nay! the truth is most of them believe not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when there came to them a Messenger from Allah (i.e. Muhammad Peace be upon him) confirming what was with them, a party of those who were given the Scripture threw away the Book of Allah behind their backs as if they did not know!\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
They followed what the Shayatin (devils) gave out (falsely of the magic) in the lifetime of Sulaiman (Solomon). Sulaiman did not disbelieve, but the Shayatin (devils) disbelieved, teaching men magic and such things that came down at Babylon to the two angels, Harut and Marut, but neither of these two (angels) taught anyone (such things) till they had said, ``We are only for trial, so disbelieve not (by learning this magic from us)." And from these (angels) people learn that by which they cause separation between man and his wife, but they could not thus harm anyone except by Allah's Leave. And they learn that which harms them and profits them not. And indeed they knew that the buyers of it (magic) would have no share in the Hereafter. And how bad indeed was that for which they sold their ownselves, if they but knew.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
And if they had believed, and guarded themselves from evil and kept their duty to Allah, far better would have been the reward from their Lord, if they but knew!\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O you who believe! Say not (to the Messenger Peace be upon him) Ra'ina but say Unzurna (Do make us understand) and hear. And for the disbelievers there is a painful torment. (See Verse 4:46)\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Neither those who disbelieve among the people of the Scripture (Jews and Christians) nor Al-Mushrikun (the disbelievers in the Oneness of Allah, idolaters, polytheists, pagans, etc.) like that there should be sent down unto you any good from your Lord. But Allah chooses for His Mercy whom He wills. And Allah is the Owner of Great Bounty.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
Whatever a Verse (revelation) do We abrogate or cause to be forgotten, We bring a better one or similar to it. Know you not that Allah is able to do all things?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Know you not that it is Allah to Whom belongs the dominion of the heavens and the earth? And besides Allah you have neither any Wali (protector or guardian) nor any helper.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or do you want to ask your Messenger (Muhammad Peace be upon him) as Musa (Moses) was asked before (i.e. show us openly our Lord?) And he who changes Faith for disbelief, verily, he has gone astray from the right way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the people of the Scripture (Jews and Christians) wish that if they could turn you away as disbelievers after you have believed, out of envy from their ownselves, even, after the truth (that Muhammad Peace be upon him is Allah's Messenger) has become manifest unto them. But forgive and overlook, till Allah brings His Command. Verily, Allah is Able to do all things.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And perform As-Salat (Iqamat-as-Salat), and give Zakat, and whatever of good (deeds that Allah loves) you send forth for yourselves before you, you shall find it with Allah. Certainly, Allah is All-Seer of what you do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say, ``None shall enter Paradise unless he be a Jew or a Christian." These are their own desires. Say (O Muhammad Peace be upon him), ``Produce your proof if you are truthful."\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Yes, but whoever submits his face (himself) to Allah (i.e. follows Allah's Religion of Islamic Monotheism) and he is a Muhsin (good-doer i.e. performs good deeds totally for Allah's sake only without any show off or to gain praise or fame, etc., and in accordance with the Sunnah of Allah's Messenger Muhammad Peace be upon him) then his reward is with his Lord (Allah), on such shall be no fear, nor shall they grieve. [See Tafsir Ibn Kathir, Vol. 1, Page 154].\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews said that the Christians follow nothing (i.e. are not on the right religion); and the Christians said that the Jews follow nothing (i.e. are not on the right religion); though they both recite the Scripture. Like unto their word, said (the pagans) who know not. Allah will judge between them on the Day of Resurrection about that wherein they have been differing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who is more unjust than those who forbid that Allah's Name be glorified and mentioned much (i.e. prayers and invocations, etc.) in Allah's Mosques and strive for their ruin? It was not fitting that such should themselves enter them (Allah's Mosques) except in fear. For them there is disgrace in this world, and they will have a great torment in the Hereafter.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
And to Allah belong the east and the west, so wherever you turn yourselves or your faces there is the Face of Allah (and He is High above, over His Throne). Surely! Allah is All-Sufficient for His creatures' needs, All-Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they (Jews, Christians and pagans) say: Allah has begotten a son (children or offspring). Glory be to Him (Exalted be He above all that they associate with Him). Nay, to Him belongs all that is in the heavens and on earth, and all surrender with obedience (in worship) to Him.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
The Originator of the heavens and the earth. When He decrees a matter, He only says to it: ``Be!" - and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
And those who have no knowledge say: ``Why does not Allah speak to us (face to face) or why does not a sign come to us?" So said the people before them words of similar import. Their hearts are alike, We have indeed made plain the signs for people who believe with certainty.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Verily, We have sent you (O Muhammad Peace be upon him) with the truth (Islam), a bringer of glad tidings (for those who believe in what you brought, that they will enter Paradise) and a warner (for those who disbelieve in what you brought, they will enter the Hell-fire). And you will not be asked about the dwellers of the blazing Fire.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
Never will the Jews nor the Christians be pleased with you (O Muhammad Peace be upon him) till you follow their religion. Say: ``Verily, the Guidance of Allah (i.e. Islamic Monotheism) that is the (only) Guidance. And if you (O Muhammad Peace be upon him) were to follow their (Jews and Christians) desires after what you have received of Knowledge (i.e. the Quran), then you would have against Allah neither any Wali (protector or guardian) nor any helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those (who embraced Islam from Bani Israel) to whom We gave the Book [the Taurat (Torah)] [or those (Muhammad's Peace be upon him companions) to whom We have given the Book (the Quran)] recite it (i.e. obey its orders and follow its teachings) as it should be recited (i.e. followed), they are the ones that believe therein. And whoso disbelieves in it (the Quran), those are they who are the losers. (Tafsir Al-Qurtubi. Vol. 2, Page 95).\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel! Remember My Favour which I bestowed upon you and that I preferred you to the 'Alamin (mankind and jinns) (of your time-period, in the past).\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear the Day (of Judgement) when no person shall avail another, nor shall compensation be accepted from him, nor shall intercession be of use to him, nor shall they be helped.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And (remember) when the Lord of Ibrahim (Abraham) [i.e., Allah] tried him with (certain) Commands, which he fulfilled. He (Allah) said (to him), ``Verily, I am going to make you a leader (Prophet) of mankind." [Ibrahim (Abraham)] said, ``And of my offspring (to make leaders)." (Allah) said, ``My Covenant (Prophethood, etc.) includes not Zalimun (polytheists and wrong-doers)."\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And (remember) when We made the House (the Ka'bah at Makkah) a place of resort for mankind and a place of safety. And take you (people) the Maqam (place) of Ibrahim (Abraham) [or the stone on which Ibrahim (Abraham) stood while he was building the Ka'bah] as a place of prayer (for some of your prayers, e.g. two Rak'at after the Tawaf of the Ka'bah at Makkah), and We commanded Ibrahim (Abraham) and Isma'il (Ishmael) that they should purify My House (the Ka'bah at Makkah) for those who are circumambulating it, or staying (I'tikaf), or bowing or prostrating themselves (there, in prayer).\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And (remember) when Ibrahim (Abraham) said, ``My Lord, make this city (Makkah) a place of security and provide its people with fruits, such of them as believe in Allah and the Last Day." He (Allah) answered: ``As for him who disbelieves, I shall leave him in contentment for a while, then I shall compel him to the torment of the Fire, and worst indeed is that destination!"\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And (remember) when Ibrahim (Abraham) and (his son) Isma'il (Ishmael) were raising the foundations of the House (the Ka'bah at Makkah), (saying), ``Our Lord! Accept (this service) from us. Verily! You are the All-Hearer, the All-Knower."\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
``Our Lord! And make us submissive unto You and of our offspring a nation submissive unto You, and show us our Manasik (all the ceremonies of pilgrimage - Hajj and 'Umrah, etc.), and accept our repentance. Truly, You are the One Who accepts repentance, the Most Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
``Our Lord! Send amongst them a Messenger of their own (and indeed Allah answered their invocation by sending Muhammad Peace be upon him), who shall recite unto them Your Verses and instruct them in the Book (this Quran) and Al-Hikmah (full knowledge of the Islamic laws and jurisprudence or wisdom or Prophethood, etc.), and sanctify them. Verily! You are the All-Mighty, the All-Wise."\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who turns away from the religion of Ibrahim (Abraham) (i.e. Islamic Monotheism) except him who befools himself? Truly, We chose him in this world and verily, in the Hereafter he will be among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, ``Submit (i.e. be a Muslim)!" He said, ``I have submitted myself (as a Muslim) to the Lord of the 'Alamin (mankind, jinns and all that exists)."\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And this (submission to Allah, Islam) was enjoined by Ibrahim (Abraham) upon his sons and by Ya'qub (Jacob), (saying), ``O my sons! Allah has chosen for you the (true) religion, then die not except in the Faith of Islam (as Muslims - Islamic Monotheism)."\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Or were you witnesses when death approached Ya'qub (Jacob)? When he said unto his sons, ``What will you worship after me?" They said, ``We shall worship your Ilah (God - Allah), the Ilah (God) of your fathers, Ibrahim (Abraham), Isma'il (Ishmael), Ishaque (Isaac), One Ilah (God), and to Him we submit (in Islam)."\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a nation who has passed away. They shall receive the reward of what they earned and you of what you earn. And you will not be asked of what they used to do.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say, ``Be Jews or Christians, then you will be guided." Say (to them, O Muhammad Peace be upon him), ``Nay, (We follow) only the religion of Ibrahim (Abraham), Hanifa [Islamic Monotheism, i.e. to worship none but Allah (Alone)], and he was not of Al-Mushrikun (those who worshipped others along with Allah - see V. 2:105)."\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say (O Muslims), ``We believe in Allah and that which has been sent down to us and that which has been sent down to Ibrahim (Abraham), Isma'il (Ishmael), Ishaque (Isaac), Ya'qub (Jacob), and to Al-Asbat [the twelve sons of Ya'qub (Jacob)], and that which has been given to Musa (Moses) and 'Iesa (Jesus), and that which has been given to the Prophets from their Lord. We make no distinction between any of them, and to Him we have submitted (in Islam)."\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
So if they believe in the like of that which you believe, then they are rightly guided, but if they turn away, then they are only in opposition. So Allah will suffice you against them. And He is the All-Hearer, the All-Knower.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
[Our Sibghah (religion) is] the Sibghah (Religion) of Allah (Islam) and which Sibghah (religion) can be better than Allah's? And we are His worshippers. [Tafsir Ibn Kathir.]\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say (O Muhammad Peace be upon him to the Jews and Christians), ``Dispute you with us about Allah while He is our Lord and your Lord? And we are to be rewarded for our deeds and you for your deeds. And we are sincere to Him in worship and obedience (i.e. we worship Him Alone and none else, and we obey His Orders)."\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or say you that Ibrahim (Abraham), Isma'il (Ishmael), Ishaque (Isaac), Ya'qub (Jacob) and Al-Asbat [the twelve sons of Ya'qub (Jacob)] were Jews or Christians? Say, ``Do you know better or does Allah (knows better that they all were Muslims)? And who is more unjust than he who conceals the testimony [i.e. to believe in Prophet Muhammad Peace be upon him when he comes, written in their Books. (See Verse 7:157)] he has from Allah? And Allah is not unaware of what you do."\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That was a nation who has passed away. They shall receive the reward of what they earned, and you of what you earn. And you will not be asked of what they used to do.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The fools (pagans, hypocrites, and Jews) among the people will say, ``What has turned them (Muslims) from their Qiblah [prayer direction (towards Jerusalem)] to which they were used to face in prayer." Say, (O Muhammad SAW) ``To Allah belong both, east and the west. He guides whom He wills to a Straight Way."\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus We have made you [true Muslims - real believers of Islamic Monotheism, true followers of Prophet Muhammad SAW and his Sunnah (legal ways)], a Wasat (just) (and the best) nation, that you be witnesses over mankind and the Messenger (Muhammad SAW) be a witness over you. And We made the Qiblah (prayer direction towards Jerusalem) which you used to face, only to test those who followed the Messenger (Muhammad SAW) from those who would turn on their heels (i.e. disobey the Messenger). Indeed it was great (heavy) except for those whom Allah guided. And Allah would never make your faith (prayers) to be lost (i.e. your prayers offered towards Jerusalem). Truly, Allah is full of kindness, the Most Merciful towards mankind.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
Verily! We have seen the turning of your (Muhammad's SAW) face towards the heaven. Surely, We shall turn you to a Qiblah (prayer direction) that shall please you, so turn your face in the direction of Al-Masjid- al-Haram (at Makkah). And wheresoever you people are, turn your faces (in prayer) in that direction. Certainly, the people who were given the Scriptures (i.e. Jews and the Christians) know well that, that (your turning towards the direction of the Ka'bah at Makkah in prayers) is the truth from their Lord. And Allah is not unaware of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
And even if you were to bring to the people of the Scripture (Jews and Christians) all the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they would not follow your Qiblah (prayer direction), nor are you going to follow their Qiblah (prayer direction). And they will not follow each other's Qiblah (prayer direction). Verily, if you follow their desires after that which you have received of knowledge (from Allah), then indeed you will be one of the Zalimun (polytheists, wrong-doers, etc.).\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We gave the Scripture (Jews and Christians) recognise him (Muhammad SAW or the Ka'bah at Makkah) as they recongise their sons. But verily, a party of them conceal the truth while they know it - [i.e. the qualities of Muhammad SAW which are written in the Taurat (Torah) and the Injeel (Gospel)].\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
(This is) the truth from your Lord. So be you not one of those who doubt.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
For every nation there is a direction to which they face (in their prayers). So hasten towards all that is good. Wheresoever you may be, Allah will bring you together (on the Day of Resurrection). Truly, Allah is Able to do all things.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
And from wheresoever you start forth (for prayers), turn your face in the direction of Al-Masjid-al-Haram (at Makkah), that is indeed the truth from your Lord. And Allah is not unaware of what you do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
And from wheresoever you start forth (for prayers), turn your face in the direction of Al-Masjid-al-Haram (at Makkah), and wheresoever you are, turn your faces towards, it (when you pray) so that men may have no argument against you except those of them that are wrong-doers, so fear them not, but fear Me! - And so that I may complete My Blessings on you and that you may be guided.\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Similarly (to complete My Blessings on you) We have sent among you a Messenger (Muhammad SAW) of your own, reciting to you Our Verses (the Quran) and sanctifying you, and teaching you the Book (the Quran) and the Hikmah (i.e. Sunnah, Islamic laws and Fiqh - jurisprudence), and teaching you that which you used not to know.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
Therefore remember Me (by praying, glorifying, etc.). I will remember you, and be grateful to Me (for My countless Favours on you) and never be ungrateful to Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O you who believe! Seek help in patience and As-Salat (the prayer). Truly! Allah is with As-Sabirin (the patient ones, etc.).\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And say not of those who are killed in the Way of Allah, ``They are dead." Nay, they are living, but you perceive (it) not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
And certainly, We shall test you with something of fear, hunger, loss of wealth, lives and fruits, but give glad tidings to As-Sabirin (the patient ones, etc.).\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who, when afflicted with calamity, say: ``Truly! To Allah we belong and truly, to Him we shall return."\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
They are those on whom are the Salawat (i.e. blessings, etc.) (i.e. who are blessed and will be forgiven) from their Lord, and (they are those who) receive His Mercy, and it is they who are the guided-ones.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Verily! As-Safa and Al-Marwah (two mountains in Makkah) are of the Symbols of Allah. So it is not a sin on him who perform Hajj or 'Umrah (pilgrimage) of the House (the Ka'bah at Makkah) to perform the going (Tawaf) between them (As-Safa and Al-Marwah). And whoever does good voluntarily, then verily, Allah is All-Recogniser, All-Knower.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Verily, those who conceal the clear proofs, evidences and the guidance, which We have sent down, after We have made it clear for the people in the Book, they are the ones cursed by Allah and cursed by the cursers.\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent and do righteous deeds, and openly declare (the truth which they concealed). These, I will accept their repentance. And I am the One Who accepts repentance, the Most Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Verily, those who disbelieve, and die while they are disbelievers, it is they on whom is the Curse of Allah and of the angels and of mankind, combined.\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They will abide therein (under the curse in Hell), their punishment will neither be lightened, nor will they be reprieved.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
And your Ilah (God) is One Ilah (God - Allah), La ilaha illa Huwa (there is none who has the right to be worshipped but He), the Most Beneficent, the Most Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Verily! In the creation of the heavens and the earth, and in the alternation of night and day, and the ships which sail through the sea with that which is of use to mankind, and the water (rain) which Allah sends down from the sky and makes the earth alive therewith after its death, and the moving (living) creatures of all kinds that He has scattered therein, and in the veering of winds and clouds which are held between the sky and the earth, are indeed Ayat (proofs, evidences, signs, etc.) for people of understanding.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
And of mankind are some who take (for worship) others besides Allah as rivals (to Allah). They love them as they love Allah. But those who believe, love Allah more (than anything else). If only, those who do wrong could see, when they will see the torment, that all power belongs to Allah and that Allah is Severe in punishment.\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
When those who were followed, disown (declare themselves innocent of) those who followed (them), and they see the torment, then all their relations will be cut off from them.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And those who followed will say: ``If only we had one more chance to return (to the worldly life), we would disown (declare ourselves as innocent from) them as they have disowned (declared themselves as innocent from) us." Thus Allah will show them their deeds as regrets for them. And they will never get out of the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O mankind! Eat of that which is lawful and good on the earth, and follow not the footsteps of Shaitan (Satan). Verily, he is to you an open enemy.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
[Shaitan (Satan)] commands you only what is evil and Fahsha (sinful), and that you should say against Allah what you know not.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
When it is said to them: ``Follow what Allah has sent down." They say: ``Nay! We shall follow what we found our fathers following." (Would they do that!) Even though their fathers did not understand anything nor were they guided?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
And the example of those who disbelieve, is as that of him who shouts to the (flock of sheep) that hears nothing but calls and cries. (They are) deaf, dumb and blind. So they do not understand.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O you who believe (in the Oneness of Allah - Islamic Monotheism)! Eat of the lawful things that We have provided you with, and be grateful to Allah, if it is indeed He Whom you worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has forbidden you only the Maytatah (dead animals), and blood, and the flesh of swine, and that which is slaughtered as a scrifice for others than Allah (or has been slaughtered for idols, etc., on which Allah's Name has not been mentioned while slaughtering). But if one is forced by necessity without wilful disobedience nor transgressing due limits, then there is no sin on him. Truly, Allah is Oft-Forgiving, Most Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Verily, those who conceal what Allah has sent down of the Book, and purchase a small gain therewith (of worldly things), they eat into their bellies nothing but fire. Allah will not speak to them on the Day of Resurrection, nor purify them, and theirs will be a painful torment.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Those are they who have purchased error at the price of Guidance, and torment at the price of Forgiveness. So how bold they are (for evil deeds which will push them) to the Fire.\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is because Allah has sent down the Book (the Quran) in truth. And verily, those who disputed as regards the Book are far away in opposition.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is not Al-Birr (piety, righteousness, and each and every act of obedience to Allah, etc.) that you turn your faces towards east and (or) west (in prayers); but Al-Birr is (the quality of) the one who believes in Allah, the Last Day, the Angels, the Book, the Prophets and gives his wealth, in spite of love for it, to the kinsfolk, to the orphans, and to Al-Masakin (the poor), and to the wayfarer, and to those who ask, and to set slaves free, performs As-Salat (Iqamat-as-Salat), and gives the Zakat, and who fulfill their covenant when they make it, and who are As-Sabirin (the patient ones, etc.) in extreme poverty and ailment (disease) and at the time of fighting (during the battles). Such are the people of the truth and they are Al-Muttaqun (pious - see V. 2:2).\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O you who believe! Al-Qisas (the Law of Equality in punishment) is prescribed for you in case of murder: the free for the free, the slave for the slave, and the female for the female. But if the killer is forgiven by the brother (or the relatives, etc.) of the killed against blood money, then adhering to it with fairness and payment of the blood money, to the heir should be made in fairness. This is an alleviation and a mercy from your Lord. So after this whoever transgresses the limits (i.e. kills the killer after taking the blood money), he shall have a painful torment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And there is (a saving of) life for you in Al-Qisas (the Law of Equality in punishment), O men of understanding, that you may become Al-Muttaqun (the pious - see V. 2:2).\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is prescribed for you, when death approaches any of you, if he leaves wealth, that he make a bequest to parents and next of kin, according to reasonable manners. (This is) a duty upon Al-Muttaqun (the pious - see V. 2:2).\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then whoever changes the bequest after hearing it, the sin shall be on those who make the change. Truly, Allah is All-Hearer, All-Knower.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But he who fears from a testator some unjust act or wrong-doing, and thereupon he makes peace between the parties concerned, there shall be no sin on him. Certainly, Allah is Oft-Forgiving, Most Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O you who believe! Observing As-Saum (the fasting) is prescribed for you as it was prescribed for those before you, that you may become Al-Muttaqun (the pious - see V. 2:2).\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
[Observing Saum (fasts)] for a fixed number of days, but if any of you is ill or on a journey, the same number (should be made up) from other days. And as for those who can fast with difficulty, (e.g. an old man, etc.), they have (a choice either to fast or) to feed a Miskin (poor person) (for every day). But whoever does good of his own accord, it is better for him. And that you fast, it is better for you if only you know.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadan in which was revealed the Quran, a guidance for mankind and clear proofs for the guidance and the criterion (between right and wrong). So whoever of you sights (the crescent on the first night of) the month (of Ramadan i.e. is present at his home), he must observe Saum (fasts) that month, and whoever is ill or on a journey, the same number [of days which one did not observe Saum (fasts) must be made up] from other days. Allah intends for you ease, and He does not want to make things difficult for you. (He wants that you) must complete the same number (of days), and that you must magnify Allah [i.e. to say Takbir (Allahu-Akbar; Allah is the Most Great) on seeing the crescent of the months of Ramadan and Shawwal] for having guided you so that you may be grateful to Him.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My slaves ask you (O Muhammad SAW) concerning Me, then (answer them), I am indeed near (to them by My Knowledge). I respond to the invocations of the supplicant when he calls on Me (without any mediator or intercessor). So let them obey Me and believe in Me, so that they may be led aright.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
It is made lawful for you to have sexual relations with your wives on the night of As-Saum (the fasts). They are Libas [i.e. body cover, or screen, or Sakan, (i.e. you enjoy the pleasure of living with her - as in Verse 7:189) Tafsir At-Tabari], for you and you are the same for them. Allah knows that you used to deceive yourselves, so He turned to you (accepted your repentance) and forgave you. So now have sexual relations with them and seek that which Allah has ordained for you (offspring), and eat and drink until the white thread (light) of dawn appears to you distinct from the black thread (darkness of night), then complete your Saum (fast) till the nightfall. And do not have sexual relations with them (your wives) while you are in I'tikaf (i.e. confining oneself in a mosque for prayers and invocations leaving the worldly activities) in the mosques. These are the limits (set) by Allah, so approach them not. Thus does Allah make clear His Ayat (proofs, evidences, lessons, signs, revelations, verses, laws, legal and illegal things, Allah's set limits, orders, etc.) to mankind that they may become Al-Muttaqun (the pious - see V. 2:2).\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And eat up not one another's property unjustly (in any illegal way e.g. stealing, robbing, deceiving, etc.), nor give bribery to the rulers (judges before presenting your cases) that you may knowingly eat up a part of the property of others sinfully.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you (O Muhammad SAW) about the new moons. Say: These are signs to mark fixed periods of time for mankind and for the pilgrimage. It is not Al-Birr (piety, righteousness, etc.) that you enter the houses from the back but Al-Birr (is the quality of the one) who fears Allah. So enter houses through their proper doors, and fear Allah that you may be successful.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the Way of Allah those who fight you, but transgress not the limits. Truly, Allah likes not the transgressors. [This Verse is the first one that was revealed in connection with Jihad, but it was supplemented by another (V. 9:36)].\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And kill them wherever you find them, and turn them out from where they have turned you out. And Al-Fitnah is worse than killing. And fight not with them at Al-Masjid-al-Haram (the sanctuary at Makkah), unless they (first) fight you there. But if they attack you, then kill them. Such is the recompense of the disbelievers.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
But if they cease, then Allah is Oft-Forgiving, Most Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until there is no more Fitnah (disbelief and worshipping of others along with Allah) and (all and every kind of) worship is for Allah (Alone). But if they cease, let there be no transgression except against Az-Zalimun (the polytheists, and wrong-doers, etc.)\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The sacred month is for the sacred month, and for the prohibited things, there is the Law of Equality (Qisas). Then whoever transgresses the prohibition against you, you transgress likewise against him. And fear Allah, and know that Allah is with Al-Muttaqun (the pious - see V. 2:2).\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend in the Cause of Allah (i.e. Jihad of all kinds, etc.) and do not throw yourselves into destruction (by not spending your wealth in the Cause of Allah), and do good. Truly, Allah loves Al-Muhsinun (the good-doers).\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And perform properly (i.e. all the ceremonies according to the ways of Prophet Muhammad SAW), the Hajj and 'Umrah (i.e. the pilgrimage to Makkah) for Allah. But if you are prevented (from completing them), sacrifice a Hady (animal, i.e. a sheep, a cow, or a camel, etc.) such as you can afford, and do not shave your heads until the Hady reaches the place of sacrifice. And whosoever of you is ill or has an ailment in his scalp (necessitating shaving), he must pay a Fidyah (ransom) of either observing Saum (fasts) (three days) or giving Sadaqah (charity - feeding six poor persons) or offering sacrifice (one sheep). Then if you are in safety and whosoever performs the 'Umrah in the months of Hajj, before (performing) the Hajj, (i.e. Hajj-at-Tamattu' and Al-Qiran), he must slaughter a Hady such as he can afford, but if he cannot afford it, he should observe Saum (fasts) three days during the Hajj and seven days after his return (to his home), making ten days in all. This is for him whose family is not present at Al-Masjid-al-Haram (i.e. non-resident of Makkah). And fear Allah much and know that Allah is Severe in punishment.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The Hajj (pilgrimage) is (in) the well-known (lunar year) months (i.e. the 10th month, the 11th month and the first ten days of the 12th month of the Islamic calendar, i.e. two months and ten days). So whosoever intends to perform Hajj therein by assuming Ihram), then he should not have sexual relations (with his wife), nor commit sin, nor dispute unjustly during the Hajj. And whatever good you do, (be sure) Allah knows it. And take a provision (with you) for the journey, but the best provision is At-Taqwa (piety, righteousness, etc.). So fear Me, O men of understanding!\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
There is no sin on you if you seek the Bounty of your Lord (during pilgrimage by trading, etc.). Then when you leave 'Arafat, remember Allah (by glorifying His Praises, i.e. prayers and invocations, etc.) at the Mash'ar-il-Haram. And remember Him (by invoking Allah for all good, etc.) as He has guided you, and verily, you were, before, of those who were astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then depart from the place whence all the people depart and ask Allah for His Forgiveness. Truly, Allah is Oft-Forgiving, Most-Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
So when you have accomplished your Manasik [(i.e. Ihram, Tawaf of the Ka'bah and As-Safa and Al-Marwah), stay at 'Arafat, Muzdalifah and Mina, Ramy of Jamarat, (stoning of the specified pillars in Mina) slaughtering of Hady (animal, etc.)]. Remember Allah as you remember your forefathers or with a far more remembrance. But of mankind there are some who say: ``Our Lord! Give us (Your Bounties) in this world!" and for such there will be no portion in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And of them there are some who say: ``Our Lord! Give us in this world that which is good and in the Hereafter that which is good, and save us from the torment of the Fire!"\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
For them there will be alloted a share for what they have earned. And Allah is Swift at reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember Allah during the appointed Days. But whosoever hastens to leave in two days, there is no sin on him and whosoever stays on, there is no sin on him, if his aim is to do good and obey Allah (fear Him), and know that you will surely be gathered unto Him.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And of mankind there is he whose speech may please you (O Muhammad SAW), in this worldly life, and he calls Allah to witness as to that which is in his heart, yet he is the most quarrelsome of the opponents.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he turns away (from you ``O Muhammad SAW ``), his effort in the land is to make mischief therein and to destroy the crops and the cattle, and Allah likes not mischief.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said to him, ``Fear Allah", he is led by arrogance to (more) crime. So enough for him is Hell, and worst indeed is that place to rest!\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And of mankind is he who would sell himself, seeking the Pleasure of Allah. And Allah is full of Kindness to (His) slaves.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O you who believe! Enter perfectly in Islam (by obeying all the rules and regulations of the Islamic religion) and follow not the footsteps of Shaitan (Satan). Verily! He is to you a plain enemy.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
Then if you slide back after the clear signs (Prophet Muhammad SAW and this Quran, and Islam) have come to you, then know that Allah is All-Mighty, All-Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Do they then wait for anything other than that Allah should come to them in the shadows of the clouds and the angels? (Then) the case would be already judged. And to Allah return all matters (for decision).\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many clear Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) We gave them. And whoever changes Allah's Favour after it had come to him, [e.g. renounces the Religion of Allah (Islam) and accepts Kufr (disbelief),] then surely, Allah is Severe in punishment.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Beautified is the life of this world for those who disbelieve, and they mock at those who believe. But those who obey Allah's Orders and keep away from what He has forbidden, will be above them on the Day of Resurrection. And Allah gives (of His Bounty, Blessings, Favours, Honours, etc. on the Day of Resurrection) to whom He wills without limit.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind were one community and Allah sent Prophets with glad tidings and warnings, and with them He sent the Scripture in truth to judge between people in matters wherein they differed. And only those to whom (the Scripture) was given differed concerning it after clear proofs had come unto them through hatred, one to another. Then Allah by His Leave guided those who believed to the truth of that wherein they differed. And Allah guides whom He wills to a Straight Path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or think you that you will enter Paradise without such (trials) as came to those who passed away before you? They were afflicted with severe poverty and ailments and were so shaken that even the Messenger and those who believed along with him said, ``When (will come) the Help of Allah?" Yes! Certainly, the Help of Allah is near!\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask you (O Muhammad SAW) what they should spend. Say: Whatever you spend of good must be for parents and kindred and orphans and Al-Masakin (the poor) and the wayfarers, and whatever you do of good deeds, truly, Allah knows it well.\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Jihad (holy fighting in Allah's Cause) is ordained for you (Muslims) though you dislike it, and it may be that you dislike a thing which is good for you and that you like a thing which is bad for you. Allah knows but you do not know.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you concerning fighting in the Sacred Months (i.e. 1st, 7th, 11th and 12th months of the Islamic calendar). Say, ``Fighting therein is a great (transgression) but a greater (transgression) with Allah is to prevent mankind from following the Way of Allah, to disbelieve in Him, to prevent access to Al-Masjid-al-Haram (at Makkah), and to drive out its inhabitants, and Al-Fitnah is worse than killing. And they will never cease fighting you until they turn you back from your religion (Islamic Monotheism) if they can. And whosoever of you turns back from his religion and dies as a disbeliever, then his deeds will be lost in this life and in the Hereafter, and they will be the dwellers of the Fire. They will abide therein forever.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Verily, those who have believed, and those who have emigrated (for Allah's Religion) and have striven hard in the Way of Allah, all these hope for Allah's Mercy. And Allah is Oft-Forgiving, Most-Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you (O Muhammad SAW) concerning alcoholic drink and gambling. Say: ``In them is a great sin, and (some) benefit for men, but the sin of them is greater than their benefit." And they ask you what they ought to spend. Say: ``That which is beyond your needs." Thus Allah makes clear to you His Laws in order that you may give thought."\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
In (to) this worldly life and in the Hereafter. And they ask you concerning orphans. Say: ``The best thing is to work honestly in their property, and if you mix your affairs with theirs, then they are your brothers. And Allah knows him who means mischief (e.g. to swallow their property) from him who means good (e.g. to save their property). And if Allah had wished, He could have put you into difficulties. Truly, Allah is All-Mighty, All-Wise."\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
And do not marry Al-Mushrikat (idolatresses, etc.) till they believe (worship Allah Alone). And indeed a slave woman who believes is better than a (free) Mushrikah (idolatress, etc.), even though she pleases you. And give not (your daughters) in marriage to Al-Mushrikun till they believe (in Allah Alone) and verily, a believing slave is better than a (free) Mushrik (idolater, etc.), even though he pleases you. Those (Al-Mushrikun) invite you to the Fire, but Allah invites (you) to Paradise and Forgiveness by His Leave, and makes His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) clear to mankind that they may remember.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They ask you concerning menstruation. Say: that is an Adha (a harmful thing for a husband to have a sexual intercourse with his wife while she is having her menses), therefore keep away from women during menses and go not unto them till they have purified (from menses and have taken a bath). And when they have purified themselves, then go in unto them as Allah has ordained for you (go in unto them in any manner as long as it is in their vagina). Truly, Allah loves those who turn unto Him in repentance and loves those who purify themselves (by taking a bath and cleaning and washing thoroughly their private parts, bodies, for their prayers, etc.).\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your wives are a tilth for you, so go to your tilth when or how you will, and send (good deeds, or ask Allah to bestow upon you pious offspring) before you for your ownselves. And fear Allah, and know that you are to meet Him (in the Hereafter), and give good tidings to the believers (O Muhammad SAW).\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And make not Allah's (Name) an excuse in your oaths against your doing good and acting piously, and making peace among mankind. And Allah is All-Hearer, All-Knower (i.e. do not swear much and if you have sworn against doing something good then give an expiation for the oath and do good).\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not call you to account for that which is unintentional in your oaths, but He will call you to account for that which your hearts have earned. And Allah is Oft-Forgiving, Most-Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who take an oath not to have sexual relation with their wives must wait four months, then if they return (change their idea in this period), verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they decide upon divorce, then Allah is All-Hearer, All-Knower.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
And divorced women shall wait (as regards their marriage) for three menstrual periods, and it is not lawful for them to conceal what Allah has created in their wombs, if they believe in Allah and the Last Day. And their husbands have the better right to take them back in that period, if they wish for reconciliation. And they (women) have rights (over their husbands as regards living expenses, etc.) similar (to those of their husbands) over them (as regards obedience and respect, etc.) to what is reasonable, but men have a degree (of responsibility) over them. And Allah is All-Mighty, All-Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
The divorce is twice, after that, either you retain her on reasonable terms or release her with kindness. And it is not lawful for you (men) to take back (from your wives) any of your Mahr (bridal money given by the husband to his wife at the time of marriage) which you have given them, except when both parties fear that they would be unable to keep the limits ordained by Allah (e.g. to deal with each other on a fair basis). Then if you fear that they would not be able to keep the limits ordained by Allah, then there is no sin on either of them if she gives back (the Mahr or a part of it) for her Al-Khul' (divorce). These are the limits ordained by Allah, so do not transgress them. And whoever transgresses the limits ordained by Allah, then such are the Zalimun (wrong-doers, etc.).\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
And if he has divorced her (the third time), then she is not lawful unto him thereafter until she has married another husband. Then, if the other husband divorces her, it is no sin on both of them that they reunite, provided they feel that they can keep the limits ordained by Allah. These are the limits of Allah, which He makes plain for the people who have knowledge.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when you have divorced women and they have fulfilled the term of their prescribed period, either take them back on reasonable basis or set them free on reasonable basis. But do not take them back to hurt them, and whoever does that, then he has wronged himself. And treat not the Verses (Laws) of Allah as a jest, but remember Allah's Favours on you (i.e. Islam), and that which He has sent down to you of the Book (i.e. the Quran) and Al-Hikmah (the Prophet's Sunnah - legal ways - Islamic jurisprudence, etc.) whereby He instructs you. And fear Allah, and know that Allah is All-Aware of everything.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when you have divorced women and they have fulfilled the term of their prescribed period, do not prevent them from marrying their (former) husbands, if they mutually agree on reasonable basis. This (instruction) is an admonition for him among you who believes in Allah and the Last Day. That is more virtuous and purer for you. Allah knows and you know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
The mothers shall give suck to their children for two whole years, (that is) for those (parents) who desire to complete the term of suckling, but the father of the child shall bear the cost of the mother's food and clothing on a reasonable basis. No person shall have a burden laid on him greater than he can bear. No mother shall be treated unfairly on account of her child, nor father on account of his child. And on the (father's) heir is incumbent the like of that (which was incumbent on the father). If they both decide on weaning, by mutual consent, and after due consultation, there is no sin on them. And if you decide on a foster suckling-mother for your children, there is no sin on you, provided you pay (the mother) what you agreed (to give her) on reasonable basis. And fear Allah and know that Allah is All-Seer of what you do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those of you who die and leave wives behind them, they (the wives) shall wait (as regards their marriage) for four months and ten days, then when they have fulfilled their term, there is no sin on you if they (the wives) dispose of themselves in a just and honourable manner (i.e. they can marry). And Allah is Well-Acquainted with what you do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
And there is no sin on you if you make a hint of betrothal or conceal it in yourself, Allah knows that you will remember them, but do not make a promise of contract with them in secret except that you speak an honourable saying according to the Islamic law (e.g. you can say to her, ``If one finds a wife like you, he will be happy"). And do not consummate the marriage until the term prescribed is fulfilled. And know that Allah knows what is in your minds, so fear Him. And know that Allah is Oft-Forgiving, Most Forbearing.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no sin on you, if you divorce women while yet you have not touched (had sexual relation with) them, nor appointed unto them their Mahr (bridal money given by the husband to his wife at the time of marriage). But bestow on them (a suitable gift), the rich according to his means, and the poor according to his means, a gift of reasonable amount is a duty on the doers of good.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if you divorce them before you have touched (had a sexual relation with) them, and you have appointed unto them the Mahr (bridal money given by the husbands to his wife at the time of marriage), then pay half of that (Mahr), unless they (the women) agree to forego it, or he (the husband), in whose hands is the marriage tie, agrees to forego and give her full appointed Mahr. And to forego and give (her the full Mahr) is nearer to At-Taqwa (piety, right-eousness, etc.). And do not forget liberality between yourselves. Truly, Allah is All-Seer of what you do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard strictly (five obligatory) As-Salawat (the prayers) especially the middle Salat (i.e. the best prayer - 'Asr). And stand before Allah with obedience [and do not speak to others during the Salat (prayers)].\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you fear (an enemy), perfrom Salat (pray) on foot or riding. And when you are in safety, offer the Salat (prayer) in the manner He has taught you, which you knew not (before).\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those of you who die and leave behind wives should bequeath for their wives a year's maintenance and residence without turning them out, but if they (wives) leave, there is no sin on you for that which they do of themselves, provided it is honourable (e.g. lawful marriage). And Allah is All-Mighty, All-Wise. [The order of this Verse has been cancelled (abrogated) by Verse 4:12].\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And for divorced women, maintenance (should be provided) on reasonable (scale). This is a duty on Al-Muttaqun (the pious - see V. 2:2).\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus Allah makes clear His Ayat (Laws) to you, in order that you may understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Did you (O Muhammad SAW) not think of those who went forth from their homes in thousands, fearing death? Allah said to them, ``Die". And then He restored them to life. Truly, Allah is full of Bounty to mankind, but most men thank not.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
And fight in the Way of Allah and know that Allah is All-Hearer, All-Knower.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will lend to Allah a goodly loan so that He may multiply it to him many times? And it is Allah that decreases or increases (your provisions), and unto Him you shall return.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you not thought about the group of the Children of Israel after (the time of) Musa (Moses)? When they said to a Prophet of theirs, ``Appoint for us a king and we will fight in Allah's Way." He said, ``Would you then refrain from fighting, if fighting was prescribed for you?" They said, ``Why should we not fight in Allah's Way while we have been driven out of our homes and our children (families have been taken as captives)?" But when fighting was ordered for them, they turned away, all except a few of them. And Allah is All-Aware of the Zalimun (polytheists and wrong-doers).\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
And their Prophet (Samuel) said to them, ``Indeed Allah has appointed Talut (Saul) as a king over you." They said, ``How can he be a king over us when we are better fitted than him for the kingdom, and he has not been given enough wealth." He said: ``Verily, Allah has chosen him above you and has increased him abundantly in knowledge and stature. And Allah grants His Kingdom to whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower."\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their Prophet (Samuel) said to them: Verily! The sign of His Kingdom is that there shall come to you At-Tabut (a wooden box), wherein is Sakinah (peace and reassurance) from your Lord and a remnant of that which Musa (Moses) and Harun (Aaron) left behind, carried by the angels. Verily, in this is a sign for you if you are indeed believers.\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
Then when Talut (Saul) set out with the army, he said: ``Verily! Allah will try you by a river. So whoever drinks thereof, he is not of me, and whoever tastes it not, he is of me, except him who takes (thereof) in the hollow of his hand." Yet, they drank thereof, all, except a few of them. So when he had crossed it (the river), he and those who believed with him, they said: ``We have no power this day against Jalut (Goliath) and his hosts." But those who knew with certainty that they were to meet their Lord, said: ``How often a small group overcame a mighty host by Allah's Leave?" And Allah is with As-Sabirin (the patient ones, etc.).\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they advanced to meet Jalut (Goliath) and his forces, they invoked: ``Our Lord! Pour forth on us patience and make us victorious over the disbelieving people."\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
So they routed them by Allah's Leave and Dawud (David) killed Jalut (Goliath), and Allah gave him [Dawud (David)] the kingdom [after the death of Talut (Saul) and Samuel] and Al-Hikmah (Prophethood), and taught him of that which He willed. And if Allah did not check one set of people by means of another, the earth would indeed be full of mischief. But Allah is full of Bounty to the 'Alamin (mankind, jinns and all that exists).\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the Verses of Allah, We recite them to you (O Muhammad SAW) in truth, and surely, you are one of the Messengers (of Allah).\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
Those Messengers! We preferred some to others; to some of them Allah spoke (directly); others He raised to degrees (of honour); and to 'Iesa (Jesus), the son of Maryam (Mary), We gave clear proofs and evidences, and supported him with Ruh-ul-Qudus [Jibrael (Gabriel)]. If Allah had willed, succeeding generations would not have fought against each other, after clear Verses of Allah had come to them, but they differed - some of them believed and others disbelieved. If Allah had willed, they would not have fought against one another, but Allah does what He likes.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O you who believe! Spend of that with which We have provided for you, before a Day comes when there will be no bargaining, nor friendship, nor intercession. And it is the disbelievers who are the Zalimun (wrong-doers, etc.).\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah! La ilaha illa Huwa (none has the right to be worshipped but He), the Ever Living, the One Who sustains and protects all that exists. Neither slumber, nor sleep overtake Him. To Him belongs whatever is in the heavens and whatever is on earth. Who is he that can intercede with Him except with His Permission? He knows what happens to them (His creatures) in this world, and what will happen to them in the Hereafter. And they will never compass anything of His Knowledge except that which He wills. His Kursi extends over the heavens and the earth, and He feels no fatigue in guarding and preserving them. And He is the Most High, the Most Great. [This Verse 2:255 is called Ayat-ul-Kursi.]\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion in religion. Verily, the Right Path has become distinct from the wrong path. Whoever disbelieves in Taghut and believes in Allah, then he has grasped the most trustworthy handhold that will never break. And Allah is All-Hearer, All-Knower.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Wali (Protector or Guardian) of those who believe. He brings them out from darkness into light. But as for those who disbelieve, their Auliya (supporters and helpers) are Taghut [false deities and false leaders, etc.], they bring them out from light into darkness. Those are the dwellers of the Fire, and they will abide therein forever.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not looked at him who disputed with Ibrahim (Abraham) about his Lord (Allah), because Allah had given him the kingdom? When Ibrahim (Abraham) said (to him): ``My Lord (Allah) is He Who gives life and causes death." He said, ``I give life and cause death." Ibrahim (Abraham) said, ``Verily! Allah causes the sun to rise from the east; then cause it you to rise from the west." So the disbeliever was utterly defeated. And Allah guides not the people, who are Zalimun (wrong-doers, etc.).\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or like the one who passed by a town and it had tumbled over its roofs. He said: ``Oh! How will Allah ever bring it to life after its death?" So Allah caused him to die for a hundred years, then raised him up (again). He said: ``How long did you remain (dead)?" He (the man) said: ``(Perhaps) I remained (dead) a day or part of a day". He said: ``Nay, you have remained (dead) for a hundred years, look at your food and your drink, they show no change; and look at your donkey! And thus We have made of you a sign for the people. Look at the bones, how We bring them together and clothe them with flesh". When this was clearly shown to him, he said, ``I know (now) that Allah is Able to do all things."\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And (remember) when Ibrahim (Abraham) said, ``My Lord! Show me how You give life to the dead." He (Allah) said: ``Do you not believe?" He [Ibrahim (Abraham)] said: ``Yes (I believe), but to be stronger in Faith." He said: ``Take four birds, then cause them to incline towards you (then slaughter them, cut them into pieces), and then put a portion of them on every hill, and call them, they will come to you in haste. And know that Allah is All-Mighty, All-Wise."\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The likeness of those who spend their wealth in the Way of Allah, is as the likeness of a grain (of corn); it grows seven ears, and each ear has a hundred grains. Allah gives manifold increase to whom He pleases. And Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in the Cause of Allah, and do not follow up their gifts with reminders of their generosity or with injury, their reward is with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Kind words and forgiving of faults are better than Sadaqah (charity) followed by injury. And Allah is Rich (Free of all wants) and He is Most-Forbearing.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O you who believe! Do not render in vain your Sadaqah (charity) by reminders of your generosity or by injury, like him who spends his wealth to be seen of men, and he does not believe in Allah, nor in the Last Day. His likeness is the likeness of a smooth rock on which is a little dust; on it falls heavy rain which leaves it bare. They are not able to do anything with what they have earned. And Allah does not guide the disbelieving people.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the likeness of those who spend their wealth seeking Allah's Pleasure while they in their ownselves are sure and certain that Allah will reward them (for their spending in His Cause), is the likeness of a garden on a height; heavy rain falls on it and it doubles its yield of harvest. And if it does not receive heavy rain, light rain suffices it. And Allah is All-Seer of (knows well) what you do.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any of you wish to have a garden with date-palms and vines, with rivers flowing underneath, and all kinds of fruits for him therein, while he is striken with old age, and his children are weak (not able to look after themselves), then it is struck with a fiery whirlwind, so that it is burnt? Thus does Allah make clear His Ayat (proofs, evidences, verses) to you that you may give thought.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O you who believe! Spend of the good things which you have (legally) earned, and of that which We have produced from the earth for you, and do not aim at that which is bad to spend from it, (though) you would not accept it save if you close your eyes and tolerate therein. And know that Allah is Rich (Free of all wants), and Worthy of all praise.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Shaitan (Satan) threatens you with poverty and orders you to commit Fahsha (evil deeds, illegal sexual intercourse, sins etc.); whereas Allah promises you Forgiveness from Himself and Bounty, and Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He grants Hikmah to whom He pleases, and he, to whom Hikmah is granted, is indeed granted abundant good. But none remember (will receive admonition) except men of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever you spend for spendings (e.g., in Sadaqah - charity, etc. for Allah's Cause) or whatever vow you make, be sure Allah knows it all. And for the Zalimun (wrong-doers, etc.) there are no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you disclose your Sadaqat (alms-giving), it is well, but if you conceal it, and give it to the poor, that is better for you. (Allah) will forgive you some of your sins. And Allah is Well-Acquainted with what you do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Not upon you (Muhammad SAW) is their guidance, but Allah guides whom He wills. And whatever you spend in good, it is for yourselves, when you spend not except seeking Allah's Countenance. And whatever you spend in good, it will be repaid to you in full, and you shall not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Charity is) for Fuqara (the poor), who in Allah's Cause are restricted (from travel), and cannot move about in the land (for trade or work). The one who knows them not, thinks that they are rich because of their modesty. You may know them by their mark, they do not beg of people at all. And whatever you spend in good, surely Allah knows it well.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth (in Allah's Cause) by night and day, in secret and in public, they shall have their reward with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who eat Riba (usury) will not stand (on the Day of Resurrection) except like the standing of a person beaten by Shaitan (Satan) leading him to insanity. That is because they say: ``Trading is only like Riba (usury)," whereas Allah has permitted trading and forbidden Riba (usury). So whosoever receives an admonition from his Lord and stops eating Riba (usury) shall not be punished for the past; his case is for Allah (to judge); but whoever returns [to Riba (usury)], such are the dwellers of the Fire - they will abide therein.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah will destroy Riba (usury) and will give increase for Sadaqat (deeds of charity, alms, etc.) And Allah likes not the disbelievers, sinners.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Truly those who believe, and do deeds of righteousness, and perform As-Salat (Iqamat-as-Salat), and give Zakat, they will have their reward with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O you who believe! Be afraid of Allah and give up what remains (due to you) from Riba (usury) (from now onward), if you are (really) believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
And if you do not do it, then take a notice of war from Allah and His Messenger but if you repent, you shall have your capital sums. Deal not unjustly (by asking more than your capital sums), and you shall not be dealt with unjustly (by receiving less than your capital sums).\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if the debtor is in a hard time (has no money), then grant him time till it is easy for him to repay, but if you remit it by way of charity, that is better for you if you did but know.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And be afraid of the Day when you shall be brought back to Allah. Then every person shall be paid what he earned, and they shall not be dealt with unjustly.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O you who believe! When you contract a debt for a fixed period, write it down. Let a scribe write it down in justice between you. Let not the scribe refuse to write as Allah has taught him, so let him write. Let him (the debtor) who incurs the liability dictate, and he must fear Allah, his Lord, and diminish not anything of what he owes. But if the debtor is of poor understanding, or weak, or is unable himself to dictate, then let his guardian dictate in justice. And get two witnesses out of your own men. And if there are not two men (available), then a man and two women, such as you agree for witnesses, so that if one of them (two women) errs, the other can remind her. And the witnesses should not refuse when they are called on (for evidence). You should not become weary to write it (your contract), whether it be small or big, for its fixed term, that is more just with Allah; more solid as evidence, and more convenient to prevent doubts among yourselves, save when it is a present trade which you carry out on the spot among yourselves, then there is no sin on you if you do not write it down. But take witnesses whenever you make a commercial contract. Let neither scribe nor witness suffer any harm, but if you do (such harm), it would be wickedness in you. So be afraid of Allah; and Allah teaches you. And Allah is the All-Knower of each and everything.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if you are on a journey and cannot find a scribe, then let there be a pledge taken (mortgaging); then if one of you entrust the other, let the one who is entrusted discharge his trust (faithfully), and let him be afraid of Allah, his Lord. And conceal not the evidence for he, who hides it, surely his heart is sinful. And Allah is All-Knower of what you do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongs all that is in the heavens and all that is on the earth, and whether you disclose what is in your ownselves or conceal it, Allah will call you to account for it. Then He forgives whom He wills and punishes whom He wills. And Allah is Able to do all things.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger (Muhammad SAW) believes in what has been sent down to him from his Lord, and (so do) the believers. Each one believes in Allah, His Angels, His Books, and His Messengers. They say, ``We make no distinction between one another of His Messengers" - and they say, ``We hear, and we obey. (We seek) Your Forgiveness, our Lord, and to You is the return (of all)."\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah burdens not a person beyond his scope. He gets reward for that (good) which he has earned, and he is punished for that (evil) which he has earned. ``Our Lord! Punish us not if we forget or fall into error, our Lord! Lay not on us a burden like that which You did lay on those before us (Jews and Christians); our Lord! Put not on us a burden greater than we have strength to bear. Pardon us and grant us Forgiveness. Have mercy on us. You are our Maula (Patron, Suppor-ter and Protector, etc.) and give us victory over the disbelieving people.\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah! La ilaha illa Huwa (none has the right to be worshipped but He), the Ever Living, the One Who sustains and protects all that exists.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
It is He Who has sent down the Book (the Quran) to you (Muhammad SAW) with truth, confirming what came before it. And he sent down the Taurat (Torah) and the Injeel (Gospel).\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Aforetime, as a guidance to mankind, And He sent down the criterion [of judgement between right and wrong (this Quran)]. Truly, those who disbelieve in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, for them there is a severe torment; and Allah is All-Mighty, All-Able of Retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Truly, nothing is hidden from Allah, in the earth or in the heavens.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
He it is Who shapes you in the wombs as He pleases. La ilaha illa Huwa (none has the right to be worshipped but He), the All-Mighty, the All-Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He Who has sent down to you (Muhammad SAW) the Book (this Quran). In it are Verses that are entirely clear, they are the foundations of the Book [and those are the Verses of Al-Ahkam (commandments, etc.), Al-Fara'id (obligatory duties) and Al-Hudud (legal laws for the punishment of thieves, adulterers, etc.)]; and others not entirely clear. So as for those in whose hearts there is a deviation (from the truth) they follow that which is not entirely clear thereof, seeking Al-Fitnah (polytheism and trials, etc.), and seeking for its hidden meanings, but none knows its hidden meanings save Allah. And those who are firmly grounded in knowledge say: ``We believe in it; the whole of it (clear and unclear Verses) are from our Lord." And none receive admonition except men of understanding. (Tafsir At-Tabari).\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
(They say): ``Our Lord! Let not our hearts deviate (from the truth) after You have guided us, and grant us mercy from You. Truly, You are the Bestower."\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord! Verily, it is You Who will gather mankind together on the Day about which there is no doubt. Verily, Allah never breaks His Promise".\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
Verily, those who disbelieve, neither their properties nor their offspring will avail them whatsoever against Allah; and it is they who will be fuel of the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like the behaviour of the people of Fir'aun (Pharaoh) and those before them; they belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), so Allah seized (destroyed) them for their sins. And Allah is Severe in punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say (O Muhammad SAW) to those who disbelieve: ``You will be defeated and gathered together to Hell, and worst indeed is that place to rest."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
There has already been a sign for you (O Jews) in the two armies that met (in combat i.e. the battle of Badr): One was fighting in the Cause of Allah, and as for the other (they) were disbelievers. They (the believers) saw them (the disbelievers) with their own eyes twice their number (although they were thrice their number). And Allah supports with His Victory whom He pleases. Verily, in this is a lesson for those who understand. (See Verse 8:44). (Tafsir At-Tabari)\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Beautified for men is the love of things they covet; women, children, much of gold and silver (wealth), branded beautiful horses, cattle and well-tilled land. This is the pleasure of the present world's life; but Allah has the excellent return (Paradise with flowing rivers, etc.) with Him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: ``Shall I inform you of things far better than those? For Al-Muttaqun (the pious - see V. 2:2) there are Gardens (Paradise) with their Lord, underneath which rivers flow. Therein (is their) eternal (home) and Azwajun Mutahharatun (purified mates or wives) [i.e. they will have no menses, urine, or stool, etc.], And Allah will be pleased with them. And Allah is All-Seer of the (His) slaves".\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say: ``Our Lord! We have indeed believed, so forgive us our sins and save us from the punishment of the Fire."\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
(They are) those who are patient ones, those who are true (in Faith, words, and deeds), and obedient with sincere devotion in worship to Allah. Those who spend [give the Zakat and alms in the Way of Allah] and those who pray and beg Allah's Pardon in the last hours of the night.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah bears witness that La ilaha illa Huwa (none has the right to be worshipped but He), and the angels, and those having knowledge (also give this witness); (He is always) maintaining His creation in Justice. La ilah illa Huwa (none has the right to be worshipped but He), the All-Mighty, the All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Truly, the religion with Allah is Islam. Those who were given the Scripture (Jews and Christians) did not differ except, out of mutual jealousy, after knowledge had come to them. And whoever disbelieves in the Ayat (proofs, evidences, verses, signs, revelations, etc.) of Allah, then surely, Allah is Swift in calling to account.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
So if they dispute with you (Muhammad SAW) say: ``I have submitted myself to Allah (in Islam), and (so have) those who follow me." And say to those who were given the Scripture (Jews and Christians) and to those who are illiterates (Arab pagans): ``Do you (also) submit yourselves (to Allah in Islam)?" If they do, they are rightly guided; but if they turn away, your duty is only to convey the Message; and Allah is All-Seer of (His) slaves.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Verily! Those who disbelieve in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah and kill the Prophets without right, and kill those men who order just dealings,  announce to them a painful torment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are those whose works will be lost in this world and in the Hereafter, and they will have no helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Have you not seen those who have been given a portion of the Scripture? They are being invited to the Book of Allah to settle their dispute, then a party of them turn away, and they are averse.\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
This is because they say: ``The Fire shall not touch us but for a number of days." And that which they used to invent regarding their religion has deceived them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How (will it be) when We gather them together on the Day about which there is no doubt (i.e. the Day of Resurrection). And each person will be paid in full what he has earned? And they will not be dealt with unjustly.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say (O Muhammad SAW): ``O Allah! Possessor of the kingdom, You give the kingdom to whom You will, and You take the kingdom from whom You will, and You endue with honour whom You will, and You humiliate whom You will. In Your Hand is the good. Verily, You are Able to do all things.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
You make the night to enter into the day, and You make the day to enter into the night (i.e. increase and decrease in the hours of the night and the day during winter and summer), You bring the living out of the dead, and You bring the dead out of the living. And You give wealth and sustenance to whom You will, without limit (measure or account).\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers take the disbelievers as Auliya (supporters, helpers, etc.) instead of the believers, and whoever does that will never be helped by Allah in any way, except if you indeed fear a danger from them. And Allah warns you against Himself (His Punishment), and to Allah is the final return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say (O Muhammad SAW): ``Whether you hide what is in your breasts or reveal it, Allah knows it, and He knows what is in the heavens and what is in the earth. And Allah is Able to do all things."\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
On the Day when every person will be confronted with all the good he has done, and all the evil he has done, he will wish that there were a great distance between him and his evil. And Allah warns you against Himself (His Punishment) and Allah is full of Kindness to the (His) slaves.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say (O Muhammad SAW to mankind): ``If you (really) love Allah then follow me (i.e. accept Islamic Monotheism, follow the Quran and the Sunnah), Allah will love you and forgive you of your sins. And Allah is Oft-Forgiving, Most Merciful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say (O Muhammad SAW): ``Obey Allah and the Messenger (Muhammad SAW)." But if they turn away, then Allah does not like the disbelievers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Allah chose Adam, Nuh (Noah), the family of Ibrahim (Abraham) and the family of 'Imran above the 'Alamin (mankind and jinns) (of their times).\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Offspring, one of the other, and Allah is the All-Hearer, All-Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(Remember) when the wife of 'Imran said: ``O my Lord! I have vowed to You what (the child that) is in my womb to be dedicated for Your services (free from all worldly work; to serve Your Place of worship), so accept this, from me. Verily, You are the All-Hearer, the All-Knowing."\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
Then when she delivered her [child Maryam (Mary)], she said: ``O my Lord! I have delivered a female child," - and Allah knew better what she delivered, - ``And the male is not like the female, and I have named her Maryam (Mary), and I seek refuge with You (Allah) for her and for her offspring from Shaitan (Satan), the outcast."\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
So her Lord (Allah) accepted her with goodly acceptance. He made her grow in a good manner and put her under the care of Zakariya (Zachariya). Every time he entered Al-Mihrab to (visit) her, he found her supplied with sustenance. He said: ``O Maryam (Mary)! From where have you got this?" She said, ``This is from Allah." Verily, Allah provides sustenance to whom He wills, without limit."\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
At that time Zakariya (Zachariya) invoked his Lord, saying: ``O my Lord! Grant me from You, a good offspring. You are indeed the All-Hearer of invocation."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
Then the angels called him, while he was standing in prayer in Al-Mihrab (a praying place or a private room), (saying): ``Allah gives you glad tidings of Yahya (John), confirming (believing in) the Word from Allah [i.e. the creation of 'Iesa (Jesus), the Word from Allah ("Be!" - and he was!)], noble, keeping away from sexual relations with women, a Prophet, from among the righteous."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: ``O my Lord! How can I have a son when I am very old, and my wife is barren?" Allah said: ``Thus Allah does what He wills."\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: ``O my Lord! Make a sign for me." Allah said: ``Your sign is that you shall not speak to mankind for three days except with signals. And remember your Lord much (by praising Him again and again), and glorify (Him) in the afternoon and in the morning."\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And (remember) when the angels said: ``O Maryam (Mary)! Verily, Allah has chosen you, purified you (from polytheism and disbelief), and chosen you above the women of the 'Alamin (mankind and jinns) (of her lifetime)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
O Mary! ``Submit yourself with obedience to your Lord (Allah, by worshipping none but Him Alone) and prostrate yourself, and Irka'i (bow down etc.) along with Ar-Raki'un (those who bow down etc.)."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is a part of the news of the Ghaib (unseen, i.e. the news of the past nations of which you have no knowledge) which We inspire you with (O Muhammad SAW). You were not with them, when they cast lots with their pens as to which of them should be charged with the care of Maryam (Mary); nor were you with them when they disputed.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
(Remember) when the angels said: ``O Maryam (Mary)! Verily, Allah gives you the glad tidings of a Word ["Be!" - and he was! i.e. 'Iesa (Jesus) the son of Maryam (Mary)] from Him, his name will be the Messiah 'Iesa (Jesus), the son of Maryam (Mary), held in honour in this world and in the Hereafter, and will be one of those who are near to Allah."\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
``He will speak to the people in the cradle and in manhood, and he will be one of the righteous."\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: ``O my Lord! How shall I have a son when no man has touched me." He said: ``So (it will be) for Allah creates what He wills. When He has decreed something, He says to it only: ``Be!" and it is.\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He (Allah) will teach him ['Iesa (Jesus)] the Book and Al-Hikmah (i.e. the Sunnah, the faultless speech of the Prophets, wisdom, etc.), (and) the Taurat (Torah) and the Injeel (Gospel).\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
And will make him ['Iesa (Jesus)] a Messenger to the Children of Israel (saying): ``I have come to you with a sign from your Lord, that I design for you out of clay, as it were, the figure of a bird, and breathe into it, and it becomes a bird by Allah's Leave; and I heal him who was born blind, and the leper, and I bring the dead to life by Allah's Leave. And I inform you of what you eat, and what you store in your houses. Surely, therein is a sign for you, if you believe.\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
And I have come confirming that which was before me of the Taurat (Torah), and to make lawful to you part of what was forbidden to you, and I have come to you with a proof from your Lord. So fear Allah and obey me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Truly! Allah is my Lord and your Lord, so worship Him (Alone). This is the Straight Path.\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
Then when 'Iesa (Jesus) came to know of their disbelief, he said: ``Who will be my helpers in Allah's Cause?" Al-Hawariun (the disciples) said: ``We are the helpers of Allah; we believe in Allah, and bear witness that we are Muslims (i.e. we submit to Allah)."\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Our Lord! We believe in what You have sent down, and we follow the Messenger ['Iesa (Jesus)]; so write us down among those who bear witness (to the truth i.e. La ilaha ill-Allah - none has the right to be worshipped but Allah).\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And they (disbelievers) plotted [to kill 'Iesa (Jesus)], and Allah planned too. And Allah is the Best of the planners.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
And (remember) when Allah said: ``O 'Iesa (Jesus)! I will take you and raise you to Myself and clear you [of the forged statement that 'Iesa (Jesus) is Allah's son] of those who disbelieve, and I will make those who follow you (Monotheists, who worship none but Allah) superior to those who disbelieve [in the Oneness of Allah, or disbelieve in some of His Messengers, e.g. Muhammad SAW, 'Iesa (Jesus), Musa (Moses), etc., or in His Holy Books, e.g. the Taurat (Torah), the Injeel (Gospel), the Quran] till the Day of Resurrection. Then you will return to Me and I will judge between you in the matters in which you used to dispute."\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
``As to those who disbelieve, I will punish them with a severe torment in this world and in the Hereafter, and they will have no helpers."\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
And as for those who believe (in the Oneness of Allah) and do righteous good deeds, Allah will pay them their reward in full. And Allah does not like the Zalimun (polytheists and wrong-doers).\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This is what We recite to you (O Muhammad SAW) of the Verses and the Wise Reminder (i.e. the Quran).\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Verily, the likeness of 'Iesa (Jesus) before Allah is the likeness of Adam. He created him from dust, then (He) said to him: ``Be!" - and he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
(This is) the truth from your Lord, so be not of those who doubt.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
Then whoever disputes with you concerning him ['Iesa (Jesus)] after (all this) knowledge that has come to you, [i.e. 'Iesa (Jesus)] being a slave of Allah, and having no share in Divinity) say: (O Muhammad SAW) ``Come, let us call our sons and your sons, our women and your women, ourselves and yourselves - then we pray and invoke (sincerely) the Curse of Allah upon those who lie."\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
Verily! This is the true narrative [about the story of 'Iesa (Jesus)], and, La ilaha ill-Allah (none has the right to be worshipped but Allah, the One and the Only True God, Who has neither a wife nor a son). And indeed, Allah is the All-Mighty, the All-Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
And if they turn away (and do not accept these true proofs and evidences), then surely, Allah is All-Aware of those who do mischief.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say (O Muhammad SAW): ``O people of the Scripture (Jews and Christians): Come to a word that is just between us and you, that we worship none but Allah, and that we associate no partners with Him, and that none of us shall take others as lords besides Allah. Then, if they turn away, say: ``Bear witness that we are Muslims."\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O people of the Scripture (Jews and Christians)! Why do you dispute about Ibrahim (Abraham), while the Taurat (Torah) and the Injeel (Gospel) were not revealed till after him? Have you then no sense?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Verily, you are those who have disputed about that of which you have knowledge. Why do you then dispute concerning that which you have no knowledge? It is Allah Who knows, and you know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Ibrahim (Abraham) was neither a Jew nor a Christian, but he was a true Muslim Hanifa (Islamic Monotheism - to worship none but Allah Alone) and he was not of Al-Mushrikun (See V. 2:105).\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Verily, among mankind who have the best claim to Ibrahim (Abraham) are those who followed him, and this Prophet (Muhammad SAW) and those who have believed (Muslims). And Allah is the Wali (Protector and Helper) of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A party of the people of the Scripture (Jews and Christians) wish to lead you astray. But they shall not lead astray anyone except themselves, and they perceive not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O people of the Scripture! (Jews and Christians): ``Why do you disbelieve in the Ayat of Allah, [the Verses about Prophet Muhammad SAW present in the Taurat (Torah) and the Injeel (Gospel)] while you (yourselves) bear witness (to their truth)."\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O people of the Scripture (Jews and Christians): ``Why do you mix truth with falsehood and conceal the truth while you know?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a party of the people of the Scripture say: ``Believe in the morning in that which is revealed to the believers (Muslims), and reject it at the end of the day, so that they may turn back.\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And believe no one except the one who follows your religion. Say (O Muhammad SAW): ``Verily! Right guidance is the Guidance of Allah" and do not believe that anyone can receive like that which you have received (of Revelation) except when he follows your religion, otherwise they would engage you in argument before your Lord. Say (O Muhammad SAW): ``All the bounty is in the Hand of Allah; He grants to whom He wills. And Allah is All-Sufficient for His creatures' needs, the All-Knower."\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He selects for His Mercy (Islam and the Quran with Prophethood) whom He wills and Allah is the Owner of Great Bounty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the people of the Scripture (Jews and Christians) is he who, if entrusted with a Cantar (a great amount of wealth, etc.), will readily pay it back; and among them there is he who, if entrusted with a single silver coin, will not repay it unless you constantly stand demanding, because they say: ``There is no blame on us to betray and take the properties of the illiterates (Arabs)." But they tell a lie against Allah while they know it.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Yes, whoever fulfils his pledge and fears Allah much; verily, then Allah loves those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Verily, those who purchase a small gain at the cost of Allah's Covenant and their oaths, they shall have no portion in the Hereafter (Paradise). Neither will Allah speak to them, nor look at them on the Day of Resurrection, nor will He purify them, and they shall have a painful torment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And verily, among them is a party who distort the Book with their tongues (as they read), so that you may think it is from the Book, but it is not from the Book, and they say: ``This is from Allah," but it is not from Allah; and they speak a lie against Allah while they know it.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not (possible) for any human being to whom Allah has given the Book and Al-Hukma (the knowledge and understanding of the laws of religion, etc.) and Prophethood to say to the people: ``Be my worshippers rather than Allah's." On the contrary (he would say): ``Be you Rabbaniyun (learned men of religion who practise what they know and also preach others), because you are teaching the Book, and you are studying it."\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor would he order you to take angels and Prophets for lords (gods). Would he order you to disbelieve after you have submitted to Allah's Will? (Tafsir At-Tabari).\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And (remember) when Allah took the Covenant of the Prophets, saying: ``Take whatever I gave you from the Book and Hikmah (understanding of the Laws of Allah, etc.), and afterwards there will come to you a Messenger (Muhammad SAW) confirming what is with you; you must, then, believe in him and help him." Allah said: ``Do you agree (to it) and will you take up My Covenant (which I conclude with you)?" They said: ``We agree." He said: ``Then bear witness; and I am with you among the witnesses (for this)."\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Then whoever turns away after this, they are the Fasiqun (rebellious: those who turn away from Allah's Obedience).\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Do they seek other than the religion of Allah (the true Islamic Monotheism worshipping none but Allah Alone), while to Him submitted all creatures in the heavens and the earth, willingly or unwillingly. And to Him shall they all be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say (O Muhammad SAW): ``We believe in Allah and in what has been sent down to us, and what was sent down to Ibrahim (Abraham), Isma'il (Ishmael), Ishaque (Isaac), Ya'qub (Jacob) and Al-Asbat [the twelve sons of Ya'qub (Jacob)] and what was given to Musa (Moses), 'Iesa (Jesus) and the Prophets from their Lord. We make no distinction between one another among them and to Him (Allah) we have submitted (in Islam)."\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whoever seeks a religion other than Islam, it will never be accepted of him, and in the Hereafter he will be one of the losers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who disbelieved after their belief and after they bore witness that the Messenger (Muhammad SAW) is true and after clear proofs had come unto them? And Allah guides not the people who are Zalimun (polytheists and wrong-doers).\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
They are those whose recompense is that on them (rests) the Curse of Allah, of the angels, and of all mankind.\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
They will abide therein (Hell). Neither will their torment be lightened, nor will it be delayed or postponed (for a while).\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except for those who repent after that and do righteous deeds. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Verily, those who disbelieved after their Belief and then went on increasing in their disbelief (i.e. disbelief in the Quran and in Prophet Muhammad SAW) - never will their repentance be accepted [because they repent only by their tongues and not from their hearts]. And they are those who are astray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Verily, those who disbelieved, and died while they were disbelievers, the (whole) earth full of gold will not be accepted from anyone of them even if they offered it as a ransom. For them is a painful torment and they will have no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
By no means shall you attain Al-Birr (piety, righteousness, etc., it means here Allah's Reward, i.e. Paradise), unless you spend (in Allah's Cause) of that which you love; and whatever of good you spend, Allah knows it well.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel, except what Israel made unlawful for himself before the Taurat (Torah) was revealed. Say (O Muhammad SAW): ``Bring here the Taurat (Torah) and recite it, if you are truthful."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Then after that, whosoever shall invent a lie against Allah,  such shall indeed be the Zalimun (disbelievers).\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say (O Muhammad SAW): ``Allah has spoken the truth; follow the religion of Ibrahim (Abraham) Hanifa (Islamic Monotheism, i.e. he used to worship Allah Alone), and he was not of Al-Mushrikun." (See V. 2:105)\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Verily, the first House (of worship) appointed for mankind was that at Bakkah (Makkah), full of blessing, and a guidance for Al-'Alamin (the mankind and jinns).\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are manifest signs (for example), the Maqam (place) of Ibrahim (Abraham); whosoever enters it, he attains security. And Hajj (pilgrimage to Makkah) to the House (Ka'bah) is a duty that mankind owes to Allah, those who can afford the expenses (for one's conveyance, provision and residence); and whoever disbelieves [i.e. denies Hajj (pilgrimage to Makkah), then he is a disbeliever of Allah], then Allah stands not in need of any of the 'Alamin (mankind and jinns).\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: ``O people of the Scripture (Jews and Christians)! Why do you reject the Ayat of Allah (proofs, evidences, verses, lessons, signs, revelations, etc.) while Allah is Witness to what you do?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: ``O people of the Scripture (Jews and Christians)! Why do you stop those who have believed, from the Path of Allah, seeking to make it seem crooked, while you (yourselves) are witnesses [to Muhammad SAW as a Messenger of Allah and Islam (Allah's Religion, i.e. to worship none but Him Alone)]? And Allah is not unaware of what you do."\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O you who believe! If you obey a group of those who were given the Scripture (Jews and Christians), they would (indeed) render you disbelievers after you have believed!\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how would you disbelieve, while unto you are recited the Verses of Allah, and among you is His Messenger (Muhammad SAW)? And whoever holds firmly to Allah, (i.e. follows Islam Allah's Religion, and obeys all that Allah has ordered, practically), then he is indeed guided to a Right Path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O you who believe! Fear Allah (by doing all that He has ordered and by abstaining from all that He has forbidden) as He should be feared. [Obey Him, be thankful to Him, and remember Him always], and die not except in a state of Islam (as Muslims) with complete submission to Allah.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast, all of you together, to the Rope of Allah (i.e. this Quran), and be not divided among yourselves, and remember Allah's Favour on you, for you were enemies one to another but He joined your hearts together, so that, by His Grace, you became brethren (in Islamic Faith), and you were on the brink of a pit of Fire, and He saved you from it. Thus Allah makes His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.,) clear to you, that you may be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
Let there arise out of you a group of people inviting to all that is good (Islam), enjoining Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam orders one to do) and forbidding Al-Munkar (polytheism and disbelief and all that Islam has forbidden). And it is they who are the successful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And be not as those who divided and differed among themselves after the clear proofs had come to them. It is they for whom there is an awful torment.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day (i.e. the Day of Resurrection) when some faces will become white and some faces will become black; as for those whose faces will become black (to them will be said): ``Did you reject Faith after accepting it? Then taste the torment (in Hell) for rejecting Faith."\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
And for those whose faces will become white, they will be in Allah's Mercy (Paradise), therein they shall dwell forever.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the Verses of Allah: We recite them to you (O Muhammad SAW) in truth, and Allah wills no injustice to the 'Alamin (mankind and jinns).\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
And to Allah belongs all that is in the heavens and all that is in the earth. And all matters go back (for decision) to Allah.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
You [true believers in Islamic Monotheism, and real followers of Prophet Muhammad SAW and his Sunnah (legal ways, etc.)] are the best of peoples ever raised up for mankind; you enjoin Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam has ordained) and forbid Al-Munkar (polytheism, disbelief and all that Islam has forbidden), and you believe in Allah. And had the people of the Scripture (Jews and Christians) believed, it would have been better for them; among them are some who have faith, but most of them are Al-Fasiqun (disobedient to Allah - and rebellious against Allah's Command).\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will do you no harm, barring a trifling annoyance; and if they fight against you, they will show you their backs, and they will not be helped.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
Indignity is put over them wherever they may be, except when under a covenant (of protection) from Allah, and from men; they have drawn on themselves the Wrath of Allah, and destruction is put over them. This is because they disbelieved in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah and killed the Prophets without right. This is because they disobeyed (Allah) and used to transgress beyond bounds (in Allah's disobedience, crimes and sins).\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
Not all of them are alike; a party of the people of the Scripture stand for the right, they recite the Verses of Allah during the hours of the night, prostrating themselves in prayer.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and the Last Day; they enjoin Al-Ma'ruf (Islamic Monotheism, and following Prophet Muhammad SAW) and forbid Al-Munkar (polytheism, disbelief and opposing Prophet Muhammad SAW); and they hasten in (all) good works; and they are among the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatever good they do, nothing will be rejected of them; for Allah knows well those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Surely, those who reject Faith (disbelieve in Muhammad SAW as being Allah's Prophet and in all that which he has brought from Allah), neither their properties, nor their offspring will avail them aught against Allah. They are the dwellers of the Fire, therein they will abide. (Tafsir At-Tabari, Vol. 4, Page 58).\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The likeness of what they spend in this world is the likeness of a wind which is extremely cold; it struck the harvest of a people who did wrong aginst themselves and destroyed it, (i.e. the good deed of a person is only accepted if he is a monotheist and believes in all the Prophets of Allah, including Christ and Muhammad SAW). Allah wronged them not, but they wronged themselves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O you who believe! Take not as (your) Bitanah (advisors, consultants, protectors, helpers, friends, etc.) those outside your religion (pagans, Jews, Christians, and hypocrites) since they will not fail to do their best to corrupt you. They desire to harm you severely. Hatred has already appeared from their mouths, but what their breasts conceal is far worse. Indeed We have made plain to you the Ayat (proofs, evidences, verses) if you understand.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Lo! You are the ones who love them but they love you not, and you believe in all the Scriptures [i.e. you believe in the Taurat (Torah) and the Injeel (Gospel), while they disbelieve in your Book, the Quran]. And when they meet you, they say, ``We believe". But when they are alone, they bite the tips of their fingers at you in rage. Say: ``Perish in your rage. Certainly, Allah knows what is in the breasts (all the secrets)."\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If a good befalls you, it grieves them, but if some evil overtakes you, they rejoice at it. But if you remain patient and become Al-Muttaqun (the pious - see V. 2:2), not the least harm will their cunning do to you. Surely, Allah surrounds all that they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And (remember) when you (Muhammad SAW) left your household in the morning to post the believers at their stations for the battle (of Uhud). And Allah is All-Hearer, All-Knower.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two parties from among you were about to lose heart, but Allah was their Wali (Supporter and Protector). And in Allah should the believers put their trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
And Allah has already made you victorious at Badr, when you were a weak little force. So fear Allah much [abstain from all kinds of sins and evil deeds which He has forbidden and love Allah much, perform all kinds of good deeds which He has ordained] that you may be grateful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
(Remember) when you (Muhammad SAW) said to the believers, ``Is it not enough for you that your Lord (Allah) should help you with three thousand angels; sent down?"\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
``Yes, if you hold on to patience and piety, and the enemy comes rushing at you; your Lord will help you with five thousand angels having marks (of distinction)."\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah made it not but as a message of good news for you and as an assurance to your hearts. And there is no victory except from Allah, the All-Mighty, the All-Wise.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He might cut off a part of those who disbelieve, or expose them to infamy, so that they retire frustrated.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
Not for you (O Muhammad SAW, but for Allah) is the decision; whether He turns in mercy to (pardons) them or punishes them; verily, they are the Zalimun (polytheists, disobedients, and wrong-doers, etc.).\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
And to Allah belongs all that is in the heavens and all that is in the earth. He forgives whom He wills, and punishes whom He wills. And Allah is Oft-Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O you who believe! Eat not Riba (usury) doubled and multiplied, but fear Allah that you may be successful.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And fear the Fire, which is prepared for the disbelievers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Messenger (Muhammad SAW) that you may obtain mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And march forth in the way (which leads to) forgiveness from your Lord, and for Paradise as wide as are the heavens and the earth, prepared for Al-Muttaqun (the pious - see V. 2:2).\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who spend [in Allah's Cause - deeds of charity, alms, etc.] in prosperity and in adversity, who repress anger, and who pardon men; verily, Allah loves Al-Muhsinun (the good-doers).\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they have committed Fahishah (illegal sexual intercourse etc.) or wronged themselves with evil, remember Allah and ask forgiveness for their sins; - and none can forgive sins but Allah - And do not persist in what (wrong) they have done, while they know.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
For such, the reward is Forgiveness from their Lord, and Gardens with rivers flowing underneath (Paradise), wherein they shall abide forever. How excellent is this reward for the doers (who do righteous deeds according to Allah's Orders).\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Many similar ways (and mishaps of life) were faced by nations (believers and disbelievers) that have passed away before you (as you have faced in the battle of Uhud), so travel through the earth, and see what was the end of those who disbelieved (in the Oneness of Allah, and disobeyed Him and His Messengers).\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This (the Quran) is a plain statement for mankind, a guidance and instruction to those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
So do not become weak (against your enemy), nor be sad, and you will be superior (in victory) if you are indeed (true) believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound (and killing) has touched you, be sure a similar wound (and killing) has touched the others. And so are the days (good and not so good), We give to men by turns, that Allah may test those who believe, and that He may take martyrs from among you. And Allah likes not the Zalimun (polytheists and wrong-doers).\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And that Allah may test (or purify) the believers (from sins) and destroy the disbelievers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Do you think that you will enter Paradise before Allah tests those of you who fought (in His Cause) and (also) tests those who are As-Sabirin (the patient ones, etc.)?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You did indeed wish for death (Ash-Shahadah - martyrdom) before you met it. Now you have seen it openly with your own eyes.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad (SAW) is no more than a Messenger, and indeed (many) Messengers have passed away before him. If he dies or is killed, will you then turn back on your heels (as disbelievers)? And he who turns back on his heels, not the least harm will he do to Allah, and Allah will give reward to those who are grateful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
And no person can ever die except by Allah's Leave and at an appointed term. And whoever desires a reward in (this) world, We shall give him of it; and whoever desires a reward in the Hereafter, We shall give him thereof. And We shall reward the grateful\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And many a Prophet (i.e. many from amongst the Prophets) fought (in Allah's Cause) and along with him (fought) large bands of religious learned men. But they never lost heart for that which did befall them in Allah's Way, nor did they weaken nor degrade themselves. And Allah loves As-Sabirin (the patient ones, etc.).\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
And they said nothing but: ``Our Lord! Forgive us our sins and our transgressions (in keeping our duties to You), establish our feet firmly, and give us victory over the disbelieving folk."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
So Allah gave them the reward of this world, and the excellent reward of the Hereafter. And Allah loves Al-Muhsinun (the good-doers - see the footnote of V. 3:134).\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O you who believe! If you obey those who disbelieve, they will send you back on your heels, and you will turn back (from Faith) as losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
Nay, Allah is your Maula (Patron, Lord, Helper and Protector, etc.), and He is the Best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We shall cast terror into the hearts of those who disbelieve, because they joined others in worship with Allah, for which He had sent no authority; their abode will be the Fire and how evil is the abode of the Zalimun (polytheists and wrong-doers).\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
And Allah did indeed fulfil His Promise to you when you were killing them (your enemy) with His Permission; until (the moment) you lost your courage and fell to disputing about the order, and disobeyed after He showed you (of the booty) which you love. Among you are some that desire this world and some that desire the Hereafter. Then He made you flee from them (your enemy), that He might test you. But surely, He forgave you, and Allah is Most Gracious to the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
(And remember) when you ran away (dreadfully) without even casting a side glance at anyone, and the Messenger (Muhammad SAW) was in your rear calling you back. There did Allah give you one distress after another by way of requital to teach you not to grieve for that which had escaped you, nor for that which had befallen you. And Allah is Well-Aware of all that you do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then after the distress, He sent down security for you. Slumber overtook a party of you, while another party was thinking about themselves (as how to save their ownselves, ignoring the others and the Prophet SAW) and thought wrongly of Allah - the thought of ignorance. They said, ``Have we any part in the affair?" Say you (O Muhammad SAW): ``Indeed the affair belongs wholly to Allah." They hide within themselves what they dare not reveal to you, saying: ``If we had anything to do with the affair, none of us would have been killed here." Say: ``Even if you had remained in your homes, those for whom death was decreed would certainly have gone forth to the place of their death," but that Allah might test what is in your breasts; and to Mahis that which was in your hearts (sins), and Allah is All-Knower of what is in (your) breasts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned back on the day the two hosts met (i.e. the battle of Uhud), it was Shaitan (Satan) who caused them to backslide (run away from the battlefield) because of some (sins) they had earned. But Allah, indeed, has forgiven them. Surely, Allah is Oft-Forgiving, Most Forbearing.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O you who believe! Be not like those who disbelieve (hypocrites) and who say to their brethren when they travel through the earth or go out to fight: ``If they had stayed with us, they would not have died or been killed," so that Allah may make it a cause of regret in their hearts. It is Allah that gives life and causes death. And Allah is All-Seer of what you do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
And if you are killed or die in the Way of Allah, forgiveness and mercy from Allah are far better than all that they amass (of worldly wealths, etc.).\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
And whether you die, or are killed, verily, unto Allah you shall be gathered.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
And by the Mercy of Allah, you dealt with them gently. And had you been severe and harsh-hearted, they would have broken away from about you; so pass over (their faults), and ask (Allah's) Forgiveness for them; and consult them in the affairs. Then when you have taken a decision, put your trust in Allah, certainly, Allah loves those who put their trust (in Him).\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah helps you, none can overcome you; and if He forsakes you, who is there after Him that can help you? And in Allah (Alone) let believers put their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for any Prophet to take illegally a part of booty (Ghulul), and whosoever deceives his companions as regards the booty, he shall bring forth on the Day of Resurrection that which he took (illegally). Then every person shall be paid in full what he has earned, - and they shall not be dealt with unjustly.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is then one who follows (seeks) the good Pleasure of Allah (by not taking illegally a part of the booty) like the one who draws on himself the Wrath of Allah (by taking a part of the booty illegally - Ghulul)? - his abode is Hell, - and worst, indeed is that destination!\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in varying grades with Allah, and Allah is All-Seer of what they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Indeed Allah conferred a great favour on the believers when He sent among them a Messenger (Muhammad SAW) from among themselves, reciting unto them His Verses (the Quran), and purifying them (from sins by their following him), and instructing them (in) the Book (the Quran) and Al-Hikmah [the wisdom and the Sunnah of the Prophet SAW (i.e. his legal ways, statements, acts of worship, etc.)], while before that they had been in manifest error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
(What is the matter with you?) When a single disaster smites you, although you smote (your enemies) with one twice as great, you say: ``From where does this come to us?" Say (to them), ``It is from yourselves (because of your evil deeds)." And Allah has power over all things.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
And what you suffered (of the disaster) on the day (of the battle of Uhud when) the two armies met, was by the leave of Allah, in order that He might test the believers.\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that He might test the hypocrites, it was said to them: ``Come, fight in the Way of Allah or (at least) defend yourselves." They said: ``Had we known that fighting will take place, we would certainly have followed you." They were that day, nearer to disbelief than to Faith, saying with their mouths what was not in their hearts. And Allah has full knowledge of what they conceal.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
(They are) the ones who said about their killed brethren while they themselves sat (at home): ``If only they had listened to us, they would not have been killed." Say: ``Avert death from your ownselves, if you speak the truth."\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Think not of those who are killed in the Way of Allah as dead. Nay, they are alive, with their Lord, and they have provision.\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
They rejoice in what Allah has bestowed upon them of His Bounty, rejoicing for the sake of those who have not yet joined them, but are left behind (not yet martyred) that on them no fear shall come, nor shall they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice in a Grace and a Bounty from Allah, and that Allah will not waste the reward of the believers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who answered (the Call of) Allah and the Messenger (Muhammad SAW) after being wounded; for those of them who did good deeds and feared Allah, there is a great reward.\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those (i.e. believers) unto whom the people (hypocrites) said, ``Verily, the people (pagans) have gathered against you (a great army), therefore, fear them." But it (only) increased them in Faith, and they said: ``Allah (Alone) is Sufficient for us, and He is the Best Disposer of affairs (for us)."\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with Grace and Bounty from Allah. No harm touched them; and they followed the good Pleasure of Allah. And Allah is the Owner of Great Bounty.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is only Shaitan (Satan) that suggests to you the fear of his Auliya' [supporters and friends (polytheists, disbelievers in the Oneness of Allah and in His Messenger, Muhammad SAW)], so fear them not, but fear Me, if you are (true) believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And let not those grieve you (O Muhammad SAW) who rush with haste to disbelieve; verily, not the least harm will they do to Allah. It is Allah's Will to give them no portion in the Hereafter. For them there is a great torment.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Verily, those who purchase disbelief at the price of Faith, not the least harm will they do to Allah. For them, there is a painful torment.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not the disbelievers think that Our postponing of their punishment is good for them. We postpone the punishment only so that they may increase in sinfulness. And for them is a disgracing torment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not leave the believers in the state in which you are now, until He distinguishes the wicked from the good. Nor will Allah disclose to you the secrets of the Ghaib (unseen), but Allah chooses of His Messengers whom He pleases. So believe in Allah and His Messengers. And if you believe and fear Allah, then for you there is a great reward.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who covetously withhold of that which Allah has bestowed on them of His Bounty (Wealth) think that it is good for them (and so they do not pay the obligatory Zakat). Nay, it will be worse for them; the things which they covetously withheld shall be tied to their necks like a collar on the Day of Resurrection. And to Allah belongs the heritage of the heavens and the earth; and Allah is Well-Acquainted with all that you do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Indeed, Allah has heard the statement of those (Jews) who say: ``Truly, Allah is poor and we are rich!" We shall record what they have said and their killing of the Prophets unjustly, and We shall say: ``Taste you the torment of the burning (Fire)."\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
This is because of that (evil) which your hands have sent before you. And certainly, Allah is never unjust to (His) slaves.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those (Jews) who said: ``Verily, Allah has taken our promise not to believe in any Messenger unless he brings to us an offering which the fire (from heaven) shall devour." Say: ``Verily, there came to you Messengers before me, with clear signs and even with what you speak of; why then did you kill them, if you are truthful?"\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
Then if they reject you (O Muhammad SAW), so were Messengers rejected before you, who came with Al-Baiyinat (clear signs, proofs, evidences) and the Scripture and the Book of Enlightenment.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Everyone shall taste death. And only on the Day of Resurrection shall you be paid your wages in full. And whoever is removed away from the Fire and admitted to Paradise, he indeed is successful. The life of this world is only the enjoyment of deception (a deceiving thing).\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You shall certainly be tried and tested in your wealth and properties and in your personal selves, and you shall certainly hear much that will grieve you from those who received the Scripture before you (Jews and Christians) and from those who ascribe partners to Allah, but if you persevere patiently, and become Al-Muttaqun (the pious - see V. 2:2) then verily, that will be a determining factor in all affairs, and that is from the great matters, [which you must hold on with all your efforts].\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
(And remember) when Allah took a covenant from those who were given the Scripture (Jews and Christians) to make it (the news of the coming of Prophet Muhammad SAW and the religious knowledge) known and clear to mankind, and not to hide it, but they threw it away behind their backs, and purchased with it some miserable gain! And indeed worst is that which they bought.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Think not that those who rejoice in what they have done (or brought about), and love to be praised for what they have not done,- think not you that they are rescued from the torment, and for them is a painful torment.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
And to Allah belongs the dominion of the heavens and the earth, and Allah has power over all things.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Verily! In the creation of the heavens and the earth, and in the alternation of night and day, there are indeed signs for men of understanding.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Those who remember Allah (always, and in prayers) standing, sitting, and lying down on their sides, and think deeply about the creation of the heavens and the earth, (saying): ``Our Lord! You have not created (all) this without purpose, glory to You! (Exalted be You above all that they associate with You as partners). Give us salvation from the torment of the Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
``Our Lord! Verily, whom You admit to the Fire, indeed, You have disgraced him, and never will the Zalimun (polytheists and wrong-doers) find any helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
``Our Lord! Verily, we have heard the call of one (Muhammad SAW) calling to Faith: 'Believe in your Lord,' and we have believed. Our Lord! Forgive us our sins and remit from us our evil deeds, and make us die in the state of righteousness along with Al-Abrar (those who are obedient to Allah and follow strictly His Orders).\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
``Our Lord! Grant us what You promised unto us through Your Messengers and disgrace us not on the Day of Resurrection, for You never break (Your) Promise."\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
So their Lord accepted of them (their supplication and answered them), ``Never will I allow to be lost the work of any of you, be he male or female. You are (members) one of another, so those who emigrated and were driven out from their homes, and suffered harm in My Cause, and who fought, and were killed (in My Cause), verily, I will remit from them their evil deeds and admit them into Gardens under which rivers flow (in Paradise); a reward from Allah, and with Allah is the best of rewards."\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let not the free disposal (and affluence) of the disbelievers throughout the land deceive you.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
A brief enjoyment; then, their ultimate abode is Hell; and worst indeed is that place for rest.\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But, for those who fear their Lord, are Gardens under which rivers flow (in Paradise); therein are they to dwell (for ever), an entertainment from Allah; and that which is with Allah is the Best for Al-Abrar (those who are obedient to Allah and follow strictly His Orders).\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And there are, certainly, among the people of the Scripture (Jews and Christians), those who believe in Allah and in that which has been revealed to you, and in that which has been revealed to them, humbling themselves before Allah. They do not sell the Verses of Allah for a little price, for them is a reward with their Lord. Surely, Allah is Swift in account.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O you who believe! Endure and be more patient (than your enemy), and guard your territory by stationing army units permanently at the places from where the enemy can attack you, and fear Allah, so that you may be successful.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind! Be dutiful to your Lord, Who created you from a single person (Adam), and from him (Adam) He created his wife [Hawwa (Eve)], and from them both He created many men and women and fear Allah through Whom you demand your mutual (rights), and (do not cut the relations of) the wombs (kinship). Surely, Allah is Ever an All-Watcher over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give unto orphans their property and do not exchange (your) bad things for (their) good ones; and devour not their substance (by adding it) to your substance. Surely, this is a great sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if you fear that you shall not be able to deal justly with the orphan-girls, then marry (other) women of your choice, two or three, or four but if you fear that you shall not be able to deal justly (with them), then only one or (the captives and the slaves) that your right hands possess. That is nearer to prevent you from doing injustice.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give to the women (whom you marry) their Mahr (obligatory bridal money given by the husband to his wife at the time of marriage) with a good heart, but if they, of their own good pleasure, remit any part of it to you, take it, and enjoy it without fear of any harm (as Allah has made it lawful).\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
And give not unto the foolish your property which Allah has made a means of support for you, but feed and clothe them therewith, and speak to them words of kindness and justice.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And try orphans (as regards their intelligence) until they reach the age of marriage; if then you find sound judgement in them, release their property to them, but consume it not wastefully, and hastily fearing that they should grow up, and whoever amongst guardians is rich, he should take no wages, but if he is poor, let him have for himself what is just and reasonable (according to his work). And when you release their property to them, take witness in their presence; and Allah is All-Sufficient in taking account.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
There is a share for men and a share for women from what is left by parents and those nearest related, whether, the property be small or large - a legal share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
And when the relatives and the orphans and Al-Masakin (the poor) are present at the time of division, give them out of the property, and speak to them words of kindness and justice.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let those (executors and guardians) have the same fear in their minds as they would have for their own, if they had left weak offspring behind. So let them fear Allah and speak right words.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Verily, those who unjustly eat up the property of orphans, they eat up only a fire into their bellies, and they will be burnt in the blazing Fire!\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah commands you as regards your children's (inheritance); to the male, a portion equal to that of two females; if (there are) only daughters, two or more, their share is two thirds of the inheritance; if only one, her share is half. For parents, a sixth share of inheritance to each if the deceased left children; if no children, and the parents are the (only) heirs, the mother has a third; if the deceased left brothers or (sisters), the mother has a sixth. (The distribution in all cases is) after the payment of legacies he may have bequeathed or debts. You know not which of them, whether your parents or your children, are nearest to you in benefit, (these fixed shares) are ordained by Allah. And Allah is Ever All-Knower, All-Wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
In that which your wives leave, your share is a half if they have no child; but if they leave a child, you get a fourth of that which they leave after payment of legacies that they may have bequeathed or debts. In that which you leave, their (your wives) share is a fourth if you leave no child; but if you leave a child, they get an eighth of that which you leave after payment of legacies that you may have bequeathed or debts. If the man or woman whose inheritance is in question has left neither ascendants nor descendants, but has left a brother or a sister, each one of the two gets a sixth; but if more than two, they share in a third; after payment of lagacies he (or she) may have bequeathed or debts, so that no loss is caused (to anyone). This is a Commandment from Allah; and Allah is Ever All-Knowing, Most-Forbearing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the limits (set by) Allah (or ordainments as regards laws of inheritance), and whosoever obeys Allah and His Messenger (Muhammad SAW) will be admitted to Gardens under which rivers flow (in Paradise), to abide therein, and that will be the great success.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
And whosoever disobeys Allah and His Messenger (Muhammad SAW), and transgresses His limits, He will cast him into the Fire, to abide therein; and he shall have a disgraceful torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
And those of your women who commit illegal sexual intercourse, take the evidence of four witnesses from amongst you against them; and if they testify, confine them (i.e. women) to houses until death comes to them or Allah ordains for them some (other) way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And the two persons (man and woman) among you who commit illegal sexual intercourse, punish them both. And if they repent (promise Allah that they will never repeat, i.e. commit illegal sexual intercourse and other similar sins) and do righteous good deeds, leave them alone. Surely, Allah is Ever the One Who accepts repentance, (and He is) Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
Allah accepts only the repentance of those who do evil in ignorance and foolishness and repent soon afterwards; it is they to whom Allah will forgive and Allah is Ever All-Knower, All-Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
And of no effect is the repentance of those who continue to do evil deeds until death faces one of them and he says: ``Now I repent;" nor of those who die while they are disbelievers. For them We have prepared a painful torment.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O you who believe! You are forbidden to inherit women against their will, and you should not treat them with harshness, that you may take away part of the Mahr you have given them, unless they commit open illegal sexual intercourse. And live with them honourably. If you dislike them, it may be that you dislike a thing and Allah brings through it a great deal of good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
But if you intend to replace a wife by another and you have given one of them a Cantar (of gold i.e. a great amount) as Mahr, take not the least bit of it back; would you take it wrongfully without a right and (with) a manifest sin?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how could you take it (back) while you have gone in unto each other, and they have taken from you a firm and strong covenant?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And marry not women whom your fathers married, except what has already passed; indeed it was shameful and most hateful, and an evil way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden to you (for marriage) are: your mothers, your daughters, your sisters, your father's sisters, your mother's sisters, your brother's daughters, your sister's daughters, your foster mother who gave you suck, your foster milk suckling sisters, your wives' mothers, your step daughters under your guardianship, born of your wives to whom you have gone in - but there is no sin on you if you have not gone in them (to marry their daughters), - the wives of your sons who (spring) from your own loins, and two sisters in wedlock at the same time, except for what has already passed; verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
Also (forbidden are) women already married, except those (captives and slaves) whom your right hands possess. Thus has Allah ordained for you. All others are lawful, provided you seek (them in marriage) with Mahr (bridal money given by the husband to his wife at the time of marriage) from your property, desiring chastity, not committing illegal sexual intercourse, so with those of whom you have enjoyed sexual relations, give them their Mahr as prescribed; but if after a Mahr is prescribed, you agree mutually (to give more), there is no sin on you. Surely, Allah is Ever All-Knowing, All-Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whoever of you have not the means wherewith to wed free, believing women, they may wed believing girls from among those (captives and slaves) whom your right hands possess, and Allah has full knowledge about your Faith, you are one from another. Wed them with the permission of their own folk (guardians, Auliya' or masters) and give them their Mahr according to what is reasonable; they (the above said captive and slave-girls) should be chaste, not adulterous, nor taking boy-friends. And after they have been taken in wedlock, if they commit illegal sexual intercourse, their punishment is half that for free (unmarried) women. This is for him among you who is afraid of being harmed in his religion or in his body; but it is better for you that you practise self-restraint, and Allah is Oft-Forgiving, Most Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wishes to make clear (what is lawful and what is unlawful) to you, and to show you the ways of those before you, and accept your repentance, and Allah is All-Knower, All-Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
Allah wishes to accept your repentance, but those who follow their lusts, wish that you (believers) should deviate tremendously away from the Right Path.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah wishes to lighten (the burden) for you; and man was created weak (cannot be patient to leave sexual intercourse with woman).\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O you who believe! Eat not up your property among yourselves unjustly except it be a trade amongst you, by mutual consent. And do not kill yourselves (nor kill one another). Surely, Allah is Most Merciful to you.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whoever commits that through aggression and injustice, We shall cast him into the Fire, and that is easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the great sins which you are forbidden to do, We shall remit from you your (small) sins, and admit you to a Noble Entrance (i.e. Paradise).\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And wish not for the things in which Allah has made some of you to excel others. For men there is reward for what they have earned, (and likewise) for women there is reward for what they have earned, and ask Allah of His Bounty. Surely, Allah is Ever All-Knower of everything.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And to everyone, We have appointed heirs of that (property) left by parents and relatives. To those also with whom you have made a pledge (brotherhood), give them their due portion (by Wasiya - wills, etc.). Truly, Allah is Ever a Witness over all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the protectors and maintainers of women, because Allah has made one of them to excel the other, and because they spend (to support them) from their means. Therefore the righteous women are devoutly obedient (to Allah and to their husbands), and guard in the husband's absence what Allah orders them to guard (e.g. their chastity, their husband's property, etc.). As to those women on whose part you see ill-conduct, admonish them (first), (next), refuse to share their beds, (and last) beat them (lightly, if it is useful), but if they return to obedience, seek not against them means (of annoyance). Surely, Allah is Ever Most High, Most Great.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If you fear a breach between them twain (the man and his wife), appoint (two) arbitrators, one from his family and the other from her's; if they both wish for peace, Allah will cause their reconciliation. Indeed Allah is Ever All-Knower, Well-Acquainted with all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Worship Allah and join none with Him in worship, and do good to parents, kinsfolk, orphans, Al-Masakin (the poor), the neighbour who is near of kin, the neighbour who is a stranger, the companion by your side, the wayfarer (you meet), and those (slaves) whom your right hands possess. Verily, Allah does not like such as are proud and boastful;\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Those who are miserly and enjoin miserliness on other men and hide what Allah has bestowed upon them of His Bounties. And We have prepared for the disbelievers a disgraceful torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And (also) those who spend of their substance to be seen of men, and believe not in Allah and the Last Day [they are the friends of Shaitan (Satan)], and whoever takes Shaitan (Satan) as an intimate; then what a dreadful intimate he has!\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what loss have they if they had believed in Allah and in the Last Day, and they spend out of what Allah has given them for sustenance? And Allah is Ever All-Knower of them.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Surely! Allah wrongs not even of the weight of an atom (or a small ant), but if there is any good (done), He doubles it, and gives from Him a great reward.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How (will it be) then, when We bring from each nation a witness and We bring you (O Muhammad SAW) as a witness against these people?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that day those who disbelieved and disobeyed the Messenger (Muhammad SAW) will wish that they were buried in the earth, but they will never be able to hide a single fact from Allah.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O you who believe! Approach not As-Salat (the prayer) when you are in a drunken state until you know (the meaning) of what you utter, nor when you are in a state of Janaba, (i.e. in a state of sexual impurity and have not yet taken a bath) except when travelling on the road (without enough water, or just passing through a mosque), till you wash your whole body. And if you are ill, or on a journey, or one of you comes after answering the call of nature, or you have been in contact with women (by sexual relations) and you find no water, perform Tayammum with clean earth and rub therewith your faces and hands (Tayammum). Truly, Allah is Ever Oft-Pardoning, Oft-Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not seen those who were given a portion of the book (the Jews), purchasing the wrong path, and wish that you should go astray from the Right Path?\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
Allah has full knowledge of your enemies, and Allah is Sufficient as a Wali (Protector), and Allah is Sufficient as a Helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Among those who are Jews, there are some who displace words from (their) right places and say: ``We hear your word (O Muhammad SAW) and disobey," and ``Hear and let you (O Muhammad SAW) hear nothing." And Ra'ina with a twist of their tongues and as a mockery of the religion (Islam). And if only they had said: ``We hear and obey", and ``Do make us understand," it would have been better for them, and more proper, but Allah has cursed them for their disbelief, so they believe not except a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O you who have been given the Scripture (Jews and Christians)! Believe in what We have revealed (to Muhammad SAW) confirming what is (already) with you, before We efface faces (by making them like the back of necks; without nose, mouth, eyes, etc.) and turn them hindwards, or curse them as We cursed the Sabbath-breakers. And the Commandment of Allah is always executed.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Verily, Allah forgives not that partners should be set up with him in worship, but He forgives except that (anything else) to whom He pleases, and whoever sets up partners with Allah in worship, he has indeed invented a tremendous sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not seen those who claim sanctity for themselves. Nay - but Allah sanctifies whom He pleases, and they will not be dealt with injustice even equal to the extent of a Fatila (A scalish thread in the long slit of a date-stone).\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Look, how they invent a lie against Allah, and enough is that as a manifest sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not seen those who were given a portion of the Scripture? They believe in Jibt and Taghut and say to the disbelievers that they are better guided as regards the way than the believers (Muslims).\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
They are those whom Allah has cursed, and he whom Allah curses, you will not find for him (any) helper,\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or have they a share in the dominion? Then in that case they would not give mankind even a Naqira (speck on the back of a date-stone).\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy men (Muhammad SAW and his followers) for what Allah has given them of His Bounty? Then We had already given the family of Ibrahim (Abraham) the Book and Al-Hikmah (As-Sunnah - Divine Inspiration to those Prophets not written in the form of a book), and conferred upon them a great kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
Of them were (some) who believed in him (Muhammad SAW), and of them were (some) who averted their faces from him (Muhammad SAW); and enough is Hell for burning (them).\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Surely! Those who disbelieved in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) We shall burn them in Fire. As often as their skins are roasted through, We shall change them for other skins that they may taste the punishment. Truly, Allah is Ever Most Powerful, All-Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
But those who believe (in the Oneness of Allah - Islamic Monotheism) and do deeds of righteousness, We shall admit them to Gardens under which rivers flow (Paradise), abiding therein forever. Therein they shall have Azwajun Mutahharatun [purified mates or wives (having no menses, stools, urine, etc.)] and We shall admit them to shades wide and ever deepening (Paradise).\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Verily! Allah commands that you should render back the trusts to those, to whom they are due; and that when you judge between men, you judge with justice. Verily, how excellent is the teaching which He (Allah) gives you! Truly, Allah is Ever All-Hearer, All-Seer.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O you who believe! Obey Allah and obey the Messenger (Muhammad SAW), and those of you (Muslims) who are in authority. (And) if you differ in anything amongst yourselves, refer it to Allah and His Messenger (SAW), if you believe in Allah and in the Last Day. That is better and more suitable for final determination.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Have you seen those (hyprocrites) who claim that they believe in that which has been sent down to you, and that which was sent down before you, and they wish to go for judgement (in their disputes) to the Taghut (false judges, etc.) while they have been ordered to reject them. But Shaitan (Satan) wishes to lead them far astray.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said to them: ``Come to what Allah has sent down and to the Messenger (Muhammad SAW)," you (Muhammad SAW) see the hypocrites turn away from you (Muhammad SAW) with aversion.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How then, when a catastrophe befalls them because of what their hands have sent forth, they come to you swearing by Allah, ``We meant no more than goodwill and conciliation!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
They (hypocrites) are those of whom Allah knows what is in their hearts; so turn aside from them (do not punish them) but admonish them, and speak to them an effective word (i.e. to believe in Allah, worship Him, obey Him, and be afraid of Him) to reach their innerselves.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We sent no Messenger, but to be obeyed by Allah's Leave. If they (hypocrites), when they had been unjust to themselves, had come to you (Muhammad SAW) and begged Allah's Forgiveness, and the Messenger had begged forgiveness for them: indeed, they would have found Allah All-Forgiving (One Who accepts repentance), Most Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they can have no Faith, until they make you (O Muhammad SAW) judge in all disputes between them, and find in themselves no resistance against your decisions, and accept (them) with full submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
And if We had ordered them (saying), ``Kill yourselves (i.e. the innnocent ones kill the guilty ones) or leave your homes," very few of them would have done it; but if they had done what they were told, it would have been better for them, and would have strengthened their (Faith);\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And indeed We should then have bestowed upon them a great reward from Ourselves.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And indeed We should have guided them to a Straight Way.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
And whoso obeys Allah and the Messenger (Muhammad SAW), then they will be in the company of those on whom Allah has bestowed His Grace, of the Prophets, the Siddiqun (those followers of the Prophets who were first and foremost to believe in them, like Abu Bakr As-Siddiq), the martyrs, and the righteous. And how excellent these companions are!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
Such is the Bounty from Allah, and Allah is Sufficient as All-Knower.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O you who believe! Take your precautions, and either go forth (on an expedition) in parties, or go forth all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
There is certainly among you he who would linger behind (from fighting in Allah's Cause). If a misfortune befalls you, he says, ``Indeed Allah has favoured me in that I was not present among them."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But if a bounty (victory and booty) comes to you from Allah, he would surely say - as if there had never been ties of affection between you and him - ``Oh! I wish I had been with them; then I would have achieved a great success (a good share of booty)."\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let those (believers) who sell the life of this world for the Hereafter fight in the Cause of Allah, and whoso fights in the Cause of Allah, and is killed or gets victory, We shall bestow on him a great reward.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And what is wrong with you that you fight not in the Cause of Allah, and for those weak, ill-treated and oppressed among men, women, and children, whose cry is: ``Our Lord! Rescue us from this town whose people are oppressors; and raise for us from You one who will protect, and raise for us from You one who will help."\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe, fight in the Cause of Allah, and those who disbelieve, fight in the cause of Taghut (Satan, etc.). So fight you against the friends of Shaitan (Satan); Ever feeble indeed is the plot of Shaitan (Satan).\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not seen those who were told to hold back their hands (from fighting) and perform As-Salat (Iqamat-as-Salat), and give Zakat, but when the fighting was ordained for them, behold! a section of them fear men as they fear Allah or even more. They say: ``Our Lord! Why have you ordained for us fighting? Would that you had granted us respite for a short period?" Say: ``Short is the enjoyment of this world. The Hereafter is (far) better for him who fears Allah, and you shall not be dealt with unjustly even equal to the Fatila (a scalish thread in the long slit of a date-stone).\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
``Wheresoever you may be, death will overtake you even if you are in fortresses built up strong and high!" And if some good reaches them, they say, ``This is from Allah," but if some evil befalls them, they say, ``This is from you (O Muhammad SAW)." Say: ``All things are from Allah," so what is wrong with these people that they fail to understand any word?\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever of good reaches you, is from Allah, but whatever of evil befalls you, is from yourself. And We have sent you (O Muhammad SAW) as a Messenger to mankind, and Allah is Sufficient as a Witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
He who obeys the Messenger (Muhammad SAW), has indeed obeyed Allah, but he who turns away, then we have not sent you (O Muhammad SAW) as a watcher over them.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They say: ``We are obedient," but when they leave you (Muhammad SAW), a section of them spend all night in planning other than what you say. But Allah records their nightly (plots). So turn aside from them (do not punish them), and put your trust in Allah. And Allah is Ever All-Sufficient as a Disposer of affairs.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Do they not then consider the Quran carefully? Had it been from other than Allah, they would surely have found therein much contradictions.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When there comes to them some matter touching (public) safety or fear, they make it known (among the people), if only they had referred it to the Messenger or to those charged with authority among them, the proper investigators would have understood it from them (directly). Had it not been for the Grace and Mercy of Allah upon you, you would have followed Shaitan (Satan), save a few of you.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Then fight (O Muhammad SAW) in the Cause of Allah, you are not tasked (held responsible) except for yourself, and incite the believers (to fight along with you), it may be that Allah will restrain the evil might of the disbelievers. And Allah is Stronger in Might and Stronger in punishing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whosoever intercedes for a good cause will have the reward thereof, and whosoever intercedes for an evil cause will have a share in its burden. And Allah is Ever All-Able to do (and also an All-Witness to) everything.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When you are greeted with a greeting, greet in return with what is better than it, or (at least) return it equally. Certainly, Allah is Ever a Careful Account Taker of all things.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! La ilaha illa Huwa (none has the right to be worshipped but He). Surely, He will gather you together on the Day of Resurrection about which there is no doubt. And who is truer in statement than Allah?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
Then what is the matter with you that you are divided into two parties about the hypocrites? Allah has cast them back (to disbelief) because of what they have earned. Do you want to guide him whom Allah has made to go astray? And he whom Allah has made to go astray, you will never find for him any way (of guidance).\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you reject Faith, as they have rejected (Faith), and thus that you all become equal (like one another). So take not Auliya' (protectors or friends) from them, till they emigrate in the Way of Allah (to Muhammad SAW). But if they turn back (from Islam), take (hold) of them and kill them wherever you find them, and take neither Auliya' (protectors or friends) nor helpers from them.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who join a group, between you and whom there is a treaty (of peace), or those who approach you with their breasts restraining from fighting you as well as fighting their own people. Had Allah willed, indeed He would have given them power over you, and they would have fought you. So if they withdraw from you, and fight not against you, and offer you peace, then Allah has opened no way for you against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others that wish to have security from you and security from their people. Every time they are sent back to temptation, they yield thereto. If they withdraw not from you, nor offer you peace, nor restrain their hands, take (hold) of them and kill them wherever you find them. In their case, We have provided you with a clear warrant against them.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to kill a believer except (that it be) by mistake, and whosoever kills a believer by mistake, (it is ordained that) he must set free a believing slave and a compensation (blood money, i.e. Diya) be given to the deceased's family, unless they remit it. If the deceased belonged to a people at war with you and he was a believer; the freeing of a believing slave (is prescribed), and if he belonged to a people with whom you have a treaty of mutual alliance, compensation (blood money - Diya) must be paid to his family, and a believing slave must be freed. And whoso finds this (the penance of freeing a slave) beyond his means, he must fast for two consecutive months in order to seek repentance from Allah. And Allah is Ever All-Knowing, All-Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And whoever kills a believer intentionally, his recompense is Hell to abide therein, and the Wrath and the Curse of Allah are upon him, and a great punishment is prepared for him.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O you who believe! When you go (to fight) in the Cause of Allah, verify (the truth), and say not to anyone who greets you (by embracing Islam): ``You are not a believer"; seeking the perishable goods of the worldly life. There are much more profits and booties with Allah. Even as he is now, so were you yourselves before till Allah conferred on you His Favours (i.e. guided you to Islam), therefore, be cautious in discrimination. Allah is Ever Well-Aware of what you do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are those of the believers who sit (at home), except those who are disabled (by injury or are blind or lame, etc.), and those who strive hard and fight in the Cause of Allah with their wealth and their lives. Allah has preferred in grades those who strive hard and fight with their wealth and their lives above those who sit (at home). Unto each, Allah has promised good (Paradise), but Allah has preferred those who strive hard and fight, above those who sit (at home) by a huge reward;\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Degrees of (higher) grades from Him, and Forgiveness and Mercy. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
Verily! As for those whom the angels take (in death) while they are wronging themselves (as they stayed among the disbelievers even though emigration was obligatory for them), they (angels) say (to them): ``In what (condition) were you?" They reply: ``We were weak and oppressed on earth." They (angels) say: ``Was not the earth of Allah spacious enough for you to emigrate therein?" Such men will find their abode in Hell - What an evil destination!\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except the weak ones among men, women and children who cannot devise a plan, nor are they able to direct their way.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
For these there is hope that Allah will forgive them, and Allah is Ever Oft Pardoning, Oft-Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
He who emigrates (from his home) in the Cause of Allah, will find on earth many dwelling places and plenty to live by. And whosoever leaves his home as an emigrant unto Allah and His Messenger, and death overtakes him, his reward is then surely incumbent upon Allah. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you (Muslims) travel in the land, there is no sin on you if you shorten your Salat (prayer) if you fear that the disbelievers may attack you, verily, the disbelievers are ever unto you open enemies.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
When you (O Messenger Muhammad SAW) are among them, and lead them in As-Salat (the prayer), let one party of them stand up [in Salat (prayer)] with you taking their arms with them; when they finish their prostrations, let them take their positions in the rear and let the other party come up which has not yet prayed, and let them pray with you taking all the precautions and bearing arms. Those who disbelieve wish, if you were negligent of your arms and your baggage, to attack you in a single rush, but there is no sin on you if you put away your arms because of the inconvenience of rain or because you are ill, but take every precaution for yourselves. Verily, Allah has prepared a humiliating torment for the disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have finished As-Salat (the prayer - congregational), remember Allah standing, sitting down, and lying down on your sides, but when you are free from danger, perform As-Salat (Iqamat-as- Salat). Verily, the prayer is enjoined on the believers at fixed hours.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And don't be weak in the pursuit of the enemy; if you are suffering (hardships) then surely, they (too) are suffering (hardships) as you are suffering, but you have a hope from Allah (for the reward, i.e. Paradise) that for which they hope not, and Allah is Ever All-Knowing, All-Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Surely, We have sent down to you (O Muhammad SAW) the Book (this Quran) in truth that you might judge between men by that which Allah has shown you (i.e. has taught you through Divine Inspiration), so be not a pleader for the treacherous.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And seek the Forgiveness of Allah, certainly, Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And argue not on behalf of those who deceive themselves. Verily, Allah does not like anyone who is a betrayer of his trust, and indulges in crime.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They may hide (their crimes) from men, but they cannot hide (them) from Allah, for He is with them (by His Knowledge), when they plot by night in words that He does not approve, And Allah ever encompasses what they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Lo! You are those who have argued for them in the life of this world, but who will argue for them on the Day of Resurrection against Allah, or who will then be their defender?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
And whoever does evil or wrongs himself but afterwards seeks Allah's Forgiveness, he will find Allah Oft-Forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And whoever earns sin, he earns it only against himself. And Allah is Ever All-Knowing, All-Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whoever earns a fault or a sin and then throws it on to someone innocent, he has indeed burdened himself with falsehood and a manifest sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
Had not the Grace of Allah and His Mercy been upon you (O Muhammad SAW), a party of them would certainly have made a decision to mislead you, but (in fact) they mislead none except their own selves, and no harm can they do to you in the least. Allah has sent down to you the Book (The Quran), and Al-Hikmah (Islamic laws, knowledge of legal and illegal things i.e. the Prophet's Sunnah - legal ways), and taught you that which you knew not. And Ever Great is the Grace of Allah unto you (O Muhammad SAW).\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
There is no good in most of their secret talks save (in) him who orders Sadaqah (charity in Allah's Cause), or Ma'ruf (Islamic Monotheism and all the good and righteous deeds which Allah has ordained), or conciliation between mankind, and he who does this, seeking the good Pleasure of Allah, We shall give him a great reward.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whoever contradicts and opposes the Messenger (Muhammad SAW) after the right path has been shown clearly to him, and follows other than the believers' way. We shall keep him in the path he has chosen, and burn him in Hell - what an evil destination.\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Verily! Allah forgives not (the sin of) setting up partners in worship with Him, but He forgives whom he pleases sins other than that, and whoever sets up partners in worship with Allah, has indeed strayed far away.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They (all those who worship others than Allah) invoke nothing but female deities besides Him (Allah), and they invoke nothing but Shaitan (Satan), a persistent rebel!\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Allah cursed him. And he [Shaitan (Satan)] said: ``I will take an appointed portion of your slaves;\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
Verily, I will mislead them, and surely, I will arouse in them false desires; and certainly, I will order them to slit the ears of cattle, and indeed I will order them to change the nature created by Allah." And whoever takes Shaitan (Satan) as a Wali (protector or helper) instead of Allah, has surely suffered a manifest loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
He [Shaitan (Satan)] makes promises to them, and arouses in them false desires; and Shaitan's (Satan) promises are nothing but deceptions.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
The dwelling of such (people) is Hell, and they will find no way of escape from it.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But those who believe (in the Oneness of Allah - Islamic Monotheism) and do deeds of righteousness, We shall admit them to the Gardens under which rivers flow (i.e. in Paradise) to dwell therein forever. Allah's Promise is the Truth, and whose words can be truer than those of Allah? (Of course, none).\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It will not be in accordance with your desires (Muslims), nor those of the people of the Scripture (Jews and Christians), whosoever works evil, will have the recompense thereof, and he will not find any protector or helper besides Allah.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whoever does righteous good deeds, male or female, and is a true believer in the Oneness of Allah (Muslim), such will enter Paradise and not the least injustice, even to the size of a Naqira (speck on the back of a date-stone), will be done to them.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who can be better in religion than one who submits his face (himself) to Allah (i.e. follows Allah's Religion of Islamic Monotheism); and he is a Muhsin (a good-doer - see V. 2:112). And follows the religion of Ibrahim (Abraham) Hanifa (Islamic Monotheism - to worship none but Allah Alone). And Allah did take Ibrahim (Abraham) as a Khalil (an intimate friend).\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
And to Allah belongs all that is in the heavens and all that is in the earth. And Allah is Ever Encompassing all things.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They ask your legal instruction concerning women, say: Allah instructs you about them, and about what is recited unto you in the Book concerning the orphan girls whom you give not the prescribed portions (as regards Mahr and inheritance) and yet whom you desire to marry, and (concerning) the children who are weak and oppressed, and that you stand firm for justice to orphans. And whatever good you do, Allah is Ever All-Aware of it.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
And if a woman fears cruelty or desertion on her husband's part, there is no sin on them both if they make terms of peace between themselves; and making peace is better. And human inner-selves are swayed by greed. But if you do good and keep away from evil, verily, Allah is Ever Well-Acquainted with what you do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will never be able to do perfect justice between wives even if it is your ardent desire, so do not incline too much to one of them (by giving her more of your time and provision) so as to leave the other hanging (i.e. neither divorced nor married). And if you do justice, and do all that is right and fear Allah by keeping away from all that is wrong, then Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate (by divorce), Allah will provide abundance for everyone of them from His Bounty. And Allah is Ever All-Sufficient for His creatures' need, All-Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
And to Allah belongs all that is in the heavens and all that is in the earth. And verily, We have recommended to the people of the Scripture before you, and to you (O Muslims) that you (all) fear Allah, and keep your duty to Him, But if you disbelieve, then unto Allah belongs all that is in the heavens and all that is in the earth, and Allah is Ever Rich (Free of all wants), Worthy of all praise.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And to Allah belongs all that is in the heavens and all that is in the earth. And Allah is Ever All-Sufficient as a Disposer of affairs.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He wills, He can take you away, O people, and bring others. And Allah is Ever All-Potent over that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoever desires a reward in this life of the world, then with Allah (Alone and none else) is the reward of this worldly life and of the Hereafter. And Allah is Ever All-Hearer, All-Seer.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O you who believe! Stand out firmly for justice, as witnesses to Allah, even though it be against yourselves, or your parents, or your kin, be he rich or poor, Allah is a Better Protector to both (than you). So follow not the lusts (of your hearts), lest you may avoid justice, and if you distort your witness or refuse to give it, verily, Allah is Ever Well-Acquainted with what you do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O you who believe! Believe in Allah, and His Messenger (Muhammad SAW), and the Book (the Quran) which He has sent down to His Messenger, and the Scripture which He sent down to those before (him), and whosoever disbelieves in Allah, His Angels, His Books, His Messengers, and the Last Day, then indeed he has strayed far away.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Verily, those who believe, then disbelieve, then believe (again), and (again) disbelieve, and go on increasing in disbelief; Allah will not forgive them, nor guide them on the (Right) Way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give to the hypocrites the tidings that there is for them a painful torment.\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take disbelievers for Auliya' (protectors or helpers or friends) instead of believers, do they seek honour, power and glory with them? Verily, then to Allah belongs all honour, power and glory.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
And it has already been revealed to you in the Book (this Quran) that when you hear the Verses of Allah being denied and mocked at, then sit not with them, until they engage in a talk other than that; (but if you stayed with them) certainly in that case you would be like them. Surely, Allah will collect the hypocrites and disbelievers all together in Hell,\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those (hyprocrites) who wait and watch about you; if you gain a victory from Allah, they say: ``Were we not with you," but if the disbelievers gain a success, they say (to them): ``Did we not gain mastery over you and did we not protect you from the believers?" Allah will judge between you (all) on the Day of Resurrection. And never will Allah grant to the disbelievers a way (to triumph) over the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Verily, the hypocrites seek to deceive Allah, but it is He Who deceives them. And when they stand up for As-Salat (the prayer), they stand with laziness and to be seen of men, and they do not remember Allah but little.\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
(They are) swaying between this and that, belonging neither to these nor to those, and he whom Allah sends astray, you will not find for him a way (to the truth - Islam).\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O you who believe! Take not for Auliya' (protectors or helpers or friends) disbelievers instead of believers. Do you wish to offer Allah a manifest proof against yourselves?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
vVerily, the hyprocrites will be in the lowest depths (grade) of the Fire; no helper will you find for them.\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except those who repent (from hypocrisy), do righteous good deeds, hold fast to Allah, and purify their religion for Allah (by worshipping none but Allah, and do good for Allah's sake only, not to show-off), then they will be with the believers. And Allah will grant to the believers a great reward.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
Why should Allah punish you if you have thanked (Him) and have believed in Him. And Allah is Ever All-Appreciative (of good), All-Knowing.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not like that the evil should be uttered in public except by him who has been wronged. And Allah is Ever All-Hearer, All-Knower.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
Whether you (mankind) disclose (by good words of thanks) a good deed (done to you in the form of a favour by someone), or conceal it, or pardon an evil,  verily, Allah is Ever Oft­Pardoning, All­Powerful.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Verily, those who disbelieve in Allah and His Messengers and wish to make distinction between Allah and His Messengers (by believing in Allah and disbelieving in His Messengers) saying, ``We believe in some but reject others," and wish to adopt a way in between.\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
They are in truth disbelievers. And We have prepared for the disbelievers a humiliating torment.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in Allah and His Messengers and make no distinction between any of them (Messengers), We shall give them their rewards, and Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The people of the Scripture (Jews) ask you to cause a book to descend upon them from heaven. Indeed they asked Musa (Moses) for even greater than that, when they said: ``Show us Allah in public," but they were struck with thunder clap and lightning for their wickedness. Then they worshipped the calf even after clear proofs, evidences, and signs had come to them. (Even) so We forgave them. And We gave Musa (Moses) a clear proof of authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And for their covenant, We raised over them the Mount and (on the other occasion) We said: ``Enter the gate prostrating (or bowing) with humility;" and We commanded them: ``Transgress not (by doing worldly works on) the Sabbath (Saturday)." And We took from them a firm covenant.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
Because of their breaking the covenant, and of their rejecting the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, and of their killing the Prophets unjustly, and of their saying: ``Our hearts are wrapped (with coverings, i.e. we do not understand what the Messengers say)" - nay, Allah has set a seal upon their hearts because of their disbelief, so they believe not but a little.\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And because of their (Jews) disbelief and uttering against Maryam (Mary) a grave false charge (that she has committed illegal sexual intercourse);\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And because of their saying (in boast), ``We killed Messiah 'Iesa (Jesus), son of Maryam (Mary), the Messenger of Allah," - but they killed him not, nor crucified him, but the resemblance of 'Iesa (Jesus) was put over another man (and they killed that man), and those who differ therein are full of doubts. They have no (certain) knowledge, they follow nothing but conjecture. For surely; they killed him not [i.e. 'Iesa (Jesus), son of Maryam (Mary)]:\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
But Allah raised him ['Iesa (Jesus)] up (with his body and soul) unto Himself (and he is in the heavens). And Allah is Ever All-Powerful, All-Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
And there is none of the people of the Scripture (Jews and Christians), but must believe in him ['Iesa (Jesus), son of Maryam (Mary), as only a Messenger of Allah and a human being], before his ['Iesa (Jesus) or a Jew's or a Christian's] death (at the time of the appearance of the angel of death). And on the Day of Resurrection, he ['Iesa (Jesus)] will be a witness against them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
For the wrong-doing of the Jews, We made unlawful to them certain good foods which has been lawful to them, and for their hindering many from Allah's Way;\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And their taking of Riba (usury) though they were forbidden from taking it and their devouring of men's substance wrongfully (bribery, etc.). And We have prepared for the disbelievers among them a painful torment.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those among them who are well-grounded in knowledge, and the believers, believe in what has been sent down to you (Muhammad SAW) and what was sent down before you, and those who perform As-Salat (Iqamat-as-Salat), and give Zakat and believe in Allah and in the Last Day, it is they to whom We shall give a great reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
Verily, We have inspired you (O Muhammad SAW) as We inspired Nuh (Noah) and the Prophets after him; We (also) inspired Ibrahim (Abraham), Isma'il (Ishmael), Ishaque (Isaac), Ya'qub (Jacob), and Al-Asbat [the twelve sons of Ya'qub (Jacob)], 'Iesa (Jesus), Ayub (Job), Yunus (Jonah), Harun (Aaron), and Sulaiman (Solomon), and to Dawud (David) We gave the Zabur (Psalms).\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
And Messengers We have mentioned to you before, and Messengers We have not mentioned to you, - and to Musa (Moses) Allah spoke directly.\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers as bearers of good news as well as of warning in order that mankind should have no plea against Allah after the Messengers. And Allah is Ever All-Powerful, All-Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah bears witness to that which He has sent down (the Quran) unto you (O Muhammad SAW), He has sent it down with His Knowledge, and the angels bear witness. And Allah is All-Sufficient as a Witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Verily, those who disbelieve [by concealing the truth about Prophet Muhammad SAW and his message of true Islamic Monotheism written with them in the Taurat (Torah) and the Injeel (Gospel)] and prevent (mankind) from the Path of Allah (Islamic Monotheism), they have certainly strayed far away. (Tafsir Al-Qurtubi). (See V. 7:157)\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Verily, those who disbelieve and did wrong [by concealing the truth about Prophet Muhammad SAW and his message of true Islamic Monotheism written with them in the Taurat (Torah) and the Injeel (Gospel)], Allah will not forgive them, nor will He guide them to any way, - (Tafsir Al-Qurtubi).\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the way of Hell, to dwell therein forever, and this is ever easy for Allah.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O mankind! Verily, there has come to you the Messenger (Muhammad SAW) with the truth from your Lord, so believe in him, it is better for you. But if you disbelieve, then certainly to Allah belongs all that is in the heavens and the earth. And Allah is Ever All-Knowing, All-Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O people of the Scripture (Jews and Christians)! Do not exceed the limits in your religion, nor say of Allah aught but the truth. The Messiah 'Iesa (Jesus), son of Maryam (Mary), was (no more than) a Messenger of Allah and His Word, ("Be!" - and he was) which He bestowed on Maryam (Mary) and a spirit (Ruh) created by Him; so believe in Allah and His Messengers. Say not: ``Three (trinity)!" Cease! (it is) better for you. For Allah is (the only) One Ilah (God), Glory be to Him (Far Exalted is He) above having a son. To Him belongs all that is in the heavens and all that is in the earth. And Allah is All-Sufficient as a Disposer of affairs.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah will never be proud to reject to be a slave to Allah, nor the angels who are near (to Allah). And whosoever rejects His worship and is proud, then He will gather them all together unto Himself.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
So, as for those who believed (in the Oneness of Allah - Islamic Monotheism) and did deeds of righteousness, He will give their (due) rewards, and more out of His Bounty. But as for those who refuse His worship and were proud, He will punish them with a painful torment. And they will not find for themselves besides Allah any protector or helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind! Verily, there has come to you a convincing proof (Prophet Muhammad SAW) from your Lord, and We sent down to you a manifest light (this Quran).\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
So, as for those who believed in Allah and held fast to Him, He will admit them to His Mercy and Grace (i.e. Paradise), and guide them to Himself by a Straight Path.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask you for a legal verdict. Say: ``Allah directs (thus) about Al-Kalalah (those who leave neither descendants nor ascendants as heirs). If it is a man that dies, leaving a sister, but no child, she shall have half the inheritance. If (such a deceased was) a woman, who left no child, her brother takes her inheritance. If there are two sisters, they shall have two-thirds of the inheritance; if there are brothers and sisters, the male will have twice the share of the female. (Thus) does Allah makes clear to you (His Law) lest you go astray. And Allah is the All-Knower of everything."\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O you who believe! Fulfill (your) obligations. Lawful to you (for food) are all the beasts of cattle except that which will be announced to you (herein), game (also) being unlawful when you assume Ihram for Hajj or 'Umrah (pilgrimage). Verily, Allah commands that which He wills.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O you who believe! Violate not the sanctity of the Symbols of Allah, nor of the Sacred Month, nor of the animals brought for sacrifice, nor the garlanded people or animals, etc. [Marked by the garlands on their necks made from the outer part of the tree-stems (of Makkah) for their security], nor the people coming to the Sacred House (Makkah), seeking the bounty and good pleasure of their Lord. But when you finish the Ihram (of Hajj or 'Umrah), you may hunt, and let not the hatred of some people in (once) stopping you from Al-Masjid-al-Haram (at Makkah) lead you to transgression (and hostility on your part). Help you one another in Al-Birr and At-Taqwa (virtue, righteousness and piety); but do not help one another in sin and transgression. And fear Allah. Verily, Allah is Severe in punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden to you (for food) are: Al-Maytatah (the dead animals - cattle-beast not slaughtered), blood, the flesh of swine, and the meat of that which has been slaughtered as a sacrifice for others than Allah, or has been slaughtered for idols, etc., or on which Allah's Name has not been mentioned while slaughtering, and that which has been killed by strangling, or by a violent blow, or by a headlong fall, or by the goring of horns - and that which has been (partly) eaten by a wild animal - unless you are able to slaughter it (before its death) - and that which is sacrificed (slaughtered) on An-Nusub (stone altars). (Forbidden) also is to use arrows seeking luck or decision, (all) that is Fisqun (disobedience of Allah and sin). This day, those who disbelieved have given up all hope of your religion, so fear them not, but fear Me. This day, I have perfected your religion for you, completed My Favour upon you, and have chosen for you Islam as your religion. But as for him who is forced by severe hunger, with no inclination to sin (such can eat these above-mentioned meats), then surely, Allah is Oft-Forgiving, Most Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you (O Muhammad SAW) what is lawful for them (as food). Say: ``Lawful unto you are At-Tayyibat [all kind of Halal (lawful-good) foods which Allah has made lawful (meat of slaughtered eatable animals, milk products, fats, vegetables and fruits, etc.)]. And those beasts and birds of prey which you have trained as hounds, training and teaching them (to catch) in the manner as directed to you by Allah; so eat of what they catch for you, but pronounce the Name of Allah over it, and fear Allah. Verily, Allah is Swift in reckoning."\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
Made lawful to you this day are At-Tayyibat [all kinds of Halal (lawful) foods, which Allah has made lawful (meat of slaughtered eatable animals, etc., milk products, fats, vegetables and fruits, etc.). The food (slaughtered cattle, eatable animals, etc.) of the people of the Scripture (Jews and Christians) is lawful to you and yours is lawful to them. (Lawful to you in marriage) are chaste women from the believers and chaste women from those who were given the Scripture (Jews and Christians) before your time, when you have given their due Mahr (bridal money given by the husband to his wife at the time of marriage), desiring chastity (i.e. taking them in legal wedlock) not committing illegal sexual intercourse, nor taking them as girl-friends. And whosoever disbelieves in the Oneness of Allah and in all the other Articles of Faith [i.e. His (Allah's), Angels, His Holy Books, His Messengers, the Day of Resurrection and Al-Qadar (Divine Preordainments)], then fruitless is his work, and in the Hereafter he will be among the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O you who believe! When you intend to offer As-Salat (the prayer), wash your faces and your hands (forearms) up to the elbows, rub (by passing wet hands over) your heads, and (wash) your feet up to ankles. If you are in a state of Janaba (i.e. had a sexual discharge), purify yourself (bathe your whole body). But if you are ill or on a journey or any of you comes from answering the call of nature, or you have been in contact with women (i.e. sexual intercourse) and you find no water, then perform Tayammum with clean earth and rub therewith your faces and hands. Allah does not want to place you in difficulty, but He wants to purify you, and to complete His Favour on you that you may be thankful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember Allah's Favour upon you and His Covenant with which He bound you when you said: ``We hear and we obey." And fear Allah. Verily, Allah is All-Knower of the secrets of (your) breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O you who believe! Stand out firmly for Allah and be just witnesses and let not the enmity and hatred of others make you avoid justice. Be just: that is nearer to piety, and fear Allah. Verily, Allah is Well-Acquainted with what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah has promised those who believe (in the Oneness of Allah - Islamic Monotheism) and do deeds of righteousness, that for them there is forgiveness and a great reward (i.e. Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
They who disbelieve and deny our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) are those who will be the dwellers of the Hell-fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O you who believe! Remember the Favour of Allah unto you when some people desired (made a plan) to stretch out their hands against you, but (Allah) withheld their hands from you. So fear Allah. And in Allah let believers put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Indeed Allah took the covenant from the Children of Israel (Jews), and We appointed twelve leaders among them. And Allah said: ``I am with you if you perform As-Salat (Iqamat-as-Salat) and give Zakat and believe in My Messengers; honour and assist them, and lend to Allah a good loan. Verily, I will remit your sins and admit you to Gardens under which rivers flow (in Paradise). But if any of you after this, disbelieved, he has indeed gone astray from the Straight Path."\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
So because of their breach of their covenant, We cursed them, and made their hearts grow hard. They change the words from their (right) places and have abandoned a good part of the Message that was sent to them. And you will not cease to discover deceit in them, except a few of them. But forgive them, and overlook (their misdeeds). Verily, Allah loves Al-Muhsinun (good-doers - see V. 2:112).\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And from those who call themselves Christians, We took their covenant, but they have abandoned a good part of the Message that was sent to them. So We planted amongst them enmity and hatred till the Day of Resurrection (when they discarded Allah's Book, disobeyed Allah's Messengers and His Orders and transgressed beyond bounds in Allah's disobedience), and Allah will inform them of what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O people of the Scripture (Jews and Christians)! Now has come to you Our Messenger (Muhammad SAW) explaining to you much of that which you used to hide from the Scripture and passing over (i.e. leaving out without explaining) much. Indeed, there has come to you from Allah a light (Prophet Muhammad SAW) and a plain Book (this Quran).\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
Wherewith Allah guides all those who seek His Good Pleasure to ways of peace, and He brings them out of darkness by His Will unto light and guides them to a Straight Way (Islamic Monotheism).\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
Surely, in disbelief are they who say that Allah is the Messiah, son of Maryam (Mary). Say (O Muhammad SAW): ``Who then has the least power against Allah, if He were to destroy the Messiah, son of Maryam (Mary), his mother, and all those who are on the earth together?" And to Allah belongs the dominion of the heavens and the earth, and all that is between them. He creates what He wills. And Allah is Able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
And (both) the Jews and the Christians say: ``We are the children of Allah and His loved ones." Say: ``Why then does He punish you for your sins?" Nay, you are but human beings, of those He has created, He forgives whom He wills and He punishes whom He wills. And to Allah belongs the dominion of the heavens and the earth and all that is between them, and to Him is the return (of all).\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O people of the Scripture (Jews and Christians)! Now has come to you Our Messenger (Muhammad SAW) making (things) clear unto you, after a break in (the series of) Messengers, lest you say: ``There came unto us no bringer of glad tidings and no warner." But now has come unto you a bringer of glad tidings and a warner. And Allah is Able to do all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And (remember) when Musa (Moses) said to his people: ``O my people! Remember the Favour of Allah to you, when He made Prophets among you, made you kings, and gave you what He had not given to any other among the 'Alamin (mankind and jinns, in the past)."\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
``O my people! Enter the holy land (Palestine) which Allah has assigned to you, and turn not back (in flight) for then you will be returned as losers."\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said: ``O Musa (Moses)! In it (this holy land) are a people of great strength, and we shall never enter it, till they leave it; when they leave, then we will enter."\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Two men of those who feared (Allah and) on whom Allah had bestowed His Grace [they were Yusha' (Joshua) and Kalab (Caleb)] said: ``Assault them through the gate, for when you are in, victory will be yours, and put your trust in Allah if you are believers indeed."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: ``O Musa (Moses)! We shall never enter it as long as they are there. So go you and your Lord and fight you two, we are sitting right here."\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He [Musa (Moses)] said: ``O my Lord! I have power only over myself and my brother, so separate us from the people who are the Fasiqun (rebellious and disobedient to Allah)!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
(Allah) said: ``Therefore it (this holy land) is forbidden to them for forty years; in distraction they will wander through the land. So be not sorrowful over the people who are the Fasiqun (rebellious and disobedient to Allah)."\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And (O Muhammad SAW) recite to them (the Jews) the story of the two sons of Adam [Habil (Abel) and Qabil (Cain)] in truth; when each offered a sacrifice (to Allah), it was accepted from the one but not from the other. The latter said to the former: ``I will surely kill you." The former said: ``Verily, Allah accepts only from those who are Al-Muttaqun (the pious - see V. 2:2)."\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
``If you do stretch your hand against me to kill me, I shall never stretch my hand against you to kill you, for I fear Allah; the Lord of the 'Alamin (mankind, jinns, and all that exists)."\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
``Verily, I intend to let you draw my sin on yourself as well as yours, then you will be one of the dwellers of the Fire, and that is the recompense of the Zalimun (polytheists and wrong-doers)."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
So the Nafs (self) of the other (latter one) encouraged him and made fair-seeming to him the murder of his brother; he murdered him and became one of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a crow who scratched the ground to show him to hide the dead body of his brother. He (the murderer) said: ``Woe to me! Am I not even able to be as this crow and to hide the dead body of my brother?" Then he became one of those who regretted.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Because of that We ordained for the Children of Israel that if anyone killed a person not in retaliation of murder, or (and) to spread mischief in the land - it would be as if he killed all mankind, and if anyone saved a life, it would be as if he saved the life of all mankind. And indeed, there came to them Our Messengers with clear proofs, evidences, and signs, even then after that many of them continued to exceed the limits (e.g. by doing oppression unjustly and exceeding beyond the limits set by Allah by committing the major sins) in the land!.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The recompense of those who wage war against Allah and His Messenger and do mischief in the land is only that they shall be killed or crucified or their hands and their feet be cut off on the opposite sides, or be exiled from the land. That is their disgrace in this world, and a great torment is theirs in the Hereafter.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except for those who (having fled away and then) came back (as Muslims) with repentance before they fall into your power; in that case, know that Allah is Oft-Forgiving, Most Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O you who believe! Do your duty to Allah and fear Him. Seek the means of approach to Him, and strive hard in His Cause as much as you can. So that you may be successful.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
Verily, those who disbelieve, if they had all that is in the earth, and as much again therewith to ransom themselves thereby from the torment on the Day of Resurrection, it would never be accepted of them, and theirs would be a painful torment.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will long to get out of the Fire, but never will they get out therefrom, and theirs will be a lasting torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
Cut off (from the wrist joint) the (right) hand of the thief, male or female, as a recompense for that which they committed, a punishment by way of example from Allah. And Allah is All-Powerful, All-Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whosoever repents after his crime and does righteous good deeds (by obeying Allah), then verily, Allah will pardon him (accept his repentance). Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Know you not that to Allah (Alone) belongs the dominion of the heavens and the earth! He punishes whom He wills and He forgives whom He wills. And Allah is Able to do all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger (Muhammad SAW)! Let not those who hurry to fall into disbelief grieve you, of such who say: ``We believe" with their mouths but their hearts have no faith. And of the Jews are men who listen much and eagerly to lies - listen to others who have not come to you. They change the words from their places; they say, ``If you are given this, take it, but if you are not given this, then beware!" And whomsoever Allah wants to put in Al-Fitnah [error, because of his rejecting the Faith], you can do nothing for him against Allah. Those are the ones whose hearts Allah does not want to purify (from disbelief and hypocrisy); for them there is a disgrace in this world, and in the Hereafter a great torment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
(They like to) listen to falsehood, to devour anything forbidden. So if they come to you (O Muhammad SAW), either judge between them, or turn away from them. If you turn away from them, they cannot hurt you in the least. And if you judge, judge with justice between them. Verily, Allah loves those who act justly.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
But how do they come to you for decision while they have the Taurat (Torah), in which is the (plain) Decision of Allah; yet even after that, they turn away. For they are not (really) believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Verily, We did send down the Taurat (Torah) [to Musa (Moses)], therein was guidance and light, by which the Prophets, who submitted themselves to Allah's Will, judged the Jews. And the rabbis and the priests [too judged the Jews by the Taurat (Torah) after those Prophets] for to them was entrusted the protection of Allah's Book, and they were witnesses thereto. Therefore fear not men but fear Me (O Jews) and sell not My Verses for a miserable price. And whosoever does not judge by what Allah has revealed, such are the Kafirun (i.e. disbelievers - of a lesser degree as they do not act on Allah's Laws).\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We ordained therein for them: ``Life for life, eye for eye, nose for nose, ear for ear, tooth for tooth, and wounds equal for equal." But if anyone remits the retaliation by way of charity, it shall be for him an expiation. And whosoever does not judge by that which Allah has revealed, such are the Zalimun (polytheists and wrong-doers - of a lesser degree).\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And in their footsteps, We sent 'Iesa (Jesus), son of Maryam (Mary), confirming the Taurat (Torah) that had come before him, and We gave him the Injeel (Gospel), in which was guidance and light and confirmation of the Taurat (Torah) that had come before it, a guidance and an admonition for Al-Muttaqun (the pious - see V. 2:2).\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Let the people of the Injeel (Gospel) judge by what Allah has revealed therein. And whosoever does not judge by what Allah has revealed (then) such (people) are the Fasiqun (the rebellious i.e. disobedient (of a lesser degree) to Allah.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We have sent down to you (O Muhammad SAW) the Book (this Quran) in truth, confirming the Scripture that came before it and Mohayminan (trustworthy in highness and a witness) over it (old Scriptures). So judge between them by what Allah has revealed, and follow not their vain desires, diverging away from the truth that has come to you. To each among you, We have prescribed a law and a clear way. If Allah willed, He would have made you one nation, but that (He) may test you in what He has given you; so strive as in a race in good deeds. The return of you (all) is to Allah; then He will inform you about that in which you used to differ.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And so judge (you O Muhammad SAW) between them by what Allah has revealed and follow not their vain desires, but beware of them lest they turn you (O Muhammad SAW) far away from some of that which Allah has sent down to you. And if they turn away, then know that Allah's Will is to punish them for some sins of theirs. And truly, most of men are Fasiqun (rebellious and disobedient to Allah).\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Do they then seek the judgement of (the Days of) Ignorance? And who is better in judgement than Allah for a people who have firm Faith.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O you who believe! Take not the Jews and the Christians as Auliya' (friends, protectors, helpers, etc.), they are but Auliya' to one another. And if any amongst you takes them as Auliya', then surely he is one of them. Verily, Allah guides not those people who are the Zalimun (polytheists and wrong-doers and unjust).\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
And you see those in whose hearts there is a disease (of hypocrisy), they hurry to their friendship, saying: ``We fear lest some misfortune of a disaster may befall us." Perhaps Allah may bring a victory or a decision according to His Will. Then they will become regretful for what they have been keeping as a secret in themselves.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And those who believe will say: ``Are these the men (hypocrites) who swore their strongest oaths by Allah that they were with you (Muslims)?" All that they did has been in vain (because of their hypocrisy), and they have become the losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O you who believe! Whoever from among you turns back from his religion (Islam), Allah will bring a people whom He will love and they will love Him; humble towards the believers, stern towards the disbelievers, fighting in the Way of Allah, and never afraid of the blame of the blamers. That is the Grace of Allah which He bestows on whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Verily, your Wali (Protector or Helper) is Allah, His Messenger, and the believers, - those who perform As-Salat (Iqamat-as-Salat), and give Zakat, and they bow down (submit themselves with obedience to Allah in prayer).\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whosoever takes Allah, His Messenger, and those who have believed, as Protectors, then the party of Allah will be the victorious.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O you who believe! Take not for Auliya' (protectors and helpers) those who take your religion for a mockery and fun from among those who received the Scripture (Jews and Christians) before you, nor from among the disbelievers; and fear Allah if you indeed are true believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when you proclaim the call for As-Salat [call for the prayer (Adhan)], they take it (but) as a mockery and fun; that is because they are a people who understand not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: ``O people of the Scripture (Jews and Christians)! Do you criticize us for no other reason than that we believe in Allah, and in (the revelation) which has been sent down to us and in that which has been sent down before (us), and that most of you are Fasiqun [rebellious and disobedient (to Allah)]?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say (O Muhammad SAW to the people of the Scripture): ``Shall I inform you of something worse than that, regarding the recompense from Allah: those (Jews) who incurred the Curse of Allah and His Wrath, those of whom (some) He transformed into monkeys and swines, those who worshipped Taghut (false deities); such are worse in rank (on the Day of Resurrection in the Hell-fire), and far more astray from the Right Path (in the life of this world)."\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come to you, they say: ``We believe." But in fact they enter with (an intention of) disbelief and they go out with the same. And Allah knows all what they were hiding.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And you see many of them (Jews) hurrying for sin and transgression, and eating illegal things [as bribes and Riba (usury), etc.]. Evil indeed is that which they have been doing.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do not the rabbis and the religious learned men forbid them from uttering sinful words and from eating illegal things. Evil indeed is that which they have been performing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: ``Allah's Hand is tied up (i.e. He does not give and spend of His Bounty)." Be their hands tied up and be they accursed for what they uttered. Nay, both His Hands are widely outstretched. He spends (of His Bounty) as He wills. Verily, the Revelation that has come to you from Allah increases in most of them their obstinate rebellion and disbelief. We have put enmity and hatred amongst them till the Day of Resurrection. Every time they kindled the fire of war, Allah extinguished it; and they (ever) strive to make mischief on earth. And Allah does not like the Mufsidun (mischief-makers).\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
And if only the people of the Scripture (Jews and Christians) had believed (in Muhammad SAW) and warded off evil (sin, ascribing partners to Allah) and had become Al-Muttaqun (the pious - see V. 2:2) We would indeed have blotted out their sins and admitted them to Gardens of pleasure (in Paradise).\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
And if only they had acted according to the Taurat (Torah), the Injeel (Gospel), and what has (now) been sent down to them from their Lord (the Quran), they would surely have gotten provision from above them and from underneath their feet. There are from among them people who are on the right course (i.e. they act on the revelation and believe in Prophet Muhammad SAW like 'Abdullah bin Salam), but many of them do evil deeds.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger (Muhammad SAW)! Proclaim (the Message) which has been sent down to you from your Lord. And if you do not, then you have not conveyed His Message. Allah will protect you from mankind. Verily, Allah guides not the people who disbelieve.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say (O Muhammad SAW) ``O people of the Scripture (Jews and Christians)! You have nothing (as regards guidance) till you act according to the Taurat (Torah), the Injeel (Gospel), and what has (now) been sent down to you from your Lord (the Quran)." Verily, that which has been sent down to you (Muhammad SAW) from your Lord increases in many of them their obstinate rebellion and disbelief. So be not sorrowful over the people who disbelieve.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Surely, those who believe (in the Oneness of Allah, in His Messenger Muhammad SAW and all that was revealed to him from Allah), those who are the Jews and the Sabians and the Christians, - whosoever believed in Allah and the Last Day, and worked righteousness, on them shall be no fear, nor shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
Verily, We took the covenant of the Children of Israel and sent them Messengers. Whenever there came to them a Messenger with what they themselves desired not - a group of them they called liars, and others among them they killed.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
They thought there will be no Fitnah (trial or punishment), so they became blind and deaf; after that Allah turned to them (with Forgiveness); yet again many of them became blind and deaf. And Allah is the All-Seer of what they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
Surely, they have disbelieved who say: ``Allah is the Messiah ['Iesa (Jesus)], son of Maryam (Mary)." But the Messiah ['Iesa (Jesus)] said: ``O Children of Israel! Worship Allah, my Lord and your Lord." Verily, whosoever sets up partners in worship with Allah, then Allah has forbidden Paradise for him, and the Fire will be his abode. And for the Zalimun (polytheists and wrong-doers) there are no helpers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
Surely, disbelievers are those who said: ``Allah is the third of the three (in a Trinity)." But there is no ilah (god) (none who has the right to be worshipped) but One Ilah (God -Allah). And if they cease not from what they say, verily, a painful torment will befall the disbelievers among them.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not repent to Allah and ask His Forgiveness? For Allah is Oft-Forgiving, Most Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah ['Iesa (Jesus)], son of Maryam (Mary), was no more than a Messenger; many were the Messengers that passed away before him. His mother [Maryam (Mary)] was a Siddiqah [i.e. she believed in the words of Allah and His Books (see Verse 66:12)]. They both used to eat food (as any other human being, while Allah does not eat). Look how We make the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) clear to them, yet look how they are deluded away (from the truth).\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say (O Muhammad SAW to mankind): ``How do you worship besides Allah something which has no power either to harm or to benefit you? But it is Allah Who is the All-Hearer, All-Knower."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say (O Muhammad SAW): ``O people of the Scripture (Jews and Christians)! Exceed not the limits in your religion (by believing in something) other than the truth, and do not follow the vain desires of people who went astray in times gone by, and who misled many, and strayed (themselves) from the Right Path."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those among the Children of Israel who disbelieved were cursed by the tongue of Dawud (David) and 'Iesa (Jesus), son of Maryam (Mary). That was because they disobeyed (Allah and the Messengers) and were ever transgressing beyond bounds.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They used not to forbid one another from the Munkar (wrong, evil-doing, sins, polytheism, disbelief, etc.) which they committed. Vile indeed was what they used to do.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You see many of them taking the disbelievers as their Auliya' (protectors and helpers). Evil indeed is that which their ownselves have sent forward before them, for that (reason) Allah's Wrath fell upon them and in torment they will abide.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
And had they believed in Allah, and in the Prophet (Muhammad SAW) and in what has been revealed to him, never would they have taken them (the disbelievers) as Auliya' (protectors and helpers), but many of them are the Fasiqun (rebellious, disobedient to Allah).\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Verily, you will find the strongest among men in enmity to the believers (Muslims) the Jews and those who are Al-Mushrikun (see V. 2:105), and you will find the nearest in love to the believers (Muslims) those who say: ``We are Christians." That is because amongst them are priests and monks, and they are not proud.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they (who call themselves Christians) listen to what has been sent down to the Messenger (Muhammad SAW), you see their eyes overflowing with tears because of the truth they have recognised. They say: ``Our Lord! We believe; so write us down among the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
``And why should we not believe in Allah and in that which has come to us of the truth (Islamic Monotheism)? And we wish that our Lord will admit us (in Paradise on the Day of Resurrection) along with the righteous people (Prophet Muhammad SAW and his Companions)."\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
So because of what they said, Allah rewarded them Gardens under which rivers flow (in Paradise), they will abide therein forever. Such is the reward of good-doers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieved and belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they shall be the dwellers of the (Hell) Fire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O you who believe! Make not unlawful the Taiyibat (all that is good as regards foods, things, deeds, beliefs, persons, etc.) which Allah has made lawful to you, and transgress not. Verily, Allah does not like the transgressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And eat of the things which Allah has provided for you, lawful and good, and fear Allah in Whom you believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not punish you for what is uninentional in your oaths, but He will punish you for your deliberate oaths; for its expiation (a deliberate oath) feed ten Masakin (poor persons), on a scale of the average of that with which you feed your own families; or clothe them; or manumit a slave. But whosoever cannot afford (that), then he should fast for three days. That is the expiation for the oaths when you have sworn. And protect your oaths (i.e. do not swear much). Thus Allah make clear to you His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) that you may be grateful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O you who believe! Intoxicants (all kinds of alcoholic drinks), gambling, Al-Ansab, and Al-Azlam (arrows for seeking luck or decision) are an abomination of Shaitan's (Satan) handiwork. So avoid (strictly all) that (abomination) in order that you may be successful.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Shaitan (Satan) wants only to excite enmity and hatred between you with intoxicants (alcoholic drinks) and gambling, and hinder you from the remembrance of Allah and from As-Salat (the prayer). So, will you not then abstain?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
And obey Allah and the Messenger (Muhammad SAW), and beware (of even coming near to drinking or gambling or Al-Ansab, or Al-Azlam, etc.) and fear Allah. Then if you turn away, you should know that it is Our Messenger's duty to convey (the Message) in the clearest way.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
Those who believe and do righteous good deeds, there is no sin on them for what they ate (in the past), if they fear Allah (by keeping away from His forbidden things), and believe and do righteous good deeds, and again fear Allah and believe, and once again fear Allah and do good deeds with Ihsan (perfection). And Allah loves the good-doers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O you who believe! Allah will certainly make a trial of you with something in (the matter of) the game that is well within reach of your hands and your lances, that Allah may test who fears Him unseen. Then whoever transgresses thereafter, for him there is a painful torment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O you who believe! Kill not game while you are in a state of Ihram for Hajj or 'Umrah (pilgrimage), and whosoever of you kills it intentionally, the penalty is an offering, brought to the Ka'bah, of an eatable animal (i.e. sheep, goat, cow, etc.) equivalent to the one he killed, as adjudged by two just men among you; or, for expiation, he should feed Masakin (poor persons), or its equivalent in Saum (fasting), that he may taste the heaviness (punishment) of his deed. Allah has forgiven what is past, but whosoever commits it again, Allah will take retribution from him. And Allah is All-Mighty, All-Able of Retribution.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Lawful to you is (the pursuit of) water-game and its use for food - for the benefit of yourselves and those who travel, but forbidden is (the pursuit of) land-game as long as you are in a state of Ihram (for Hajj or 'Umrah). And fear Allah to Whom you shall be gathered back.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has made the Ka'bah, the Sacred House, an asylum of security and Hajj and 'Umrah (pilgrimage) for mankind, and also the Sacred Month and the animals of offerings and the garlanded (people or animals, etc. marked with the garlands on their necks made from the outer part of the stem of the Makkah trees for their security), that you may know that Allah has knowledge of all that is in the heavens and all that is in the earth, and that Allah is the All-Knower of each and everything.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is Severe in punishment and that Allah is Oft-Forgiving, Most Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The Messenger's duty [i.e. Our Messenger Muhammad SAW whom We have sent to you, (O mankind)] is but to convey (the Message). And Allah knows all that you reveal and all that you conceal.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say (O Muhammad SAW): ``Not equal are Al-Khabith (all that is evil and bad as regards things, deeds, beliefs, persons, foods, etc.) and At-Taiyib (all that is good as regards things, deeds, beliefs, persons, foods, etc.), even though the abundance of Al-Khabith (evil) may please you." So fear Allah much [(abstain from all kinds of sins and evil deeds which He has forbidden) and love Allah much (perform all kinds of good deeds which He has ordained)], O men of understanding in order that you may be successful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O you who believe! Ask not about things which, if made plain to you, may cause you trouble. But if you ask about them while the Quran is being revealed, they will be made plain to you. Allah has forgiven that, and Allah is Oft-Forgiving, Most Forbearing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
Before you, a community asked such questions, then on that account they became disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has not instituted things like Bahirah (a she-camel whose milk was spared for the idols and nobody was allowed to milk it) or a Sa'ibah (a she-camel let loose for free pasture for their false gods, e.g. idols, etc., and nothing was allowed to be carried on it), or a Wasilah (a she-camel set free for idols because it has given birth to a she-camel at its first delivery and then again gives birth to a she-camel at its second delivery) or a Ham (a stallion-camel freed from work for their idols, after it had finished a number of copulations assigned for it, all these animals were liberated in honour of idols as practised by pagan Arabs in the pre-Islamic period). But those who disbelieve invent lies against Allah, and most of them have no understanding.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them: ``Come to what Allah has revealed and unto the Messenger (Muhammad SAW for the verdict of that which you have made unlawful)." They say: ``Enough for us is that which we found our fathers following," even though their fathers had no knowledge whatsoever and no guidance.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O you who believe! Take care of your ownselves, [do righteous deeds, fear Allah much (abstain from all kinds of sins and evil deeds which He has forbidden) and love Allah much (perform all kinds of good deeds which He has ordained)]. If you follow the right guidance and enjoin what is right (Islamic Monotheism and all that Islam orders one to do) and forbid what is wrong (polytheism, disbelief and all that Islam has forbidden) no hurt can come to you from those who are in error. The return of you all is to Allah, then He will inform you about (all) that which you used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O you who believe! When death approaches any of you, and you make a bequest, then take the testimony of two just men of your own folk or two others from outside, if you are travelling through the land and the calamity of death befalls you. Detain them both after As-Salat (the prayer), (then) if you are in doubt (about their truthfulness), let them both swear by Allah (saying): ``We wish not for any worldly gain in this, even though he (the beneficiary) be our near relative. We shall not hide Testimony of Allah, for then indeed we should be of the sinful."\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
If then it gets known that these two had been guilty of sin, let two others stand forth in their places, nearest in kin from among those who claim a lawful right. Let them swear by Allah (saying): ``We affirm that our testimony is truer than that of both of them, and that we have not trespassed (the truth), for then indeed we should be of the wrong-doers."\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That should make it closer (to the fact) that their testimony would be in its true nature and shape (and thus accepted), or else they would fear that (other) oaths would be admitted after their oaths. And fear Allah and listen (with obedience to Him). And Allah guides not the people who are Al-Fasiqun (the rebellious and disobedient).\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
On the Day when Allah will gather the Messengers together and say to them: ``What was the response you received (from men to your teaching)? They will say: ``We have no knowledge, verily, only You are the All-Knower of all that is hidden (or unseen, etc.)."\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
(Remember) when Allah will say (on the Day of Resurrection). ``O 'Iesa (Jesus), son of Maryam (Mary)! Remember My Favour to you and to your mother when I supported you with Ruh-ul-Qudus [Jibrael (Gabriel)] so that you spoke to the people in the cradle and in maturity; and when I taught you writing, Al-Hikmah (the power of understanding), the Taurat (Torah) and the Injeel (Gospel); and when you made out of the clay, as it were, the figure of a bird, by My Permission, and you breathed into it, and it became a bird by My Permission, and you healed those born blind, and the lepers by My Permission, and when you brought forth the dead by My Permission; and when I restrained the Children of Israel from you (when they resolved to kill you) since you came unto them with clear proofs, and the disbelievers among them said: 'This is nothing but evident magic.' ``\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And when I (Allah) put in the hearts of Al-Hawarieen (the disciples) [of 'Iesa (Jesus)] to believe in Me and My Messenger, they said: ``We believe. And bear witness that we are Muslims."\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
(Remember) when Al-Hawariun (the disciples) said: ``O 'Iesa (Jesus), son of Maryam (Mary)! Can your Lord send down to us a table spread (with food) from heaven?" 'Iesa (Jesus) said: ``Fear Allah, if you are indeed believers."\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said: ``We wish to eat thereof and to be stronger in Faith, and to know that you have indeed told us the truth and that we ourselves be its witnesses."\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
'Iesa (Jesus), son of Maryam (Mary), said: ``O Allah, our Lord! Send us from heaven a table spread (with food) that there may be for us - for the first and the last of us - a festival and a sign from You; and provide us sustenance, for You are the Best of sustainers."\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: ``I am going to send it down unto you, but if any of you after that disbelieves, then I will punish him with a torment such as I have not inflicted on anyone among (all) the 'Alamin (mankind and jinns)."\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And (remember) when Allah will say (on the Day of Resurrection): ``O 'Iesa (Jesus), son of Maryam (Mary)! Did you say unto men: 'Worship me and my mother as two gods besides Allah?' `` He will say: ``Glory be to You! It was not for me to say what I had no right (to say). Had I said such a thing, You would surely have known it. You know what is in my inner-self though I do not know what is in Yours, truly, You, only You, are the All-Knower of all that is hidden and unseen.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
``Never did I say to them aught except what You (Allah) did command me to say: 'Worship Allah, my Lord and your Lord.' And I was a witness over them while I dwelt amongst them, but when You took me up, You were the Watcher over them, and You are a Witness to all things. (This is a great admonition and warning to the Christians of the whole world).\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
``If You punish them, they are Your slaves, and if You forgive them, verily You, only You are the All-Mighty, the All-Wise."\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say: ``This is a Day on which the truthful will profit from their truth: theirs are Gardens under which rivers flow (in Paradise) - they shall abide therein forever. Allah is pleased with them and they with Him. That is the great success (Paradise).\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah belongs the dominion of the heavens and the earth and all that is therein, and He is Able to do all things.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen All praises and thanks be to Allah, Who (Alone) created the heavens and the earth, and originated the darkness and the light, yet those who disbelieve hold others as equal with their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is Who has created you from clay, and then has decreed a stated term (for you to die). And there is with Him another determined term (for you to be resurrected), yet you doubt (in the Resurrection).\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He is Allah (to be worshipped Alone) in the heavens and on the earth, He knows what you conceal and what you reveal, and He knows what you earn (good or bad).\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
And never an Ayah (sign) comes to them from the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord, but that they have been turning away from it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
Indeed, they rejected the truth (the Quran and Muhammad SAW) when it came to them, but there will come to them the news of that (the torment) which they used to mock at.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not seen how many a generation before them We have destroyed whom We had established on the earth such as We have not established you? And We poured out on them rain from the sky in abundance, and made the rivers flow under them. Yet We destroyed them for their sins, and created after them other generations.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
And even if We had sent down unto you (O Muhammad SAW) a Message written on paper so that they could touch it with their hands, the disbelievers would have said: ``This is nothing but obvious magic!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they say: ``Why has not an angel been sent down to him?" Had We sent down an angel, the matter would have been judged at once, and no respite would be granted to them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And had We appointed him an angel, We indeed would have made him a man, and We would have certainly caused them confusion in a matter which they have already covered with confusion (i.e. the Message of Prophet Muhammad SAW).\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And indeed (many) Messengers were mocked before you, but their scoffers were surrounded by the very thing that they used to mock at.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say (O Muhammad SAW): ``Travel in the land and see what was the end of those who rejected truth."\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say (O Muhammad SAW): ``To whom belongs all that is in the heavens and the earth?" Say: ``To Allah. He has prescribed Mercy for Himself. Indeed He will gather you together on the Day of Resurrection, about which there is no doubt. Those who destroy themselves will not believe [in Allah as being the only Ilah (God), and Muhammad SAW as being one of His Messengers, and in Resurrection, etc.].\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him belongs whatsoever exists in the night and the day, and He is the All-Hearing, the All-Knowing."\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say (O Muhammad SAW): ``Shall I take as a Wali (helper, protector, etc.) any other than Allah, the Creator of the heavens and the earth? And it is He Who feeds but is not fed." Say: ``Verily, I am commanded to be the first of those who submit themselves to Allah (as Muslims)." And be not you (O Muhammad SAW) of the Mushrikun [polytheists, pagans, idolaters and disbelievers in the Oneness of Allah].\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: ``I fear, if I disobey my Lord, the torment of a Mighty Day."\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
Who is averted from (such a torment) on that Day, (Allah) has surely been Merciful to him. And that would be the obvious success.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
And if Allah touches you with harm, none can remove it but He, and if He touches you with good, then He is Able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
And He is the Irresistible, above His slaves, and He is the All-Wise, Well-Acquainted with all things.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say (O Muhammad SAW): ``What thing is the most great in witness?" Say: ``Allah (the Most Great!) is Witness between me and you; this Quran has been revealed to me that I may therewith warn you and whomsoever it may reach. Can you verily bear witness that besides Allah there are other aliha (gods)?" Say ``I bear no (such) witness!" Say: ``But in truth He (Allah) is the only one Ilah (God). And truly I am innocent of what you join in worship with Him."\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Scripture (Jews and Christians) recognize him (i.e. Muhammad SAW as a Messenger of Allah, and they also know that there is no Ilah (God) but Allah and Islam is Allah's Religion), as they recognize their own sons. Those who destroy themselves will not believe. (Tafsir At-Tabari)\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who does more wrong than he who invents a lie against Allah or rejects His Ayat (proofs, evidences, verses, lessons, revelations, etc.)? Verily, the Zalimun (polytheists and wrong-doers, etc.) shall never be successful.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the Day when We shall gather them all together, We shall say to those who joined partners in worship (with Us): ``Where are your partners (false deities) whom you used to assert (as partners in worship with Allah)?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
There will then be (left) no Fitnah (excuses or statements or arguments) for them but to say: ``By Allah, our Lord, we were not those who joined others in worship with Allah."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Look! How they lie against themselves! But the (lie) which they invented will disappear from them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And of them there are some who listen to you; but We have set veils on their hearts, so they understand it not, and deafness in their ears; if they see every one of the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) they will not believe therein; to the point that when they come to you to argue with you, the disbelievers say: ``These are nothing but tales of the men of old."\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they prevent others from him (from following Prophet Muhammad SAW) and they themselves keep away from him, and (by doing so) they destroy not but their ownselves, yet they perceive (it) not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If you could but see when they will be held over the (Hell) Fire! They will say: ``Would that we were but sent back (to the world)! Then we would not deny the Ayat (proofs, evidences, verses, lessons, revelations, etc.) of our Lord, and we would be of the believers!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Nay, it has become manifest to them what they had been concealing before. But if they were returned (to the world), they would certainly revert to that which they were forbidden. And indeed they are liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they said: ``There is no (other life) but our (present) life of this world, and never shall we be resurrected (on the Day of Resurrection)."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If you could but see when they will be held (brought and made to stand) in front of their Lord! He will say: ``Is not this (Resurrection and the taking of the accounts) the truth?" They will say: ``Yes, by our Lord!" He will then say: ``So taste you the torment because you used not to believe."\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
They indeed are losers who denied their Meeting with Allah, until all of a sudden, the Hour (signs of death) is on them, and they say: ``Alas for us that we gave no thought to it," while they will bear their burdens on their backs; and evil indeed are the burdens that they will bear!\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
And the life of this world is nothing but play and amusement. But far better is the house in the Hereafter for those who are Al-Muttaqun (the pious - see V. 2:2). Will you not then understand?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know indeed the grief which their words cause you (O Muhammad SAW): it is not you that they deny, but it is the Verses (the Quran) of Allah that the Zalimun (polytheists and wrong-doers) deny.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Verily, (many) Messengers were denied before you (O Muhammad SAW), but with patience they bore the denial, and they were hurt, till Our Help reached them, and none can alter the Words (Decisions) of Allah. Surely there has reached you the information (news) about the Messengers (before you).\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
If their aversion (from you, O Muhammad SAW and from that with which you have been sent) is hard on you, (and you cannot be patient from their harm to you), then if you were able to seek a tunnel in the ground or a ladder to the sky, so that you may bring them a sign (and you cannot do it, so be patient). And had Allah willed, He could have gathered them together (all) unto true guidance, so be not you one of those who are Al-Jahilun (the ignorant).\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
It is only those who listen (to the Message of Prophet Muhammad SAW), will respond (benefit from it), but as for the dead (disbelievers), Allah will raise them up, then to Him they will be returned (for their recompense).\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they said: ``Why is not a sign sent down to him from his Lord?" Say: ``Allah is certainly Able to send down a sign, but most of them know not."\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is not a moving (living) creature on earth, nor a bird that flies with its two wings, but are communities like you. We have neglected nothing in the Book, then unto their Lord they (all) shall be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) are deaf and dumb in darkness. Allah sends astray whom He wills and He guides on the Straight Path whom He wills.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say (O Muhammad SAW): ``Tell me if Allah's Torment comes upon you, or the Hour comes upon you, would you then call upon any one other than Allah? (Reply) if you are truthful!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
Nay! To Him Alone you call, and, if He will, He would remove that (distress) for which you call upon Him, and you forget at that time whatever partners you joined with Him (in worship)!\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
Verily, We sent (Messengers) to many nations before you (O Muhammad SAW). And We seized them with extreme poverty (or loss in wealth) and loss in health with calamities so that they might believe with humility.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
When Our Torment reached them, why then did they not believe with humility? But their hearts became hardened, and Shaitan (Satan) made fair-seeming to them that which they used to do.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So, when they forgot (the warning) with which they had been reminded, We opened to them the gates of every (pleasant) thing, until in the midst of their enjoyment in that which they were given, all of a sudden, We took them to punishment, and lo! They were plunged into destruction with deep regrets and sorrows.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
So the roots of the people who did wrong were cut off. And all the praises and thanks be to Allah, the Lord of the 'Alamin (mankind, jinns, and all that exists).\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say (to the disbelievers): ``Tell me, if Allah took away your hearing and your sight, and sealed up your hearts, who is there - an ilah (a god) other than Allah who could restore them to you?" See how variously We explain the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), yet they turn aside.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: ``Tell me, if the punishment of Allah comes to you suddenly (during the night), or openly (during the day), will any be destroyed except the Zalimun (polytheists and wrong-doing people)?"\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
And We send not the Messengers but as givers of glad tidings and as warners. So whosoever believes and does righteous good deeds, upon such shall come no fear, nor shall they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), the torment will touch them for their disbelief (and for their belying the Message of Muhammad SAW). [Tafsir Al-Qurtubi].\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say (O Muhammad SAW): ``I don't tell you that with me are the treasures of Allah, nor (that) I know the unseen; nor I tell you that I am an angel. I but follow what is revealed to me by inspiration." Say: ``Are the blind and the one who sees equal? will you not then take thought?"\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn therewith (the Quran) those who fear that they will be gathered before their Lord, when there will be neither a protector nor an intercessor for them besides Him, so that they may fear Allah and keep their duty to Him (by abstaining from committing sins and by doing all kinds of good deeds which He has ordained).\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And turn not away those who invoke their Lord, morning and afternoon seeking His Face. You are accountable for them in nothing, and they are accountable for you in nothing, that you may turn them away, and thus become of the Zalimun (unjust).\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Thus We have tried some of them with others, that they might say: ``Is it these (poor believers) that Allah has favoured from amongst us?" Does not Allah know best those who are grateful?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
When those who believe in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) come to you, say: ``Salamun 'Alaikum" (peace be on you); your Lord has written Mercy for Himself, so that, if any of you does evil in ignorance, and thereafter repents and does righteous good deeds (by obeying Allah), then surely, He is Oft-Forgiving, Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
And thus do We explain the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in detail, that the way of the Mujrimun (criminals, polytheists, sinners), may become manifest.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say (O Muhammad SAW): ``I have been forbidden to worship those whom you invoke (worship) besides Allah." Say: ``I will not follow your vain desires. If I did, I would go astray, and I would not be one of the rightly guided."\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say (O Muhammad SAW): ``I am on clear proof from my Lord (Islamic Monotheism), but you deny (the truth that has come to me from Allah). I have not gotten what you are asking for impatiently (the torment). The decision is only for Allah, He declares the truth, and He is the Best of judges."\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: ``If I had that which you are asking for impatiently (the torment), the matter would have been settled at once between me and you, but Allah knows best the Zalimun (polytheists and wrong-doers, etc.)."\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And with Him are the keys of the Ghaib (all that is hidden), none knows them but He. And He knows whatever there is in (or on) the earth and in the sea; not a leaf falls, but he knows it. There is not a grain in the darkness of the earth nor anything fresh or dry, but is written in a Clear Record.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He, Who takes your souls by night (when you are asleep), and has knowledge of all that you have done by day, then he raises (wakes) you up again that a term appointed (your life period) be fulfilled, then in the end unto Him will be your return. Then He will inform you what you used to do.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Irresistible, Supreme over His slaves, and He sends guardians (angels guarding and writing all of one's good and bad deeds) over you, until when death approaches one of you, Our Messengers (angel of death and his assistants) take his soul, and they never neglect their duty.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they are returned to Allah, their Maula [True Master (God), the Just Lord (to reward them)]. Surely, His is the judgement and He is the Swiftest in taking account.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say (O Muhammad SAW): ``Who rescues you from the darkness of the land and the sea (dangers like storms), when you call upon Him in humility and in secret (saying): If He (Allah) only saves us from this (danger), we shall truly be grateful."\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say (O Muhammad SAW): ``Allah rescues you from it and from all (other) distresses, and yet you worship others besides Allah."\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: ``He has power to send torment on you from above or from under your feet, or to cover you with confusion in party strife, and make you to taste the violence of one another." See how variously We explain the Ayat (proofs, evidences, lessons, signs, revelations, etc.), so that they may understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
But your people (O Muhammad SAW) have denied it (the Quran) though it is the truth. Say: ``I am not responsible for your affairs."\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every news there is a fact, i.e. for everything there is an appointed term (and it is also said that for every deed there is a recompense) and you will come to know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And when you (Muhammad SAW) see those who engage in a false conversation about Our Verses (of the Quran) by mocking at them, stay away from them till they turn to another topic. And if Shaitan (Satan) causes you to forget, then after the remembrance sit not you in the company of those people who are the Zalimun (polytheists and wrong-doers, etc.).\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
Those who fear Allah, keep their duty to Him and avoid evil are not responsible for them (the disbelievers) in any case, but (their duty) is to remind them, that they may avoid that (mockery at the Quran). [The order of this Verse was cancelled (abrogated) by the Verse 4:140].\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
And leave alone those who take their religion as play and amusement, and are deceived by the life of this world. But remind (them) with it (the Quran) lest a person be given up to destruction for that which he has earned, when he will find for himself no protector or intercessor besides Allah, and even if he offers every ransom, it will not be accepted from him. Such are they who are given up to destruction because of that which they have earned. For them will be a drink of boiling water and a painful torment because they used to disbelieve\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say (O Muhammad SAW): ``Shall we invoke others besides Allah (false deities), that can do us neither good nor harm, and shall we turn on our heels after Allah has guided us (to true Monotheism)? - like one whom the Shayatin (devils) have made to go astray, confused (wandering) through the earth, his companions calling him to guidance (saying): 'Come to us.' `` Say: ``Verily, Allah's Guidance is the only guidance, and we have been commanded to submit (ourselves) to the Lord of the 'Alamin (mankind, jinns and all that exists);\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
And to perform As-Salat (Iqamat-as-Salat)", and to be obedient to Allah and fear Him, and it is He to Whom you shall be gathered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It is He Who has created the heavens and the earth in truth, and on the Day (i.e. the Day of Resurrection) He will say: ``Be!", - and it shall become. His Word is the truth. His will be the dominion on the Day when the trumpet will be blown. All-Knower of the unseen and the seen. He is the All-Wise, Well-Aware (of all things).\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And (remember) when Ibrahim (Abraham) said to his father Azar: ``Do you take idols as aliha (gods)? Verily, I see you and your people in manifest error.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
Thus did we show Ibrahim (Abraham) the kingdom of the heavens and the earth that he be one of those who have Faith with certainty.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When the night covered him over with darkness he saw a star. He said: ``This is my lord." But when it set, he said: ``I like not those that set."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
When he saw the moon rising up, he said: ``This is my lord." But when it set, he said: ``Unless my Lord guides me, I shall surely be among the erring people."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
When he saw the sun rising up, he said: ``This is my lord. This is greater." But when it set, he said: ``O my people! I am indeed free from all that you join as partners in worship with Allah.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Verily, I have turned my face towards Him Who has created the heavens and the earth Hanifa (Islamic Monotheism, i.e. worshipping none but Allah Alone) and I am not of Al-Mushrikun (see V. 2:105)".\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His people disputed with him. He said: ``Do you dispute with me concerning Allah while He has guided me, and I fear not those whom you associate with Allah in worship. (Nothing can happen to me) except when my Lord (Allah) wills something. My Lord comprehends in His Knowledge all things. Will you not then remember?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And how should I fear those whom you associate in worship with Allah (though they can neither benefit nor harm), while you fear not that you have joined in worship with Allah things for which He has not sent down to you any authority. (So) which of the two parties has more right to be in security? If you but know."\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
It is those who believe (in the Oneness of Allah and worship none but Him Alone) and confuse not their belief with Zulm (wrong i.e. by worshipping others besides Allah), for them (only) there is security and they are the guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
And that was Our Proof which We gave Ibrahim (Abraham) against his people. We raise whom We will in degrees. Certainly your Lord is All-Wise, All-Knowing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon him Ishaque (Isaac) and Ya'qub (Jacob), each of them We guided, and before him, We guided Nuh (Noah), and among his progeny Dawud (David), Sulaiman (Solomon), Ayub (Job), Yusuf (Joseph), Musa (Moses), and Harun (Aaron). Thus do We reward the good-doers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zakariya (Zachariya), and Yahya (John) and 'Iesa (Jesus) and Iliyas (Elias), each one of them was of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Isma'il (Ishmael) and Al-Yas'a (Elisha), and Yunus (Jonah) and Lout (Lot), and each one of them We preferred above the 'Alamin (mankind and jinns) (of their times).\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And also some of their fathers and their progeny and their brethren, We chose them, and We guided them to a Straight Path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
This is the Guidance of Allah with which He guides whomsoever He will of His slaves. But if they had joined in worship others with Allah, all that they used to do would have been of no benefit to them.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
They are those whom We gave the Book, Al-Hukm (understanding of the religious laws), and Prophethood. But if these disbelieve therein (the Book, Al-Hukm and Prophethood), then, indeed We have entrusted it to a people (such as the Companions of Prophet Muhammad SAW) who are not disbelievers therein.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
They are those whom Allah had guided. So follow their guidance. Say: ``No reward I ask of you for this (the Quran). It is only a reminder for the 'Alamin (mankind and jinns)."\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They (the Jews, Quraish pagans, idolaters, etc.) did not estimate Allah with an estimation due to Him when they said: ``Nothing did Allah send down to any human being (by inspiration)." Say (O Muhammad SAW): ``Who then sent down the Book which Musa (Moses) brought, a light and a guidance to mankind which you (the Jews) have made into (separate) papersheets, disclosing (some of it) and concealing (much). And you (believers in Allah and His Messenger Muhammad SAW), were taught (through the Quran) that which neither you nor your fathers knew." Say: ``Allah (sent it down)." Then leave them to play in their vain discussions. (Tafsir Al-Qurtubi, Vol. 7, Page 37).\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this (the Quran) is a blessed Book which We have sent down, confirming (the revelations) which came before it, so that you may warn the Mother of Towns (i.e. Makkah) and all those around it. Those who believe in the Hereafter believe in (the Quran), and they are constant in guarding their Salat (prayers).\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
And who can be more unjust than he who invents a lie against Allah, or says: ``I have received inspiration," whereas he is not inspired in anything; and who says, ``I will reveal the like of what Allah has revealed." And if you could but see when the Zalimun (polytheists and wrong-doers, etc.) are in the agonies of death, while the angels are stretching forth their hands (saying): ``Deliver your souls! This day you shall be recompensed with the torment of degradation because of what you used to utter against Allah other than the truth. And you used to reject His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) with disrespect!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
And truly you have come unto Us alone (without wealth, companions or anything else) as We created you the first time. You have left behind you all that which We had bestowed on you. We see not with you your intercessors whom you claimed to be partners with Allah. Now all relations between you and them have been cut off, and all that you used to claim has vanished from you.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Verily! It is Allah Who causes the seed-grain and the fruit-stone (like date-stone, etc.) to split and sprout. He brings forth the living from the dead, and it is He Who brings forth the dead from the living. Such is Allah, then how are you deluded away from the truth?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
(He is the) Cleaver of the daybreak. He has appointed the night for resting, and the sun and the moon for reckoning. Such is the measuring of the All-Mighty, the All-Knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He Who has set the stars for you, so that you may guide your course with their help through the darkness of the land and the sea. We have (indeed) explained in detail Our Ayat (proofs, evidences, verses, lessons, signs, Revelations, etc.) for people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He Who has created you from a single person (Adam), and has given you a place of residing (on the earth or in your mother's wombs) and a place of storage [in the earth (in your graves) or in your father's loins]. Indeed, We have explained in detail Our revelations (this Quran) for people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
It is He Who sends down water (rain) from the sky, and with it We bring forth vegetation of all kinds, and out of it We bring forth green stalks, from which We bring forth thick clustered grain. And out of the date-palm and its spathe come forth clusters of dates hanging low and near, and gardens of grapes, olives and pomegranates, each similar (in kind) yet different (in variety and taste). Look at their fruits when they begin to bear, and the ripeness thereof. Verily! In these things there are signs for people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet, they join the jinns as partners in worship with Allah, though He has created them (the jinns), and they attribute falsely without knowledge sons and daughters to Him. Be He Glorified and Exalted above (all) that they attribute to Him.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
He is the Originator of the heavens and the earth. How can He have children when He has no wife? He created all things and He is the All-Knower of everything.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord! La ilaha illa Huwa (none has the right to be worshipped but He), the Creator of all things. So worship Him (Alone), and He is the Wakil (Trustee, Disposer of affairs, Guardian, etc.) over all things.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No vision can grasp Him, but His Grasp is over all vision. He is the Most Subtle and Courteous, Well-Acquainted with all things.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Verily, proofs have come to you from your Lord, so whosoever sees, will do so for (the good of) his ownself, and whosoever blinds himself, will do so to his own harm, and I (Muhammad SAW) am not a watcher over you.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
Thus We explain variously the Verses so that they (the disbelievers) may say: ``You have studied (the Books of the people of the Scripture and brought this Quran from that)" and that We may make the matter clear for the people who have knowledge.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow what has been inspired to you (O Muhammad SAW) from your Lord, La ilaha illa Huwa (none has the right to be worshipped but He) and turn aside from Al-Mushrikun.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had Allah willed, they would not have taken others besides Him in worship. And We have not made you a watcher over them nor are you set over them to dispose of their affairs.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
And insult not those whom they (disbelievers) worship besides Allah, lest they insult Allah wrongfully without knowledge. Thus We have made fair-seeming to each people its own doings; then to their Lord is their return and He shall then inform them of all that they used to do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swear their strongest oaths by Allah, that if there came to them a sign, they would surely believe therein. Say: ``Signs are but with Allah and what will make you (Muslims) perceive that (even) if it (the sign) came, they will not believe?"\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We shall turn their hearts and their eyes away (from guidance), as they refused to believe therein for the first time, and We shall leave them in their trespass to wander blindly.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
And even if We had sent down unto them angels, and the dead had spoken unto them, and We had gathered together all things before their very eyes, they would not have believed, unless Allah willed, but most of them behave ignorantly.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
And so We have appointed for every Prophet enemies - Shayatin (devils) among mankind and jinns, inspiring one another with adorned speech as a delusion (or by way of deception). If your Lord had so willed, they would not have done it, so leave them alone with their fabrications. (Tafseer Qurtubi, Vol. 7, Page 67)\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
(And this is in order) that the hearts of those who disbelieve in the Hereafter may incline to such (deceit), and that they may remain pleased with it, and that they may commit what they are committing (all kinds of sins and evil deeds, etc.).\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
[Say (O Muhammad SAW)] ``Shall I seek a judge other than Allah while it is He Who has sent down unto you the Book (The Quran), explained in detail." Those unto whom We gave the Scripture [the Taurat (Torah) and the Injeel (Gospel)] know that it is revealed from your Lord in truth. So be not you of those who doubt.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
And the Word of your Lord has been fulfilled in truth and in justice. None can change His Words. And He is the All-Hearer, the All-Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
And if you obey most of those on earth, they will mislead you far away from Allah's Path. They follow nothing but conjectures, and they do nothing but lie.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Verily, your Lord! It is He Who knows best who strays from His Way, and He knows best the rightly guided ones.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat of that (meat) on which Allah's Name has been pronounced (while slaughtering the animal), if you are believers in His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
And why should you not eat of that (meat) on which Allah's Name has been pronounced (at the time of slaughtering the animal), while He has explained to you in detail what is forbidden to you, except under compulsion of necessity? And surely many do lead (mankind) astray by their own desires through lack of knowledge. Certainly your Lord knows best the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
Leave (O mankind, all kinds of) sin, open and secret. Verily, those who commit sin will get due recompense for that which they used to commit.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
Eat not (O believers) of that (meat) on which Allah's Name has not been pronounced (at the time of the slaughtering of the animal), for sure it is Fisq (a sin and disobedience of Allah). And certainly, the Shayatin (devils) do inspire their friends (from mankind) to dispute with you, and if you obey them [by making Al-Maytatah (a dead animal) legal by eating it], then you would indeed be Mushrikun (polytheists) [because they (devils and their friends) made lawful to you to eat that which Allah has made unlawful to eat and you obeyed them by considering it lawful to eat, and by doing so you worshipped them, and to worship others besides Allah is polytheism].\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead (without Faith by ignorance and disbelief) and We gave him life (by knowledge and Faith) and set for him a light (of Belief) whereby he can walk amongst men, like him who is in the darkness (of disbelief, polytheism and hypocrisy) from which he can never come out? Thus it is made fair-seeming to the disbelievers that which they used to do.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And thus We have set up in every town great ones of its wicked people to plot therein. But they plot not except against their ownselves, and they perceive (it) not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when there comes to them a sign (from Allah) they say: ``We shall not believe until we receive the like of that which the Messengers of Allah had received." Allah knows best with whom to place His Message. Humiliation and disgrace from Allah and a severe torment will overtake the criminals (polytheists, sinners, etc.) for that which they used to plot.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
And whomsoever Allah wills to guide, He opens his breast to Islam, and whomsoever He wills to send astray, He makes his breast closed and constricted, as if he is climbing up to the sky. Thus Allah puts the wrath on those who believe not.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
And this is the Path of your Lord (the Quran and Islam) leading Straight. We have detailed Our Revelations for a people who take heed.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them will be the home of peace (Paradise) with their Lord. And He will be their Wali (Helper and Protector) because of what they used to do.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
And on the Day when He will gather them (all) together (and say): ``O you assembly of jinns! Many did you mislead of men," and their Auliya' (friends and helpers, etc.) amongst men will say: ``Our Lord! We benefited one from the other, but now we have reached our appointed term which You did appoint for us." He will say: ``The Fire be your dwelling-place, you will dwell therein forever, except as Allah may will. Certainly your Lord is All-Wise, All-Knowing."\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
And thus We do make the Zalimun (polytheists and wrong-doers, etc.) Auliya' (supporters and helpers) one to another (in committing crimes etc.), because of that which they used to earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
O you assembly of jinns and mankind! ``Did not there come to you Messengers from amongst you, reciting unto you My Verses and warning you of the meeting of this Day of yours?" They will say: ``We bear witness against ourselves." It was the life of this world that deceived them. And they will bear witness against themselves that they were disbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
This is because your Lord would not destroy the (populations of) towns for their wrong-doing (i.e. associating others in worship along with Allah) while their people were unaware (so the Messengers were sent).\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
For all there will be degrees (or ranks) according to what they did. And your Lord is not unaware of what they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
And your Lord is Rich (Free of all wants), full of Mercy, if He will, He can destroy you, and in your place make whom He will as your successors, as He raised you from the seed of other people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Surely, that which you are promised will verily come to pass, and you cannot escape (from the Punishment of Allah).\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say (O Muhammad SAW): ``O my people! Work according to your way, surely, I too am working (in my way), and you will come to know for which of us will be the (happy) end in the Hereafter. Certainly the Zalimun (polytheists and wrong-doers, etc.) will not be successful.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And they assign to Allah a share of the tilth and cattle which He has created, and they say: ``This is for Allah according to their pretending, and this is for our (Allah's so-called) partners." But the share of their (Allah's so-called) ``partners" reaches not Allah, while the share of Allah reaches their (Allah's so-called) ``partners"! Evil is the way they judge!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And so to many of the Mushrikun (polytheists - see V. 2:105) their (Allah's so-called) ``partners" have made fair-seeming the killing of their children, in order to lead them to their own destruction and cause confusion in their religion. And if Allah had willed they would not have done so. So leave them alone with their fabrications.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And according to their pretending, they say that such and such cattle and crops are forbidden, and none should eat of them except those whom we allow. And (they say) there are cattle forbidden to be used for burden or any other work, and cattle on which (at slaughtering) the Name of Allah is not pronounced; lying against Him (Allah). He will recompense them for what they used to fabricate.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say: ``What is in the bellies of such and such cattle (milk or foetus) is for our males alone, and forbidden to our females (girls and women), but if it is born dead, then all have shares therein." He will punish them for their attribution (of such false orders to Allah). Verily, He is All-Wise, All-Knower. (Tafsir At-Tabari, Vol. 8, Page 49).\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Indeed lost are they who have killed their children, from folly, without knowledge, and have forbidden that which Allah has provided for them, inventing a lie against Allah. They have indeed gone astray and were not guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
And it is He Who produces gardens trellised and untrellised, and date-palms, and crops of different shape and taste (its fruits and its seeds) and olives, and pomegranates, similar (in kind) and different (in taste). Eat of their fruit when they ripen, but pay the due thereof (its Zakat, according to Allah's Orders 1/10th or 1/20th) on the day of its harvest, and waste not by extravagance. Verily, He likes not Al-Musrifun (those who waste by extravagance),\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle (are some) for burden (like camels etc.) and (some are) small (unable to carry burden like sheep, goats etc. for food, meat, milk, wool etc.). Eat of what Allah has provided for you, and follow not the footsteps of Shaitan (Satan). Surely he is to you an open enemy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
Eight pairs; of the sheep two (male and female), and of the goats two (male and female). Say: ``Has He forbidden the two males or the two females, or (the young) which the wombs of the two females enclose? Inform me with knowledge if you are truthful."\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And of the camels two (male and female), and of oxen two (male and female). Say: ``Has He forbidden the two males or the two females or (the young) which the wombs of the two females enclose? Or were you present when Allah ordered you such a thing? Then who does more wrong than one who invents a lie against Allah, to lead mankind astray without knowledge. Certainly Allah guides not the people who are Zalimun (polytheists and wrong-doers, etc.)."\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say (O Muhammad SAW): ``I find not in that which has been inspired to me anything forbidden to be eaten by one who wishes to eat it, unless it be Maytatah (a dead animal) or blood poured forth (by slaughtering or the like), or the flesh of swine (pork, etc.) for that surely is impure, or impious (unlawful) meat (of an animal) which is slaughtered as a sacrifice for others than Allah (or has been slaughtered for idols, etc., or on which Allah's Name has not been mentioned while slaughtering). But whosoever is forced by necessity without wilful disobedience, nor transgressing due limits, (for him) certainly, your Lord is Oft-Forgiving, Most Merciful."\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And unto those who are Jews, We forbade every (animal) with undivided hoof, and We forbade them the fat of the ox and the sheep except what adheres to their backs or their entrails, or is mixed up with a bone. Thus We recompensed them for their rebellion [committing crimes like murdering the Prophets, eating of Riba (usury), etc.]. And verily, We are Truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
If they (Jews) belie you (Muhammad SAW) say you: ``Your Lord is the Owner of Vast Mercy, and never will His Wrath be turned back from the people who are Mujrimun (criminals, polytheists, sinners, etc.)."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Those who took partners (in worship) with Allah will say: ``If Allah had willed, we would not have taken partners (in worship) with Him, nor would our fathers, and we would not have forbidden anything (against His Will)." Likewise belied those who were before them, (they argued falsely with Allah's Messengers), till they tasted of Our Wrath. Say: ``Have you any knowledge (proof) that you can produce before us? Verily, you follow nothing but guess and you do nothing but lie."\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say: ``With Allah is the perfect proof and argument, (i.e. the Oneness of Allah, the sending of His Messengers and His Holy Books, etc. to mankind), had He so willed, He would indeed have guided you all."\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: ``Bring forward your witnesses, who can testify that Allah has forbidden this. Then if they testify, testify not you (O Muhammad SAW) with them. And you should not follow the vain desires of such as treat Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) as falsehoods, and such as believe not in the Hereafter, and they hold others as equal (in worship) with their Lord."\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say (O Muhammad SAW): ``Come, I will recite what your Lord has prohibited you from: Join not anything in worship with Him; be good and dutiful to your parents; kill not your children because of poverty - We provide sustenance for you and for them; come not near to Al-Fawahish (shameful sins, illegal sexual intercourse, etc.) whether committed openly or secretly, and kill not anyone whom Allah has forbidden, except for a just cause (according to Islamic law). This He has commanded you that you may understand.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
``And come not near to the orphan's property, except to improve it, until he (or she) attains the age of full strength; and give full measure and full weight with justice. We burden not any person, but that which he can bear. And whenever you give your word (i.e. judge between men or give evidence, etc.), say the truth even if a near relative is concerned, and fulfill the Covenant of Allah, This He commands you, that you may remember.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
``And verily, this (i.e. Allah's Commandments mentioned in the above two Verses 151 and 152) is my Straight Path, so follow it, and follow not (other) paths, for they will separate you away from His Path. This He has ordained for you that you may become Al-Muttaqun (the pious - see V. 2:2)."\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then, We gave Musa (Moses) the Book [the Taurat (Torah)], to complete (Our Favour) upon those who would do right, and explaining all things in detail and a guidance and a mercy that they might believe in the meeting with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this is a blessed Book (the Quran) which We have sent down, so follow it and fear Allah (i.e. do not disobey His Orders), that you may receive mercy (i.e. saved from the torment of Hell).\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest you (pagan Arabs) should say: ``The Book was only sent down to two sects before us (the Jews and the Christians), and for our part, we were in fact unaware of what they studied."\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest you (pagan Arabs) should say: ``If only the Book had been sent down to us, we would surely have been better guided than they (Jews and Christians)." So now has come unto you a clear proof (the Quran) from your Lord, and a guidance and a mercy. Who then does more wrong than one who rejects the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah and turns away therefrom? We shall requite those who turn away from Our Ayat with an evil torment, because of their turning away (from them). [Tafsir At-Tabari, Vol. 8, Page 95]\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Do they then wait for anything other than that the angels should come to them, or that your Lord should come, or that some of the Signs of your Lord should come (i.e. portents of the Hour e.g., arising of the sun from the west)! The day that some of the Signs of your Lord do come, no good will it do to a person to believe then, if he believed not before, nor earned good (by performing deeds of righteousness) through his Faith. Say: ``Wait you! we (too) are waiting."\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Verily, those who divide their religion and break up into sects (all kinds of religious sects), you (O Muhammad SAW) have no concern in them in the least. Their affair is only with Allah, Who then will tell them what they used to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoever brings a good deed (Islamic Monotheism and deeds of obedience to Allah and His Messenger SAW) shall have ten times the like thereof to his credit, and whoever brings an evil deed (polytheism, disbelief, hypocrisy, and deeds of disobedience to Allah and His Messenger SAW) shall have only the recompense of the like thereof, and they will not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say (O Muhammad SAW): ``Truly, my Lord has guided me to a Straight Path, a right religion, the religion of Ibrahim (Abraham), Hanifa [i.e. the true Islamic Monotheism - to believe in One God (Allah i.e. to worship none but Allah, Alone)] and he was not of Al-Mushrikun (see V. 2:105)."\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say (O Muhammad SAW): ``Verily, my Salat (prayer), my sacrifice, my living, and my dying are for Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
``He has no partner. And of this I have been commanded, and I am the first of the Muslims."\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: ``Shall I seek a lord other than Allah, while He is the Lord of all things? No person earns any (sin) except against himself (only), and no bearer of burdens shall bear the burden of another. Then unto your Lord is your return, so He will tell you that wherein you have been differing."\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
And it is He Who has made you generations coming after generations, replacing each other on the earth. And He has raised you in ranks, some above others that He may try you in that which He has bestowed on you. Surely your Lord is Swift in retribution, and certainly He is Oft-Forgiving, Most Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif-Lam-Mim-Sad. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
(This is the) Book (the Quran) sent down unto you (O Muhammad SAW), so let not your breast be narrow therefrom, that you warn thereby, and a reminder unto the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
[Say (O Muhammad SAW) to these idolaters (pagan Arabs) of your folk:] Follow what has been sent down unto you from your Lord (the Quran and Prophet Muhammad's Sunnah), and follow not any Auliya' (protectors and helpers, etc. who order you to associate partners in worship with Allah), besides Him (Allah). Little do you remember!\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
And a great number of towns (their population) We destroyed (for their crimes). Our torment came upon them (suddenly) by night or while they were sleeping for their afternoon rest.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
No cry did they utter when Our Torment came upon them but this: ``Verily, we were Zalimun (polytheists and wrong-doers, etc.)".\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then surely, We shall question those (people) to whom it (the Book) was sent and verily, We shall question the Messengers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then surely, We shall narrate unto them (their whole story) with knowledge, and indeed We were not absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
And the weighing on that day (Day of Resurrection) will be the true (weighing). So as for those whose scale (of good deeds) will be heavy, they will be the successful (by entering Paradise).\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And as for those whose scale will be light, they are those who will lose their ownselves (by entering Hell) because they denied and rejected Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And surely, We gave you authority on the earth and appointed for you therein provisions (for your life). Little thanks do you give.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And surely, We created you (your father Adam) and then gave you shape (the noble shape of a human being), then We told the angels, ``Prostrate to Adam", and they prostrated, except Iblis (Satan), he refused to be of those who prostrate.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
(Allah) said: ``What prevented you (O Iblis) that you did not prostrate, when I commanded you?" Iblis said: ``I am better than him (Adam), You created me from fire, and him You created from clay."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
(Allah) said: ``(O Iblis) get down from this (Paradise), it is not for you to be arrogant here. Get out, for you are of those humiliated and disgraced."\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
(Iblis) said: ``Allow me respite till the Day they are raised up (i.e. the Day of Resurrection)."\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
(Allah) said: ``You are of those allowed respite."\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
(Iblis) said: ``Because You have sent me astray, surely I will sit in wait against them (human beings) on Your Straight Path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then I will come to them from before them and behind them, from their right and from their left, and You will not find most of them as thankful ones (i.e. they will not be dutiful to You)."\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
(Allah) said (to Iblis) ``Get out from this (Paradise) disgraced and expelled. Whoever of them (mankind) will follow you, then surely I will fill Hell with you all."\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
``And O Adam! Dwell you and your wife in Paradise, and eat thereof as you both wish, but approach not this tree otherwise you both will be of the Zalimun (unjust and wrong-doers)."\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then Shaitan (Satan) whispered suggestions to them both in order to uncover that which was hidden from them of their private parts (before); he said: ``Your Lord did not forbid you this tree save you should become angels or become of the immortals."\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he [Shaitan (Satan)] swore by Allah to them both (saying): ``Verily, I am one of the sincere well-wishers for you both."\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he misled them with deception. Then when they tasted of the tree, that which was hidden from them of their shame (private parts) became manifest to them and they began to stick together the leaves of Paradise over themselves (in order to cover their shame). And their Lord called out to them (saying): ``Did I not forbid you that tree and tell you: Verily, Shaitan (Satan) is an open enemy unto you?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said: ``Our Lord! We have wronged ourselves. If You forgive us not, and bestow not upon us Your Mercy, we shall certainly be of the losers."\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
(Allah) said: ``Get down, one of you an enemy to the other [i.e. Adam, Hawwa (Eve), and Shaitan (Satan), etc.]. On earth will be a dwelling-place for you and an enjoyment, - for a time."\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said: ``Therein you shall live, and therein you shall die, and from it you shall be brought out (i.e. resurrected)."\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Children of Adam! We have bestowed raiment upon you to cover yourselves (screen your private parts, etc.) and as an adornment, and the raiment of righteousness, that is better. Such are among the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, that they may remember (i.e. leave falsehood and follow truth).\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Children of Adam! Let not Shaitan (Satan) deceive you, as he got your parents [Adam and Hawwa (Eve)] out of Paradise, stripping them of their raiments, to show them their private parts. Verily, he and Qabiluhu (his soldiers from the jinns or his tribe) see you from where you cannot see them. Verily, We made the Shayatin (devils) Auliya' (protectors and helpers) for those who believe not.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit a Fahisha (evil deed, going round the Ka'bah in naked state, every kind of unlawful sexual intercourse, etc.), they say: ``We found our fathers doing it, and Allah has commanded us of it." Say: ``Nay, Allah never commands of Fahisha. Do you say of Allah what you know not?\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say (O Muhammad SAW): My Lord has commanded justice and (said) that you should face Him only (i.e. worship none but Allah and face the Qiblah, i.e. the Ka'bah at Makkah during prayers) in each and every place of worship, in prayers (and not to face other false deities and idols), and invoke Him only making your religion sincere to Him by not joining in worship any partner to Him and with the intention that you are doing your deeds for Allah's sake only. As He brought you (into being) in the beginning, so shall you be brought into being (on the Day of Resurrection) [in two groups, one as a blessed one (believers), and the other as a wretched one (disbelievers)].\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A group He has guided, and a group deserved to be in error; (because) surely they took the Shayatin (devils) as Auliya' (protectors and helpers) instead of Allah, and consider that they are guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! Take your adornment (by wearing your clean clothes), while praying and going round (the Tawaf of) the Ka'bah, and eat and drink but waste not by extravagance, certainly He (Allah) likes not Al-Musrifun (those who waste by extravagance).\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say (O Muhammad SAW): ``Who has forbidden the adoration with clothes given by Allah, which He has produced for his slaves, and At-Taiyibat [all kinds of Halal (lawful) things] of food?" Say: ``They are, in the life of this world, for those who believe, (and) exclusively for them (believers) on the Day of Resurrection (the disbelievers will not share them)." Thus We explain the Ayat (Islamic laws) in detail for people who have knowledge.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say (O Muhammad SAW): ``(But) the things that my Lord has indeed forbidden are Al-Fawahish (great evil sins, every kind of unlawful sexual intercourse, etc.) whether committed openly or secretly, sins (of all kinds), unrighteous oppression, joining partners (in worship) with Allah for which He has given no authority, and saying things about Allah of which you have no knowledge."\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And every nation has its appointed term; when their term is reached, neither can they delay it nor can they advance it an hour (or a moment).\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Children of Adam! If there come to you Messengers from amongst you, reciting to you, My Verses, then whosoever becomes pious and righteous, on them shall be no fear, nor shall they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But those who reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and treat them with arrogance, they are the dwellers of the (Hell) Fire, they will abide therein forever.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who is more unjust than one who invents a lie against Allah or rejects His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.)? For such their appointed portion (good things of this worldly life and their period of stay therein) will reach them from the Book (of Decrees) until, when Our Messengers (the angel of death and his assistants) come to them to take their souls, they (the angels) will say: ``Where are those whom you used to invoke and worship besides Allah," they will reply, ``They have vanished and deserted us." And they will bear witness against themselves, that they were disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
(Allah) will say: ``Enter you in the company of nations who passed away before you, of men and jinns, into the Fire." Every time a new nation enters, it curses its sister nation (that went before), until they will be gathered all together in the Fire. The last of them will say to the first of them: ``Our Lord! These misled us, so give them a double torment of the Fire." He will say: ``For each one there is double (torment), but you know not."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
The first of them will say to the last of them: ``You were not better than us, so taste the torment for what you used to earn."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Verily, those who belie Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and treat them with arrogance, for them the gates of heaven will not be opened, and they will not enter Paradise until the camel goes through the eye of the needle (which is impossible). Thus do We recompense the Mujrimun (criminals, polytheists, sinners, etc.).\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Theirs will be a bed of Hell (Fire), and over them coverings (of Hell-fire). Thus do We recompense the Zalimun (polytheists and wrong-doers, etc.).\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
But those who believed (in the Oneness of Allah - Islamic Monotheism), and worked righteousness - We tax not any person beyond his scope, such are the dwellers of Paradise. They will abide therein.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We shall remove from their breasts any (mutual) hatred or sense of injury (which they had, if at all, in the life of this world); rivers flowing under them, and they will say: ``All the praises and thanks be to Allah, Who has guided us to this, never could we have found guidance, were it not that Allah had guided us! Indeed, the Messengers of our Lord did come with the truth." And it will be cried out to them: ``This is the Paradise which you have inherited for what you used to do."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the dwellers of Paradise will call out to the dwellers of the Fire (saying): ``We have indeed found true what our Lord had promised us; have you also found true, what your Lord promised (warnings, etc.)?" They shall say: ``Yes." Then a crier will proclaim between them: ``The Curse of Allah is on the Zalimun (polytheists and wrong-doers, etc.),"\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
Those who hindered (men) from the Path of Allah, and would seek to make it crooked, and they were disbelievers in the Hereafter.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And between them will be a barrier screen and on Al-A'raf (a wall with elevated places) will be men (whose good and evil deeds would be equal in scale), who would recognise all (of the Paradise and Hell people), by their marks (the dwellers of Paradise by their white faces and the dwellers of Hell by their black faces), they will call out to the dwellers of Paradise, ``Salamun 'Alaikum" (peace be on you), and at that time they (men on Al-A'raf) will not yet have entered it (Paradise), but they will hope to enter (it) with certainty.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes will be turned towards the dwellers of the Fire, they will say: ``Our Lord! Place us not with the people who are Zalimun (polytheists and wrong-doers)."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the men on Al-A'raf (the wall) will call unto the men whom they would recognise by their marks, saying: ``Of what benefit to you were your great numbers (and hoards of wealth), and your arrogance against Faith?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
Are they those, of whom you swore that Allah would never show them mercy. (Behold! It has been said to them): ``Enter Paradise, no fear shall be on you, nor shall you grieve."\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
And the dwellers of the Fire will call to the dwellers of Paradise: ``Pour on us some water or anything that Allah has provided you with." They will say: ``Both (water and provision) Allah has forbidden to the disbelievers."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
``Who took their religion as an amusement and play, and the life of the world deceived them." So this Day We shall forget them as they forgot their meeting of this Day, and as they used to reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
Certainly, We have brought to them a Book (the Quran) which We have explained in detail with knowledge, - a guidance and a mercy to a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Await they just for the final fulfillment of the event? On the Day the event is finally fulfilled (i.e. the Day of Resurrection), those who neglected it before will say: ``Verily, the Messengers of our Lord did come with the truth, now are there any intercessors for us that they might intercede on our behalf? Or could we be sent back (to the first life of the world) so that we might do (good) deeds other than those (evil) deeds which we used to do?" Verily, they have lost their ownselves (i.e. destroyed themselves) and that which they used to fabricate (invoking and worshipping others besides Allah) has gone away from them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Indeed your Lord is Allah, Who created the heavens and the earth in Six Days, and then He Istawa (rose over) the Throne (really in a manner that suits His Majesty). He brings the night as a cover over the day, seeking it rapidly, and (He created) the sun, the moon, the stars subjected to His Command. Surely, His is the Creation and Commandment. Blessed be Allah, the Lord of the 'Alamin (mankind, jinns and all that exists)!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Invoke your Lord with humility and in secret. He likes not the aggressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
And do not do mischief on the earth, after it has been set in order, and invoke Him with fear and hope; Surely, Allah's Mercy is (ever) near unto the good-doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He Who sends the winds as heralds of glad tidings, going before His Mercy (rain). Till when they have carried a heavy-laden cloud, We drive it to a land that is dead, then We cause water (rain) to descend thereon. Then We produce every kind of fruit therewith. Similarly, We shall raise up the dead, so that you may remember or take heed.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
The vegetation of a good land comes forth (easily) by the Permission of its Lord, and that which is bad, brings forth nothing but a little with difficulty. Thus do We explain variously the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) for a people who give thanks.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
Indeed, We sent Nuh (Noah) to his people and he said: ``O my people! Worship Allah! You have no other Ilah (God) but Him. (La ilaha ill-Allah: none has the right to be worshipped but Allah). Certainly, I fear for you the torment of a Great Day!"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The leaders of his people said: ``Verily, we see you in plain error."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
[Nuh (Noah)] said: ``O my people! There is no error in me, but I am a Messenger from the Lord of the 'Alamin (mankind, jinns and all that exists)!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
``I convey unto you the Messages of my Lord and give sincere advice to you. And I know from Allah what you know not.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
``Do you wonder that there has come to you a Reminder from your Lord through a man from amongst you, that he may warn you, so that you may fear Allah and that you may receive (His) Mercy?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they belied him, so We saved him and those along with him in the ship, and We drowned those who belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.). They were indeed a blind people.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And to 'Ad (people, We sent) their brother Hud. He said: ``O my people! Worship Allah! You have no other Ilah (God) but Him. (La ilaha ill-Allah: none has the right to be worshipped but Allah). Will you not fear (Allah)?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The leaders of those who disbelieved among his people said: ``Verily, we see you in foolishness, and verily, we think you are one of the liars."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
(Hud) said: ``O my people! There is no foolishness in me, but (I am) a Messenger from the Lord of the 'Alamin (mankind, jinns and all that exists)!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
``I convey unto you the Messages of my Lord, and I am a trustworthy adviser (or well-wisher) for you.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
``Do you wonder that there has come to you a Reminder (and an advice) from your Lord through a man from amongst you that he may warn you? And remember that He made you successors after the people of Nuh (Noah), and increased you amply in stature. So remember the graces (bestowed upon you) from Allah, so that you may be successful."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: ``You have come to us that we should worship Allah Alone and forsake that which our fathers used to worship. So bring us that wherewith you have threatened us if you are of the truthful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
(Hud) said: ``Torment and wrath have already fallen on you from your Lord. Dispute you with me over names which you have named - you and your fathers, with no authority from Allah? Then wait, I am with you among those who wait."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
So We saved him and those who were with him by a Mercy from Us, and We cut the roots of those who belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and they were not believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamud (people, We sent) their brother Salih (Saleh). He said: ``O my people! Worship Allah! You have no other Ilah (God) but Him. (La ilaha ill-Allah: none has the right to be worshipped but Allah). Indeed there has come to you a clear sign (the miracle of the coming out of a huge she-camel from the midst of a rock) from your Lord. This she-camel of Allah is a sign unto you; so you leave her to graze in Allah's earth, and touch her not with harm, lest a painful torment should seize you.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
``And remember when He made you successors after 'Ad (people) and gave you habitations in the land, you build for yourselves palaces in plains, and carve out homes in the mountains. So remember the graces (bestowed upon you) from Allah, and do not go about making mischief on the earth."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The leaders of those who were arrogant among his people said to those who were counted weak - to such of them as believed: ``Know you that Salih (Saleh) is one sent from his Lord." They said: ``We indeed believe in that with which he has been sent."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were arrogant said: ``Verily, we disbelieve in that which you believe in."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they killed the she-camel and insolently defied the Commandment of their Lord, and said: ``O Salih (Saleh)! Bring about your threats if you are indeed one of the Messengers (of Allah)."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake seized them, and they lay (dead), prostrate in their homes.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
Then he [Salih (Saleh)] turned from them, and said: ``O my people! I have indeed conveyed to you the Message of my Lord, and have given you good advice but you like not good advisers."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And (remember) Lout (Lot), when he said to his people: ``Do you commit the worst sin such as none preceding you has committed in the 'Alamin (mankind and jinns)?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
``Verily, you practise your lusts on men instead of women. Nay, but you are a people transgressing beyond bounds (by committing great sins)."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And the answer of his people was only that they said: ``Drive them out of your town, these are indeed men who want to be pure (from sins)!"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
Then We saved him and his family, except his wife; she was of those who remained behind (in the torment).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained down on them a rain (of stones). Then see what was the end of the Mujrimun (criminals, polytheists, sinners, etc.).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to (the people of) Madyan (Midian), (We sent) their brother Shu'aib. He said: ``O my people! Worship Allah! You have no other Ilah (God) but Him. [La ilaha ill-Allah (none has the right to be worshipped but Allah)]." Verily, a clear proof (sign) from your Lord has come unto you; so give full measure and full weight and wrong not men in their things, and do not mischief on the earth after it has been set in order, that will be better for you, if you are believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
``And sit not on every road, threatening, and hindering from the Path of Allah those who believe in Him. and seeking to make it crooked. And remember when you were but few, and He multiplied you. And see what was the end of the Mufsidun (mischief-makers, corrupts, liars).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
``And if there is a party of you who believes in that with which I have been sent and a party who do not believe, so be patient until Allah judges between us, and He is the Best of judges."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The chiefs of those who were arrogant among his people said: ``We shall certainly drive you out, O Shu'aib, and those who have believed with you from our town, or else you (all) shall return to our religion." He said: ``Even though we hate it!\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
``We should have invented a lie against Allah if we returned to your religion, after Allah has rescued us from it. And it is not for us to return to it unless Allah, our Lord, should will. Our Lord comprehends all things in His Knowledge. In Allah (Alone) we put our trust. Our Lord! Judge between us and our people in truth, for You are the Best of those who give judgment."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
The chiefs of those who disbelieved among his people said (to their people): ``If you follow Shu'aib, be sure then you will be the losers!"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them and they lay (dead), prostrate in their homes.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who belied Shu'aib, became as if they had never dwelt there (in their homes). Those who belied Shu'aib, they were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
Then he (Shu'aib) turned from them and said: ``O my people! I have indeed conveyed my Lord's Messages unto you and I have given you good advice. Then how can I sorrow for the disbelieving people's (destruction)."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And We sent no Prophet unto any town (and they denied him), but We seized its people with suffering from extreme poverty (or loss in wealth) and loss of health and calamities, so that they might humiliate themselves (and repent to Allah).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed the evil for the good, until they increased in number and in wealth, and said: ``Our fathers were touched with evil (loss of health and calamities) and with good (prosperity, etc.)." So We seized them of a sudden while they were unaware.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
And if the people of the towns had believed and had the Taqwa (piety), certainly, We should have opened for them blessings from the heaven and the earth, but they belied (the Messengers). So We took them (with punishment) for what they used to earn (polytheism and crimes, etc.).\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Did the people of the towns then feel secure against the coming of Our Punishment by night while they are asleep?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or, did the people of the towns then feel secure against the coming of Our Punishment in the forenoon while they play?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Did they then feel secure against the Plan of Allah. None feels secure from the Plan of Allah except the people who are the losers.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not clear to those who inherit the earth in succession from its (previous) possessors, that had We willed, We would have punished them for their sins. And We seal up their hearts so that they hear not?\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Those were the towns whose story We relate unto you (O Muhammad SAW). And there came indeed to them their Messengers with clear proofs, but they were not such as to believe in that which they had rejected before. Thus Allah does seal up the hearts of the disbelievers (from each and every kind of religious guidance).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
And most of them We found not (true) to their covenant, but most of them We found indeed Fasiqun (rebellious, disobedient to Allah).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then after them We sent Musa (Moses) with Our Signs to Fir'aun (Pharaoh) and his chiefs, but they wrongfully rejected them. So see how was the end of the Mufsidun (mischief-makers, corrupts, etc.).\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Musa (Moses) said: ``O Fir'aun (Pharaoh)! I am a Messenger from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
``Proper it is for me that I say nothing concerning Allah but the truth. Indeed I have come unto you from your Lord with a clear proof. So let the Children of Israel depart along with me."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
[Fir'aun (Pharaoh)] said: ``If you have come with a sign, show it forth, - if you are one of those who tell the truth."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
Then [Musa (Moses)] threw his stick and behold! it was a serpent, manifest!\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew out his hand, and behold! it was white (with radiance) for the beholders.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The chiefs of the people of Fir'aun (Pharaoh) said: ``This is indeed a well-versed sorcerer;\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
``He wants to get you out of your land, so what do you advise?"\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said: ``Put him and his brother off (for a time), and send callers (men) to the cities to collect (and) -\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
``That they bring up to you all well-versed sorcerers."\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And so the sorcerers came to Fir'aun (Pharaoh). They said: ``Indeed there will be a (good) reward for us if we are the victors."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said: ``Yes, and moreover you will (in that case) be of the nearest (to me)."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: ``O Musa (Moses)! Either you throw (first), or shall we have the (first) throw?"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He [Musa (Moses)] said: ``Throw you (first)." So when they threw, they bewitched the eyes of the people, and struck terror into them, and they displayed a great magic.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We inspired Musa (Moses) (saying): ``Throw your stick," and behold! It swallowed up straight away all the falsehoods which they showed.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus truth was confirmed, and all that they did was made of no effect.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
So they were defeated there and then, and were returned disgraced.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the sorcerers fell down prostrate.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said: ``We believe in the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
``The Lord of Musa (Moses) and Harun (Aaron)."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Fir'aun (Pharaoh) said: ``You have believed in him [Musa (Moses)] before I give you permission. Surely, this is a plot which you have plotted in the city to drive out its people, but you shall come to know.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
``Surely, I will cut off your hands and your feet on opposite sides, then I will crucify you all."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said: ``Verily, we are returning to our Lord.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
``And you take vengeance on us only because we believed in the Ayat (proofs, evidences, lessons, signs, etc.) of our Lord when they reached us! Our Lord! pour out on us patience, and cause us to die as Muslims."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The chiefs of Fir'aun's (Pharaoh) people said: ``Will you leave Musa (Moses) and his people to spread mischief in the land, and to abandon you and your gods?" He said: ``We will kill their sons, and let live their women, and we have indeed irresistible power over them."\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Musa (Moses) said to his people: ``Seek help in Allah and be patient. Verily, the earth is Allah's. He gives it as a heritage to whom He will of His slaves, and the (blessed) end is for the Muttaqun (pious - see V. 2:2)."\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said: ``We (Children of Israel) had suffered troubles before you came to us, and since you have come to us." He said: ``It may be that your Lord will destroy your enemy and make you successors on the earth, so that He may see how you act?"\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And indeed We punished the people of Fir'aun (Pharaoh) with years of drought and shortness of fruits (crops, etc.), that they might remember (take heed).\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But whenever good came to them, they said: ``Ours is this." And if evil afflicted them, they ascribed it to evil omens connected with Musa (Moses) and those with him. Be informed! Verily, their evil omens are with Allah but most of them know not.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
They said [to Musa (Moses)]: ``Whatever Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) you may bring to us, to work therewith your sorcery on us, we shall never believe in you."\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent on them: the flood, the locusts, the lice, the frogs, and the blood: (as a succession of) manifest signs, yet they remained arrogant, and they were of those people who were Mujrimun (criminals, polytheists, sinners, etc.).\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the punishment fell on them they said: ``O Musa (Moses)! Invoke your Lord for us because of His Promise to you. If you will remove the punishment from us, we indeed shall believe in you, and we shall let the Children of Israel go with you."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We removed the punishment from them to a fixed term, which they had to reach, behold! They broke their word!\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We took retribution from them. We drowned them in the sea, because they belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and were heedless about them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made the people who were considered weak to inherit the eastern parts of the land and the western parts thereof which We have blessed. And the fair Word of your Lord was fulfilled for the Children of Israel, because of their endurance. And We destroyed completely all the great works and buildings which Fir'aun (Pharaoh) and his people erected.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We brought the Children of Israel (with safety) across the sea, and they came upon a people devoted to some of their idols (in worship). They said: ``O Musa (Moses)! Make for us an ilahan (a god) as they have aliha (gods)." He said: ``Verily, you are a people who know not (the Majesty and Greatness of Allah and what is obligatory upon you, i.e. to worship none but Allah Alone, the One and the Only God of all that exists)."\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
[Musa (Moses) added:] ``Verily, these people will be destroyed for that which they are engaged in (idols-worship). And all that they are doing is in vain."\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said: ``Shall I seek for you an Ilahan (a God) other than Allah, while He has given you superiority over the 'Alamin (mankind and jinns of your time)."\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And (remember) when We rescued you from Fir'aun's (Pharaoh) people, who were afflicting you with the worst torment, killing your sons and letting your women live. And in that was a great trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We appointed for Musa (Moses) thirty nights and added (to the period) ten (more), and he completed the term, appointed by his Lord, of forty nights. And Musa (Moses) said to his brother Harun (Aaron): ``Replace me among my people, act in the Right Way (by ordering the people to obey Allah and to worship Him Alone) and follow not the way of the Mufsidun (mischief-makers)."\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Musa (Moses) came at the time and place appointed by Us, and his Lord spoke to him, he said: ``O my Lord! Show me (Yourself), that I may look upon You." Allah said: ``You cannot see Me, but look upon the mountain if it stands still in its place then you shall see Me." So when his Lord appeared to the mountain, He made it collapse to dust, and Musa (Moses) fell down unconscious. Then when he recovered his senses he said: ``Glory be to You, I turn to You in repentance and I am the first of the believers."\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
(Allah) said: ``O Musa (Moses) I have chosen you above men by My Messages, and by My speaking (to you). So hold that which I have given you and be of the grateful."\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him on the Tablets the lesson to be drawn from all things and the explanation of all things (and said): Hold unto these with firmness, and enjoin your people to take the better therein. I shall show you the home of Al-Fasiqun (the rebellious, disobedient to Allah).\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn away from My Ayat (verses of the Quran) those who behave arrogantly on the earth, without a right, and (even) if they see all the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they will not believe in them. And if they see the way of righteousness (monotheism, piety, and good deeds), they will not adopt it as the Way, but if they see the way of error (polytheism, crimes and evil deeds), they will adopt that way, that is because they have rejected Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and were heedless (to learn a lesson) from them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who deny Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and the Meeting in the Hereafter (Day of Resurrection,), vain are their deeds. Do they expect to be rewarded with anything except what they used to do?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And the people of Musa (Moses) made in his absence, out of their ornaments, the image of a calf (for worship). It had a sound (as if it was mooing). Did they not see that it could neither speak to them nor guide them to the way? They took it for worship and they were Zalimun (wrong-doers).\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they regretted and saw that they had gone astray, they (repented and) said: ``If our Lord have not mercy upon us and forgive us, we shall certainly be of the losers."\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Musa (Moses) returned to his people, angry and grieved, he said: ``What an evil thing is that which you have done (i.e. worshipping the calf) during my absence. Did you hasten and go ahead as regards the matter of your Lord (you left His worship)?" And he threw down the Tablets and seized his brother by (the hair of) his head and dragged him towards him. Harun (Aaron) said: ``O son of my mother! Indeed the people judged me weak and were about to kill me, so make not the enemies rejoice over me, nor put me amongst the people who are Zalimun (wrong-doers)."\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
Musa (Moses) said: ``O my Lord! Forgive me and my brother, and make us enter into Your Mercy, for you are the Most Merciful of those who show mercy."\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Certainly, those who took the calf (for worship), wrath from their Lord and humiliation will come upon them in the life of this world. Thus do We recompense those who invent lies.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
But those who committed evil deeds and then repented afterwards and believed, verily, your Lord after (all) that is indeed Oft-Forgiving, Most Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the anger of Musa (Moses) was appeased, he took up the Tablets, and in their inscription was guidance and mercy for those who fear their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Musa (Moses) chose out of his people seventy (of the best) men for Our appointed time and place of meeting, and when they were seized with a violent earthquake, he said: ``O my Lord, if it had been Your Will, You could have destroyed them and me before; would You destroy us for the deeds of the foolish ones among us? It is only Your Trial by which You lead astray whom You will, and keep guided whom You will. You are our Wali (Protector), so forgive us and have Mercy on us, for You are the Best of those who forgive.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
And ordain for us good in this world, and in the Hereafter. Certainly we have turned unto You." He said: (As to) My Punishment I afflict therewith whom I will and My Mercy embraces all things. That (Mercy) I shall ordain for those who are the Muttaqun (pious - see V. 2:2), and give Zakat; and those who believe in Our Ayat (proofs, evidences, verses, lessons, signs and revelations, etc.);\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the Messenger, the Prophet who can neither read nor write (i.e. Muhammad SAW) whom they find written with them in the Taurat (Torah) (Deut, xviii, 15) and the Injeel (Gospel) (John xiv, 16), - he commands them for Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam has ordained); and forbids them from Al-Munkar (i.e. disbelief, polytheism of all kinds, and all that Islam has forbidden); he allows them as lawful At-Taiyibat [(i.e. all good and lawful) as regards things, deeds, beliefs, persons, foods, etc.], and prohibits them as unlawful Al-Khaba'ith (i.e. all evil and unlawful as regards things, deeds, beliefs, persons, foods, etc.), he releases them from their heavy burdens (of Allah's Covenant), and from the fetters (bindings) that were upon them. So those who believe in him (Muhammad SAW), honour him, help him, and follow the light (the Quran) which has been sent down with him, it is they who will be successful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say (O Muhammad SAW): ``O mankind! Verily, I am sent to you all as the Messenger of Allah - to Whom belongs the dominion of the heavens and the earth. La ilaha illa Huwa (none has the right to be worshipped but He); It is He Who gives life and causes death. So believe in Allah and His Messenger (Muhammad SAW), the Prophet who can neither read nor write (i.e. Muhammad SAW) who believes in Allah and His Words [(this Quran), the Taurat (Torah) and the Injeel (Gospel) and also Allah's Word: ``Be!" - and he was, i.e. 'Iesa (Jesus) son of Maryam (Mary)], and follow him so that you may be guided."\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And of the people of Musa (Moses) there is a community who lead (the men) with truth and establish justice therewith (i.e. judge men with truth and justice).\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We divided them into twelve tribes (as distinct) nations. We directed Musa (Moses) by inspiration, when his people asked him for water, (saying): ``Strike the stone with your stick", and there gushed forth out of it twelve springs: each group knew its own place for water. We shaded them with the clouds and sent down upon them Al-Manna and the quails (saying): ``Eat of the good things with which We have provided you." They harmed Us not but they used to harm themselves.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And (remember) when it was said to them: ``Dwell in this town (Jerusalem) and eat therefrom wherever you wish, and say, '(O Allah) forgive our sins'; and enter the gate prostrate (bowing with humility). We shall forgive you your wrong-doings. We shall increase (the reward) for the good-doers."\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But those among them who did wrong changed the word that had been told to them. So We sent on them a torment from heaven in return for their wrong-doings.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask them (O Muhammad SAW) about the town that was by the sea, when they transgressed in the matter of the Sabbath (i.e. Saturday): when their fish came to them openly on the Sabbath day, and did not come to them on the day they had no Sabbath. Thus We made a trial of them for they used to rebel (see the Quran: V. 4:154).\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a community among them said: ``Why do you preach to a people whom Allah is about to destroy or to punish with a severe torment?" (The preachers) said: ``In order to be free from guilt before your Lord (Allah), and perhaps they may fear Allah."\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
So when they forgot the remindings that had been given to them, We rescued those who forbade evil, but We seized those who did wrong with a severe torment because they used to rebel (disobey Allah).\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
So when they exceeded the limits of what they were prohibited, We said to them: ``Be you monkeys, despised and rejected." (It is a severe warning to the mankind that they should not disobey what Allah commands them to do, and be far away from what He prohibits them).\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And (remember) when your Lord declared that He would certainly keep on sending against them (i.e. the Jews), till the Day of Resurrection, those who would afflict them with a humiliating torment. Verily, your Lord is Quick in Retribution (for the disobedient, wicked) and certainly He is Oft-Forgiving, Most Merciful (for the obedient and those who beg Allah's Forgiveness).\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We have broken them (i.e. the Jews) up into various separate groups on the earth, some of them are righteous and some are away from that. And We tried them with good (blessings) and evil (calamities) in order that they might turn (to Allah's Obedience).\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
Then after them succeeded an (evil) generation, which inherited the Book, but they chose (for themselves) the goods of this low life (evil pleasures of this world) saying (as an excuse): ``(Everything) will be forgiven to us." And if (again) the offer of the like (evil pleasures of this world) came their way, they would (again) seize them (would commit those sins). Was not the covenant of the Book taken from them that they would not say about Allah anything but the truth? And they have studied what is in it (the Book). And the home of the Hereafter is better for those who are Al-Muttaqun (the pious - see V. 2:2). Do not you then understand?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And as to those who hold fast to the Book (i.e. act on its teachings) and perform As-Salat (Iqamat-as-Salat), certainly, We shall never waste the reward of those who do righteous deeds.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And (remember) when We raised the mountain over them as if it had been a canopy, and they thought that it was going to fall on them. (We said): ``Hold firmly to what We have given you [i.e. the Taurat (Torah)], and remember that which is therein (act on its commandments), so that you may fear Allah and obey Him."\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And (remember) when your Lord brought forth from the Children of Adam, from their loins, their seed (or from Adam's loin his offspring) and made them testify as to themselves (saying): ``Am I not your Lord?" They said: ``Yes! We testify," lest you should say on the Day of Resurrection: ``Verily, we have been unaware of this."\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or lest you should say: ``It was only our fathers afortime who took others as partners in worship along with Allah, and we were (merely their) descendants after them; will You then destroy us because of the deeds of men who practised Al-Batil (i.e. polytheism and committing crimes and sins, invoking and worshipping others besides Allah)?" (Tafsir At-Tabari).\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
Thus do We explain the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in detail, so that they may turn (unto the truth).\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite (O Muhammad SAW) to them the story of him to whom We gave Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), but he threw them away, so Shaitan (Satan) followed him up, and he became of those who went astray.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed, We would surely have elevated him therewith but he clung to the earth and followed his own vain desire. So his description is the description of a dog: if you drive him away, he lolls his tongue out, or if you leave him alone, he (still) lolls his tongue out. Such is the description of the people who reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.). So relate the stories, perhaps they may reflect.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil is the likeness of the people who reject Our Ayat (proofs, evidences, verses and signs, etc.), and used to wrong their ownselves.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomsoever Allah guides, he is the guided one, and whomsoever He sends astray, those! They are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And surely, We have created many of the jinns and mankind for Hell. They have hearts wherewith they understand not, they have eyes wherewith they see not, and they have ears wherewith they hear not (the truth). They are like cattle, nay even more astray; those! They are the heedless ones.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
And (all) the Most Beautiful Names belong to Allah, so call on Him by them, and leave the company of those who belie or deny (or utter impious speech against) His Names. They will be requited for what they used to do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And of those whom We have created, there is a community who guides (others) with the truth, and establishes justice therewith.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
Those who reject Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), We shall gradually seize them with punishment in ways they perceive not.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I respite them; certainly My Plan is strong.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Do they not reflect? There is no madness in their companion (Muhammad SAW). He is but a plain warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Do they not look in the dominion of the heavens and the earth and all things that Allah has created, and that it may be that the end of their lives is near. In what message after this will they then believe?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whomsoever Allah sends astray, none can guide him; and He lets them wander blindly in their transgressions.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you about the Hour (Day of Resurrection): ``When will be its appointed time?" Say: ``The knowledge thereof is with my Lord (Alone). None can reveal its time but He. Heavy is its burden through the heavens and the earth. It shall not come upon you except all of a sudden." They ask you as if you have a good knowledge of it. Say: ``The knowledge thereof is with Allah (Alone) but most of mankind know not."\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say (O Muhammad SAW): ``I possess no power of benefit or hurt to myself except as Allah wills. If I had the knowledge of the Ghaib (unseen), I should have secured for myself an abundance of wealth, and no evil should have touched me. I am but a warner, and a bringer of glad tidings unto people who believe."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He Who has created you from a single person (Adam), and (then) He has created from him his wife [Hawwa (Eve)], in order that he might enjoy the pleasure of living with her. When he had sexual relation with her, she became pregnant and she carried it about lightly. Then when it became heavy, they both invoked Allah, their Lord (saying): ``If You give us a Salih (good in every aspect) child, we shall indeed be among the grateful."\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He gave them a Salih (good in every aspect) child, they ascribed partners to Him (Allah) in that which He has given to them. High be Allah, Exalted above all that they ascribe as partners to Him. (Tafsir At-Tabari, Vol. 9, Page 148).\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they attribute as partners to Allah those who created nothing but they themselves are created?\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
No help can they give them, nor can they help themselves.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you call them to guidance, they follow you not. It is the same for you whether you call them or you keep silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Verily, those whom you call upon besides Allah are slaves like you. So call upon them and let them answer you if you are truthful.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet wherewith they walk? Or have they hands wherewith they hold? Or have they eyes wherewith they see? Or have they ears wherewith they hear? Say (O Muhammad SAW): ``Call your (so-called) partners (of Allah) and then plot against me, and give me no respite!\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
``Verily, my Wali (Protector, Supporter, and Helper, etc.) is Allah Who has revealed the Book (the Quran), and He protects (supports and helps) the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
``And those whom you call upon besides Him (Allah) cannot help you nor can they help themselves."\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you call them to guidance, they hear not and you will see them looking at you, yet they see not.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Show forgiveness, enjoin what is good, and turn away from the foolish (i.e. don't punish them).\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if an evil whisper comes to you from Shaitan (Satan) then seek refuge with Allah. Verily, He is All-Hearer, All-Knower.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Verily, those who are Al-Muttaqun (the pious - see V. 2:2), when an evil thought comes to them from Shaitan (Satan), they remember (Allah), and (indeed) they then see (aright).\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
But (as for) their brothers (the devils) they (i.e. the devils) plunge them deeper into error, and they never stop short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And if you do not bring them a miracle [according to their (i.e. Quraish-pagans') proposal], they say: ``Why have you not brought it?" Say: ``I but follow what is revealed to me from my Lord. This (the Quran) is nothing but evidences from your Lord, and a guidance and a mercy for a people who believe."\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
So, when the Quran is recited, listen to it, and be silent that you may receive mercy. [i.e. during the compulsory congregational prayers when the Imam (of a mosque) is leading the prayer (except Surat Al-Fatiha), and also when he is delivering the Friday-prayer Khutbah]. [Tafsir At-Tabari, Vol. 9, Pages 162-4]\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember your Lord by your tongue and within yourself, humbly and with fear without loudness in words in the mornings, and in the afternoons and be not of those who are neglectful.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Surely, those who are with your Lord (angels) are never too proud to perform acts of worship to Him, but they glorify His Praise and prostrate before Him.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you (O Muhammad SAW) about the spoils of war. Say: ``The spoils are for Allah and the Messenger." So fear Allah and adjust all matters of difference among you, and obey Allah and His Messenger (Muhammad SAW), if you are believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
The believers are only those who, when Allah is mentioned, feel a fear in their hearts and when His Verses (this Quran) are recited unto them, they (i.e. the Verses) increase their Faith; and they put their trust in their Lord (Alone);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Who perform As-Salat (Iqamat-as-Salat) and spend out of that We have provided them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
It is they who are the believers in truth. For them are grades of dignity with their Lord, and Forgiveness and a generous provision (Paradise).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
As your Lord caused you (O Muhammad SAW) to go out from your home with the truth, and verily, a party among the believers disliked it;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with you concerning the truth after it was made manifest, as if they were being driven to death, while they were looking (at it).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And (remember) when Allah promised you (Muslims) one of the two parties (of the enemy i.e. either the army or the caravan) that it should be yours, you wished that the one not armed (the caravan) should be yours, but Allah willed to justify the truth by His Words and to cut off the roots of the disbelievers (i.e. in the battle of Badr).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
That He might cause the truth to triumph and bring falsehood to nothing, even though the Mujrimun (disbelievers, polytheists, sinners, criminals, etc.) hate it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
(Remember) when you sought help of your Lord and He answered you (saying): ``I will help you with a thousand of the angels each behind the other (following one another) in succession."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah made it only as glad tidings, and that your hearts be at rest therewith. And there is no victory except from Allah. Verily, Allah is All-Mighty, All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
(Remember) when He covered you with a slumber as a security from Him, and He caused water (rain) to descend on you from the sky, to clean you thereby and to remove from you the Rijz (whispering, evil-suggestions, etc.) of Shaitan (Satan), and to strengthen your hearts, and make your feet firm thereby.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
(Remember) when your Lord inspired the angels, ``Verily, I am with you, so keep firm those who have believed. I will cast terror into the hearts of those who have disbelieved, so strike them over the necks, and smite over all their fingers and toes."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This is because they defied and disobeyed Allah and His Messenger. And whoever defies and disobeys Allah and His Messenger, then verily, Allah is Severe in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
This is the torment, so taste it, and surely for the disbelievers is the torment of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O you who believe! When you meet those who disbelieve, in a battle-field, never turn your backs to them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
And whoever turns his back to them on such a day - unless it be a stratagem of war, or to retreat to a troop (of his own), - he indeed has drawn upon himself wrath from Allah. And his abode is Hell, and worst indeed is that destination!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
You killed them not, but Allah killed them. And you (Muhammad SAW) threw not when you did throw but Allah threw, that He might test the believers by a fair trial from Him. Verily, Allah is All-Hearer, All-Knower.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
This (is the fact) and surely, Allah weakens the deceitful plots of the disbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
(O disbelievers) if you ask for a judgement, now has the judgement come unto you and if you cease (to do wrong), it will be better for you, and if you return (to the attack), so shall We return, and your forces will be of no avail to you, however numerous it be, and verily, Allah is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O you who believe! Obey Allah and His Messenger, and turn not away from him (i.e. Messenger Muhammad SAW) while you are hearing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And be not like those who say: ``We have heard," but they hear not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Verily! The worst of (moving) living creatures with Allah are the deaf and the dumb, those who understand not (i.e. the disbelievers).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Had Allah known of any good in them, He would indeed have made them listen, and even if He had made them listen, they would but have turned away, averse (to the truth).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O you who believe! Answer Allah (by obeying Him) and (His) Messenger when he (SAW) calls you to that which will give you life, and know that Allah comes in between a person and his heart (i.e. He prevents an evil person to decide anything). And verily to Him you shall (all) be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear the Fitnah (affliction and trial, etc.) which affects not in particular (only) those of you who do wrong (but it may afflict all the good and the bad people), and know that Allah is Severe in punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were few and were reckoned weak in the land, and were afraid that men might kidnap you, but He provided a safe place for you, strengthened you with His Help, and provided you with good things so that you might be grateful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O you who believe! Betray not Allah and His Messenger, nor betray knowingly your Amanat (things entrusted to you, and all the duties which Allah has ordained for you).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your possessions and your children are but a trial and that surely with Allah is a mighty reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O you who believe! If you obey and fear Allah, He will grant you Furqan a criterion [(to judge between right and wrong), or (Makhraj, i.e. making a way for you to get out from every difficulty)], and will expiate for you your sins, and forgive you, and Allah is the Owner of the Great Bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And (remember) when the disbelievers plotted against you (O Muhammad SAW) to imprison you, or to kill you, or to get you out (from your home, i.e. Makkah); they were plotting and Allah too was planning, and Allah is the Best of the planners.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our Verses (of the Quran) are recited to them, they say: ``We have heard this (the Quran); if we wish we can say the like of this. This is nothing but the tales of the ancients."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And (remember) when they said: ``O Allah! If this (the Quran) is indeed the truth (revealed) from You, then rain down stones on us from the sky or bring on us a painful torment."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
And Allah would not punish them while you (Muhammad SAW) are amongst them, nor will He punish them while they seek (Allah's) Forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
And why should not Allah punish them while they stop (men) from Al-Masjid-al-Haram, and they are not its guardians? None can be its guardian except Al-Muttaqun (the pious - see V. 2:2), but most of them know not.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their Salat (prayer) at the House (of Allah, i.e. the Ka'bah at Makkah) was nothing but whistling and clapping of hands. Therefore taste the punishment because you used to disbelieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Verily, those who disbelieve spend their wealth to hinder (men) from the Path of Allah, and so will they continue to spend it; but in the end it will become an anguish for them. Then they will be overcomed. And those who disbelieve will be gathered unto Hell.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
In order that Allah may distinguish the wicked (disbelievers, polytheists and doers of evil deeds) from the good (believers of Islamic Monotheism and doers of righteous deeds), and put the wicked (disbelievers, polytheists and doers of evil deeds) one on another, heap them together and cast them into Hell. Those! it is they who are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to those who have disbelieved, if they cease (from disbelief) their past will be forgiven. But if they return (thereto), then the examples of those (punished) before them have already preceded (as a warning).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them until there is no more Fitnah (disbelief and polytheism: i.e. worshipping others besides Allah) and the religion (worship) will all be for Allah Alone [in the whole of the world]. But if they cease (worshipping others besides Allah), then certainly, Allah is All-Seer of what they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, then know that Allah is your Maula (Patron, Lord, Protector and Supporter, etc.), (what) an Excellent Maula, and (what) an Excellent Helper!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatever of war-booty that you may gain, verily one-fifth (1/5th) of it is assigned to Allah, and to the Messenger, and to the near relatives [of the Messenger (Muhammad SAW)], (and also) the orphans, Al-Masakin (the poor) and the wayfarer, if you have believed in Allah and in that which We sent down to Our slave (Muhammad SAW) on the Day of criterion (between right and wrong), the Day when the two forces met (the battle of Badr) - And Allah is Able to do all things.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
(And remember) when you (the Muslim army) were on the near side of the valley, and they on the farther side, and the caravan on the ground lower than you. Even if you had made a mutual appointment to meet, you would certainly have failed in the appointment, but (you met) that Allah might accomplish a matter already ordained (in His Knowledge); so that those who were to be destroyed (for their rejecting the Faith) might be destroyed after a clear evidence, and those who were to live (i.e. believers) might live after a clear evidence. And surely, Allah is All-Hearer, All-Knower.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
(And remember) when Allah showed them to you as few in your (i.e. Muhammad's SAW) dream, if He had shown them to you as many, you would surely have been discouraged, and you would surely have disputed in making a decision. But Allah saved (you). Certainly, He is the All-Knower of what is in the breasts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
appear And (remember) when you met (the army of the disbelievers on the Day of the battle of Badr), He showed them to you as few in your eyes and He made you as few in their eyes, so that Allah might accomplish a matter already ordained (in His Knowledge), and to Allah return all matters (for decision).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O you who believe! When you meet (an enemy) force, take a firm stand against them and remember the Name of Allah much (both with tongue and mind), so that you may be successful.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Messenger, and do not dispute (with one another) lest you lose courage and your strength depart, and be patient. Surely, Allah is with those who are As-Sabirin (the patient ones, etc.).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And be not like those who come out of their homes boastfully and to be seen of men, and hinder (men) from the Path of Allah. and Allah is Muhitun (encircling and thoroughly comprehending) all that they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And (remember) when Shaitan (Satan) made their (evil) deeds seem fair to them and said, ``No one of mankind can overcome you this Day (of the battle of Badr) and verily, I am your neighbour (for each and every help)." But when the two forces came in sight of each other, he ran away and said ``Verily, I have nothing to do with you. Verily! I see what you see not. Verily! I fear Allah for Allah is Severe in punishment."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
When the hypocrites and those in whose hearts was a disease (of disbelief) said: ``These people (Muslims) are deceived by their religion." But whoever puts his trust in Allah, then surely, Allah is All-Mighty, All-Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
And if you could see when the angels take away the souls of those who disbelieve (at death), they smite their faces and their backs, (saying): ``Taste the punishment of the blazing Fire."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
``This is because of that which your hands had forwarded. And verily, Allah is not unjust to His slaves."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
Similar to the behaviour of the people of Fir'aun (Pharaoh), and of those before them; they rejected the Ayat (proofs, verses, etc.) of Allah, so Allah punished them for their sins. Verily, Allah is All-Strong, Severe in punishment.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is so because Allah will never change a grace which He has bestowed on a people until they change what is in their ownselves. And verily, Allah is All-Hearer, All-Knower.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Similar to the behaviour of the people of Fir'aun (Pharaoh), and those before them. They belied the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), of their Lord, so We destroyed them for their sins, and We drowned the people of Fir'aun (Pharaoh) for they were all Zalimun (polytheists and wrong-doers, etc.).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Verily, The worst of moving (living) creatures before Allah are those who disbelieve, - so they shall not believe.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
They are those with whom you made a covenant, but they break their covenant every time and they do not fear Allah.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So if you gain the mastery over them in war, punish them severely in order to disperse those who are behind them, so that they may learn a lesson.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If you (O Muhammad SAW) fear treachery from any people throw back (their covenant) to them (so as to be) on equal terms (that there will be no more covenant between you and them). Certainly Allah likes not the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
And let not those who disbelieve think that they can outstrip (escape from the punishment). Verily, they will never be able to save themselves (from Allah's Punishment).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
And make ready against them all you can of power, including steeds of war (tanks, planes, missiles, artillery, etc.) to threaten the enemy of Allah and your enemy, and others besides whom, you may not know but whom Allah does know. And whatever you shall spend in the Cause of Allah shall be repaid unto you, and you shall not be treated unjustly.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
But if they incline to peace, you also incline to it, and (put your) trust in Allah. Verily, He is the All-Hearer, the All-Knower.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they intend to deceive you, then verily, Allah is All-Sufficient for you. He it is Who has supported you with His Help and with the believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And He has united their (i.e. believers') hearts. If you had spent all that is in the earth, you could not have united their hearts, but Allah has united them. Certainly He is All-Mighty, All-Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet (Muhammad SAW)! Allah is Sufficient for you and for the believers who follow you.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet (Muhammad SAW)! Urge the believers to fight. If there are twenty steadfast persons amongst you, they will overcome two hundred, and if there be a hundred steadfast persons they will overcome a thousand of those who disbelieve, because they (the disbelievers) are people who do not understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now Allah has lightened your (task), for He knows that there is weakness in you. So if there are of you a hundred steadfast persons, they shall overcome two hundred, and if there are a thousand of you, they shall overcome two thousand with the Leave of Allah. And Allah is with As-Sabirin (the patient ones, etc.).\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for a Prophet that he should have prisoners of war (and free them with ransom) until he had made a great slaughter (among his enemies) in the land. You desire the good of this world (i.e. the money of ransom for freeing the captives), but Allah desires (for you) the Hereafter. And Allah is All-Mighty, All-Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Were it not a previous ordainment from Allah, a severe torment would have touched you for what you took.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
So enjoy what you have gotten of booty in war, lawful and good, and be afraid of Allah. Certainly, Allah is Oft-Forgiving, Most Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! Say to the captives that are in your hands: ``If Allah knows any good in your hearts, He will give you something better than what has been taken from you, and He will forgive you, and Allah is Oft-Forgiving, Most Merciful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they intend to betray you (O Muhammad SAW), they have already betrayed Allah before. So He gave (you) power over them. And Allah is All-Knower, All-Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Verily, those who believed, and emigrated and strove hard and fought with their property and their lives in the Cause of Allah as well as those who gave (them) asylum and help, - these are (all) allies to one another. And as to those who believed but did not emigrate (to you O Muhammad SAW), you owe no duty of protection to them until they emigrate, but if they seek your help in religion, it is your duty to help them except against a people with whom you have a treaty of mutual alliance, and Allah is the All-Seer of what you do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieve are allies to one another, (and) if you (Muslims of the whole world collectively) do not do so (i.e. become allies, as one united block with one Khalifah - chief Muslim ruler for the whole Muslim world to make victorious Allah's Religion of Islamic Monotheism), there will be Fitnah (wars, battles, polytheism, etc.) and oppression on earth, and a great mischief and corruption (appearance of polytheism).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
And those who believed, and emigrated and strove hard in the Cause of Allah (Al-Jihad), as well as those who gave (them) asylum and aid; - these are the believers in truth, for them is forgiveness and Rizqun Karim (a generous provision i.e. Paradise).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed afterwards, and emigrated and strove hard along with you, (in the Cause of Allah) they are of you. But kindred by blood are nearer to one another regarding inheritance in the decree ordained by Allah. Verily, Allah is the All-Knower of everything.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen Freedom from (all) obligations (is declared) from Allah and His Messenger (SAW) to those of the Mushrikun (polytheists, pagans, idolaters, disbelievers in the Oneness of Allah), with whom you made a treaty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
So travel freely (O Mushrikun - see V. 2:105) for four months (as you will) throughout the land, but know that you cannot escape (from the Punishment of) Allah, and Allah will disgrace the disbelievers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And a declaration from Allah and His Messenger to mankind on the greatest day (the 10th of Dhul-Hijjah - the 12th month of Islamic calendar) that Allah is free from (all) obligations to the Mushrikun (see V. 2:105) and so is His Messenger. So if you (Mushrikun) repent, it is better for you, but if you turn away, then know that you cannot escape (from the Punishment of) Allah. And give tidings (O Muhammad SAW) of a painful torment to those who disbelieve.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Except those of the Mushrikun with whom you have a treaty, and who have not subsequently failed you in aught, nor have supported anyone against you. So fulfill their treaty to them to the end of their term. Surely Allah loves Al- Mattaqun (the pious - see V. 2:2).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
Then when the Sacred Months (the Ist, 7th, 11th, and 12th months of the Islamic calendar) have passed, then kill the Mushrikun (see V. 2:105) wherever you find them, and capture them and besiege them, and prepare for them each and every ambush. But if they repent and perform As-Salat (Iqamat-as-Salat), and give Zakat, then leave their way free. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if anyone of the Mushrikun (polytheists, idolaters, pagans, disbelievers in the Oneness of Allah) seeks your protection then grant him protection, so that he may hear the Word of Allah (the Quran), and then escort him to where he can be secure, that is because they are men who know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a covenant with Allah and with His Messenger for the Mushrikun (polytheists, idolaters, pagans, disbelievers in the Oneness of Allah) except those with whom you made a covenant near Al-Masjid-al-Haram (at Makkah)? So long, as they are true to you, stand you true to them. Verily, Allah loves Al-Muttaqun (the pious - see V. 2:2).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How (can there be such a covenant with them) that when you are overpowered by them, they regard not the ties, either of kinship or of covenant with you? With (good words from) their mouths they please you, but their hearts are averse to you, and most of them are Fasiqun (rebellious, disobedient to Allah).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have purchased with the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah a little gain, and they hindered men from His Way; evil indeed is that which they used to do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
With regard to a believer, they respect not the ties, either of kinship or of covenant! It is they who are the transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent, perform As-Salat (Iqamat-as-Salat) and give Zakat, then they are your brethren in religion. (In this way) We explain the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in detail for a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they violate their oaths after their covenant, and attack your religion with disapproval and criticism then fight (you) the leaders of disbelief (chiefs of Quraish - pagans of Makkah) - for surely their oaths are nothing to them - so that they may stop (evil actions).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight a people who have violated their oaths (pagans of Makkah) and intended to expel the Messenger, while they did attack you first? Do you fear them? Allah has more right that you should fear Him, if you are believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight against them so that Allah will punish them by your hands and disgrace them and give you victory over them and heal the breasts of a believing people,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And remove the anger of their (believers') hearts. Allah accepts the repentance of whom He wills. Allah is All-Knowing, All-Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Do you think that you shall be left alone while Allah has not yet tested those among you who have striven hard and fought and have not taken Walijah [(Batanah - helpers, advisors and consultants from disbelievers, pagans, etc.) giving openly to them their secrets] besides Allah and His Messenger, and the believers. Allah is Well-Acquainted with what you do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the Mushrikun (polytheists, idolaters, pagans, disbelievers in the Oneness of Allah), to maintain the Mosques of Allah (i.e. to pray and worship Allah therein, to look after their cleanliness and their building, etc.), while they witness against their ownselves of disbelief. The works of such are in vain and in Fire shall they abide.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
The Mosques of Allah shall be maintained only by those who believe in Allah and the Last Day; perform As-Salat (Iqamat-as-Salat), and give Zakat and fear none but Allah. It is they who are expected to be on true guidance.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you consider the providing of drinking water to the pilgrims and the maintenance of Al-Masjid-al-Haram (at Makkah) as equal to the worth of those who believe in Allah and the Last Day, and strive hard and fight in the Cause of Allah? They are not equal before Allah. And Allah guides not those people who are the Zalimun (polytheists and wrong-doers).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believed (in the Oneness of Allah - Islamic Monotheism) and emigrated and strove hard and fought in Allah's Cause with their wealth and their lives are far higher in degree with Allah. They are the successful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them glad tidings of a Mercy from Him, and that He is pleased (with them), and of Gardens (Paradise) for them wherein are everlasting delights.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
They will dwell therein forever. Verily, with Allah is a great reward.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O you who believe! Take not for Auliya' (supporters and helpers) your fathers and your brothers if they prefer disbelief to Belief. And whoever of you does so, then he is one of the Zalimun (wrong-doers, etc.).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: If your fathers, your sons, your brothers, your wives, your kindred, the wealth that you have gained, the commerce in which you fear a decline, and the dwellings in which you delight  are dearer to you than Allah and His Messenger, and striving hard and fighting in His Cause, then wait until Allah brings about His Decision (torment). And Allah guides not the people who are Al-Fasiqun (the rebellious, disobedient to Allah).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Truly Allah has given you victory on many battle fields, and on the Day of Hunain (battle) when you rejoiced at your great number but it availed you naught and the earth, vast as it is, was straitened for you, then you turned back in flight.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah did send down His Sakinah (calmness, tranquillity and reassurance, etc.) on the Messenger (Muhammad SAW), and on the believers, and sent down forces (angels) which you saw not, and punished the disbelievers. Such is the recompense of disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then after that Allah will accept the repentance of whom He will. And Allah is Oft-Forgiving, Most Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O you who believe (in Allah's Oneness and in His Messenger (Muhammad SAW)! Verily, the Mushrikun (polytheists, pagans, idolaters, disbelievers in the Oneness of Allah, and in the Message of Muhammad SAW) are Najasun (impure). So let them not come near Al-Masjid-al-Haram (at Makkah) after this year, and if you fear poverty, Allah will enrich you if He will, out of His Bounty. Surely, Allah is All-Knowing, All-Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight against those who (1) believe not in Allah, (2) nor in the Last Day, (3) nor forbid that which has been forbidden by Allah and His Messenger (4) and those who acknowledge not the religion of truth (i.e. Islam) among the people of the Scripture (Jews and Christians), until they pay the Jizyah with willing submission, and feel themselves subdued.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
And the Jews say: 'Uzair (Ezra) is the son of Allah, and the Christians say: Messiah is the son of Allah. That is a saying from their mouths. They imitate the saying of the disbelievers of old. Allah's Curse be on them, how they are deluded away from the truth!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They (Jews and Christians) took their rabbis and their monks to be their lords besides Allah (by obeying them in things which they made lawful or unlawful according to their own desires without being ordered by Allah), and (they also took as their Lord) Messiah, son of Maryam (Mary), while they (Jews and Christians) were commanded [in the Taurat (Torah) and the Injeel (Gospel)) to worship none but One Ilah (God - Allah) La ilaha illa Huwa (none has the right to be worshipped but He). Praise and glory be to Him, (far above is He) from having the partners they associate (with Him)."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They (the disbelievers, the Jews and the Christians) want to extinguish Allah's Light (with which Muhammad SAW has been sent - Islamic Monotheism) with their mouths, but Allah will not allow except that His Light should be perfected even though the Kafirun (disbelievers) hate (it).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He Who has sent His Messenger (Muhammad SAW) with guidance and the religion of truth (Islam), to make it superior over all religions even though the Mushrikun (polytheists, pagans, idolaters, disbelievers in the Oneness of Allah) hate (it).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O you who believe! Verily, there are many of the (Jewish) rabbis and the (Christian) monks who devour the wealth of mankind in falsehood, and hinder (them) from the Way of Allah (i.e. Allah's Religion of Islamic Monotheism). And those who hoard up gold and silver [Al-Kanz: the money, the Zakat of which has not been paid], and spend it not in the Way of Allah, -announce unto them a painful torment.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On the Day when that (Al-Kanz: money, gold and silver, etc., the Zakat of which has not been paid) will be heated in the Fire of Hell and with it will be branded their foreheads, their flanks, and their backs, (and it will be said unto them):-"This is the treasure which you hoarded for yourselves. Now taste of what you used to hoard."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Verily, the number of months with Allah is twelve months (in a year), so was it ordained by Allah on the Day when He created the heavens and the earth; of them four are Sacred, (i.e. the 1st, the 7th, the 11th and the 12th months of the Islamic calendar). That is the right religion, so wrong not yourselves therein, and fight against the Mushrikun (polytheists, pagans, idolaters, disbelievers in the Oneness of Allah) collectively, as they fight against you collectively. But know that Allah is with those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The postponing (of a Sacred Month) is indeed an addition to disbelief: thereby the disbelievers are led astray, for they make it lawful one year and forbid it another year in order to adjust the number of months forbidden by Allah, and make such forbidden ones lawful. The evil of their deeds seems pleasing to them. And Allah guides not the people, who disbelieve.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O you who believe! What is the matter with you, that when you are asked to march forth in the Cause of Allah (i.e. Jihad) you cling heavily to the earth? Are you pleased with the life of this world rather than the Hereafter? But little is the enjoyment of the life of this world as compared with the Hereafter.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you march not forth, He will punish you with a painful torment and will replace you by another people, and you cannot harm Him at all, and Allah is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you help him (Muhammad SAW) not (it does not matter), for Allah did indeed help him when the disbelievers drove him out, the second of two, when they (Muhammad SAW and Abu Bakr) were in the cave, and he (SAW) said to his companion (Abu Bakr): ``Be not sad (or afraid), surely Allah is with us." Then Allah sent down His Sakinah (calmness, tranquillity, peace, etc.) upon him, and strengthened him with forces (angels) which you saw not, and made the word of those who disbelieved the lowermost, while it was the Word of Allah that became the uppermost, and Allah is All-Mighty, All-Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
March forth, whether you are light (being healthy, young and wealthy) or heavy (being ill, old and poor), strive hard with your wealth and your lives in the Cause of Allah. This is better for you, if you but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had it been a near gain (booty in front of them) and an easy journey, they would have followed you, but the distance (Tabuk expedition) was long for them, and they would swear by Allah, ``If we only could, we would certainly have come forth with you." They destroy their ownselves, and Allah knows that they are liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
May Allah forgive you (O Muhammad SAW). Why did you grant them leave (for remaining behind, you should have persisted as regards your order to them to proceed on Jihad), until those who told the truth were seen by you in a clear light, and you had known the liars?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day would not ask your leave to be exempted from fighting with their properties and their lives, and Allah is the All-Knower of Al-Muttaqun (the pious - see V. 2:2).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
It is only those who believe not in Allah and the Last Day and whose hearts are in doubt that ask your leave (to be exempted from Jihad). So in their doubts they waver.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And if they had intended to march out, certainly, they would have made some preparation for it, but Allah was averse to their being sent forth, so He made them lag behind, and it was said (to them), ``Sit you among those who sit (at home)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they marched out with you, they would have added to you nothing except disorder, and they would have hurried about in your midst (spreading corruption) and sowing sedition among you, and there are some among you who would have listened to them. And Allah is the All-Knower of the Zalimun (polytheists and wrong-doers, etc.).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Verily, they had plotted sedition before, and had upset matters for you, - until the truth (victory) came and the Decree of Allah (His Religion, Islam) became manifest though they hated it.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And among them is he who says:"Grant me leave (to be exempted from Jihad) and put me not into trial." Surely, they have fallen into trial. And verily, Hell is surrounding the disbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalls you (O Muhammad SAW), it grieves them, but if a calamity overtakes you, they say: ``We took our precaution beforehand," and they turn away rejoicing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: ``Nothing shall ever happen to us except what Allah has ordained for us. He is our Maula (Lord, Helper and Protector)." And in Allah let the believers put their trust.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: ``Do you wait for us (anything) except one of the two best things (martyrdom or victory); while we await for you either that Allah will afflict you with a punishment from Himself or at our hands. So wait, we too are waiting with you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: ``Spend (in Allah's Cause) willingly or unwillingly, it will not be accepted from you. Verily, you are ever a people who are Fasiqun (rebellious, disobedient to Allah)."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And nothing prevents their contributions from being accepted from them except that they disbelieved in Allah and in His Messenger (Muhammad SAW); and that they came not to As-Salat (the prayer) except in a lazy state; and that they offer not contributions but unwillingly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their wealth or their children amaze you (O Muhammad SAW); in reality Allah's Plan is to punish them with these things in the life of the this world, and that their souls shall depart (die) while they are disbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by Allah that they are truly of you while they are not of you, but they are a people (hypocrites) who are afraid (that you may kill them).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
Should they find a refuge, or caves, or a place of concealment, they would turn straightway thereto with a swift rush.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And of them are some who accuse you (O Muhammad SAW) in the matter of (the distribution of) the alms. If they are given part thereof, they are pleased, but if they are not given thereof, behold! They are enraged!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
Would that they were contented with what Allah and His Messenger (SAW) gave them and had said: ``Allah is Sufficient for us. Allah will give us of His Bounty, and (also) His Messenger (from alms, etc.). We implore Allah (to enrich us)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
As-Sadaqat (here it means Zakat) are only for the Fuqara' (poor), and Al-Masakin (the poor) and those employed to collect (the funds); and for to attract the hearts of those who have been inclined (towards Islam); and to free the captives; and for those in debt; and for Allah's Cause (i.e. for Mujahidun - those fighting in the holy wars), and for the wayfarer (a traveller who is cut off from everything); a duty imposed by Allah. And Allah is All-Knower, All-Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And among them are men who hurt the Prophet (Muhammad SAW) and say: ``He is (lending his) ear (to every news)." Say: ``He listens to what is best for you; he believes in Allah; has faith in the believers; and is a mercy to those of you who believe." But those who hurt Allah's Messenger (Muhammad SAW) will have a painful torment.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah to you (Muslims) in order to please you, but it is more fitting that they should please Allah and His Messenger (Muhammad SAW), if they are believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Know they not that whoever opposes and shows hostility to Allah and His Messenger (SAW), certainly for him will be the Fire of Hell to abide therein. That is extreme disgrace.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites fear lest a Surah (chapter of the Quran) should be revealed about them, showing them what is in their hearts. Say: ``(Go ahead and) mock! But certainly Allah will bring to light all that you fear."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
If you ask them (about this), they declare: ``We were only talking idly and joking." Say: ``Was it at Allah, and His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and His Messenger (SAW) that you were mocking?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuse; you have disbelieved after you had believed. If We pardon some of you, We will punish others amongst you because they were Mujrimun (disbelievers, polytheists, sinners, criminals, etc.).\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrites, men and women, are from one another, they enjoin (on the people) Al-Munkar (i.e. disbelief and polytheism of all kinds and all that Islam has forbidden), and forbid (people) from Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam orders one to do), and they close their hands [from giving (spending in Allah's Cause) alms, etc.]. They have forgotten Allah, so He has forgotten them. Verily, the hypocrites are the Fasiqun (rebellious, disobedient to Allah).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised the hypocrites; men and women, and the disbelievers, the Fire of Hell, therein shall they abide. It will suffice them. Allah has cursed them and for them is the lasting torment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
Like those before you, they were mightier than you in power, and more abundant in wealth and children. They had enjoyed their portion awhile, so enjoy your portion awhile as those before you enjoyed their portion awhile; and you indulged in play and pastime (and in telling lies against Allah and His Messenger Muhammad SAW) as they indulged in play and pastime. Such are they whose deeds are in vain in this world and in the Hereafter. Such are they who are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Has not the story reached them of those before them? - The people of Nuh (Noah), 'Ad, and Thamud, the people of Ibrahim (Abraham), the dwellers of Madyan (Midian) and the cities overthrown [i.e. the people to whom Lout (Lot) preached], to them came their Messengers with clear proofs. So it was not Allah Who wronged them, but they used to wrong themselves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believers, men and women, are Auliya' (helpers, supporters, friends, protectors) of one another, they enjoin (on the people) Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam orders one to do), and forbid (people) from Al-Munkar (i.e. polytheism and disbelief of all kinds, and all that Islam has forbidden); they perform As-Salat (Iqamat-as-Salat) and give the Zakat, and obey Allah and His Messenger. Allah will have His Mercy on them. Surely Allah is All-Mighty, All-Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised to the believers -men and women, - Gardens under which rivers flow to dwell therein forever, and beautiful mansions in Gardens of 'Adn (Eden Paradise). But the greatest bliss is the Good Pleasure of Allah. That is the supreme success.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet (Muhammad SAW)! Strive hard against the disbelievers and the hypocrites, and be harsh against them, their abode is Hell, - and worst indeed is that destination.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing (bad), but really they said the word of disbelief, and they disbelieved after accepting Islam, and they resolved that (plot to murder Prophet Muhammad SAW) which they were unable to carry out, and they could not find any cause to do so except that Allah and His Messenger had enriched them of His Bounty. If then they repent, it will be better for them, but if they turn away, Allah will punish them with a painful torment in this worldly life and in the Hereafter. And there is none for them on earth as a Wali (supporter, protector) or a helper.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And of them are some who made a covenant with Allah (saying): ``If He bestowed on us of His Bounty, we will verily, give Sadaqah (Zakat and voluntary charity in Allah's Cause) and will be certainly among those who are righteous."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Then when He gave them of His Bounty, they became niggardly [refused to pay the Sadaqah (Zakat or voluntary charity)], and turned away, averse.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He punished them by putting hypocrisy into their hearts till the Day whereon they shall meet Him, because they broke that (covenant with Allah) which they had promised Him and because they used to tell lies.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Know they not that Allah knows their secret ideas, and their Najwa (secret counsels), and that Allah is the All-Knower of the unseen.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who defame such of the believers who give charity (in Allah's Cause) voluntarily, and those who could not find to give charity (in Allah's Cause) except what is available to them, so they mock at them (believers), Allah will throw back their mockery on them, and they shall have a painful torment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Whether you (O Muhammad SAW) ask forgiveness for them (hypocrites) or ask not forgiveness for them  (and even) if you ask seventy times for their forgiveness  Allah will not forgive them, because they have disbelieved in Allah and His Messenger (Muhammad SAW). And Allah guides not those people who are Fasiqun (rebellious, disobedient to Allah).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who stayed away (from Tabuk expedition) rejoiced in their staying behind the Messenger of Allah; they hated to strive and fight with their properties and their lives in the Cause of Allah, and they said: ``March not forth in the heat." Say: ``The Fire of Hell is more intense in heat", if only they could understand!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
So let them laugh a little and (they will) cry much as a recompense of what they used to earn (by committing sins).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If Allah brings you back to a party of them (the hypocrites), and they ask your permission to go out (to fight), say: ``Never shall you go out with me, nor fight an enemy with me; you agreed to sit inactive on the first occasion, then you sit (now) with those who lag behind."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And never (O Muhammad SAW) pray (funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave. Certainly they disbelieved in Allah and His Messenger, and died while they were Fasiqun (rebellious, - disobedient to Allah and His Messenger SAW).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And let not their wealth or their children amaze you. Allah's Plan is to punish them with these things in this world, and that their souls shall depart (die) while they are disbelievers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a Surah (chapter from the Quran) is revealed, enjoining them to believe in Allah and to strive hard and fight along with His Messenger, the wealthy among them ask your leave to exempt them (from Jihad) and say, ``Leave us (behind), we would be with those who sit (at home)."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They are content to be with those (the women) who sit behind (at home). Their hearts are sealed up (from all kinds of goodness and right guidance), so they understand not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger (Muhammad SAW) and those who believed with him (in Islamic Monotheism) strove hard and fought with their wealth and their lives (in Allah's Cause). Such are they for whom are the good things, and it is they who will be successful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
For them Allah has got ready Gardens (Paradise) under which rivers flow, to dwell therein forever. That is the supreme success.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And those who made excuses from the bedouins came (to you, O Prophet SAW) asking your permission to exempt them (from the battle), and those who had lied to Allah and His Messenger sat at home (without asking the permission for it); a painful torment will seize those of them who disbelieve.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no blame on those who are weak or ill or who find no resources to spend [in holy fighting (Jihad)], if they are sincere and true (in duty) to Allah and His Messenger. No ground (of complaint) can there be against the Muhsinun (good-doers - see the footnote of V. 9:120). And Allah is Oft-Forgiving, Most Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor (is there blame) on those who came to you to be provided with mounts, and when you said: ``I can find no mounts for you," they turned back, while their eyes overflowing with tears of grief that they could not find anything to spend (for Jihad).\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The ground (of complaint) is only against those who are rich, and yet ask exemption. They are content to be with (the women) who sit behind (at home) and Allah has sealed up their hearts (from all kinds of goodness and right guidance) so that they know not (what they are losing).\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They (the hypocrites) will present their excuses to you (Muslims), when you return to them. Say (O Muhammad SAW) ``Present no excuses, we shall not believe you. Allah has already informed us of the news concerning you. Allah and His Messenger will observe your deeds. In the end you will be brought back to the All-Knower of the unseen and the seen, then He (Allah) will inform you of what you used to do." [Tafsir At-Tabari]\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear by Allah to you (Muslims) when you return to them, that you may turn away from them. So turn away from them. Surely, they are Rijsun [i.e. Najasun (impure) because of their evil deeds], and Hell is their dwelling place, - a recompense for that which they used to earn.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They (the hypocrites) swear to you (Muslims) that you may be pleased with them, but if you are pleased with them, certainly Allah is not pleased with the people who are Al-Fasiqun (rebellious, disobedient to Allah).\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The bedouins are the worst in disbelief and hypocrisy, and more likely to be in ignorance of the limits (Allah's Commandments and His Legal Laws, etc.) which Allah has revealed to His Messenger. And Allah is All-Knower, All-Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And of the bedouins there are some who look upon what they spend (in Allah's Cause) as a fine and watch for calamities for you, on them be the calamity of evil. And Allah is All-Hearer, All-Knower.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And of the bedouins there are some who believe in Allah and the Last Day, and look upon what they spend in Allah's Cause as approaches to Allah, and a cause of receiving the Messenger's invocations. Indeed these (spendings in Allah's Cause) are an approach for them. Allah will admit them to His Mercy. Certainly Allah is Oft-Forgiving, Most Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the first to embrace Islam of the Muhajirun (those who migrated from Makkah to Al-Madinah) and the Ansar (the citizens of Al-Madinah who helped and gave aid to the Muhajirun) and also those who followed them exactly (in Faith). Allah is well-pleased with them as they are well-pleased with Him. He has prepared for them Gardens under which rivers flow (Paradise), to dwell therein forever. That is the supreme success.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And among the bedouins round about you, some are hypocrites, and so are some among the people of Al-Madinah, they exaggerate and persist in hypocrisy, you (O Muhammad SAW) know them not, We know them. We shall punish them twice, and thereafter they shall be brought back to a great (horrible) torment.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And (there are) others who have acknowledged their sins, they have mixed a deed that was righteous with another that was evil. Perhaps Allah will turn unto them in forgiveness. Surely, Allah is Oft-Forgiving, Most Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take Sadaqah (alms) from their wealth in order to purify them and sanctify them with it, and invoke Allah for them. Verily! Your invocations are a source of security for them, and Allah is All-Hearer, All-Knower.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Know they not that Allah accepts repentance from His slaves and takes the Sadaqat (alms, charities) and that Allah Alone is the One Who forgives and accepts repentance, Most Merciful?\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say (O Muhammad SAW) ``Do deeds! Allah will see your deeds, and (so will) His Messenger and the believers. And you will be brought back to the All-Knower of the unseen and the seen. Then He will inform you of what you used to do."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And others await Allah's Decree, whether He will punish them or will forgive them. And Allah is All-Knowing, All-Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And as for those who put up a mosque by way of harming and disbelief, and to disunite the believers, and as an outpost for those who warred against Allah and His Messenger (Muhammad SAW) aforetime, they will indeed swear that their intention is nothing but good. Allah bears witness that they are certainly liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand you therein. Verily, the mosque whose foundation was laid from the first day on piety is more worthy that you stand therein (to pray). In it are men who love to clean and to purify themselves. And Allah loves those who make themselves clean and pure (i.e. who clean their private parts with dust [i.e. to be considered as soap) and water from urine and stools, after answering the call of nature].\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is it then he, who laid the foundation of his building on piety to Allah and His Good Pleasure, better, or he who laid the foundation of his building on an undetermined brink of a precipice ready to crumble down, so that it crumbled to pieces with him into the Fire of Hell. And Allah guides not the people who are the Zalimun (cruel, violent, proud, polytheist and wrong-doer).\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The building which they built will never cease to be a cause of hypocrisy and doubt in their hearts, unless their hearts are cut to pieces. (i.e. till they die). And Allah is All-Knowing, All-Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Verily, Allah has purchased of the believers their lives and their properties; for the price that theirs shall be the Paradise. They fight in Allah's Cause, so they kill (others) and are killed. It is a promise in truth which is binding on Him in the Taurat (Torah) and the Injeel (Gospel) and the Quran. And who is truer to his covenant than Allah? Then rejoice in the bargain which you have concluded. That is the supreme success.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
(The believers whose lives Allah has purchased are) those who repent to Allah (from polytheism and hypocrisy, etc.), who worship Him, who praise Him, who fast (or go out in Allah's Cause), who bow down (in prayer), who prostrate themselves (in prayer), who enjoin (people) for Al-Ma'ruf (i.e. Islamic Monotheism and all what Islam has ordained) and forbid (people) from Al-Munkar (i.e. disbelief, polytheism of all kinds and all that Islam has forbidden), and who observe the limits set by Allah (do all that Allah has ordained and abstain from all kinds of sins and evil deeds which Allah has forbidden). And give glad tidings to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not (proper) for the Prophet and those who believe to ask Allah's Forgiveness for the Mushrikun (polytheists, idolaters, pagans, disbelievers in the Oneness of Allah) even though they be of kin, after it has become clear to them that they are the dwellers of the Fire (because they died in a state of disbelief).\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And [Ibrahim's (Abraham)] invoking (of Allah) for his father's forgiveness was only because of a promise he [Ibrahim (Abraham)] had made to him (his father). But when it became clear to him [Ibrahim (Abraham)] that he (his father) is an enemy to Allah, he dissociated himself from him. Verily Ibrahim (Abraham) was Al-Awwah (has fifteen different meanings but the correct one seems to be that he used to invoke Allah with humility, glorify Him and remember Him much), and was forbearing. (Tafsir Al-Qurtubi).\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
And Allah will never lead a people astray after He has guided them until He makes clear to them as to what they should avoid. Verily, Allah is the All-Knower of everything.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Verily, Allah! Unto Him belongs the dominion of the heavens and the earth, He gives life and He causes death. And besides Allah you have neither any Wali (protector or guardian) nor any helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Allah has forgiven the Prophet (SAW), the Muhajirun (Muslim emigrants who left their homes and came to Al-Madinah) and the Ansar (Muslims of Al-Madinah) who followed him (Muhammad SAW) in the time of distress (Tabuk expedition, etc.), after the hearts of a party of them had nearly deviated (from the Right Path), but He accepted their repentance. Certainly, He is unto them full of Kindness, Most Merciful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And (He did forgive also) the three [who did not join the Tabuk expedition (whom the Prophet SAW)] left (i.e. he did not give his judgement in their case, and their case was suspended for Allah's Decision) till for them the earth, vast as it is, was straitened and their ownselves were straitened to them, and they perceived that there is no fleeing from Allah, and no refuge but with Him. Then, He accepted their repentance, that they might repent (unto Him). Verily, Allah is the One Who accepts repentance, Most Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O you who believe! Be afraid of Allah, and be with those who are true (in words and deeds).\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It was not becoming of the people of Al-Madinah and the bedouins of the neighbourhood to remain behind Allah's Messenger (Muhammad SAW when fighting in Allah's Cause) and (it was not becoming of them) to prefer their own lives to his life. That is because they suffer neither thirst nor fatigue, nor hunger in the Cause of Allah, nor they take any step to raise the anger of disbelievers nor inflict any injury upon an enemy but is written to their credit as a deed of righteousness. Surely, Allah wastes not the reward of the Muhsinun\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor do they spend anything (in Allah's Cause) - small or great - nor cross a valley, but is written to their credit, that Allah may recompense them with the best of what they used to do (i.e. Allah will reward their good deeds according to the reward of their best deeds which they did in the most perfect manner).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And it is not (proper) for the believers to go out to fight (Jihad) all together. Of every troop of them, a party only should go forth, that they (who are left behind) may get instructions in (Islamic) religion, and that they may warn their people when they return to them, so that they may beware (of evil).\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O you who believe! Fight those of the disbelievers who are close to you, and let them find harshness in you, and know that Allah is with those who are the Al-Muttaqun (the pious - see V. 2:2).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever there comes down a Surah (chapter from the Quran), some of them (hypocrites) say: ``Which of you has had his Faith increased by it?" As for those who believe, it has increased their Faith, and they rejoice.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose hearts is a disease (of doubt, disbelief and hypocrisy), it will add suspicion and doubt to their suspicion, disbelief and doubt, and they die while they are disbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
See they not that they are tried once or twice every year (with different kinds of calamities, disease, famine, etc.)? Yet, they turn not in repentance, nor do they learn a lesson (from it).\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever there comes down a Surah (chapter from the Quran), they look at one another (saying): ``Does any one see you?" Then they turn away. Allah has turned their hearts (from the light) because they are a people that understand not.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Verily, there has come unto you a Messenger (Muhammad SAW) from amongst yourselves (i.e. whom you know well). It grieves him that you should receive any injury or difficulty. He (Muhammad SAW) is anxious over you (to be rightly guided, to repent to Allah, and beg Him to pardon and forgive your sins, in order that you may enter Paradise and be saved from the punishment of the Hell-fire), for the believers (he SAW is) full of pity, kind, and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
But if they turn away, say (O Muhammad SAW): ``Allah is sufficient for me. La ilaha illa Huwa (none has the right to be worshipped but He), in Him I put my trust and He is the Lord of the Mighty Throne.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif-Lam-Ra. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. These are the Verses of the Book (the Quran) Al-Hakim [showing lawful and unlawful things, explaining Allah's (Divine) Laws for mankind, leading them to eternal happiness by ordering them to follow the true Islamic Monotheism, - worshipping none but Allah Alone - that will guide them to Paradise and save them from Hell].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it wonder for mankind that We have sent Our Inspirationto a man from among themselves (i.e. Prophet Muhammad SAW) (saying): ``Warn mankind (of the coming torment in Hell), and give good news to those who believe (in the Oneness of Allah and in His Prophet Muhammad SAW) that they shall have with their Lord the rewards of their good deeds?" (But) the disbelievers say: ``This is indeed an evident sorcerer (i.e. Prophet Muhammad SAW and the Quran)!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Surely, your Lord is Allah Who created the heavens and the earth in six Days and then Istawa (rose over) the Throne (really in a manner that suits His Majesty), disposing the affair of all things. No intercessor (can plead with Him) except after His Leave. That is Allah, your Lord; so worship Him (Alone). Then, will you not remember?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him is the return of all of you. The Promise of Allah is true. It is He Who begins the creation and then will repeat it, that He may reward with justice those who believed (in the Oneness of Allah - Islamic Monotheism) and did deeds of righteousness. But those who disbelieved will have a drink of boiling fluids and painful torment because they used to disbelieve.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He Who made the sun a shining thing and the moon as a light and measured out its (their) stages, that you might know the number of years and the reckoning. Allah did not create this but in truth. He explains the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in detail for people who have knowledge.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Verily, in the alternation of the night and the day and in all that Allah has created in the heavens and the earth are Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) for those people who keep their duty to Allah, and fear Him much.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Verily, those who hope not for their meeting with Us, but are pleased and satisfied with the life of the present world, and those who are heedless of Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.),\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
Those, their abode will be the Fire, because of what they used to earn.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Verily, those who believe [in the Oneness of Allah along with the six articles of Faith, i.e. to believe in Allah, His Angels, His Books, His Messengers, Day of Resurrection, and Al-Qadar (Divine Preordainments) - Islamic Monotheism], and do deeds of righteousness, their Lord will guide them through their Faith; under them will flow rivers in the Gardens of delight (Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their way of request therein will be Subhanaka Allahumma (Glory to You, O Allah!) and Salam (peace, safe from each and every evil) will be their greetings therein (Paradise)! and the close of their request will be: Al-Hamdu Lillahi Rabbil-'Alamin [All the praises and thanks are to Allah, the Lord of 'Alamin (mankind, jinns and all that exists)].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
And were Allah to hasten for mankind the evil (they invoke for themselves and for their children, etc. while in a state of anger) as He hastens for them the good (they invoke) then they would have been ruined. So We leave those who expect not their meeting with Us, in their trespasses, wandering blindly in distraction. (Tafsir At-Tabari; Vol. 11, Page 91)\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And when harm touches man, he invokes Us, lying down on his side, or sitting or standing. But when We have removed his harm from him, he passes on his way as if he had never invoked Us for a harm that touched him! Thus it seems fair to the Musrifunthat which they used to do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
And indeed, We destroyed generations before you, when they did wrong while their Messengers came to them with clear proofs, but they were not such as to believe! Thus do We requite the people who are Mujrimun (disbelievers, polytheists, sinners, criminals, etc.).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We made you follow after them, generations after generations in the land, that We might see how you would work!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our Clear Verses are recited unto them, those who hope not for their meeting with Us, say: Bring us a Quran other than this, or change it."Say (O Muhammad SAW): ``It is not for me to change it on my own accord; I only follow that which is revealed unto me. Verily, I fear if I were to disobey my Lord, the torment of the Great Day (i.e. the Day of Resurrection)."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say (O Muhammad SAW): ``If Allah had so willed, I should not have recited it to you nor would He have made it known to you. Verily, I have stayed amongst you a life time before this. Have you then no sense?"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
So who does more wrong than he who forges a lie against Allah or denies His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.)? Surely, the Mujrimun (criminals, sinners, disbelievers and polytheists) will never be successful!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship besides Allah things that hurt them not, nor profit them, and they say: ``These are our intercessors with Allah." Say: ``Do you inform Allah of that which He knows not in the heavens and on the earth?" Glorified and Exalted be He above all that which they associate as partners with Him!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind were but one community (i.e. on one religion - Islamic Monotheism), then they differed (later), and had not it been for a Word that went forth before from your Lord, it would have been settled between them regarding what they differed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say: ``How is it that not a sign is sent down on him from his Lord?" Say: ``The unseen belongs to Allah Alone, so wait you, verily I am with you among those who wait (for Allah's Judgement)."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We let mankind taste of mercy after some adversity has afflicted them, behold! They take to plotting against Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.)! Say: ``Allah is more Swift in planning!" Certainly, Our Messengers (angels) record all of that which you plot.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is Who enables you to travel through land and sea, till when you are in the ships and they sail with them with a favourable wind, and they are glad therein, then comes a stormy wind and the waves come to them from all sides, and they think that they are encircled therein, they invoke Allah, making their Faith pure for Him Alone, saying: ``If You (Allah) deliver us from this, we shall truly be of the grateful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But when He delivered them, behold! They rebel (disobey Allah) in the earth wrongfully. O mankind! Your rebellion (disobedience to Allah) is only against your ownselves, - a brief enjoyment of this worldly life, then (in the end) unto Us is your return, and We shall inform you that which you used to do.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
Verily the likeness of (this) worldly life is as the water (rain) which We send down from the sky, so by it arises the intermingled produce of the earth of which men and cattle eat until when the earth is clad with its adornments and is beautified, and its people think that they have all the powers of disposal over it, Our Command reaches it by night or by day and We make it like a clean-mown harvest, as if it had not flourished yesterday! Thus do We explain the Ayat (proofs, evidences, verses, lessons, signs, revelations, laws, etc.) in detail for the people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
Allah calls to the home of peace (i.e. Paradise, by accepting Allah's religion of Islamic Monotheism and by doing righteous good deeds and abstaining from polytheism and evil deeds) and guides whom He wills to a Straight Path.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For those who have done good is the best (reward, i.e. Paradise) and even more (i.e. having the honour of glancing at the Countenance of Allah) Neither darkness nor dust nor any humiliating disgrace shall cover their faces. They are the dwellers of Paradise, they will abide therein forever.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And those who have earned evil deeds, the recompense of an evil deed is the like thereof, and humiliating disgrace will cover them (their faces). No defender will they have from Allah. Their faces will be covered, as it were, with pieces from the darkness of night. They are dwellers of the Fire, they will abide therein forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And the Day whereon We shall gather them all together, then We shall say to those who did set partners in worship with Us: ``Stop at your place! You and your partners (whom you had worshipped in the worldly life)." then We shall separate them, and their (Allah's so-called) partners shall say: ``It was not us that you used to worship."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
``So sufficient is Allah for a witness between us and you, that We indeed knew nothing of your worship of us."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There! Every person will know (exactly) what (all) he had earned before, and they will be brought back to Allah, their rightful Lord (Maula), and their invented false deities will vanish from them.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say (O MuhammadSAW): ``Who provides for you from the sky and from the earth? Or who owns hearing and sight? And who brings out the living from the dead and brings out the dead from the living? And who disposes the affairs?" They will say: ``Allah." Say: ``Will you not then be afraid of Allah's Punishment (for setting up rivals in worship with Allah)?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is Allah, your Lord in truth. So after the truth, what else can there be, save error? How then are you turned away?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus is the Word of your Lord justified against those who rebel (disobey Allah) that they will not believe (in the Oneness of Allah and in Muhammad SAW as the Messenger of Allah).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: ``Is there of your (Allah's so-called) partners one that originates the creation and then repeats it?" Say: ``Allah originates the creation and then He repeats it. Then how are you deluded away (from the truth)?"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: ``Is there of your (Allah's so-called) partners one that guides to the truth?" Say: ``It is Allah Who guides to the truth. Is then He, Who gives guidance to the truth, more worthy to be followed, or he who finds not guidance (himself) unless he is guided? Then, what is the matter with you? How judge you?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
And most of them follow nothing but conjecture. Certainly, conjecture can be of no avail against the truth. Surely, Allah is All-Aware of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this Quran is not such as could ever be produced by other than Allah (Lord of the heavens and the earth), but it is a confirmation of (the revelation) which was before it [i.e. the Taurat (Torah), and the Injeel (Gospel), etc.], and a full explanation of the Book (i.e. laws and orders, etc, decreed for mankind) - wherein there is no doubt from the the Lord of the 'Alamin (mankind, jinns, and all that exists).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say: ``He (Muhammad SAW) has forged it?" Say: ``Bring then a Surah (chapter) like unto it, and call upon whomsoever you can, besides Allah, if you are truthful!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Nay, they deny that; the knowledge whereof they could not compass and whereof the interpretation has not yet come unto them. Thus those before them did deny. Then see what was the end of the Zalimun (polytheists and wrong-doers, etc.)!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And of them there are some who believe therein, and of them there are some who believe not therein, and your Lord is All-Aware of the Mufsidun (evil-doers, liars, etc.).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they belie you, say: ``For me are my deeds and for you are your deeds! You are innocent of what I do, and I am innocent of what you do!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And among them are some who listen to you, but can you make the deaf to hear, even though they apprehend not?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them are some who look at you, but can you guide the blind, even though they see not?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Truly! Allah wrongs not mankind in aught; but mankind wrong themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And on the Day when He shall gather (resurrect) them together, (it will be) as if they had not stayed (in the life of this world and graves, etc.) but an hour of a day. They will recognise each other. Ruined indeed will be those who denied the meeting with Allah, and were not guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We show you (in your lifetime, O Muhammad SAW) some of what We promise them (the torment), - or We cause you to die, - still unto Us is their return, and moreover Allah is Witness over what they used to do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And for every Ummah (a community or a nation), there is a Messenger; when their Messenger comes, the matter will be judged between them with justice, and they will not be wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say: ``When will be this promise (the torment or the Day of Resurrection), - if you speak the truth?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say (O Muhammad SAW): ``I have no power over any harm or profit to myself except what Allah may will. For every Ummah (a community or a nation), there is a term appointed; when their term is reached, neither can they delay it nor can they advance it an hour (or a moment)." (Tafsir Al-Qurtubi).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: ``Tell me, - if His torment should come to you by night or by day, - which portion thereof would the Mujrimun (disbelievers, polytheists, sinners, criminals) hasten on?"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Is it then, that when it has actually befallen, that you will believe in it? What! Now (you believe)? And you used (aforetime) to hasten it on!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it will be said to them who wronged themselves: ``Taste you the everlasting torment! Are you recompensed (aught) save what you used to earn?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask you (O Muhammad SAW) to inform them (saying): ``Is it true (i.e. the torment and the establishment of the Hour; - the Day of Resurrection)?" Say: ``Yes! By my Lord! It is the very truth! and you cannot escape from it!"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if every person who had wronged (by disbelieving in Allah and by worshipping others besides Allah), possessed all that is on earth, and sought to ransom himself therewith (it will not be accepted), and they would feel in their hearts regret when they see the torment, and they will be judged with justice, and no wrong will be done unto them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
No doubt, surely, all that is in the heavens and the earth belongs to Allah. No doubt, surely, Allah's Promise is true. But most of them know not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
It is He Who gives life, and causes death, and to Him you (all) shall return.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind! There has come to you a good advice from your Lord (i.e. the Quran, ordering all that is good and forbidding all that is evil), and a healing for that (disease of ignorance, doubt, hypocrisy and differences, etc.) in your breasts, - a guidance and a mercy (explaining lawful and unlawful things, etc.) for the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: ``In the Bounty of Allah, and in His Mercy (i.e. Islam and the Quran); -therein let them rejoice." That is better than what (the wealth) they amass.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say (O Muhammad SAW to these polytheists): ``Tell me, what provision Allah has sent down to you! And you have made of it lawful and unlawful." Say (O Muhammad SAW): ``Has Allah permitted you (to do so), or do you invent a lie against Allah?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what think those who invent lies against Allah, on the Day of Resurrection? [i.e. Do they think that they will be forgiven and excused! Nay, they will have an eternal punishment in the Fire of Hell]. Truly, Allah is full of Bounty to mankind, but most of them are ungrateful.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
Whatever you (O Muhammad SAW) may be doing, and whatever portion you may be reciting from the Quran, - and whatever deed you (mankind) may be doing (good or evil), We are Witness thereof, when you are doing it. And nothing is hidden from your Lord (so much as) the weight of an atom (or small ant) on the earth or in the heaven. Not what is less than that or what is greater than that but is (written) in a Clear Record. (Tafsir At-Tabari. Vol. 11, Page 129).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
No doubt! Verily, the Auliya' of Allah [i.e. those who believe in the Oneness of Allah and fear Allah much (abstain from all kinds of sins and evil deeds which he has forbidden), and love Allah much (perform all kinds of good deeds which He has ordained)], no fear shall come upon them nor shall they grieve,\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believed (in the Oneness of Allah - Islamic Monotheism), and used to fear Allah much (by abstaining from evil deeds and sins and by doing righteous deeds).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them are glad tidings, in the life of the present world (i.e. righteous dream seen by the person himself or shown to others), and in the Hereafter. No change can there be in the Words of Allah, this is indeed the supreme success.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And let not their speech grieve you (O Muhammad SAW), for all power and honour belong to Allah. He is the All-Hearer, the All-Knower.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
No doubt! Verily, to Allah belongs whosoever is in the heavens and whosoever is in the earth. And those who worship and invoke others besides Allah, in fact they follow not the (Allah's so-called) partners, they follow only a conjecture and they only invent lies.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is Who has appointed for you the night that you may rest therein, and the day to make things visible (to you). Verily, in this are Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) for a people who listen (i.e. those who think deeply).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They (Jews, Christians and pagans) say: ``Allah has begotten a son (children)." Glory be to Him! He is Rich (Free of all wants). His is all that is in the heavens and all that is in the earth. No warrant you have for this. Do you say against Allah what you know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: ``Verily, those who invent lie against Allah will never be successful"\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
A brief enjoyment in this world! - and then unto Us will be their return, then We shall make them taste the severest torment because they used to disbelieve [in Allah, belie His Messengers, deny and challenge His Ayat (proofs, signs, verses, etc.)].\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And recite to them the news of Nuh (Noah). When he said to his people: ``O my people, if my stay (with you), and my reminding (you) of the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah is hard on you, then I put my trust in Allah. So devise your plot, you and your partners, and let not your plot be in doubt for you. Then pass your sentence on me and give me no respite.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
``But if you turn away [from accepting my doctrine of Islamic Monotheism, i.e. to worship none but Allah], then no reward have I asked of you, my reward is only from Allah, and I have been commanded to be one of the Muslims (those who submit to Allah's Will)."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
They denied him, but We delivered him, and those with him in the ship, and We made them generations replacing one after another, while We drowned those who belied Our Ayat (proofs, evidences, lessons, signs, revelations, etc.). Then see what was the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then after him We sent Messengers to their people, they brought them clear proofs, but they would not believe what they had already rejected beforehand. Thus We seal the hearts of the transgressors (those who disbelieve in the Oneness of Allah and disobey Him).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then after them We sent Musa (Moses) and Harun (Aaron) to Fir'aun (Pharaoh) and his chiefs with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.). But they behaved arrogantly and were Mujrimun (disbelievers, sinners, polytheists, criminals, etc.) folk.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
So when came to them the truth from Us, they said: ``This is indeed clear magic."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Musa (Moses) said: ``Say you (this) about the truth when it has come to you? Is this magic? But the magicians will never be successful."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: ``Have you come to us to turn us away from that (Faith) we found our fathers following, - and that you two may have greatness in the land? We are not going to believe you two!"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Fir'aun (Pharaoh) said: ``Bring to me every well-versed sorcerer."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
And when the sorcerers came, Musa (Moses) said to them: ``Cast down what you want to cast!"\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Then when they had cast down, Musa (Moses) said: ``What you have brought is sorcery, Allah will surely make it of no effect. Verily, Allah does not set right the work of Al-Mufsidun (the evil-doers, corrupts, etc.).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
``And Allah will establish and make apparent the truth by His Words, however much the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.) may hate it."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But none believed in Musa (Moses) except the offspring of his people, because of the fear of Fir'aun (Pharaoh) and his chiefs, lest they should persecute them; and verily, Fir'aun (Pharaoh) was arrogant tyrant on the earth, he was indeed one of the Musrifun (polytheists, sinners and transgressors, those who give up the truth and follow the evil, and commit all kinds of great sins).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Musa (Moses) said: ``O my people! If you have believed in Allah, then put your trust in Him if you are Muslims (those who submit to Allah's Will)."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said: ``In Allah we put our trust. Our Lord! Make us not a trial for the folk who are Zalimun (polytheists and wrong-doing) (i.e. do not make them overpower us).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
``And save us by Your Mercy from the disbelieving folk."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We inspired Musa (Moses) and his brother (saying): ``Take dwellings for your people in Egypt, and make your dwellings as places for your worship, and perform As-Salat (Iqamat-as-Salat), and give glad tidings to the believers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Musa (Moses) said: ``Our Lord! You have indeed bestowed on Fir'aun (Pharaoh) and his chiefs splendour and wealth in the life of this world, our Lord! That they may lead men astray from Your Path. Our Lord! Destroy their wealth, and harden their hearts, so that they will not believe until they see the painful torment."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
Allah said: ``Verily, the invocation of you both is accepted. So you both keep to the Straight Way (i.e. keep on doing good deeds and preaching Allah's Message with patience), and follow not the path of those who know not (the truth i.e. to believe in the Oneness of Allah, and also to believe in the Reward of Allah: Paradise, etc.)."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We took the Children of Israel across the sea, and Fir'aun (Pharaoh) with his hosts followed them in oppression and enmity, till when drowning overtook him, he said: ``I believe that La ilaha illa (Huwa): (none has the right to be worshipped but) He," in Whom the Children of Israel believe, and I am one of the Muslims (those who submit to Allah's Will)."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
Now (you believe) while you refused to believe before and you were one of the Mufsidun (evil-doers, corrupts, etc.).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
So this day We shall deliver your (dead) body (out from the sea) that you may be a sign to those who come after you! And verily, many among mankind are heedless of Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And indeed We settled the Children of Israel in an honourable dwelling place (Sham and Misr), and provided them with good things, and they differed not until the knowledge came to them. Verily, Allah will judge between them on the Day of Resurrection in that in which they used to differ.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
So if you (O Muhammad SAW) are in doubt concerning that which We have revealed unto you, [i.e. that your name is written in the Taurat (Torah) and the Injeel (Gospel)] then ask those who are reading the Book [the Taurat (Torah) and the Injeel (Gospel)] before you. Verily, the truth has come to you from your Lord. So be not of those who doubt (it).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And be not one of those who belie the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, for then you shall be one of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Truly! Those, against whom the Word (Wrath) of your Lord has been justified, will not believe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every sign should come to them, - until they see the painful torment.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Was there any town (community) that believed (after seeing the punishment), and its Faith (at that moment) saved it (from the punishment)? (The answer is none,) - except the people of Yunus (Jonah); when they believed, We removed from them the torment of disgrace in the life of the (present) world, and permitted them to enjoy for a while.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And had your Lord willed, those on earth would have believed, all of them together. So, will you (O Muhammad SAW) then compel mankind, until they become believers.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
It is not for any person to believe, except by the Leave of Allah, and He will put the wrath on those who are heedless.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: ``Behold all that is in the heavens and the earth," but neither Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) nor warners benefit those who believe not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Then do they wait for (anything) save for (destruction) like the days of the men who passed away before them? Say: ``Wait then, I am (too) with you among those who wait."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then (in the end) We save Our Messengers and those who believe! Thus it is incumbent upon Us to save the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say (O Muhammad SAW): ``O you mankind! If you are in doubt as to my religion (Islam), then (know that) I will never worship those whom you worship, besides Allah. But I worship Allah Who causes you to die, I am commanded to be one of the believers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
``And (it is inspired to me): Direct your face (O Muhammad SAW) entirely towards the religion Hanifa (Islamic Monotheism, i.e. to worship none but Allah Alone), and never be one of the Mushrikun (those who ascribe partners to Allah, polytheists, idolaters, disbelievers in the Oneness of Allah, and those who worship others along with Allah).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
``And invoke not besides Allah, any that will neither profit you, nor hurt you, but if (in case) you did so, you shall certainly be one of the Zalimun (polytheists and wrong-doers)."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
And if Allah touches you with hurt, there is none who can remove it but He; and if He intends any good for you, there is none who can repel His Favour which He causes it to reach whomsoever of His slaves He will. And He is the Oft-Forgiving, Most Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
. Say: ``O you mankind! Now truth (i.e. the Quran and Prophet Muhammad SAW), has come to you from your Lord. So whosoever receives guidance, he does so for the good of his own self, and whosoever goes astray, he does so to his own loss, and I am not (set) over you as a Wakil (disposer of affairs to oblige you for guidance)."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And (O Muhammad SAW), follow the inspiration sent unto you, and be patient till Allah gives judgement. And He is the Best of judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif-Lam-Ra. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings]. (This is) a Book, the Verses whereof are perfected (in every sphere of knowledge, etc.), and then explained in detail from One (Allah), Who is All-Wise and Well-Acquainted (with all things).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
(Saying) worship none but Allah. Verily, I (Muhammad SAW) am unto you from Him a warner and a bringer of glad tidings.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And (commanding you): ``Seek the forgiveness of your Lord, and turn to Him in repentance, that He may grant you good enjoyment, for a term appointed, and bestow His abounding Grace to every owner of grace (i.e. the one who helps and serves needy and deserving, physically and with his wealth, and even with good words). But if you turn away, then I fear for you the torment of a Great Day (i.e. the Day of Resurrection).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
To Allah is your return, and He is Able to do all things."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
No doubt! They did fold up their breasts, that they may hide from Him. Surely, even when they cover themselves with their garments, He knows what they conceal and what they reveal. Verily, He is the All-Knower of the (innermost secrets) of the breasts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And no (moving) living creature is there on earth but its provision is due from Allah. And He knows its dwelling place and its deposit (in the uterous, grave, etc.). all is in a Clear Book (Al-Lauh Al-Mahfuz - the Book of Decrees with Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And He it is Who has created the heavens and the earth in six Days and His Throne was on the water, that He might try you, which of you is the best in deeds. But if you were to say to them: ``You shall indeed be raised up after death," those who disbelieve would be sure to say, ``This is nothing but obvious magic."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We delay the torment for them till a determined term, they are sure to say, ``What keeps it back?" Verily, on the day it reaches them, nothing will turn it away from them, and they will be surrounded by (fall in) that at which they used to mock!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We give man a taste of Mercy from Us, and then withdraw it from him, verily! He is despairing, ungrateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
But if We let him taste good (favour) after evil (poverty and harm) has touched him, he is sure to say: ``Ills have departed from me." Surely, he is exultant, and boastful (ungrateful to Allah).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Except those who show patience and do righteous good deeds, those: theirs will be forgiveness and a great reward (Paradise).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
So perchance you (Muhammad SAW) may give up a part of what is revealed unto you, and that your breast feels straitened for it because they say, ``Why has not a treasure been sent down unto him, or an angel has come with him?" But you are only a warner. And Allah is a Wakil (Disposer of affairs, Trustee, Guardian, etc.) over all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or they say, ``He (Prophet Muhammad SAW) forged it (the Quran)." Say: ``Bring you then ten forged Surah (chapters) like unto it, and call whomsoever you can, other than Allah (to your help), if you speak the truth!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
If then they answer you not, know then that the Revelation (this Quran) is sent down with the Knowledge of Allah and that La ilaha illa Huwa: (none has the right to be worshipped but He)! Will you then be Muslims (those who submit to Islam)?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whosoever desires the life of the world and its glitter; to them We shall pay in full (the wages of) their deeds therein, and they will have no diminution therein.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
They are those for whom there is nothing in the Hereafter but Fire; and vain are the deeds they did therein. And of no effect is that which they used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Can they (Muslims) who rely on a clear proof (the Quran) from their Lord, and whom a witness [Prophet Muhammad SAW through Jibrael (Gabriel)] from Him follows it (can they be equal with the disbelievers); and before it, came the Book of Musa (Moses), a guidance and a mercy, they believe therein, but those of the sects (Jews, Christians and all the other non-Muslim nations) that reject it (the Quran), the Fire will be their promised meeting-place. So be not in doubt about it (i.e. those who denied Prophet Muhammad SAW and also denied all that which he brought from Allah, surely, they will enter Hell). Verily, it is the truth from your Lord, but most of the mankind believe not.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who does more wrong than he who invents a lie against Allah. Such wi, l be brought before their Lord, and the witnesses will say, ``These are the ones who lied against their Lord!" No doubt! the curse of Allah is on the Zalimun (polytheists, wrong-doers, oppressors, etc.).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Those who hinder (others) from the Path of Allah (Islamic Monotheism), and seek a crookedness therein, while they are disbelievers in the Hereafter.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
By no means will they escape (from Allah's Torment) on earth, nor have they protectors besides Allah! Their torment will be doubled! They could not bear to hear (the preachers of the truth) and they used not to see (the truth because of their severe aversin, inspite of the fact that they had the sense of hearing and sight).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
They are those who have lost their ownselves, and their invented false deities will vanish from them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Certainly, they are those who will be the greatest losers in the Hereafter.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Verily, those who believe (in the Oneness of Allah - Islamic Monotheism) and do righteous good deeds, and humble themselves (in repentance and obedience) before their Lord, - they will be dwellers of Paradise to dwell therein forever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The likeness of the two parties is as the blind and the deaf and the seer and the hearer. Are they equal when compared? Will you not then take heed?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And indeed We sent Nuh (Noah) to his people (and he said): ``I have come to you as a plain warner."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
``That you worship none but Allah, surely, I fear for you the torment of a painful Day."\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
The chiefs of the disbelievers among his people said: ``We see you but a man like ourselves, nor do we see any follow you but the meanest among us and they (too) followed you without thinking. And we do not see in you any merit above us, in fact we think you are liars."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: ``O my people! Tell me, if I have a clear proof from my Lord, and a Mercy (Prophethood, etc.) has come to me from Him, but that (Mercy) has been obscured from your sight. Shall we compel you to accept it (Islamic Monotheism) when you have a strong hatred for it?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
``And O my people! I ask of you no wealth for it, my reward is from none but Allah. I am not going to drive away those who have believed. Surely, they are going to meet their Lord, but I see that you are a people that are ignorant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
``And O my people! Who will help me against Allah, if I drove them away? Will you not then give a thought?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
``And I do not say to you that with me are the Treasures of Allah, ``Nor that I know the Ghaib (unseen); ``nor do I say I am an angel, and I do not say of those whom your eyes look down upon that Allah will not bestow any good on them. Allah knows what is in their inner-selves (as regards belief, etc.). In that case, I should, indeed be one of the Zalimun (wrong-doers, oppressors, etc.)."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: ``O Nuh (Noah)! You have disputed with us and much have you prolonged the dispute with us, now bring upon us what you threaten us with, if you are of the truthful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said: ``Only Allah will bring it (the punishment) on you, if He will, and then you will escape not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
``And my advice will not profit you, even if I wish to give you good counsel, if Allah's Will is to keep you astray. He is your Lord! and to Him you shall return."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or they (the pagans of Makkah) say: ``He (Muhammad SAW) has fabricated it (the Quran)." Say: ``If I have fabricated it, upon me be my crimes, but I am innocent of (all) those crimes which you commit."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was inspired to Nuh (Noah): ``None of your people will believe except those who have believed already. So be not sad because of what they used to do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
``And construct the ship under Our Eyes and with Our Inspiration, and address Me not on behalf of those who did wrong; they are surely to be drowned."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
And as he was constructing the ship, whenever the chiefs of his people passed by him, they made a mockery of him. He said: ``If you mock at us, so do we mock at you likewise for your mocking.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
``And you will know who it is on whom will come a torment that will cover him with disgrace and on whom will fall a lasting torment."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
(So it was) till then there came Our Command and the oven gushed forth (water like fountains from the earth). We said: ``Embark therein, of each kind two (male and female), and your family, except him against whom the Word has already gone forth, and those who believe. And none believed with him, except a few."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And he [Nuh (Noah)] said: ``Embark therein, in the Name of Allah will be its moving course and its resting anchorage. Surely, my Lord is Oft-Forgiving, Most Merciful." (Tafsir At-Tabari, Vol. 12, Page 43)\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
So it (the ship) sailed with them amidst the waves like mountains, and Nuh (Noah) called out to his son, who had separated himself (apart), ``O my son! Embark with us and be not with the disbelievers."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
The son replied: ``I will betake myself to a mountain, it will save me from the water." Nuh (Noah) said: ``This day there is no saviourfrom the Decree of Allah except him on whom He has mercy." And a wave came in between them, so he (the son) was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said: ``O earth! Swallow up your water, and O sky! Withhold (your rain)." And the water was diminished (made to subside) and the Decree (of Allah) was fulfilled (i.e. the destruction of the people of Nuh (Noah). And it (the ship) rested on Mount Judi, and it was said: ``Away with the people who are Zalimun (polytheists and wrong-doing)!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Nuh (Noah) called upon his Lord and said, ``O my Lord! Verily, my son is of my family! And certainly, Your Promise is true, and You are the Most Just of the judges."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: ``O Nuh (Noah)! Surely, he is not of your family; verily, his work is unrighteous, so ask not of Me that of which you have no knowledge! I admonish you, lest you be one of the ignorants."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
Nuh (Noah) said: ``O my Lord! I seek refuge with You from asking You that of which I have no knowledge. And unless You forgive me and have Mercy on me, I would indeed be one of the losers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said: ``O Nuh (Noah)! Come down (from the ship) with peace from Us and blessings on you and on the people who are with you (and on some of their off spring), but (there will be other) people to whom We shall grant their pleasures (for a time), but in the end a painful torment will reach them from Us."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
This is of the news of the unseen which We reveal unto you (O Muhammad SAW), neither you nor your people knew them before this. So be patient. Surely, the (good) end is for the Muttaqun (pious - see V. 2:2)\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to 'Ad (people We sent) their brother Hud. He said, ``O my people! Worship Allah! You have no other Ilah (God) but Him. Certainly, you do nothing but invent (lies)!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
``O my people I ask of you no reward for it (the Message). My reward is only from Him, Who created me. Will you not then understand?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
``And O my people! Ask forgiveness of your Lord and then repent to Him, He will send you (from the sky) abundant rain, and add strength to your strength, so do not turn away as Mujrimun (criminals, disbelievers in the Oneness of Allah)."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said: ``O Hud! No evidence have you brought us, and we shall not leave our gods for your (mere) saying! And we are not believers in you.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
``All that we say is that some of our gods (false deities) have seized you with evil (madness)." He said: ``I call Allah to witness and bear you witness that I am free from that which you ascribe as partners in worship,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
With Him (Allah). So plot against me, all of you, and give me no respite.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
``I put my trust in Allah, my Lord and your Lord! There is not a moving (living) creature but He has grasp of its forelock. Verily, my Lord is on the Straight Path (the truth).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
``So if you turn away, still I have conveyed the Message with which I was sent to you. My Lord will make another people succeed you, and you will not harm Him in the least. Surely, my Lord is Guardian over all things."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our Commandment came, We saved Hud and those who believed with him by a Mercy from Us, and We saved them from a severe torment.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
Such were 'Ad (people). They rejected the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord and disobeyed His Messengers, and followed the command of every proud obstinate (oppressor of the truth, from their leaders).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were pursued by a curse in this world and (so they will be) on the Day of Resurrection. No doubt! Verily, 'Ad disbelieved in their Lord. So away with 'Ad, the people of Hud.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamud (people, We sent) their brother Salih (Saleh). He said: ``O my people! Worship Allah, you have no other Ilah (God) but Him. He brought you forth from the earth and settled you therein, then ask forgiveness of Him and turn to Him in repentance. Certainly, my Lord is Near (to all by His Knowledge), Responsive."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: ``O Salih (Saleh)! You have been among us as a figure of good hope (and we wished for you to be our chief), till this [new thing which you have brought; that we leave our gods and worship your God (Allah) Alone]! Do you (now) forbid us the worship of what our fathers have worshipped? But we are really in grave doubt as to that which you invite us to (monotheism)."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said: ``O my people! Tell me, if I have a clear proof from my Lord, and there has come to me a Mercy (Prophethood, etc.) from Him, who then can help me against Allah, if I were to disobey Him? Then you increase me not but in loss.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
``And O my people! This she-camel of Allah is a sign to you, leave her to feed on Allah's earth, and touch her not with evil, lest a near torment will seize you."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they killed her. So he said: ``Enjoy yourselves in your homes for three days. This is a promise (i.e. a threat) that will not be belied."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
So when Our Commandment came, We saved Salih (Saleh) and those who believed with him by a Mercy from Us, and from the disgrace of that Day. Verily, your Lord, He is the All-Strong, the All-Mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And As-Saihah (torment - awful cry, etc.) overtook the wrong-doers, so they lay (dead), prostrate in their homes,\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never lived there. No doubt! Verily, Thamud disbelieved in their Lord. So away with Thamud!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And verily, there came Our Messengers to Ibrahim (Abraham) with glad tidings. They said: Salam (greetings or peace!) He answered, Salam (greetings or peace!) and he hastened to entertain them with a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw their hands went not towards it (the meal), he felt some mistrust of them, and conceived a fear of them. They said: ``Fear not, we have been sent against the people of Lout (Lot)."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing (there), and she laughed (either, because the Messengers did not eat their food or for being glad for the destruction of the people of Lout (Lot). But We gave her glad tidings of Ishaque (Isaac), and after him, of Ya'qub (Jacob).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said (in astonishment): ``Woe unto me! Shall I bear a child while I am an old woman, and here is my husband, an old man? Verily! This is a strange thing!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: ``Do you wonder at the Decree of Allah? The Mercy of Allah and His Blessings be on you, O the family [of Ibrahim (Abraham)]. Surely, He (Allah) is All-Praiseworthy, All-Glorious."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
Then when the fear had gone away from (the mind of) Ibrahim (Abraham), and the glad tidings had reached him, he began to plead with Us (Our Messengers) for the people of Lout (Lot).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Verily, Ibrahim (Abraham) was, without doubt, forbearing, used to invoke Allah with humility, and was repentant (to Allah all the time, again and again).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
``O Ibrahim (Abraham)! Forsake this. Indeed, the Commandment of your Lord has gone forth. Verily, there will come a torment for them which cannot be turned back."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our Messengers came to Lout (Lot), he was grieved on their account and felt himself straitened for them (lest the town people should approach them to commit sodomy with them). He said: ``This is a distressful day."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came rushing towards him, and since aforetime they used to commit crimes (sodomy, etc.), he said: ``O my people! Here are my daughters (i.e. the daughters of my nation), they are purer for you (if you marry them lawfully). So fear Allah and degrade me not as regards my guests! Is there not among you a single right-minded man?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: ``Surely you know that we have neither any desire nor in need of your daughters, and indeed you know well what we want!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: ``Would that I had strength (men) to overpower you, or that I could betake myself to some powerful support (to resist you)."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
They (Messengers) said: ``O Lout (Lot)! Verily, we are the Messengers from your Lord! They shall not reach you! So travel with your family in a part of the night, and let not any of you look back, but your wife (will remain behind), verily, the punishment which will afflict them, will afflict her. Indeed, morning is their appointed time. Is not the morning near?"\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our Commandment came, We turned (the towns of Sodom in Palestine) upside down, and rained on them stones of baked clay, piled up;\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked from your Lord, and they are not ever far from the Zalimun (polytheists, evil-doers, etc.).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to the Madyan (Midian) people (We sent) their brother Shu'aib. He said: ``O my people! Worship Allah, you have no other Ilah (God) but Him, and give not short measure or weight, I see you in prosperity; and verily I fear for you the torment of a Day encompassing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
``And O my people! Give full measure and weight in justice and reduce not the things that are due to the people, and do not commit mischief in the land, causing corruption.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
``That which is left by Allah for you (after giving the rights of the people) is better for you, if you are believers. And I am not set over you as a guardian.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said: ``O Shu'aib! Does your Salat (prayer) (i.e. the prayers which you offer has spoiled your mind, so you) command that we leave off what our fathers used to worship, or that we leave off doing what we like with our property? Verily, you are the forbearer, right-minded!" (They said this sarcastically).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: ``O my people! Tell me, if I have a clear evidence from my Lord, and He has given me a good sustenance from Himself (shall I corrupt it by mixing it with the unlawfully earned money). I wish not, in contradiction to you, to do that which I forbid you. I only desire reform so far as I am able, to the best of my power. And my guidance cannot come except from Allah, in Him I trust and unto Him I repent.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
``And O my people! Let not my Shiqaqcause you to suffer the fate similar to that of the people of Nuh (Noah) or of Hud or of Salih (Saleh), and the people of Lout (Lot) are not far off from you!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
``And ask forgiveness of your Lord and turn unto Him in repentance. Verily, my Lord is Most Merciful, Most Loving."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: ``O Shu'aib! We do not understand much of what you say, and we see you a weak (man, it is said that he was a blind man) among us. Were it not for your family, we should certainly have stoned you and you are not powerful against us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: ``O my people! Is then my family of more weight with you than Allah? And you have cast Him away behind your backs. Verily, my Lord is surrounding all that you do.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
``And O my people! Act according to your ability and way, and I am acting (on my way). You will come to know who it is on whom descends the torment that will cover him with ignominy, and who is a liar! And watch you! Verily, I too am watching with you."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our Commandment came, We saved Shu'aib and those who believed with him by a Mercy from Us. And As-Saihah (torment - awful cry, etc.) seized the wrong-doers, and they lay (dead) prostrate in their homes.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As if they had never lived there! So away with Madyan (Midian)! As away with Thamud! (All these nations were destroyed).\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And indeed We sent Musa (Moses) with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and a manifest authority;\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
To Fir'aun (Pharaoh) and his chiefs, but they followed the command of Fir'aun (Pharaoh), and the command of Fir'aun (Pharaoh) was no right guide.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will go ahead of his people on the Day of Resurrection, and will lead them into the Fire, and evil indeed is the place to which they are led.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
They were pursued by a curse in this (deceiving life of this world) and (so they will be pursued by a curse) on the Day of Resurrection. How bad is the curse (in this world) pursued by another curse (in the Hereafter).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
These are some of the news of the (population of) towns which We relate unto you (O Muhammad SAW); of them, some are standing, and some have been (already) reaped.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We wronged them not, but they wronged themselves. So their aliha (gods), other than Allah, whom they invoked, profited them naught when there came the Command of your Lord, nor did they add aught (to their lot) but destruction.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the Seizure of your Lord when He seizes the (population of) towns while they are doing wrong. Verily, His Seizure is painful, and severe.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Indeed in that (there) is a sure lesson for those who fear the torment of the Hereafter. That is a Day whereon mankind will be gathered together, and that is a Day when all (the dwellers of the heavens and the earth) will be present.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We delay it only for a term (already) fixed.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
On the Day when it comes, no person shall speak except by His (Allah's) Leave. Some among them will be wretched and (others) blessed.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who are wretched, they will be in the Fire, sighing in a high and low tone.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
They will dwell therein for all the time that the heavens and the earth endure, except as your Lord wills. Verily, your Lord is the doer of what He wills.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And those who are blessed, they will be in Paradise, abiding therein for all the time that the heavens and the earth endure, except as your Lord will, a gift without an end.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be not in doubt (O Muhammad SAW) as to what these (pagans and polytheists) men worship. They worship nothing but what their fathers worshipped before (them). And verily, We shall repay them in full their portion without diminution.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
Indeed, We gave the Book to Musa (Moses), but differences arose therein, and had it not been for a Word that had gone forth before from your Lord, the case would have been judged between them, and indeed they are in grave doubt concerning it (this Quran).\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And verily, to each of them your Lord will repay their works in full. Surely, He is All-Aware of what they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So stand (ask Allah to make) you (Muhammad SAW) firm and straight (on the religion of Islamic Monotheism) as you are commanded and those (your companions) who turn in repentance (unto Allah) with you, and transgress not (Allah's legal limits). Verily, He is All-Seer of what you do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And incline not toward those who do wrong, lest the Fire should touch you, and you have no protectors other than Allah, nor you would then be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And perform As-Salat (Iqamat-as-Salat), at the two ends of the day and in some hours of the night [i.e. the five compulsory Salat (prayers)]. Verily, the good deeds remove the evil deeds (i.e. small sins). That is a reminder (an advice) for the mindful (those who accept advice).\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient; verily, Allah loses not the reward of the good-doers.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
If only there had been among the generations before you, persons having wisdom, prohibiting (others) from Al-Fasad (disbelief, polytheism, and all kinds of crimes and sins) in the earth, except a few of those whom We saved from among them. Those who did wrong pursued the enjoyment of good things of (this worldly) life, and were Mujrimun (criminals, disbelievers in Allah, polytheists, sinners, etc.).\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
And your Lord would never destroy the towns wrongfully, while their people were right-doers.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
And if your Lord had so willed, He could surely have made mankind one Ummah [nation or community (following one religion only i.e. Islam)], but they will not cease to disagree,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except him on whom your Lord has bestowed His Mercy (the follower of truth - Islamic Monotheism) and for that did He create them. And the Word of your Lord has been fulfilled (i.e. His Saying): ``Surely, I shall fill Hell with jinns and men all together."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all that We relate to you (O Muhammad SAW) of the news of the Messengers is in order that We may make strong and firm your heart thereby. And in this (chapter of the Quran) has come to you the truth, as well as an admonition and a reminder for the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to those who do not believe: ``Act according to your ability and way, We are acting (in our way).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And you wait! We (too) are waiting."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
And to Allah belongs the Ghaib (unseen) of the heavens and the earth, and to Him return all affairs (for decision). So worship Him (O Muhammad SAW) and put your trust in Him. And your Lord is not unaware of what you (people) do."\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif-Lam-Ra. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. These are the Verses of the Clear Book (the Quran that makes clear the legal and illegal things, legal laws, a guidance and a blessing).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Verily, We have sent it down as an Arabic Quran in order that you may understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We relate unto you (Muhammad SAW) the best of stories through Our Revelations unto you, of this Quran. And before this (i.e. before the coming of Divine Inspiration to you), you were among those who knew nothing about it (the Quran).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
(Remember) when Yusuf (Joseph) said to his father: ``O my father! Verily, I saw (in a dream) eleven stars and the sun and the moon, I saw them prostrating themselves to me."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He (the father) said: ``O my son! Relate not your vision to your brothers, lest they arrange a plot against you. Verily! Shaitan (Satan) is to man an open enemy!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
``Thus will your Lord choose you and teach you the interpretation of dreams (and other things) and perfect His Favour on you and on the offspring of Ya'qub (Jacob), as He perfected it on your fathers, Ibrahim (Abraham) and Ishaque (Isaac) aforetime! Verily, your Lord is All-Knowing, All-Wise."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Verily, in Yusuf (Joseph) and his brethren, there were Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) for those who ask.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said: ``Truly, Yusuf (Joseph) and his brother (Benjamin) are loved more by our father than we, but we are 'Usbah (a strong group). Really, our father is in a plain error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
``Kill Yusuf (Joseph) or cast him out to some (other) land, so that the favour of your father may be given to you alone, and after that you will be righteous folk (by intending repentance before committing the sin)."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One from among them said: ``Kill not Yusuf (Joseph), but if you must do something, throw him down to the bottom of a well, he will be picked up by some caravan of travellers."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: ``O our father! Why do you not trust us with Yusuf (Joseph), - when we are indeed his well-wishers?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
``Send him with us tomorrow to enjoy himself and play, and verily, we will take care of him."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He [Ya'qub (Jacob)] said: ``Truly, it saddens me that you should take him away. I fear lest a wolf should devour him, while you are careless of him."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: ``If a wolf devours him, while we are 'Usbah (a strong group) (to guard him), then surely, we are the losers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So, when they took him away, they all agreed to throw him down to the bottom of the well, and We inspired in him:"Indeed, you shall (one day) inform them of this their affair, when they know (you) not."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father in the early part of the night weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said:"O our father! We went racing with one another, and left Yusuf (Joseph) by our belongings and a wolf devoured him; but you will never believe us even when we speak the truth."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt stained with false blood. He said: ``Nay, but your ownselves have made up a tale. So (for me) patience is most fitting. And it is Allah (Alone) Whose help can be sought against that which you assert."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And there came a caravan of travellers; they sent their water-drawer, and he let down his bucket (into the well). He said: ``What good news! Here is a boy." So they hid him as merchandise (a slave). And Allah was the All-Knower of what they did.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a low price, - for a few Dirhams (i.e. for a few silver coins). And they were of those who regarded him insignificant.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And he (the man) from Egypt who bought him, said to his wife: ``Make his stay comfortable, may be he will profit us or we shall adopt him as a son." Thus did We establish Yusuf (Joseph) in the land, that We might teach him the interpretation of events. And Allah has full power and control over His Affairs, but most of men know not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he [Yusuf (Joseph)] attained his full manhood, We gave him wisdom and knowledge (the Prophethood), thus We reward the Muhsinun (doers of good - see V. 2:112).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she, in whose house he was, sought to seduce him (to do an evil act), she closed the doors and said: ``Come on, O you." He said: ``I seek refuge in Allah (or Allah forbid)! Truly, he (your husband) is my master! He made my stay agreeable! (So I will never betray him). Verily, the Zalimun (wrong and evil-doers) will never be successful."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And indeed she did desire him and he would have inclined to her desire, had he not seen the evidence of his Lord. Thus it was, that We might turn away from him evil and illegal sexual intercourse. Surely, he was one of Our chosen, guided slaves.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
So they raced with one another to the door, and she tore his shirt from the back. They both found her lord (i.e. her husband) at the door. She said: ``What is the recompense (punishment) for him who intended an evil design against your wife, except that he be put in prison or a painful torment?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He [Yusuf (Joseph)] said: ``It was she that sought to seduce me," - and a witness of her household bore witness (saying): ``If it be that his shirt is torn from the front, then her tale is true and he is a liar!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
``But if it be that his shirt is torn from the back, then she has told a lie and he is speaking the truth!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when he (her husband) saw his [(Yusuf's (Joseph)] shirt torn at the back; (her husband) said: ``Surely, it is a plot of you women! Certainly mighty is your plot!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
``O Yusuf (Joseph)! Turn away from this! (O woman!) Ask forgiveness for your sin. Verily, you were of the sinful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And women in the city said: ``The wife of Al-'Aziz is seeking to seduce her (slave) young man, indeed she loves him violently; verily we see her in plain error."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
So when she heard of their accusation, she sent for them and prepared a banquet for them; she gave each one of them a knife (to cut the foodstuff with), and she said [(to Yusuf (Joseph)]: ``Come out before them." Then, when they saw him, they exalted him (at his beauty) and (in their astonishment) cut their hands. They said: ``How perfect is Allah (or Allah forbid)! No man is this! This is none other than a noble angel!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: ``This is he (the young man) about whom you did blame me (for his love), and I did seek to seduce him, but he refused. And now if he refuses to obey my order, he shall certainly be cast into prison, and will be one of those who are disgraced."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said:"O my Lord! Prison is more to my liking than that to which they invite me. Unless You turn away their plot from me, I will feel inclined towards them and be one (of those who commit sin and deserve blame or those who do deeds) of the ignorants."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord answered his invocation and turned away from him their plot. Verily, He is the All-Hearer, the All-Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it appeared to them, after they had seen the proofs (of his innocence) to imprison him for a time.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And there entered with him two young men in the prison. One of them said: ``Verily, I saw myself (in a dream) pressing wine." The other said: ``Verily, I saw myself (in a dream) carrying bread on my head and birds were eating thereof." (They said): ``Inform us of the interpretation of this. Verily, we think you are one of the Muhsinun (doers of good - see V. 2:112)."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: ``No food will come to you (in wakefulness or in dream) as your provision, but I will inform (in wakefulness) its interpretation before it (the food) comes. This is of that which my Lord has taught me. Verily, I have abandoned the religion of a people that believe not in Allah and are disbelievers in the Hereafter (i.e. the Kan'aniun of Egypt who were polytheists and used to worship sun and other false deities).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
``And I have followed the religion of my fathers, - Ibrahim (Abraham), Ishaque (Isaac) and Ya'qub (Jacob)], and never could we attribute any partners whatsoever to Allah. This is from the Grace of Allah to us and to mankind, but most men thank not (i.e. they neither believe in Allah, nor worship Him).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
``O two companions of the prison! Are many different lords (gods) better or Allah, the One, the Irresistible?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
``You do not worship besides Him but only names which you have named (forged), you and your fathers, for which Allah has sent down no authority. The command (or the judgement) is for none but Allah. He has commanded that you worship none but Him (i.e. His Monotheism), that is the (true) straight religion, but most men know not.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
``O two companions of the prison! As for one of you, he (as a servant) will pour out wine for his lord (king or master) to drink; and as for the other, he will be crucified and birds will eat from his head. Thus is the case judged concerning which you both did inquire."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to the one whom he knew to be saved: ``Mention me to your lord (i.e. your king, so as to get me out of the prison)." But Shaitan (Satan) made him forget to mention it to his Lord [or Satan made [(Yusuf (Joseph)] to forget the remembrance of his Lord (Allah) as to ask for His Help, instead of others]. So [Yusuf (Joseph)] stayed in prison a few (more) years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king (of Egypt) said: ``Verily, I saw (in a dream) seven fat cows, whom seven lean ones were devouring - and of seven green ears of corn, and (seven) others dry. O notables! Explain to me my dream, if it be that you can interpret dreams."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: ``Mixed up false dreams and we are not skilled in the interpretation of dreams."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
Then the man who was released (one of the two who were in prison), now at length remembered and said: ``I will tell you its interpretation, so send me forth."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
(He said): ``O Yusuf (Joseph), the man of truth! Explain to us (the dream) of seven fat cows whom seven lean ones were devouring, and of seven green ears of corn, and (seven) others dry, that I may return to the people, and that they may know."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
[(Yusuf (Joseph)] said: ``For seven consecutive years, you shall sow as usual and that (the harvest) which you reap you shall leave in ears, (all) - except a little of it which you may eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
``Then will come after that, seven hard (years), which will devour what you have laid by in advance for them, (all) except a little of that which you have guarded (stored).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
``Then thereafter will come a year in which people will have abundant rain and in which they will press (wine and oil)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said: ``Bring him to me." But when the messenger came to him, [Yusuf (Joseph)] said: ``Return to your lord and ask him, 'What happened to the women who cut their hands? Surely, my Lord (Allah) is Well-Aware of their plot. \qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
(The King) said (to the women): ``What was your affair when you did seek to seduce Yusuf (Joseph)?" The women said: ``Allah forbid! No evil know we against him!" The wife of Al-'Aziz said: ``Now the truth is manifest (to all), it was I who sought to seduce him, and he is surely of the truthful."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
[Then Yusuf (Joseph) said: ``I asked for this enquiry] in order that he (Al-'Aziz) may know that I betrayed him not in secret. And, verily! Allah guides not the plot of the betrayers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
``And I free not myself (from the blame). Verily, the (human) self is inclined to evil, except when my Lord bestows His Mercy (upon whom He wills). Verily, my Lord is Oft-Forgiving, Most Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said: ``Bring him to me that I may attach him to my person." Then, when he spoke to him, he said: ``Verily, this day, you are with us high in rank and fully trusted."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
[Yusuf (Joseph)] said: ``Set me over the storehouses of the land; I will indeed guard them with full knowledge" (as a minister of finance in Egypt, in place of Al-'Aziz who was dead at that time).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus did We give full authority to Yusuf (Joseph) in the land, to take possession therein, as when or where he likes. We bestow of Our Mercy on whom We please, and We make not to be lost the reward of Al-Muhsinun (the good doers - see V. 2:112).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And verily, the reward of the Hereafter is better for those who believe and used to fear Allah and keep their duty to Him (by abstaining from all kinds of sins and evil deeds and by performing all kinds of righteous good deeds).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Yusuf's (Joseph) brethren came and they entered unto him, and he recognized them, but they recognized him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had furnished them forth with provisions (according to their need), he said: ``Bring me a brother of yours from your father; (he meant Benjamin). See you not that I give full measure, and that I am the best of the hosts?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
``But if you bring him not to me, there shall be no measure (of corn) for you with me, nor shall you come near me."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: ``We shall try to get permission (for him) from his father, and verily, we shall do it."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And [Yusuf (Joseph)] told his servants to put their money (with which they had bought the corn) into their bags, so that they might know it when they go back to their people, in order that they might come back.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
So, when they returned to their father, they said: ``O our father! No more measure of grain shall we get (unless we take our brother). So send our brother with us, and we shall get our measure and truly we will guard him."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said: ``Can I entrust him to you except as I entrusted his brother [Yusuf (Joseph)] to you aforetime? But Allah is the Best to guard, and He is the Most Merciful of those who show mercy."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their bags, they found their money had been returned to them. They said: ``O our father! What (more) can we desire? This, our money has been returned to us, so we shall get (more) food for our family, and we shall guard our brother and add one more measure of a camel's load. This quantity is easy (for the king to give)."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He [Ya'qub (Jacob)] said: ``I will not send him with you until you swear a solemn oath to me in Allah's Name, that you will bring him back to me unless you are yourselves surrounded (by enemies, etc.)," And when they had sworn their solemn oath, he said: ``Allah is the Witness over what we have said."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said: ``O my sons! Do not enter by one gate, but enter by different gates, and I cannot avail you against Allah at all. Verily! The decision rests only with Allah. In him, I put my trust and let all those that trust, put their trust in Him."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered according to their father's advice, it did not avail them in the least against (the Will of) Allah, it was but a need of Ya'qub's (Jacob) inner-self which he discharged. And verily, he was endowed with knowledge because We had taught him, but most men know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they went in before Yusuf (Joseph), he betook his brother (Benjamin) to himself and said: ``Verily! I am your brother, so grieve not for what they used to do."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
So when he had furnished them forth with their provisions, he put the (golden) bowl into his brother's bag, then a crier cried: ``O you (in) the caravan! Surely, you are thieves!"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They, turning towards them, said: ``What is it that you have missed?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said: ``We have missed the (golden) bowl of the king and for him who produces it is (the reward of) a camel load; I will be bound by it."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said: ``By Allah! Indeed you know that we came not to make mischief in the land, and we are no thieves!"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They [Yusuf's (Joseph) men] said: ``What then shall be the penalty of him, if you are (proved to be) liars."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They [Yusuf's (Joseph) brothers] said: ``The penalty should be that he, in whose bag it is found, should be held for the punishment (of the crime). Thus we punish the Zalimun (wrong-doers, etc.)!"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he [Yusuf (Joseph)] began (the search) in their bags before the bag of his brother. Then he brought it out of his brother's bag. Thus did We plan for Yusuf (Joseph). He could not take his brother by the law of the king (as a slave), except that Allah willed it. (So Allah made the brothers to bind themselves with their way of ``punishment, i.e. enslaving of a thief.") We raise to degrees whom We please, but over all those endowed with knowledge is the All-Knowing (Allah).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They [(Yusuf's (Joseph) brothers] said: ``If he steals, there was a brother of his [Yusuf (Joseph)] who did steal before (him)." But these things did Yusuf (Joseph) keep in himself, revealing not the secrets to them. He said (within himself): ``You are in worst case, and Allah knows best the truth of what you assert!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: ``O ruler of the land! Verily, he has an old father (who will grieve for him); so take one of us in his place. Indeed we think that you are one of the Muhsinun (good-doers - see V. 2:112)."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said: ``Allah forbid, that we should take anyone but him with whom we found our property. Indeed (if we did so), we should be Zalimun (wrong-doers)."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
So, when they despaired of him, they held a conference in private. The eldest among them said: ``Know you not that your father did take an oath from you in Allah's Name, and before this you did fail in your duty with Yusuf (Joseph)? Therefore I will not leave this land until my father permits me, or Allah decides my case (by releasing Benjamin) and He is the Best of the judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
``Return to your father and say, 'O our father! Verily, your son (Benjamin) has stolen, and we testify not except according to what we know, and we could not know the unseen!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
``And ask (the people of) the town where we have been, and the caravan in which we returned, and indeed we are telling the truth."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
He [Ya'qub (Jacob)] said: ``Nay, but your ownselves have beguiled you into something. So patience is most fitting (for me). May be Allah will bring them (back) all to me. Truly He! only He is All-Knowing, All-Wise."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them and said: ``Alas, my grief for Yusuf (Joseph)!" And he lost his sight because of the sorrow that he was suppressing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: ``By Allah! You will never cease remembering Yusuf (Joseph) until you become weak with old age, or until you be of the dead."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: ``I only complain of my grief and sorrow to Allah, and I know from Allah that which you know not.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
``O my sons! Go you and enquire about Yusuf (Joseph) and his brother, and never give up hope of Allah's Mercy. Certainly no one despairs of Allah's Mercy, except the people who disbelieve."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
Then, when they entered unto him [Yusuf (Joseph)], they said: ``O ruler of the land! A hard time has hit us and our family, and we have brought but poor capital, so pay us full measure and be charitable to us. Truly, Allah does reward the charitable."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said: ``Do you know what you did with Yusuf (Joseph) and his brother, when you were ignorant?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: ``Are you indeed Yusuf (Joseph)?" He said: ``I am Yusuf (Joseph), and this is my brother (Benjamin). Allah has indeed been gracious to us. Verily, he who fears Allah with obedience to Him (by abstaining from sins and evil deeds, and by performing righteous good deeds), and is patient, then surely, Allah makes not the reward of the Muhsinun (good-doers - see V. 2:112) to be lost."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: ``By Allah! Indeed Allah has preferred you above us, and we certainly have been sinners."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said: ``No reproach on you this day, may Allah forgive you, and He is the Most Merciful of those who show mercy!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
``Go with this shirt of mine, and cast it over the face of my father, he will become clear-sighted, and bring to me all your family."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
And when the caravan departed, their father said: ``I do indeed feel the smell of Yusuf (Joseph), if only you think me not a dotard (a person who has weakness of mind because of old age)."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said: ``By Allah! Certainly, you are in your old error."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then, when the bearer of the glad tidings arrived, he cast it (the shirt) over his face, and he became clear-sighted. He said: ``Did I not say to you, 'I know from Allah that which you know not. \qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: ``O our father! Ask forgiveness (from Allah) for our sins, indeed we have been sinners."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: ``I will ask my Lord for forgiveness for you, verily He! Only He is the Oft-Forgiving, the Most Merciful."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
Then, when they entered unto Yusuf (Joseph), he betook his parents to himself and said: ``Enter Egypt, if Allah wills, in security."\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he raised his parents to the throne and they fell down before him prostrate. And he said: ``O my father! This is the interpretation of my dream aforetime! My Lord has made it come true! He was indeed good to me, when He took me out of the prison, and brought you (all here) out of the bedouin-life, after Shaitan (Satan) had sown enmity between me and my brothers. Certainly, my Lord is the Most Courteous and Kind unto whom He will. Truly He! Only He is the All-Knowing, the All-Wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
``My Lord! You have indeed bestowed on me of the sovereignty, and taught me the interpretation of dreams; The (only) Creator of the heavens and the earth! You are my Wali (Protector, Helper, Supporter, Guardian, etc.) in this world and in the Hereafter, cause me to die as a Muslim (the one submitting to Your Will), and join me with the righteous."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
This is of the news of the Ghaib (unseen) which We reveal by Inspiration to you (O Muhammad SAW). You were not (present) with them when they arranged their plan together, and (also, while) they were plotting.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And most of mankind will not believe even if you desire it eagerly.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
And no reward you (O Muhammad SAW) ask of them (those who deny your Prophethood) for it, it (the Quran) is no less than a Reminder and an advice unto the 'Alamin (men and jinns).\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many a sign in the heavens and the earth they pass by, while they are averse therefrom.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah except that they attribute partners unto Him [i.e. they are Mushrikun -polytheists - see Verse 6:121].\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they then feel secure from the coming against them of the covering veil of the Torment of Allah, or of the coming against them of the (Final) Hour, all of a sudden while they perceive not?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say (O Muhammad SAW): ``This is my way; I invite unto Allah (i.e. to the Oneness of Allah - Islamic Monotheism) with sure knowledge, I and whosoever follows me (also must invite others to Allah i.e. to the Oneness of Allah - Islamic Monotheism) with sure knowledge. And Glorified and Exalted be Allah (above all that they associate as partners with Him). And I am not of the Mushrikun (polytheists, pagans, idolaters and disbelievers in the Oneness of Allah; those who worship others along with Allah or set up rivals or partners to Allah)."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
And We sent not before you (as Messengers) any but men, whom We inspired from among the people of townships. Have they not travelled through the earth and seen what was the end of those who were before them? And verily, the home of the Hereafter is the best for those who fear Allah and obey Him (by abstaining from sins and evil deeds, and by performing righteous good deeds). Do you not then understand?\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
(They were reprieved) until, when the Messengers gave up hope and thought that they were denied (by their people), then came to them Our Help, and whomsoever We willed were delivered. And Our Punishment cannot be warded off from the people who are Mujrimun (criminals, disobedients to Allah, sinners, disbelievers, polytheists).\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Indeed in their stories, there is a lesson for men of understanding. It (the Quran) is not a forged statement but a confirmation of the Allah's existing Books [the Taurat (Torah), the Injeel (Gospel) and other Scriptures of Allah] and a detailed explanation of everything and a guide and a Mercy for the people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif-Lam-Mim-Ra [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings]. These are the Verses of the Book (the Quran), and that which has been revealed unto you (Muhammad SAW) from your Lord is the truth, but most men believe not.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
Allah is He Who raised the heavens without any pillars that you can see. Then, He Istawa (rose above) the Throne (really in a manner that suits His Majesty). He has subjected the sun and the moon (to continue going round)! Each running (its course) for a term appointed. He regulates all affairs, explaining the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in detail, that you may believe with certainty in the meeting with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He Who spread out the earth, and placed therein firm mountains and rivers and of every kind of fruits He made Zawjain Ithnain (two in pairs - may mean two kinds or it may mean: of two sorts, e.g. black and white, sweet and sour, small and big, etc.) He brings the night as a cover over the day. Verily, in these things, there are Ayat (proofs, evidences, lessons, signs, etc.) for people who reflect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the earth are neighbouring tracts, and gardens of vines, and green crops (fields etc.), and date-palms, growing out two or three from a single stem root, or otherwise (one stem root for every palm), watered with the same water, yet some of them We make more excellent than others to eat. Verily, in these things, there are Ayat (proofs, evidences, lessons, signs) for the people who understand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And if you (O Muhammad SAW) wonder (at these polytheists who deny your message of Islamic Monotheism and have taken besides Allah others for worship who can neither harm nor benefit), then wondrous is their saying: ``When we are dust, shall we indeed then be (raised) in a new creation?" They are those who disbelieve in their Lord! They are those who will have iron chains tying their hands to their necks. They will be dwellers of the Fire to abide therein.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They ask you to hasten the evil before the good, yet (many) exemplary punishments have indeed occurred before them. But verily, your Lord is full of Forgiveness for mankind inspite of their wrong-doing. And verily, your Lord is (also) Severe in punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
And the disbelievers say: ``Why is not a sign sent down to him from his Lord?" You are only a warner, and to every people there is a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows what every female bears, and by how much the wombs fall short (of their time or number) or exceed. Everything with Him is in (due) proportion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
All-Knower of the unseen and the seen, the Most Great, the Most High.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is the same (to Him) whether any of you conceal his speech or declare it openly, whether he be hid by night or go forth freely by day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For each (person), there are angels in succession, before and behind him. They guard him by the Command of Allah. Verily! Allah will not change the good condition of a people as long as they do not change their state of goodness themselves (by committing sins and by being ungrateful and disobedient to Allah). But when Allah wills a people's punishment, there can be no turning back of it, and they will find besides Him no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He who shows you the lightning, as a fear (for travellers) and as a hope (for those who wait for rain). And it is He Who brings up (or originates) the clouds, heavy (with water).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
And Ar-Ra'd (thunder) glorifies and praises Him, and so do the angels because of His Awe, He sends the thunderbolts, and therewith He strikes whom He wills, yet they (disbelievers) dispute about Allah. And He is Mighty in strength and Severe in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
For Him (Alone) is the Word of Truth (i.e. none has the right to be worshipped but He). And those whom they (polytheists and disbelievers) invoke, answer them no more than one who stretches forth his hand (at the edge of a deep well) for water to reach his mouth, but it reaches him not, and the invocation of the disbelievers is nothing but an error (i.e. of no use).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And unto Allah (Alone) falls in prostration whoever is in the heavens and the earth, willingly or unwillingly, and so do their shadows in the mornings and in the afternoons.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say (O Muhammad SAW): ``Who is the Lord of the heavens and the earth?" Say: ``(It is) Allah." Say: ``Have you then taken (for worship) Auliya' (protectors, etc.) other than Him, such as have no power either for benefit or for harm to themselves?" Say: ``Is the blind equal to the one who sees? Or darkness equal to light? Or do they assign to Allah partners who created the like of His creation, so that the creation (which they made and His creation) seemed alike to them." Say: ``Allah is the Creator of all things, He is the One, the Irresistible."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down water (rain) from the sky, and the valleys flow according to their measure, but the flood bears away the foam that mounts up to the surface, and (also) from that (ore) which they heat in the fire in order to make ornaments or utensils, rises a foam like unto it, thus does Allah (by parables) show forth truth and falsehood. Then, as for the foam it passes away as scum upon the banks, while that which is for the good of mankind remains in the earth. Thus Allah sets forth parables (for the truth and falsehood, i.e. Belief and disbelief).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who answered their Lord's Call [believed in the Oneness of Allah and followed His Messenger Muhammad SAW i.e. Islamic Monotheism] is Al-Husna (i.e. Paradise). But those who answered not His Call (disbelieved in the Oneness of Allah and followed not His Messenger Muhammad SAW), if they had all that is in the earth together with its like, they would offer it in order to save themselves (from the torment, it will be in vain). For them there will be the terrible reckoning. Their dwelling place will be Hell; - and worst indeed is that place for rest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Shall he then who knows that what has been revealed unto you (O Muhammad SAW) from your Lord is the truth be like him who is blind? But it is only the men of understanding that pay heed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfill the Covenant of Allah and break not the Mithaq (bond, treaty, covenant);\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
Those who join that which Allah has commanded to be joined (i.e. they are good to their relatives and do not sever the bond of kinship), fear their Lord, and dread the terrible reckoning (i.e. abstain from all kinds of sins and evil deeds which Allah has forbidden and perform all kinds of good deeds which Allah has ordained).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
And those who remain patient, seeking their Lord's Countenance, perform As-Salat (Iqamat-as-Salat), and spend out of that which We have bestowed on them, secretly and openly, and defend evil with good, for such there is a good end;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
'Adn (Eden) Paradise (everlasting Gardens), which they shall enter and (also) those who acted righteously from among their fathers, and their wives, and their offspring. And angels shall enter unto them from every gate (saying):\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
``Salamun 'Alaikum (peace be upon you) for that you persevered in patience! Excellent indeed is the final home!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who break the Covenant of Allah, after its ratification, and sever that which Allah has commanded to be joined (i.e. they sever the bond of kinship and are not good to their relatives), and work mischief in the land, on them is the curse (i.e. they will be far away from Allah's Mercy); And for them is the unhappy (evil) home (i.e. Hell).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah increases the provision for whom He wills, and straitens (it for whom He wills), and they rejoice in the life of the world, whereas the life of this world as compared with the Hereafter is but a brief passing enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And those who disbelieve say: ``Why is not a sign sent down to him (Muhammad SAW) from his Lord?" Say: ``Verily, Allah sends astray whom He wills and guides unto Himself those who turn to Him in repentance."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Those who believe (in the Oneness of Allah - Islamic Monotheism), and whose hearts find rest in the remembrance of Allah, Verily, in the remembrance of Allah do hearts find rest.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
Those who believe (in the Oneness of Allah - Islamic Monotheism), and work righteousness, Tuba (it means all kinds of happiness or name of a tree in Paradise) is for them and a beautiful place of (final) return.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus have We sent you (O Muhammad SAW) to a community before whom other communities have passed away, in order that you might recite unto them what We have inspired to you, while they disbelieve in the Most Beneficient (Allah) Say: ``He is my Lord! La ilaha illa Huwa (none has the right to be worshipped but He)! In Him is my trust, and to Him will be my return with repentance."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And if there had been a Quran with which mountains could be moved (from their places), or the earth could be cloven asunder, or the dead could be made to speak (it would not have been other than this Quran). But the decision of all things is certainly with Allah. Have not then those who believe yet known that had Allah willed, He could have guided all mankind? And a disaster will not cease to strike those who disbelieve because of their (evil) deeds or it (i.e. the disaster) settle close to their homes, until the Promise of Allah comes to pass. Certainly, Allah does not fail in His Promise.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And indeed (many) Messengers were mocked at before you (O Muhammad SAW), but I granted respite to those who disbelieved, and finally I punished them. Then how (terrible) was My Punishment!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is then He (Allah) Who takes charge (guards, maintains, provides, etc.) of every person and knows all that he has earned (like any other deities who know nothing)? Yet they ascribe partners to Allah. Say: ``Name them! Is it that you will inform Him of something He knows not in the earth or is it (just) a show of false words." Nay! To those who disbelieve, their plotting is made fairseeming, and they have been hindered from the Right Path, and whom Allah sends astray, for him, there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is a torment in the life of this world, and certainly, harder is the torment of the Hereafter. And they have no protector against Allah.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The description of the Paradise which the Muttaqun (pious - see V. 2:2): have been promised! -Underneath it rivers flow, its provision is eternal and so is its shade, this is the end (final destination) of the Muttaqun (pious - see V. 2:2), and the end (final destination) of the disbelievers is Fire. (See Verse 47:15)\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those to whom We have given the Book (such as 'Abdullah bin Salam and other Jews who embraced Islam), rejoice at what has been revealed unto you (i.e. the Quran), but there are among the Confederates (from the Jews and pagans) those who reject a part thereof. Say (O Muhammad SAW): ``I am commanded only to worship Allah (Alone) and not to join partners with Him. To Him (Alone) I call and to Him is my return."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And thus have We sent it (the Quran) down to be a judgement of authority in Arabic. Were you (O Muhammad SAW) to follow their (vain) desires after the knowledge which has come to you, then you will not have any Wali (protector) or defender against Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And indeed We sent Messengers before you (O Muhammad SAW), and made for them wives and offspring. And it was not for a Messenger to bring a sign except by Allah's Leave. (For) each and every matter there is a Decree (from Allah).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah blots out what He wills and confirms (what He wills). And with Him is the Mother of the Book (Al-Lauh Al-Mahfuz)\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We show you (O Muhammad SAW) part of what We have promised them or cause you to die, your duty is only to convey (the Message) and on Us is the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
See they not that We gradually reduce the land (of disbelievers, by giving it to the believers, in war victories) from its outlying borders. And Allah judges, there is none to put back His Judgement and He is Swift at reckoning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
And verily, those before them did devise plots, but all planning is Allah's. He knows what every person earns, and the disbelievers will know who gets the good end (final destination).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
And those who disbelieve, say: ``You (O Muhammad SAW) are not a Messenger." Say: ``Sufficient for a witness between me and you is Allah and those too who have knowledge of the Scripture (such as 'Abdullah bin Salam and other Jews and Christians who embraced Islam)."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif-Lam-Ra. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. (This is) a Book which We have revealed unto you (O Muhammad SAW) in order that you might lead mankind out of darkness (of disbelief and polytheism) into light (of belief in the Oneness of Allah and Islamic Monotheism) by their Lord's Leave to the Path of the All-Mighty, the Owner of all Praise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah to Whom belongs all that is in the heavens and all that is in the earth! And woe unto the disbelievers from a severe torment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who prefer the life of this world instead of the Hereafter, and hinder (men) from the Path of Allah (i.e. Islam) and seek crookedness therein - They are far astray.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We sent not a Messenger except with the language of his people, in order that he might make (the Message) clear for them. Then Allah misleads whom He wills and guides whom He wills. And He is the All-Mighty, the All-Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And indeed We sent Musa (Moses) with Our Ayat (signs, proofs, and evidences) (saying): ``Bring out your people from darkness into light, and make them remember the annals of Allah. Truly, therein are evidences, proofs and signs for every patient, thankful (person)."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And (remember) when Musa (Moses) said to his people: ``Call to mind Allah's Favour to you, when He delivered you from Fir'aun's (Pharaoh) people who were afflicting you with horrible torment, and were slaughtering your sons and letting your women alive, and in it was a tremendous trial from your Lord."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And (remember) when your Lord proclaimed: ``If you give thanks (by accepting Faith and worshipping none but Allah), I will give you more (of My Blessings), but if you are thankless (i.e. disbelievers), verily! My Punishment is indeed severe."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Musa (Moses) said: ``If you disbelieve, you and all on earth together, then verily! Allah is Rich (Free of all wants), Owner of all Praise."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has not the news reached you, of those before you, the people of Nuh (Noah), and 'Ad, and Thamud? And those after them? None knows them but Allah. To them came their Messengers with clear proofs, but they put their hands in their mouths (biting them from anger) and said: ``Verily, we disbelieve in that with which you have been sent, and we are really in grave doubt as to that to which you invite us (i.e. Islamic Monotheism)."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Messengers said: ``What! Can there be a doubt about Allah, the Creator of the heavens and the earth? He calls you (to Monotheism and to be obedient to Allah) that He may forgive you of your sins and give you respite for a term appointed." They said: ``You are no more than human beings like us! You wish to turn us away from what our fathers used to worship. Then bring us a clear authority i.e. a clear proof of what you say)."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Messengers said to them: ``We are no more than human beings like you, but Allah bestows His Grace to whom He wills of His slaves. It is not ours to bring you an authority (proof) except by the Permission of Allah. And in Allah (Alone) let the believers put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
``And why should we not put our trust in Allah while He indeed has guided us our ways. And we shall certainly bear with patience all the hurt you may cause us, and in Allah (Alone) let those who trust, put their trust."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And those who disbelieved, said to their Messengers: ``Surely, we shall drive you out of our land, or you shall return to our religion." So their Lord inspired them: ``Truly, We shall destroy the Zalimun (polytheists, disbelievers and wrong-doers.).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
``And indeed, We shall make you dwell in the land after them. This is for him who fears standing before Me (on the Day of Resurrection or fears My Punishment) and also fears My Threat."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
But they (the Messengers) sought victory and help [from their Lord (Allah)], and every obstinate, arrogant dictator (who refuses to believe in the Oneness of Allah) was brought to a complete loss and destruction.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
In front of him (every obstinate, arrogant dictator) is Hell, and he will be made to drink boiling, festering water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
He will sip it unwillingly, and he will find a great difficulty to swallow it down his throat, and death will come to him from every side, yet he will not die and in front of him, will be a great torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The parable of those who disbelieve in their Lord is that their works are as ashes, on which the wind blows furiously on a stormy day, they shall not be able to get aught of what they have earned. That is the straying, far away (from the Right Path).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Do you not see that Allah has created the heavens and the earth with truth? If He will, He can remove you and bring (in your place) a new creation!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And for Allah that is not hard or difficult (i.e. very easy for Allah).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
And they all shall appear before Allah (on the Day of Resurrection) then the weak will say to those who were arrogant (chiefs): ``Verily, we were following you; can you avail us anything from Allah's Torment?" They will say: ``Had Allah guided us, we would have guided you. It makes no difference to us (now) whether we rage, or bear (these torments) with patience, there is no place of refuge for us."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Shaitan (Satan) will say when the matter has been decided: ``Verily, Allah promised you a promise of truth. And I too promised you, but I betrayed you. I had no authority over you except that I called you, so you responded to me. So blame me not, but blame yourselves. I cannot help you, nor can you help me. I deny your former act in associating me (Satan) as a partner with Allah (by obeying me in the life of the world). Verily, there is a painful torment for the Zalimun (polytheists and wrong-doers, etc.)."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed (in the Oneness of Allah and His Messengers and whatever they brought) and did righteous deeds, will be made to enter Gardens under which rivers flow, - to dwell therein forever (i.e. in Paradise), with the permission of their Lord. Their greeting therein will be: Salam (peace!).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
See you not how Allah sets forth a parable? - A goodly word as a goodly tree, whose root is firmly fixed, and its branches (reach) to the sky (i.e. very high).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
Giving its fruit at all times, by the Leave of its Lord and Allah sets forth parables for mankind in order that they may remember.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the parable of an evil word is that of an evil tree uprooted from the surface of earth having no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah will keep firm those who believe, with the word that stands firm in this world (i.e. they will keep on worshipping Allah Alone and none else), and in the Hereafter. And Allah will cause to go astray those who are Zalimun (polytheists and wrong-doers, etc.), and Allah does what He wills.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Have you not seen those who have changed the Blessings of Allah into disbelief (by denying Prophet Muhammad SAW and his Message of Islam), and caused their people to dwell in the house of destruction?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Hell, in which they will burn, - and what an evil place to settle in!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up rivals to Allah, to mislead (men) from His Path! Say: ``Enjoy (your brief life)! But certainly, your destination is the (Hell) Fire!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Say (O Muhammad SAW) to 'Ibadi (My slaves) who have believed, that they should perform As-Salat (Iqamat-as-Salat), and spend in charity out of the sustenance We have given them, secretly and openly, before the coming of a Day on which there will be neither mutual bargaining nor befriending.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
Allah is He Who has created the heavens and the earth and sends down water (rain) from the sky, and thereby brought forth fruits as provision for you; and He has made the ships to be of service to you, that they may sail through the sea by His Command; and He has made rivers (also) to be of service to you.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He has made the sun and the moon, both constantly pursuing their courses, to be of service to you; and He has made the night and the day, to be of service to you.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He gave you of all that you asked for, and if you count the Blessings of Allah, never will you be able to count them. Verily! Man is indeed an extreme wrong-doer, - a disbeliever (an extreme ingrate, denies Allah's Blessings by disbelief, and by worshipping others besides Allah, and by disobeying Allah and His Prophet Muhammad SAW).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And (remember) when Ibrahim (Abraham) said: ``O my Lord! Make this city (Makkah) one of peace and security, and keep me and my sons away from worshipping idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
``O my Lord! They have indeed led astray many among mankind. But whoso follows me, he verily is of me. And whoso disobeys me, - still You are indeed Oft-Forgiving, Most Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
``O our Lord! I have made some of my offspring to dwell in an uncultivable valley by Your Sacred House (the Ka'bah at Makkah); in order, O our Lord, that they may perform As-Salat (Iqamat-as-Salat), so fill some hearts among men with love towards them, and (O Allah) provide them with fruits so that they may give thanks.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
``O our Lord! Certainly, You know what we conceal and what we reveal. Nothing on the earth or in the heaven is hidden from Allah.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
``All the praises and thanks be to Allah, Who has given me in old age Isma'il (Ishmael) and Ishaque (Isaac). Verily! My Lord is indeed the All-Hearer of invocations.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
``O my Lord! Make me one who performs As-Salat (Iqamat-as-Salat), and (also) from my offspring, our Lord! And accept my invocation.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
``Our Lord! Forgive me and my parents, and (all) the believers on the Day when the reckoning will be established."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Consider not that Allah is unaware of that which the Zalimun (polytheists, wrong-doers, etc.) do, but He gives them respite up to a Day when the eyes will stare in horror.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
(They will be) hastening forward with necks outstretched, their heads raised up (towards the sky), their gaze returning not towards them and their hearts empty (from thinking because of extreme fear).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn (O Muhammad SAW) mankind of the Day when the torment will come unto them; then the wrong-doers will say: ``Our Lord! Respite us for a little while, we will answer Your Call and follow the Messengers!" (It will be said): ``Had you not sworn aforetime that you would not leave (the world for the Hereafter).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
``And you dwelt in the dwellings of men who wronged themselves, and it was clear to you how We had dealt with them. And We put forth (many) parables for you."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
Indeed, they planned their plot, and their plot was with Allah, though their plot was a great (one, still) it would never be able to remove the mountains (real mountains or the Islamic law) from their places (as it is of no importance) [Tafsir Ibn Kathir, Vol. 2, Page 597]. [It is said by some interpreters regarding this Verse that the Quraish pagans plotted against Prophet Muhammad SAW to kill him but they failed and were unable to carry out their plot which they plotted].\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So think not that Allah will fail to keep His Promise to His Messengers. Certainly, Allah is All-Mighty, - All-Able of Retribution.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the Day when the earth will be changed to another earth and so will be the heavens, and they (all creatures) will appear before Allah, the One, the Irresistible.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And you will see the Mujrimun (criminals, disbelievers in the Oneness of Allah Islamic Monotheism, polytheists, disobedient to Allah, etc.) that Day bound together in fetters; [Muqarranun in fetters; mean:- with their hands and feet tied to their necks with chains.]\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their garments will be of pitch, and fire will cover their faces.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That Allah may requite each person according to what he has earned. Truly, Allah is Swift at reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This (Quran) is a Message for mankind (and a clear proof against them), in order that they may be warned thereby, and that they may know that He is the only One Ilah (God - Allah) - (none has the right to be worshipped but Allah), and that men of understanding may take heed.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif-Lam-Ra. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. These are the Verses of the Book, and a plain Quran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Perhaps (often) will those who disbelieve wish that they were Muslims [those who have submitted themselves to Allah's Will in Islam Islamic Monotheism, this will be on the Day of Resurrection when they will see the disbelievers going to Hell and the Muslims going to Paradise].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them to eat and enjoy, and let them be preoccupied with (false) hope. They will come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And never did We destroy a township but there was a known decree for it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation can anticipate its term, nor delay it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they say: ``O you (Muhammad SAW) to whom the Dhikr (the Quran) has been sent down! Verily, you are a mad man.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
``Why do you not bring angels to us if you are of the truthful ones?"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We send not the angels down except with the truth (i.e. for torment, etc.), and in that case, they (the disbelievers) would have no respite!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Verily We: It is We Who have sent down the Dhikr (i.e. the Quran) and surely, We will guard it (from corruption).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
Indeed, We sent Messengers before you (O Muhammad SAW) amongst the sects (communities) of old.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And never came a Messenger to them but they did mock him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Thus do We let it (polytheism and disbelief) enter into the hearts of the Mujrimun [criminals, polytheists, pagans, etc. (because of their mockery at the Messengers)].\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They would not believe in it (the Quran), and already the example of (Allah's punishment of) the ancients (who disbelieved) has gone forth.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And even if We opened to them a gate from the heaven and they were to continue ascending thereto,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would surely say: ``Our eyes have been (as if) dazzled. Nay, we are a people bewitched."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And indeed, We have put the big stars in the heaven and We beautified it for the beholders.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have guarded it (near heaven) from every outcast Shaitan (devil).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except him (devil) that gains hearing by stealing, he is pursued by a clear flaming fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth We spread out, and placed therein firm mountains, and caused to grow therein all kinds of things in due proportion.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And We have provided therein means of living, for you and for those whom you provide not [moving (living) creatures, cattle, beasts, and other animals].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing, but with Us are the stores thereof. And We send it not down except in a known measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We send the winds fertilizing (to fill heavily the clouds with water), then caused the water (rain) to descend from the sky, and We gave it to you to drink, and it is not you who are the owners of its stores [i.e. to give water to whom you like or to withhold it from whom you like].\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And certainly We! We it is Who give life, and cause death, and We are the Inheritors.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And indeed, We know the first generations of you who had passed away, and indeed, We know the present generations of you (mankind), and also those who will come afterwards.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
And verily, your Lord will gather them together. Truly, He is All-Wise, All-Knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
And indeed, We created man from sounding clay of altered black smooth mud.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the jinn, We created aforetime from the smokeless flame of fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And (remember) when your Lord said to the angels: ``I am going to create a man (Adam) from sounding clay of altered black smooth mud.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
``So, when I have fashioned him completely and breathed into him (Adam) the soul which I created for him, then fall (you) down prostrating yourselves unto him."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So, the angels prostrated themselves, all of them together.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Except Iblis (Satan), - he refused to be among the prostrators.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
(Allah) said: ``O Iblis (Satan)! What is your reason for not being among the prostrators?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
[Iblis (Satan)] said: ``I am not the one to prostrate myself to a human being, whom You created from sounding clay of altered black smooth mud."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
(Allah) said: ``Then, get out from here, for verily, you are Rajim (an outcast or a cursed one)." [Tafsir At-Tabari]\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
``And verily, the curse shall be upon you till the Day of Recompense (i.e. the Day of Resurrection)."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
[Iblis (Satan)] said: ``O my Lord! Give me then respite till the Day they (the dead) will be resurrected."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Allah said: ``Then, verily, you are of those reprieved,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
``Till the Day of the time appointed."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
[Iblis (Satan)] said: ``O my Lord! Because you misled me, I shall indeed adorn the path of error for them (mankind) on the earth, and I shall mislead them all.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
``Except Your chosen, (guided) slaves among them."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
(Allah) said: ``This is the Way which will lead straight to Me."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
``Certainly, you shall have no authority over My slaves, except those who follow you of the Ghawin (Mushrikun and those who go astray, criminals, polytheists, and evil-doers, etc.).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
``And surely, Hell is the promised place for them all.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
``It (Hell) has seven gates, for each of those gates is a (special) class (of sinners) assigned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
``Truly! The Muttaqun (pious and righteous persons - see V. 2:2) will be amidst Gardens and water-springs (Paradise).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
``(It will be said to them): 'Enter therein (Paradise), in peace and security.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
``And We shall remove from their breasts any sense of injury (that they may have), (So they will be like) brothers facing each other on thrones.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
``No sense of fatigue shall touch them, nor shall they (ever) be asked to leave it."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Declare (O Muhammad SAW) unto My slaves, that truly, I am the Oft-Forgiving, the Most-Merciful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that My Torment is indeed the most painful torment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And tell them about the guests (the angels) of Ibrahim (Abraham).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered unto him, and said: Salaman (peace)! [Ibrahim (Abraham)] said: ``Indeed! We are afraid of you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They (the angels) said: ``Do not be afraid! We give you glad tidings of a boy (son) possessing much knowledge and wisdom."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
[Ibrahim (Abraham)] said: ``Do you give me glad tidings (of a son) when old age has overtaken me? Of what then is your news?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They (the angels) said: ``We give you glad tidings in truth. So be not of the despairing ones."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
[Ibrahim (Abraham)] said: ``And who despairs of the Mercy of his Lord except those who are astray?"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
[Ibrahim (Abraham) again] said: ``What then is the business on which you have come, O Messengers?"\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They (the angels) said: ``We have been sent to a people who are Mujrimun (criminals, disbelievers, polytheists, sinners).\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
``(All) except the family of Lout (Lot). Them all we are surely going to save (from destruction).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
``Except his wife, of whom We have decreed that she shall be of those who remain behind (i.e. she will be destroyed)."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
Then, when the Messengers (the angels) came unto the family of Lout (Lot).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said: ``Verily! You are people unknown to me."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: ``Nay, we have come to you with that (torment) which they have been doubting.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
``And we have brought to you the truth (the news of the destruction of your nation) and certainly, we tell the truth.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
``Then travel in a part of the night with your family, and you go behind them in the rear, and let no one amongst you look back, but go on to where you are ordered."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We made known this decree to him, that the root of those (sinners) was to be cut off in the early morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the inhabitants of the city came rejoicing (at the news of the young men's arrival).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
[Lout (Lot)] said: ``Verily! these are my guests, so shame me not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
``And fear Allah and disgrace me not."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They (people of the city) said: ``Did we not forbid you to entertain (or protect) any of the 'Alamin (people, foreigners, strangers, etc. from us)?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
[Lout (Lot)] said: ``These (the girls of the nation) are my daughters (to marry lawfully), if you must act (so)."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
Verily, by your life (O Muhammad SAW), in their wild intoxication, they were wandering blindly.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
So As-Saihah (torment - awful cry, etc.) overtook them at the time of sunrise;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We turned (the towns of Sodom in Palestine) upside down and rained down on them stones of baked clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Surely! In this are signs, for those who see (or understand or learn the lessons from the Signs of Allah).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And verily! They (the cities) were right on the highroad (from Makkah to Syria i.e. the place where the Dead Sea is now).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Surely! Therein is indeed a sign for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the dwellers in the wood [i.e. the people of Madyan (Midian) to whom Prophet Shu'aib was sent by Allah), were also Zalimun (polytheists and wrong-doers, etc.).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So, We took vengeance on them. They are both on an open highway, plain to see.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And verily, the dwellers of Al-Hijr (the rocky tract) denied the Messengers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And We gave them Our Signs, but they were averse to them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they used to hew out dwellings from the mountains (feeling themselves) secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But As-Saihah (torment - awful cry etc.) overtook them in the early morning (of the fourth day of their promised punishment days).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
And all that which they used to earn availed them not.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
And We created not the heavens and the earth and all that is between them except with truth, and the Hour is surely coming, so overlook (O Muhammad SAW), their faults with gracious forgiveness. [This was before the ordainment of Jihad holy fighting in Allah's Cause].\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Verily, your Lord is the All-Knowing Creator.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And indeed, We have bestowed upon you seven of Al-Mathani (the seven repeatedly recited Verses), (i.e. Surat Al-Fatiha) and the Grand Quran.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Look not with your eyes ambitiously at what We have bestowed on certain classes of them (the disbelievers), nor grieve over them. And lower your wings for the believers (be courteous to the fellow-believers).\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say: ``I am indeed a plain warner."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
As We have sent down on the dividers, (Quraish pagans or Jews and Christians).\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Who have made the Quran into parts. (i.e. believed in a part and disbelieved in the other).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
So, by your Lord (O Muhammad SAW), We shall certainly call all of them to account.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
For all that they used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Therefore proclaim openly (Allah's Message Islamic Monotheism) that which you are commanded, and turn away from Al-Mushrikun (polytheists, idolaters, and disbelievers, etc. - see V. 2:105).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Truly! We will suffice you against the scoffers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Who set up along with Allah another ilah (god), they will come to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
Indeed, We know that your breast is straitened at what they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
So glorify the praises of your Lord and be of those who prostrate themselves (to Him).\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And worship your Lord until there comes unto you the certainty (i.e. death).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The Event (the Hour or the punishment of disbelievers and polytheists or the Islamic laws or commandments), ordained by Allah will come to pass, so seek not to hasten it. Glorified and Exalted be He above all that they associate as partners with Him.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with inspiration of His Command to whom of His slaves He pleases (saying): ``Warn mankind that La ilaha illa Ana (none has the right to be worshipped but I), so fear Me (by abstaining from sins and evil deeds).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He has created the heavens and the earth with truth. High be He Exalted above all they associate as partners with Him.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He has created man from Nutfah (mixed drops of male and female sexual discharge), then behold, this same (man) becomes an open opponent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle, He has created them for you; in them there is warmth (warm clothing), and numerous benefits, and of them you eat.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And wherein is beauty for you, when you bring them home in the evening, and as you lead them forth to pasture in the morning.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they carry your loads to a land that you could not reach except with great trouble to yourselves. Truly, your Lord is full of Kindness, Most Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And (He has created) horses, mules and donkeys, for you to ride and as an adornment. And He creates (other) things of which you have no knowledge.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And upon Allah is the responsibility to explain the Straight Path (i.e. Islamic Monotheism for mankind i.e. to show them legal and illegal, good and evil things, etc. so, whosoever accepts the guidance, it will be for his own benefit and whosoever goes astray, it will be for his own destruction), but there are ways that turn aside (such as Paganism, Judaism, Christianity, etc.). And had He willed, He would have guided you all (mankind).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
He it is Who sends down water (rain) from the sky; from it you drink and from it (grows) the vegetation on which you send your cattle to pasture;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
With it He causes to grow for you the crops, the olives, the date-palms, the grapes, and every kind of fruit. Verily! In this is indeed an evident proof and a manifest sign for people who give thought.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He has subjected to you the night and the day, the sun and the moon; and the stars are subjected by His Command. Surely, in this are proofs for people who understand.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And whatsoever He has created for you on this earth of varying colours [and qualities from vegetation and fruits, etc. (botanical life) and from animal (zoological life)]. Verily! In this is a sign for people who remember.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And He it is Who has subjected the sea (to you), that you eat thereof fresh tender meat (i.e. fish), and that you bring forth out of it ornaments to wear. And you see the ships ploughing through it, that you may seek (thus) of His Bounty (by transporting the goods from place to place) and that you may be grateful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He has affixed into the earth mountains standing firm, lest it should shake with you, and rivers and roads, that you may guide yourselves.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And landmarks (signposts, etc. during the day) and by the stars (during the night), they (mankind) guide themselves.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is then He, Who creates as one who creates not? Will you not then remember?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if you would count the graces of Allah, never could you be able to count them. Truly! Allah is Oft-Forgiving, Most Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knows what you conceal and what you reveal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those whom they (Al-Mushrikun) invoke besides Allah have not created anything, but are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
(They are) dead, lifeless, and they know not when they will be raised up.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your Ilah (God) is One Ilah (God Allah, none has the right to be worshipped but He). But for those who believe not in the Hereafter, their hearts deny (the faith in the Oneness of Allah), and they are proud.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Certainly, Allah knows what they conceal and what they reveal. Truly, He likes not the proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them: ``What is it that your Lord has sent down (unto Muhammad SAW)?" They say: ``Tales of the men of old!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
They will bear their own burdens in full on the Day of Resurrection, and also of the burdens of those whom they misled without knowledge. Evil indeed is that which they shall bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them indeed plotted, but Allah struck at the foundation of their building, and then the roof fell down upon them, from above them, and the torment overtook them from directions they did not perceive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then, on the Day of Resurrection, He will disgrace them and will say: ``Where are My (so called) 'partners' concerning whom you used to disagree and dispute (with the believers, by defying and disobeying Allah)?" Those who have been given the knowledge (about the Torment of Allah for the disbelievers) will say: ``Verily! Disgrace this Day and misery are upon the disbelievers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
``Those whose lives the angels take while they are doing wrong to themselves (by disbelief and by associating partners in worship with Allah and by committing all kinds of crimes and evil deeds)." Then, they will make (false) submission (saying): ``We used not to do any evil." (The angels will reply): ``Yes! Truly, Allah is All-Knower of what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
``So enter the gates of Hell, to abide therein, and indeed, what an evil abode will be for the arrogant."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And (when) it is said to those who are the Muttaqun (pious - see V. 2:2) ``What is it that your Lord has sent down?" They say: ``That which is good." For those who do good in this world, there is good, and the home of the Hereafter will be better. And excellent indeed will be the home (i.e. Paradise) of the Muttaqun (pious - see V. 2:2).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
'Adn (Eden) Paradise (Gardens of Eternity) which they will enter, under which rivers flow, they will have therein all that they wish. Thus Allah rewards the Muttaqun (pious - see V. 2:2).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those whose lives the angels take while they are in a pious state (i.e. pure from all evil, and worshipping none but Allah Alone) saying (to them): Salamun 'Alaikum (peace be on you) enter you Paradise, because of (the good) which you used to do (in the world)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Do they (the disbelievers and polytheists) await but that the angels should come to them [to take away their souls (at death)], or there should come the command (i.e. the torment or the Day of Resurrection) of your Lord? Thus did those before them. And Allah wronged them not, but they used to wrong themselves.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
Then, the evil results of their deeds overtook them, and that at which they used to mock surrounded them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And those who join others in worship with Allah say: ``If Allah had so willed, neither we nor our fathers would have worshipped aught but Him, nor would we have forbidden anything without (Command from) Him." So did those before them. Then! Are the Messengers charged with anything but to convey clearly the Message?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And verily, We have sent among every Ummah (community, nation) a Messenger (proclaiming): ``Worship Allah (Alone), and avoid (or keep away from) Taghut (all false deities, etc.i. e. do not worship Taghut besides Allah)." Then of them were some whom Allah guided and of them were some upon whom the straying was justified. So travel through the land and see what was the end of those who denied (the truth).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
If you (O Muhammad SAW) covet for their guidance, then verily Allah guides not those whom He makes to go astray (or none can guide him whom Allah sends astray). And they will have no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by Allah their strongest oaths, that Allah will not raise up him who dies. Yes, (He will raise them up), a promise (binding) upon Him in truth, but most of mankind know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
In order that He may make manifest to them the truth of that wherein they differ, and that those who disbelieved (in Resurrection, and in the Oneness of Allah) may know that they were liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
Verily! Our Word unto a thing when We intend it, is only that We say unto it: ``Be!" and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And as for those who emigrated for the Cause of Allah, after suffering oppression, We will certainly give them goodly residence in this world, but indeed the reward of the Hereafter will be greater, if they but knew!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
(They are) those who remained patient (in this world for Allah's sake), and put their trust in their Lord (Allah Alone).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We sent not (as Our Messengers) before you (O Muhammad SAW) any but men, whom We inspired, (to preach and invite mankind to believe in the Oneness of Allah). So ask of those who know the Scripture [learned men of the Taurat (Torah) and the Injeel (Gospel)], if you know not.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
With clear signs and Books (We sent the Messengers). And We have also sent down unto you (O Muhammad SAW) the reminder and the advice (the Quran), that you may explain clearly to men what is sent down to them, and that they may give thought.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do then those who devise evil plots feel secure that Allah will not sink them into the earth, or that the torment will not seize them from directions they perceive not?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He may catch them in the midst of their going to and fro (in their jobs), so that there be no escape for them (from Allah's Punishment)?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He may catch them with gradual wasting (of their wealth and health). Truly! Your Lord is indeed full of Kindness, Most Merciful?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not observed things that Allah has created, (how) their shadows incline to the right and to the left, making prostration unto Allah, and they are lowly?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And to Allah prostate all that is in the heavens and all that is in the earth, of the live moving creatures and the angels, and they are not proud [i.e. they worship their Lord (Allah) with humility].\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them, and they do what they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
And Allah said (O mankind!): ``Take not ilahain (two gods in worship, etc.). Verily, He (Allah) is (the) only One Ilah (God). Then, fear Me (Allah) much [and Me (Alone), i.e. be away from all kinds of sins and evil deeds that Allah has forbidden and do all that Allah has ordained and worship none but Allah].\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs all that is in the heavens and (all that is in) the earth and Ad-Din Wasiba is His [(i.e. perpetual sincere obedience to Allah is obligatory). None has the right to be worshipped but Allah)]. Will you then fear any other than Allah?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatever of blessings and good things you have, it is from Allah. Then, when harm touches you, unto Him you cry aloud for help.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Then, when He has removed the harm from you, behold! Some of you associate others in worship with their Lord (Allah).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
So (as a result of that) they deny (with ungratefulness) that (Allah's Favours) which We have bestowed on them! Then enjoy yourselves (your short stay), but you will come to know (with regrets).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they assign a portion of that which We have provided them unto what they know not (false deities). By Allah, you shall certainly be questioned about (all) that you used to fabricate.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign daughters unto Allah! Glorified (and Exalted) be He above all that they associate with Him!. And unto themselves what they desire;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when the news of (the birth of) a female (child) is brought to any of them, his face becomes dark, and he is filled with inward grief!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
He hides himself from the people because of the evil of that whereof he has been informed. Shall he keep her with dishonour or bury her in the earth? Certainly, evil is their decision.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
For those who believe not in the Hereafter is an evil description, and for Allah is the highest description. And He is the All-Mighty, the All-Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
And if Allah were to seize mankind for their wrong-doing, He would not leave on it (the earth) a single moving (living) creature, but He postpones them for an appointed term and when their term comes, neither can they delay nor can they advance it an hour (or a moment).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They assign to Allah that which they dislike (for themselves), and their tongues assert the falsehood that the better things will be theirs. No doubt for them is the Fire, and they will be the first to be hastened on into it, and left there neglected. (Tafsir Al-Qurtubi, Vol. 10, Page 121)\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We indeed sent (Messengers) to the nations before you (O Muhammad SAW), but Shaitan (Satan) made their deeds fair-seeming to them. So he (Satan) is their Wali (helper) today (i.e. in this world), and theirs will be a painful torment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have not sent down the Book (the Quran) to you (O Muhammad SAW), except that you may explain clearly unto them those things in which they differ, and (as) a guidance and a mercy for a folk who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah sends down water (rain) from the sky, then He revives the earth therewith after its death. Verily, in this is a sign (clear proof) for people who listen (obey Allah).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And verily! In the cattle, there is a lesson for you. We give you to drink of that which is in their bellies, from between excretions and blood, pure milk; palatable to the drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruits of date-palms and grapes, you derive strong drink (this was before the order of the prohibition of the alcoholic drinks) and a goodly provision. Verily, therein is indeed a sign for people who have wisdom.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And your Lord inspired the bee, saying: ``Take you habitations in the mountains and in the trees and in what they erect.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
``Then, eat of all fruits, and follow the ways of your Lord made easy (for you)." There comes forth from their bellies, a drink of varying colour wherein is healing for men. Verily, in this is indeed a sign for people who think.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah has created you and then He will cause you to die, and of you there are some who are sent back to senility, so that they know nothing after having known (much). Truly! Allah is All-Knowing, All-Powerful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah has preferred some of you above others in wealth and properties. Then, those who are preferred will by no means hand over their wealth and properties to those (slaves) whom their right hands possess, so that they may be equal with them in respect thereof. Do they then deny the Favour of Allah?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has made for you wives of your own kind, and has made for you, from your wives, sons and grandsons, and has bestowed on you good provision. Do they then believe in false deities and deny the Favour of Allah (by not worshipping Allah Alone).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship others besides Allah, such as do not and cannot own any provision for them from the heavens or the earth.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So put not forward similitudes for Allah (as there is nothing similar to Him, nor He resembles anything). Truly! Allah knows and you know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah puts forward the example (of two men a believer and a disbeliever); a slave (disbeliever) under the possession of another, he has no power of any sort, and (the other), a man (believer) on whom We have bestowed a good provision from Us, and He spends thereof secretly and openly. Can they be equal? (By no means, not). All the praises and thanks be to Allah. Nay! (But) most of them know not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah puts forward (another) example of two men, one of them dumb, who has no power over anything (disbeliever), and he is a burden to his master, whichever way he directs him, he brings no good. Is such a man equal to one (believer in the Islamic Monotheism) who commands justice, and is himself on a Straight Path?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And to Allah belongs the unseen of the heavens and the earth. And the matter of the Hour is not but as a twinkling of the eye, or even nearer. Truly! Allah is Able to do all things.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah has brought you out from the wombs of your mothers while you know nothing. And He gave you hearing, sight, and hearts that you might give thanks (to Allah).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Do they not see the birds held (flying) in the midst of the sky? None holds them but Allah [none gave them the ability to fly but Allah]. Verily, in this are clear proofs and signs for people who believe (in the Oneness of Allah).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And Allah has made for you in your homes an abode, and made for you out of the hides of the cattle (tents for) dwelling, which you find so light (and handy) when you travel and when you stay (in your travels), and of their wool, fur, and hair (sheep wool, camel fur, and goat hair), a furnishing and articles of convenience (e.g. carpets, blankets, etc.), a comfort for a while.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah has made for you out of that which He has created shades, and has made for you places of refuge in the mountains, and has made for you garments to protect you from the heat (and cold), and coats of mail to protect you from your (mutual) violence. Thus does He perfect His Grace unto you, that you may submit yourselves to His Will (in Islam).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
Then, if they turn away, your duty (O Muhammad SAW) is only to convey (the Message) in a clear way.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognise the Grace of Allah, yet they deny it (by worshipping others besides Allah) and most of them are disbelievers (deny the Prophethood of Muhammad SAW).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And (remember) the Day when We shall raise up from each nation a witness (their Messenger), then, those who have disbelieved will not be given leave (to put forward excuses), nor will they be allowed (to return to the world) to repent and ask for Allah's Forgiveness (of their sins, etc.).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when those who did wrong (the disbelievers) will see the torment, then it will not be lightened unto them, nor will they be given respite.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who associated partners with Allah see their (Allah's so-called) partners, they will say: ``Our Lord! These are our partners whom we used to invoke besides you." But they will throw back their word at them (and say): ``Surely! You indeed are liars!"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they will offer (their full) submission to Allah (Alone) on that Day, and their invented false deities [all that they used to invoke besides Allah, e.g. idols, saints, priests, monks, angels, jinns, Jibrael (Gabriel), Messengers, etc.] will vanish from them.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieved and hinder (men) from the Path of Allah, for them We will add torment over the torment; because they used to spread corruption [by disobeying Allah themselves, as well as ordering others (mankind) to do so].\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And (remember) the Day when We shall raise up from every nation a witness against them from amongst themselves. And We shall bring you (O Muhammad SAW) as a witness against these. And We have sent down to you the Book (the Quran) as an exposition of everything, a guidance, a mercy, and glad tidings for those who have submitted themselves (to Allah as Muslims).\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Verily, Allah enjoins Al-Adl (i.e. justice and worshipping none but Allah Alone - Islamic Monotheism) and Al-Ihsan [i.e. to be patient in performing your duties to Allah, totally for Allah's sake and in accordance with the Sunnah (legal ways) of the Prophet SAW in a perfect manner], and giving (help) to kith and kin (i.e. all that Allah has ordered you to give them e.g., wealth, visiting, looking after them, or any other kind of help, etc.): and forbids Al-Fahsha' (i.e. all evil deeds, e.g. illegal sexual acts, disobedience of parents, polytheism, to tell lies, to give false witness, to kill a life without right, etc.), and Al-Munkar (i.e. all that is prohibited by Islamic law: polytheism of every kind, disbelief and every kind of evil deeds, etc.), and Al-Baghy (i.e. all kinds of oppression), He admonishes you, that you may take heed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfill the Covenant of Allah (Bai'a: pledge for Islam) when you have covenanted, and break not the oaths after you have confirmed them, and indeed you have appointed Allah your surety. Verily! Allah knows what you do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And be not like her who undoes the thread which she has spun after it has become strong, by taking your oaths a means of deception among yourselves, lest a nation may be more numerous than another nation. Allah only tests you by this [i.e. who obeys Allah and fulfills Allah's Covenant and who disobeys Allah and breaks Allah's Covenant]. And on the Day of Resurrection, He will certainly make clear to you that wherein you used to differ [i.e. a believer confesses and believes in the Oneness of Allah and in the Prophethood of Prophet Muhammad SAW which the disbeliever denies it and that was their difference amongst them in the life of this world].\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
And had Allah willed, He could have made you (all) one nation, but He sends astray whom He wills and guides whom He wills. But you shall certainly be called to account for what you used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And make not your oaths, a means of deception among yourselves, lest a foot may slip after being firmly planted, and you may have to taste the evil (punishment in this world) of having hindered (men) from the Path of Allah (i.e. Belief in the Oneness of Allah and His Messenger, Muhammad SAW), and yours will be a great torment (i.e. the Fire of Hell in the Hereafter).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And purchase not a small gain at the cost of Allah's Covenant. Verily! What is with Allah is better for you if you did but know.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
Whatever is with you, will be exhausted, and whatever with Allah (of good deeds) will remain. And those who are patient, We will certainly pay them a reward in proportion to the best of what they used to do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever works righteousness, whether male or female, while he (or she) is a true believer (of Islamic Monotheism) verily, to him We will give a good life (in this world with respect, contentment and lawful provision), and We shall pay them certainly a reward in proportion to the best of what they used to do (i.e. Paradise in the Hereafter).\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
So when you want to recite the Quran, seek refuge with Allah from Shaitan (Satan), the outcast (the cursed one).\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
Verily! He has no power over those who believe and put their trust only in their Lord (Allah).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His power is only over those who obey and follow him (Satan), and those who join partners with Him (Allah) [i.e. those who are Mushrikun - polytheists - see Verse 6:121].\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We change a Verse [of the Quran, i.e. cancel (abrogate) its order] in place of another, and Allah knows the best of what He sends down, they (the disbelievers) say: ``You (O Muhammad SAW) are but a Muftari! (forger, liar)." Nay, but most of them know not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say (O Muhammad SAW) Ruh-ul-Qudus [Jibrael (Gabriel)] has brought it (the Quran) down from your Lord with truth, that it may make firm and strengthen (the Faith of) those who believe and as a guidance and glad tidings to those who have submitted (to Allah as Muslims).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And indeed We know that they (polytheists and pagans) say: ``It is only a human being who teaches him (Muhammad SAW)." The tongue of the man they refer to is foreign, while this (the Quran) is a clear Arabic tongue.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Verily! Those who believe not in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, Allah will not guide them and theirs will be a painful torment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
It is only those who believe not in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, who fabricate falsehood, and it is they who are liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoever disbelieved in Allah after his belief, except him who is forced thereto and whose heart is at rest with Faith but such as open their breasts to disbelief, on them is wrath from Allah, and theirs will be a great torment.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they loved and preferred the life of this world over that of the Hereafter. And Allah guides not the people who disbelieve.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
They are those upon whose hearts, hearing (ears) and sight (eyes) Allah has set a seal. And they are the heedless!\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
No doubt, in the Hereafter, they will be the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then, verily! Your Lord for those who emigrated after they had been put to trials and thereafter strove hard and fought (for the Cause of Allah) and were patient, verily, your Lord afterward is, Oft-Forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
(Remember) the Day when every person will come up pleading for himself, and every one will be paid in full for what he did (good or evil, belief or disbelief in the life of this world) and they will not be dealt with unjustly.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And Allah puts forward the example of a township (Makkah), that dwelt secure and well content; its provision coming to it in abundance from every place, but it (its people) denied the Favours of Allah (with ungratefulness). So Allah made it taste the extreme of hunger (famine) and fear, because of that (evil, i.e. denying Prophet Muhammad SAW) which they (its people) used to do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And verily, there had come unto them a Messenger (Muhammad SAW) from among themselves, but they denied him, so the torment overtook them while they were Zalimun (polytheists and wrong-doers, etc.).\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of the lawful and good food which Allah has provided for you. And be grateful for the Graces of Allah, if it is He Whom you worship.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He has forbidden you only Al-Maytatah (meat of a dead animal), blood, the flesh of swine, and any animal which is slaughtered as a sacrifice for others than Allah (or has been slaughtered for idols etc. or on which Allah's Name has not been mentioned while slaughtering). But if one is forced by necessity, without wilful disobedience, and not transgressing, then, Allah is Oft-Forgiving, Most Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And say not concerning that which your tongues put forth falsely: ``This is lawful and this is forbidden," so as to invent lies against Allah. Verily, those who invent lies against Allah will never prosper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A passing brief enjoyment (will be theirs), but they will have a painful torment.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And unto those who are Jews, We have forbidden such things as We have mentioned to you (O Muhammad SAW) before [in Surat-Al-An'am, (The Cattle), see Verse 6:146]. And We wronged them not, but they used to wrong themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then, verily! Your Lord for those who do evil (commit sins and are disobedient to Allah) in ignorance and afterward repent and do righteous deeds, verily, your Lord thereafter, (to such) is Oft-Forgiving, Most Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Verily, Ibrahim (Abraham) was an Ummah (a leader having all the good righteous qualities), or a nation, obedient to Allah, Hanifa (i.e. to worship none but Allah), and he was not one of those who were Al-Mushrikun (polytheists, idolaters, disbelievers in the Oneness of Allah, and those who joined partners with Allah).\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
(He was) thankful for His (Allah's) Graces. He (Allah) chose him (as an intimate friend) and guided him to a Straight Path (Islamic Monotheism, neither Judaism nor Christianity).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him good in this world, and in the Hereafter he shall be of the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then, We have inspired you (O Muhammad SAW saying): ``Follow the religion of Ibrahim (Abraham) Hanifa (Islamic Monotheism - to worship none but Allah) and he was not of the Mushrikun (polytheists, idolaters, disbelievers, etc.).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was only prescribed for those who differed concerning it, and verily, your Lord will judge between them on the Day of Resurrection about that wherein they used to differ.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Invite (mankind, O Muhammad SAW) to the Way of your Lord (i.e. Islam) with wisdom (i.e. with the Divine Inspiration and the Quran) and fair preaching, and argue with them in a way that is better. Truly, your Lord knows best who has gone astray from His Path, and He is the Best Aware of those who are guided.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if you punish (your enemy, O you believers in the Oneness of Allah), then punish them with the like of that with which you were afflicted. But if you endure patiently, verily, it is better for As-Sabirin (the patient ones, etc.).\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And endure you patiently (O Muhammad SAW), your patience is not but from Allah. And grieve not over them (polytheists and pagans, etc.), and be not distressed because of what they plot.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Truly, Allah is with those who fear Him (keep their duty unto Him), and those who are Muhsinun (good-doers, - see the footnote of V. 9:120).\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glorified (and Exalted) be He (Allah) [above all that (evil) they associate with Him] [Tafsir Qurtubi, Vol. 10, Page 204] Who took His slave (Muhammad SAW) for a journey by night from Al-Masjid-al-Haram (at Makkah) to the farthest mosque (in Jerusalem), the neighborhood whereof We have blessed, in order that We might show him (Muhammad SAW) of Our Ayat (proofs, evidences, lessons, signs, etc.). Verily, He is the All-Hearer, the All-Seer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Musa (Moses) the Scripture and made it a guidance for the Children of Israel (saying): ``Take not other than Me as (your) Wakil (Protector, Lord, or Disposer of your affairs, etc).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
``O offspring of those whom We carried (in the ship) with Nuh (Noah)! Verily, he was a grateful slave."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Children of Israel in the Scripture, that indeed you would do mischief on the earth twice and you will become tyrants and extremely arrogant!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So, when the promise came for the first of the two, We sent against you slaves of Ours given to terrible warfare. They entered the very innermost parts of your homes. And it was a promise (completely) fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We gave you once again, a return of victory over them. And We helped you with wealth and children and made you more numerous in man power.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
(And We said): ``If you do good, you do good for your ownselves, and if you do evil (you do it) against yourselves." Then, when the second promise came to pass, (We permitted your enemies) to make your faces sorrowful and to enter the mosque (of Jerusalem) as they had entered it before, and to destroy with utter destruction all that fell in their hands.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
[And We said in the Taurat (Torah)]: ``It may be that your Lord may show mercy unto you, but if you return (to sins), We shall return (to Our Punishment). And We have made Hell a prison for the disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Verily, this Quran guides to that which is most just and right and gives glad tidings to the believers (in the Oneness of Allah and His Messenger, Muhammad SAW, etc.). who work deeds of righteousness, that they shall have a great reward (Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And that those who believe not in the Hereafter (i.e. they disbelieve that they will be recompensed for what they did in this world, good or bad, etc.), for them We have prepared a painful torment (Hell).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
And man invokes (Allah) for evil as he invokes (Allah) for good and man is ever hasty [i.e., if he is angry with somebody, he invokes (saying): ``O Allah! Curse him, etc." and that one should not do, but one should be patient].\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We have appointed the night and the day as two Ayat (signs etc.). Then, We have made dark the sign of the night while We have made the sign of day illuminating, that you may seek bounty from your Lord, and that you may know the number of the years and the reckoning. And We have explained everything (in detail) with full explanation.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And We have fastened every man's deeds to his neck, and on the Day of Resurrection, We shall bring out for him a book which he will find wide open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
(It will be said to him): ``Read your book. You yourself are sufficient as a reckoner against you this Day."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whoever goes right, then he goes right only for the benefit of his ownself. And whoever goes astray, then he goes astray to his own loss. No one laden with burdens can bear another's burden. And We never punish until We have sent a Messenger (to give warning).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We decide to destroy a town (population), We (first) send a definite order (to obey Allah and be righteous) to those among them [or We (first) increase in number those of its population] who are given the good things of this life. Then, they transgress therein, and thus the word (of torment) is justified against it (them). Then We destroy it with complete destruction.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
And how many generations have We destroyed after Nuh (Noah)! And Sufficient is your Lord as an All-Knower and All-Beholder of the sins of His slaves.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoever wishes for the quick-passing (transitory enjoyment of this world), We readily grant him what We will for whom We like. Then, afterwards, We have appointed for him Hell, he will burn therein disgraced and rejected, (far away from Allah's Mercy).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whoever desires the Hereafter and strives for it, with the necessary effort due for it (i.e. do righteous deeds of Allah's Obedience) while he is a believer (in the Oneness of Allah Islamic Monotheism), then such are the ones whose striving shall be appreciated, thanked and rewarded (by Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
To each these as well as those We bestow from the Bounties of your Lord. And the Bounties of your Lord can never be forbidden.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
See how We prefer one above another (in this world) and verily, the Hereafter will be greater in degrees and greater in preference.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Set not up with Allah any other ilah (god), (O man)! (This verse is addressed to Prophet Muhammad SAW, but its implication is general to all mankind), or you will sit down reproved, forsaken (in the Hell-fire).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
And your Lord has decreed that you worship none but Him. And that you be dutiful to your parents. If one of them or both of them attain old age in your life, say not to them a word of disrespect, nor shout at them but address them in terms of honour.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower unto them the wing of submission and humility through mercy, and say: ``My Lord! Bestow on them Your Mercy as they did bring me up when I was small."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knows best what is in your inner-selves. If you are righteous, then, verily, He is Ever Most Forgiving to those who turn unto Him again and again in obedience, and in repentance.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give to the kindred his due and to the Miskin (poor) and to the wayfarer. But spend not wastefully (your wealth) in the manner of a spendthrift. [Tafsir. At-Tabari, Vol. 10, Page 158 (Verse 9:60)].\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Verily, spendthrifts are brothers of the Shayatin (devils), and the Shaitan (Devil - Satan) is ever ungrateful to his Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And if you (O Muhammad SAW) turn away from them (kindred, poor, wayfarer, etc. whom We have ordered you to give their rights, but if you have no money at the time they ask you for it) and you are awaiting a mercy from your Lord for which you hope, then, speak unto them a soft kind word (i.e. Allah will give me and I shall give you).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And let not your hand be tied (like a miser) to your neck, nor stretch it forth to its utmost reach (like a spendthrift), so that you become blameworthy and in severe poverty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Truly, your Lord enlarges the provision for whom He wills and straitens (for whom He wills). Verily, He is Ever All-Knower, All-Seer of His slaves.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And kill not your children for fear of poverty. We provide for them and for you. Surely, the killing of them is a great sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And come not near to the unlawful sexual intercourse. Verily, it is a Fahishah [i.e. anything that transgresses its limits (a great sin)], and an evil way (that leads one to Hell unless Allah forgives him).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And do not kill anyone which Allah has forbidden, except for a just cause. And whoever is killed (intentionally with hostility and oppression and not by mistake), We have given his heir the authority [(to demand Qisas, Law of Equality in punishment or to forgive, or to take Diya (blood money)]. But let him not exceed limits in the matter of taking life (i.e. he should not kill except the killer only). Verily, he is helped (by the Islamic law).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And come not near to the orphan's property except to improve it, until he attains the age of full strength. And fulfil (every) covenant. Verily! the covenant, will be questioned about.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And give full measure when you measure, and weigh with a balance that is straight. That is good (advantageous) and better in the end.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And follow not (O man i.e., say not, or do not or witness not, etc.) that of which you have no knowledge (e.g. one's saying: ``I have seen," while in fact he has not seen, or ``I have heard," while he has not heard). Verily! The hearing, and the sight, and the heart, of each of those you will be questioned (by Allah).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And walk not on the earth with conceit and arrogance. Verily, you can neither rend nor penetrate the earth, nor can you attain a stature like the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
All the bad aspects of these (the above mentioned things) are hateful to your Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
This is (part) of Al-Hikmah (wisdom, good manners and high character, etc.) which your Lord has inspired to you (O Muhammad SAW). And set not up with Allah any other ilah (god) lest you should be thrown into Hell, blameworthy and rejected, (from Allah's Mercy).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Has then your Lord (O pagans of Makkah) preferred for you sons, and taken for Himself from among the angels daughters. Verily! You utter an awful saying, indeed.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
And surely, We have explained [Our Promises, Warnings and (set forth many) examples] in this Quran that they (the disbelievers) may take heed, but it increases them in naught save aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say (O Muhammad SAW to these polytheists, pagans, etc.): ``If there had been other aliha (gods) along with Him as they assert, then they would certainly have sought out a way to the Lord of the Throne (seeking His Pleasures and to be near to Him).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Glorified and High be He! From 'Uluwan Kabira (the great falsehood) that they say! (i.e. forged statements that there are other gods along with Allah, but He is Allah, the One, the Self-Sufficient Master, whom all creatures need. He begets not, nor was He begotten, and there is none comparable or coequal unto Him).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth and all that is therein, glorify Him and there is not a thing but glorifies His Praise. But you understand not their glorification. Truly, He is Ever Forbearing, Oft-Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when you (Muhammad SAW) recite the Quran, We put between you and those who believe not in the Hereafter, an invisible veil (or screen their hearts, so they hear or understand it not).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We have put coverings over their hearts lest, they should understand it (the Quran), and in their ears deafness. And when you make mention of your Lord Alone [La ilaha ill-Allah (none has the right to be worshipped but Allah) Islamic Monotheism] in the Quran, they turn on their backs, fleeing in extreme dislikeness.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know best of what they listen to, when they listen to you. And when they take secret counsel, behold, the Zalimun (polytheists and wrong-doers, etc.) say: ``You follow none but a bewitched man."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See what examples they have put forward for you. So they have gone astray, and never can they find a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say: ``When we are bones and fragments (destroyed), should we really be resurrected (to be) a new creation?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say (O Muhammad SAW) ``Be you stones or iron,"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
``Or some created thing that is yet greater (or harder) in your breasts (thoughts to be resurrected, even then you shall be resurrected)" Then, they will say: ``Who shall bring us back (to life)?" Say: ``He Who created you first!" Then, they will shake their heads at you and say: ``When will that be?" Say: ``Perhaps it is near!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
On the Day when He will call you, and you will answer (His Call) with (words of) His Praise and Obedience, and you will think that you have stayed (in this world) but a little while!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
And say to My slaves (i.e. the true believers of Islamic Monotheism) that they should (only) say those words that are the best. (Because) Shaitan (Satan) verily, sows disagreements among them. Surely, Shaitan (Satan) is to man a plain enemy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you best, if He will, He will have mercy on you, or if He will, He will punish you. And We have not sent you (O Muhammad SAW) as a guardian over them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And your Lord knows best all who are in the heavens and the earth. And indeed, We have preferred some of the Prophets above others, and to Dawud (David) We gave the Zabur (Psalms).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say (O Muhammad SAW): ``Call unto those besides Him whom you pretend [to be gods like angels, Iesa (Jesus), 'Uzair (Ezra), etc.]. They have neither the power to remove the adversity from you nor even to shift it from you to another person."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they call upon [like 'Iesa (Jesus) - son of Maryam (Mary), 'Uzair (Ezra), angel, etc.] desire (for themselves) means of access to their Lord (Allah), as to which of them should be the nearest and they ['Iesa (Jesus), 'Uzair (Ezra), angels, etc.] hope for His Mercy and fear His Torment. Verily, the Torment of your Lord is something to be afraid of!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
And there is not a town (population) but We shall destroy it before the Day of Resurrection, or punish it with a severe torment. That is written in the Book (of our Decrees)\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And nothing stops Us from sending the Ayat (proofs, evidences, signs) but that the people of old denied them. And We sent the she-camel to Thamud as a clear sign, but they did her wrong. And We sent not the signs except to warn, and to make them afraid (of destruction).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And (remember) when We told you: ``Verily! Your Lord has encompassed mankind (i.e. they are in His Grip)." And We made not the vision which we showed you (O Muhammad as an actual eye-witness and not as a dream on the night of Al-Isra') but a trial for mankind, and likewise the accursed tree (Zaqqum, mentioned) in the Quran. We warn and make them afraid but it only increases them in naught save great disbelief, oppression and disobedience to Allah.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And (remember) when We said to the angels: ``Prostrate unto Adam." They prostrated except Iblis (Satan). He said: ``Shall I prostrate to one whom You created from clay?"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
[Iblis (Satan)] said: ``See? This one whom You have honoured above me, if You give me respite (keep me alive) to the Day of Resurrection, I will surely seize and mislead his offspring (by sending them astray) all but a few!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
(Allah) said: ``Go, and whosoever of them follows you, surely! Hell will be the recompense of you (all) an ample recompense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
``And Istafziz [literally means: befool them gradually] those whom you can among them with your voice (i.e. songs, music, and any other call for Allah's disobedience), make assaults on them with your cavalry and your infantry, mutually share with them wealth and children (by tempting them to earn money by illegal ways usury, etc., or by committing illegal sexual intercourse, etc.), and make promises to them." But Satan promises them nothing but deceit.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
``Verily! My slaves (i.e. the true believers of Islamic Monotheism), you have no authority over them. And All-Sufficient is your Lord as a Guardian."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He Who drives the ship for you through the sea, in order that you may seek of His Bounty. Truly! He is Ever Most Merciful towards you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when harm touches you upon the sea, those that you call upon besides Him vanish from you except Him (Allah Alone). But when He brings you safely to land, you turn away (from Him). And man is ever ungrateful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do you then feel secure that He will not cause a side of the land to swallow you up, or that He will not send against you a violent sand-storm? Then, you shall find no Wakil (guardian one to guard you from the torment).\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do you feel secure that He will not send you back a second time to sea and send against you a hurricane of wind and drown you because of your disbelief, then you will not find any avenger therein against Us?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
And indeed We have honoured the Children of Adam, and We have carried them on land and sea, and have provided them with At-Taiyibat (lawful good things), and have preferred them above many of those whom We have created with a marked preference.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
(And remember) the Day when We shall call together all human beings with their (respective) Imam [their Prophets, or their records of good and bad deeds, or their Holy Books like the Quran, the Taurat (Torah), the Injeel (Gospel), etc.]. So whosoever is given his record in his right hand, such will read their records, and they will not be dealt with unjustly in the least.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
And whoever is blind in this world (i.e., does not see Allah's Signs and believes not in Him), will be blind in the Hereafter, and more astray from the Path.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
Verily, they were about to tempt you away from that which We have revealed (the Quran) unto you (O Muhammad SAW), to fabricate something other than it against Us, and then they would certainly have taken you a friend!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And had We not made you stand firm, you would nearly have inclined to them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
In that case, We would have made you taste a double portion (of punishment) in this life and a double portion (of punishment) after death. And then you would have found none to help you against Us.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
And Verily, they were about to frighten you so much as to drive you out from the land. But in that case they would not have stayed (therein) after you, except for a little while.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
(This was Our) Sunnah (rule or way) with the Messengers We sent before you (O Muhammad SAW), and you will not find any alteration in Our Sunnah (rule or way, etc.).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Perform As-Salat (Iqamat-as-Salat) from mid-day till the darkness of the night (i.e. the Zuhr, 'Asr, Maghrib, and 'Isha' prayers), and recite the Quran in the early dawn (i.e. the morning prayer). Verily, the recitation of the Quran in the early dawn is ever witnessed (attended by the angels in charge of mankind of the day and the night).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And in some parts of the night (also) offer the Salat (prayer) with it (i.e. recite the Quran in the prayer), as an additional prayer (Tahajjud optional prayer Nawafil) for you (O Muhammad SAW). It may be that your Lord will raise you to Maqaman Mahmuda (a station of praise and glory, i.e. the highest degree in Paradise!).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say (O Muhammad SAW): My Lord! Let my entry (to the city of Al-Madinah) be good, and likewise my exit (from the city of Makkah) be good. And grant me from You an authority to help me (or a firm sign or a proof).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say: ``Truth (i.e. Islamic Monotheism or this Quran or Jihad against polytheists) has come and Batil (falsehood, i.e. Satan or polytheism, etc.) has vanished. Surely! Batil is ever bound to vanish."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We send down from the Quran that which is a healing and a mercy to those who believe (in Islamic Monotheism and act on it), and it increases the Zalimun (polytheists and wrong-doers) nothing but loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We bestow Our Grace on man (the disbeliever), he turns away and becomes arrogant, far away from the Right Path. And when evil touches him he is in great despair.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say (O Muhammad SAW to mankind): ``Each one does according to Shakilatihi (i.e. his way or his religion or his intentions, etc.), and your Lord knows best of him whose path (religion, etc.) is right."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
And they ask you (O Muhammad SAW) concerning the Ruh (the Spirit); Say: ``The Ruh (the Spirit): it is one of the things, the knowledge of which is only with my Lord. And of knowledge, you (mankind) have been given only a little."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We willed We could surely take away that which We have revealed to you by inspiration (i.e. this Quran). Then you would find no protector for you against Us in that respect.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except as a Mercy from your Lord. Verily! His Grace unto you (O Muhammad SAW) is ever great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: ``If the mankind and the jinns were together to produce the like of this Quran, they could not produce the like thereof, even if they helped one another."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And indeed We have fully explained to mankind, in this Quran, every kind of similitude, but most mankind refuse (the truth and accept nothing) but disbelief.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they say: ``We shall not believe in you (O Muhammad SAW), until you cause a spring to gush forth from the earth for us;\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
``Or you have a garden of date-palms and grapes, and cause rivers to gush forth in their midst abundantly;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
``Or you cause the heaven to fall upon us in pieces, as you have pretended, or you bring Allah and the angels before (us) face to face;\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
``Or you have a house of adornable materials (like silver and pure gold, etc.), or you ascend up into the sky, and even then we will put no faith in your ascension until you bring down for us a Book that we would read." Say (O Muhammad SAW): ``Glorified (and Exalted) be my Lord (Allah) above all that evil they (polytheists) associate with Him! Am I anything but a man, sent as a Messenger?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And nothing prevented men from believing when the guidance came to them, except that they said: ``Has Allah sent a man as (His) Messenger?"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: ``If there were on the earth, angels walking about in peace and security, We should certainly have sent down for them from the heaven an angel as a Messenger."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: ``Sufficient is Allah for a witness between me and you. Verily! He is the All-Knower, the All-Seer of His slaves."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And he whom Allah guides, he is led aright; but he whom He sends astray for such you will find no Auliya' (helpers and protectors, etc.), besides Him, and We shall gather them together on the Day of Resurrection on their faces, blind, dumb and deaf, their abode will be Hell; whenever it abates, We shall increase for them the fierceness of the Fire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their recompense, because they denied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and said: ``When we are bones and fragments, shall we really be raised up as a new creation?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
See they not that Allah, Who created the heavens and the earth, is Able to create the like of them. And He has decreed for them an appointed term, whereof there is not doubt. But the Zalimun (polytheists and wrong-doers, etc.) refuse (the truth the Message of Islamic Monotheism, and accept nothing) but disbelief.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say (to the disbelievers): ``If you possessed the treasure of the Mercy of my Lord (wealth, money, provision, etc.), then you would surely hold back (from spending) for fear of (being exhausted), and man is ever miserly!"\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And indeed We gave to Musa (Moses) nine clear signs. Ask then the Children of Israel, when he came to them, then Fir'aun (Pharaoh) said to him: ``O Musa (Moses)! I think you are indeed bewitched."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
[Musa (Moses)] said: ``Verily, you know that these signs have been sent down by none but the Lord of the heavens and the earth as clear (evidences i.e. proofs of Allah's Oneness and His Omnipotence, etc.). And I think you are, indeed, O Fir'aun (Pharaoh) doomed to destruction (away from all good)!"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
So he resolved to turn them out of the land (of Egypt). But We drowned him and all who were with him.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said to the Children of Israel after him: ``Dwell in the land, then, when the final and the last promise comes near [i.e. the Day of Resurrection or the descent of Christ ['Iesa (Jesus), son of Maryam (Mary) on the earth]. We shall bring you altogether as mixed crowd (gathered out of various nations). [Tafsir Al-Qurtubi, Vol. 10, Page 338]\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
And with truth We have sent it down (i.e. the Quran), and with truth it has descended. And We have sent you (O Muhammad SAW) as nothing but a bearer of glad tidings (of Paradise, for those who follow your Message of Islamic Monotheism), and a warner (of Hell-fire for those who refuse to follow your Message of Islamic Monotheism).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And (it is) a Quran which We have divided (into parts), in order that you might recite it to men at intervals. And We have revealed it by stages. (in 23 years).\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say (O Muhammad SAW to them): ``Believe in it (the Quran) or do not believe (in it). Verily! Those who were given knowledge before it (the Jews and the Christians like 'Abdullah bin Salam and Salman Al-Farisi), when it is recited to them, fall down on their faces in humble prostration."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say: ``Glory be to our Lord! Truly, the Promise of our Lord must be fulfilled."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down on their faces weeping and it adds to their humility.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say (O Muhammad SAW): ``Invoke Allah or invoke the Most Beneficent (Allah), by whatever name you invoke Him (it is the same), for to Him belong the Best Names. And offer your Salat (prayer) neither aloud nor in a low voice, but follow a way between.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say: ``All the praises and thanks be to Allah, Who has not begotten a son (nor an offspring), and Who has no partner in (His) Dominion, nor He is low to have a Wali (helper, protector or supporter). And magnify Him with all the magnificence, [Allahu-Akbar (Allah is the Most Great)]."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen All the praises and thanks be to Allah, Who has sent down to His slave (Muhammad SAW) the Book (the Quran), and has not placed therein any crookedness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
(He has made it) Straight to give warning (to the disbelievers) of a severe punishment from Him, and to give glad tidings to the believers (in the Oneness of Allah Islamic Monotheism), who work righteous deeds, that they shall have a fair reward (i.e. Paradise).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
They shall abide therein forever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those (Jews, Christians, and pagans) who say, ``Allah has begotten a son (or offspring or children)."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
No knowledge have they of such a thing, nor had their fathers. Mighty is the word that comes out of their mouths [i.e. He begot (took) sons and daughters]. They utter nothing but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Perhaps, you, would kill yourself (O Muhammad SAW) in grief, over their footsteps (for their turning away from you), because they believe not in this narration (the Quran).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Verily! We have made that which is on earth as an adornment for it, in order that We may test them (mankind) as to which of them are best in deeds. [i.e. those who do good deeds in the most perfect manner, that means to do them (deeds) totally for Allah's sake and in accordance to the legal ways of the Prophet SAW].\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And verily! We shall make all that is on it (the earth) a bare dry soil (without any vegetation or trees, etc.).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Do you think that the people of the Cave and the Inscription (the news or the names of the people of the Cave) were a wonder among Our Signs?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
(Remember) when the young men fled for refuge (from their disbelieving folk) to the Cave, they said: ``Our Lord! Bestow on us mercy from Yourself, and facilitate for us our affair in the right way!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Therefore We covered up their (sense of) hearing (causing them, to go in deep sleep) in the Cave for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Then We raised them up (from their sleep), that We might test which of the two parties was best at calculating the time period that they had tarried.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We narrate unto you (O Muhammad SAW) their story with truth: Truly! They were young men who believed in their Lord (Allah), and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We made their hearts firm and strong (with the light of Faith in Allah and bestowed upon them patience to bear the separation of their kith and kin and dwellings, etc.) when they stood up and said: ``Our Lord is the Lord of the heavens and the earth, never shall we call upon any ilah (god) other than Him; if we did, we should indeed have uttered an enormity in disbelief.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
``These our people have taken for worship aliha (gods) other than Him (Allah). Why do they not bring for them a clear authority? And who does more wrong than he who invents a lie against Allah.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
(The young men said to one another): ``And when you withdraw from them, and that which they worship, except Allah, then seek refuge in the Cave, your Lord will open a way for you from His Mercy and will make easy for you your affair (i.e. will give you what you will need of provision, dwelling, etc.)."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And you might have seen the sun, when it rose, declining to the right from their Cave, and when it set, turning away from them to the left, while they lay in the midst of the Cave. That is (one) of the Ayat (proofs, evidences, signs) of Allah. He whom Allah guides, is rightly guided; but he whom He sends astray, for him you will find no Wali (guiding friend) to lead him (to the right Path).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And you would have thought them awake, while they were asleep. And We turned them on their right and on their left sides, and their dog stretching forth his two forelegs at the entrance [of the Cave or in the space near to the entrance of the Cave (as a guard at the gate)]. Had you looked at them, you would certainly have turned back from them in flight, and would certainly have been filled with awe of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
Likewise, We awakened them (from their long deep sleep) that they might question one another. A speaker from among them said: ``How long have you stayed (here)?" They said: ``We have stayed (perhaps) a day or part of a day." They said: ``Your Lord (Alone) knows best how long you have stayed (here). So send one of you with this silver coin of yours to the town, and let him find out which is the good lawful food, and bring some of that to you. And let him be careful and let no man know of you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
``For if they come to know of you, they will stone you (to death or abuse and harm you) or turn you back to their religion, and in that case you will never be successful."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And thus We made their case known to the people, that they might know that the Promise of Allah is true, and that there can be no doubt about the Hour. (Remember) when they (the people of the city) disputed among themselves about their case, they said: ``Construct a building over them, their Lord knows best about them," (then) those who won their point said (most probably the disbelievers): ``We verily shall build a place of worship over them."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
(Some) say they were three, the dog being the fourth among them; (others) say they were five, the dog being the sixth, guessing at the unseen; (yet others) say they were seven, the dog being the eighth. Say (O Muhammad SAW): ``My Lord knows best their number; none knows them but a few." So debate not (about their number, etc.) except with the clear proof (which We have revealed to you). And consult not any of them (people of the Scripture, Jews and Christians) about (the affair of) the people of the Cave.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say of anything, ``I shall do such and such thing tomorrow."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except (with the saying), ``If Allah will!" And remember your Lord when you forget and say: ``It may be that my Lord guides me unto a nearer way of truth than this."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they stayed in their Cave three hundred (solar) years, and add nine (for lunar years).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: ``Allah knows best how long they stayed. With Him is (the knowledge of) the unseen of the heavens and the earth. How clearly He sees, and hears (everything)! They have no Wali (Helper, Disposer of affairs, Protector, etc.) other than Him, and He makes none to share in His Decision and His Rule."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite what has been revealed to you (O Muhammad SAW) of the Book (the Quran) of your Lord (i.e. recite it, understand and follow its teachings and act on its orders and preach it to men). None can change His Words, and none will you find as a refuge other than Him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And keep yourself (O Muhammad SAW) patiently with those who call on their Lord (i.e. your companions who remember their Lord with glorification, praising in prayers, etc., and other righteous deeds, etc.) morning and afternoon, seeking His Face, and let not your eyes overlook them, desiring the pomp and glitter of the life of the world; and obey not him whose heart We have made heedless of Our Remembrance, one who follows his own lusts and whose affair (deeds) has been lost.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And say: ``The truth is from your Lord." Then whosoever wills, let him believe, and whosoever wills, let him disbelieve. Verily, We have prepared for the Zalimun (polytheists and wrong-doers, etc.), a Fire whose walls will be surrounding them (disbelievers in the Oneness of Allah). And if they ask for help (relief, water, etc.) they will be granted water like boiling oil, that will scald their faces. Terrible the drink, and an evil Murtafaqa (dwelling, resting place, etc.)!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Verily! As for those who believe and do righteous deeds, certainly! We shall not suffer to be lost the reward of anyone who does his (righteous) deeds in the most perfect manner.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
These! For them will be 'Adn (Eden) Paradise (everlasting Gardens); wherein rivers flow underneath them, therein they will be adorned with bracelets of gold, and they will wear green garments of fine and thick silk. They will recline therein on raised thrones. How good is the reward, and what an excellent Murtafaqa (dwelling, resting place, etc.)!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And put forward to them the example of two men; unto one of them We had given two gardens of grapes, and We had surrounded both with date-palms; and had put between them green crops (cultivated fields etc.).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of those two gardens brought forth its produce, and failed not in the least therein, and We caused a river to gush forth in the midst of them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had property (or fruit) and he said to his companion, in the course of mutual talk: I am more than you in wealth and stronger in respect of men." [See Tafsir Qurtubi, Vol. 10, Page 403].\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he went into his garden while in a state (of pride and disbelief) unjust to himself. He said: ``I think not that this will ever perish.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
``And I think not the Hour will ever come, and if indeed I am brought back to my Lord, (on the Day of Resurrection), I surely shall find better than this when I return to Him."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion said to him, during the talk with him: ``Do you disbelieve in Him Who created you out of dust (i.e. your father Adam), then out of Nutfah (mixed semen drops of male and female discharge), then fashioned you into a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
``But as for my part (I believe) that He is Allah, my Lord and none shall I associate as partner with my Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
It was better for you to say, when you entered your garden: 'That which Allah wills (will come to pass)! There is no power but with Allah '. If you see me less than you in wealth, and children.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
``It may be that my Lord will give me something better than your garden, and will send on it Husban (torment, bolt, etc.) from the sky, then it will be a slippery earth.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
``Or the water thereof (of the gardens) becomes deep-sunken (underground) so that you will never be able to seek it."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
So his fruits were encircled (with ruin). And he remained clapping his hands with sorrow over what he had spent upon it, while it was all destroyed on its trellises, he could only say: ``Would I had ascribed no partners to my Lord!" [Tafsir Ibn Kathir]\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And he had no group of men to help him against Allah, nor could he defend or save himself.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
There (on the Day of Resurrection), Al-Walayah (the protection, power, authority and kingdom) will be for Allah (Alone), the True God. He (Allah) is the Best for reward and the Best for the final end. (La ilaha ill-Allah none has the right to be worshipped but Allah).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And put forward to them the example of the life of this world, it is like the water (rain) which We send down from the sky, and the vegetation of the earth mingles with it, and becomes fresh and green. But (later) it becomes dry and broken pieces, which the winds scatter. And Allah is Able to do everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are the adornment of the life of this world. But the good righteous deeds (five compulsory prayers, deeds of Allah's obedience, good and nice talk, remembrance of Allah with glorification, praises and thanks, etc.), that last, are better with your Lord for rewards and better in respect of hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And (remember) the Day We shall cause the mountains to pass away (like clouds of dust), and you will see the earth as a levelled plain, and we shall gather them all together so as to leave not one of them behind.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they will be set before your Lord in (lines as) rows, (and Allah will say): ``Now indeed, you have come to Us as We created you the first time. Nay, but you thought that We had appointed no meeting for you (with Us)."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book (one's Record) will be placed (in the right hand for a believer in the Oneness of Allah, and in the left hand for a disbeliever in the Oneness of Allah), and you will see the Mujrimun (criminals, polytheists, sinners, etc.), fearful of that which is (recorded) therein. They will say: ``Woe to us! What sort of Book is this that leaves neither a small thing nor a big thing, but has recorded it with numbers!" And they will find all that they did, placed before them, and your Lord treats no one with injustice.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And (remember) when We said to the angels; ``Prostrate to Adam." So they prostrated except Iblis (Satan). He was one of the jinns; he disobeyed the Command of his Lord. Will you then take him (Iblis) and his offspring as protectors and helpers rather than Me while they are enemies to you? What an evil is the exchange for the Zalimun (polytheists, and wrong-doers, etc).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I (Allah) made them (Iblis and his offspring) not to witness (nor took their help in) the creation of the heavens and the earth and not (even) their own creation, nor was I (Allah) to take the misleaders as helpers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And (remember) the Day He will say:"Call those (so-called) partners of Mine whom you pretended." Then they will cry unto them, but they will not answer them, and We shall put Maubiqa (a barrier, or enmity, or destruction, or a valley in Hell) between them.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the Mujrimun (criminals, polytheists, sinners), shall see the Fire and apprehend that they have to fall therein. And they will find no way of escape from there.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And indeed We have put forth every kind of example in this Quran, for mankind. But, man is ever more quarrelsome than anything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And nothing prevents men from believing, now when the guidance (the Quran) has come to them, and from asking Forgiveness of their Lord, except that the ways of the ancients be repeated with them (i.e. their destruction decreed by Allah), or the torment be brought to them face to face?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We send not the Messengers except as giver of glad tidings and warners. But those who disbelieve, dispute with false argument, in order to refute the truth thereby. And they treat My Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and that with which they are warned, as jest and mockery!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who does more wrong than he who is reminded of the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of his Lord, but turns away from them forgetting what (deeds) his hands have sent forth. Truly, We have set veils over their hearts lest they should understand this (the Quran), and in their ears, deafness. And if you (O Muhammad SAW) call them to guidance, even then they will never be guided.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
And your Lord is Most Forgiving, Owner of Mercy. Were He to call them to account for what they have earned, then surely, He would have hastened their punishment. But they have their appointed time, beyond which they will find no escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And these towns (population, 'Ad, Thamud, etc.) We destroyed when they did wrong. And We appointed a fixed time for their destruction.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And (remember) when Musa (Moses) said to his boy-servant: ``I will not give up (travelling) until I reach the junction of the two seas or (until) I spend years and years in travelling."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they reached the junction of the two seas, they forgot their fish, and it took its way through the sea as in a tunnel.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
So when they had passed further on (beyond that fixed place), Musa (Moses) said to his boy-servant: ``Bring us our morning meal; truly, we have suffered much fatigue in this, our journey."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said:"Do you remember when we betook ourselves to the rock? I indeed forgot the fish, none but Shaitan (Satan) made me forget to remember it. It took its course into the sea in a strange (way)!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
[Musa (Moses)] said: ``That is what we have been seeking." So they went back retracing their footsteps.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then they found one of Our slaves, unto whom We had bestowed mercy from Us, and whom We had taught knowledge from Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Musa (Moses) said to him (Khidr) ``May I follow you so that you teach me something of that knowledge (guidance and true path) which you have been taught (by Allah)?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He (Khidr) said: ``Verily! You will not be able to have patience with me!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
``And how can you have patience about a thing which you know not?"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
Musa (Moses) said: ``If Allah will, you will find me patient, and I will not disobey you in aught."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He (Khidr) said: ``Then, if you follow me, ask me not about anything till I myself mention it to you."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they both proceeded, till, when they embarked the ship, he (Khidr) scuttled it. Musa (Moses) said: ``Have you scuttled it in order to drown its people? Verily, you have committed a thing ``Imra" (a Munkar - evil, bad, dreadful thing)."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He (Khidr) said: ``Did I not tell you, that you would not be able to have patience with me?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
[Musa (Moses)] said: ``Call me not to account for what I forgot, and be not hard upon me for my affair (with you)."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then they both proceeded, till they met a boy, he (Khidr) killed him. Musa (Moses) said: ``Have you killed an innocent person who had killed none? Verily, you have committed a thing ``Nukra" (a great Munkar - prohibited, evil, dreadful thing)!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
(Khidr) said: ``Did I not tell you that you can have no patience with me?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
[Musa (Moses)] said: ``If I ask you anything after this, keep me not in your company, you have received an excuse from me."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
Then they both proceeded, till, when they came to the people of a town, they asked them for food, but they refused to entertain them. Then they found therein a wall about to collapse and he (Khidr) set it up straight. [Musa (Moses)] said: If you had wished, surely, you could have taken wages for it!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
(Khidr) said: ``This is the parting between me and you, I will tell you the interpretation of (those) things over which you were unable to hold patience.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
``As for the ship, it belonged to Masakin (poor people) working in the sea. So I wished to make a defective damage in it, as there was a king after them who seized every ship by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
``And as for the boy, his parents were believers, and we feared lest he should oppress them by rebellion and disbelief.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
``So we intended that their Lord should change him for them for one better in righteousness and near to mercy.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
``And as for the wall, it belonged to two orphan boys in the town; and there was under it a treasure belonging to them; and their father was a righteous man, and your Lord intended that they should attain their age of full strength and take out their treasure as a mercy from your Lord. And I did it not of my own accord. That is the interpretation of those (things) over which you could not hold patience."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask you about Dhul-Qarnain. Say: ``I shall recite to you something of his story."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Verily, We established him in the earth, and We gave him the means of everything.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
So he followed a way.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until, when he reached the setting place of the sun, he found it setting in a spring of black muddy (or hot) water. And he found near it a people. We (Allah) said (by inspiration): ``O Dhul-Qarnain! Either you punish them, or treat them with kindness."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: ``As for him (a disbeliever in the Oneness of Allah) who does wrong, we shall punish him; and then he will be brought back unto his Lord; Who will punish him with a terrible torment (Hell).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
``But as for him who believes (in Allah's Oneness) and works righteousness, he shall have the best reward, (Paradise), and we (Dhul-Qarnain) shall speak unto him mild words (as instructions)."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed another way,\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until, when he came to the rising place of the sun, he found it rising on a people for whom We (Allah) had provided no shelter against the sun.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So (it was)! And We knew all about him (Dhul-Qarnain).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed (another) way,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he reached between two mountains, he found, before (near) them (those two mountains), a people who scarcely understood a word.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said: ``O Dhul-Qarnain! Verily! Ya'juj and Ma'juj (Gog and Magog) are doing great mischief in the land. Shall we then pay you a tribute in order that you might erect a barrier between us and them?"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said: ``That (wealth, authority and power) in which my Lord had established me is better (than your tribute). So help me with strength (of men), I will erect between you and them a barrier.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
``Give me pieces (blocks) of iron," then, when he had filled up the gap between the two mountain-cliffs, he said: ``Blow," till when he had made it (red as) fire, he said: ``Bring me molten copper to pour over it."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
So they [Ya'juj and Ma'juj (Gog and Magog)] were made powerless to scale it or dig through it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
Dhul-Qarnain) said: ``This is a mercy from my Lord, but when the Promise of my Lord comes, He shall level it down to the ground. And the Promise of my Lord is ever true."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And on that Day [i.e. the Day Ya'juj and Ma'juj (Gog and Magog) will come out], We shall leave them to surge like waves on one another, and the Trumpet will be blown, and We shall collect them all together.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And on that Day We shall present Hell to the disbelievers, plain to view,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
(To) Those whose eyes had been under a covering from My Reminder (this Quran), and who could not bear to hear (it).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do then those who disbelieve think that they can take My slaves [i.e., the angels, Allah's Messengers, 'Iesa (Jesus), son of Maryam (Mary), etc.] as Auliya' (lords, gods, protectors, etc.) besides Me? Verily, We have prepared Hell as an entertainment for the disbelievers (in the Oneness of Allah Islamic Monotheism).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say (O Muhammad SAW): ``Shall We tell you the greatest losers in respect of (their) deeds?\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
``Those whose efforts have been wasted in this life while they thought that they were acquiring good by their deeds!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
``They are those who deny the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord and the Meeting with Him (in the Hereafter). So their works are in vain, and on the Day of Resurrection, We shall not give them any weight.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
``That shall be their recompense, Hell; because they disbelieved and took My Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and My Messengers by way of jest and mockery.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
``Verily! Those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous deeds, shall have the Gardens of Al-Firdaus (the Paradise) for their entertainment.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
``Wherein they shall dwell (forever). No desire will they have to be removed therefrom."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say (O Muhammad SAW to mankind). ``If the sea were ink for (writing) the Words of my Lord, surely, the sea would be exhausted before the Words of my Lord would be finished, even if we brought (another sea) like it for its aid."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say (O Muhammad SAW): ``I am only a man like you. It has been inspired to me that your Ilah (God) is One Ilah (God i.e. Allah). So whoever hopes for the Meeting with his Lord, let him work righteousness and associate none as a partner in the worship of his Lord."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf- Ha-Ya-'Ain-Sad. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
(This is) a mention of the mercy of your Lord to His slave Zakariya (Zachariah).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he called out his Lord (Allah) a call in secret,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
Saying: ``My Lord! Indeed my bones have grown feeble, and grey hair has spread on my head, And I have never been unblest in my invocation to You, O my Lord!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
``And Verily! I fear my relatives after me, since my wife is barren. So give me from Yourself an heir,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
``Who shall inherit me, and inherit (also) the posterity of Ya'qub (Jacob) (inheritance of the religious knowledge and Prophethood, not the wealth, etc.). And make him, my Lord, one with whom You are Well-pleased!".\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
(Allah said) ``O Zakariya (Zachariah)! Verily, We give you the glad tidings of a son, His name will be Yahya (John). We have given that name to none before (him)."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: ``My Lord! How can I have a son, when my wife is barren, and I have reached the extreme old age."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He said: ``So (it will be). Your Lord says; It is easy for Me. Certainly I have created you before, when you had been nothing!"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
[Zakariya (Zachariah)] said: ``My Lord! Appoint for me a sign." He said: ``Your sign is that you shall not speak unto mankind for three nights, though having no bodily defect."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Then he came out to his people from Al-Mihrab (a praying place or a private room, etc.), he told them by signs to glorify Allah's Praises in the morning and in the afternoon.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
(It was said to his son): ``O Yahya (John)! Hold fast the Scripture [the Taurat (Torah)]." And We gave him wisdom while yet a child.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And (made him) sympathetic to men as a mercy (or a grant) from Us, and pure from sins [i.e. Yahya (John)] and he was righteous,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And dutiful towards his parents, and he was neither an arrogant nor disobedient (to Allah or to his parents).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
So Peace on him the day he was born the day that he dies and the day that he will be raised up to life (again)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention in the Book (the Quran, O Muhammad SAW, the story of) Maryam (Mary), when she withdrew in seclusion from her family to a place facing east.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
She placed a screen (to screen herself) from them; then We sent to her Our Ruh [angel Jibrael (Gabriel)], and he appeared before her in the form of a man in all respects.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said: ``Verily! I seek refuge with the Most Beneficent (Allah) from you, if you do fear Allah."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
(The angel) said: ``I am only a Messenger from your Lord, (to announce) to you the gift of a righteous son."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said: ``How can I have a son, when no man has touched me, nor am I unchaste?"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said: ``So (it will be), your Lord said: 'That is easy for Me (Allah): And (We wish) to appoint him as a sign to mankind and a mercy from Us (Allah), and it is a matter (already) decreed, (by Allah). \qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and she withdrew with him to a far place (i.e. Bethlehem valley about 4-6 miles from Jerusalem).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the pains of childbirth drove her to the trunk of a date-palm. She said: ``Would that I had died before this, and had been forgotten and out of sight!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Then [the babe 'Iesa (Jesus) or Jibrael (Gabriel)] cried unto her from below her, saying: ``Grieve not! Your Lord has provided a water stream under you;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
``And shake the trunk of date-palm towards you, it will let fall fresh ripe-dates upon you."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
``So eat and drink and be glad, and if you see any human being, say: 'Verily! I have vowed a fast unto the Most Beneficent (Allah) so I shall not speak to any human being this day. \qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought him (the baby) to her people, carrying him. They said: ``O Mary! Indeed you have brought a thing Fariya (an unheard mighty thing).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
``O sister (i.e. the like) of Harun (Aaron) [not the brother of Musa (Moses), but he was another pious man at the time of Maryam (Mary)]! Your father was not a man who used to commit adultery, nor your mother was an unchaste woman."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Then she pointed to him. They said: ``How can we talk to one who is a child in the cradle?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
``He ['Iesa (Jesus)] said: Verily! I am a slave of Allah, He has given me the Scripture and made me a Prophet;"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
``And He has made me blessed wheresoever I be, and has enjoined on me Salat (prayer), and Zakat, as long as I live."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
``And dutiful to my mother, and made me not arrogant, unblest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
``And Salam (peace) be upon me the day I was born, and the day I die, and the day I shall be raised alive!"\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such is 'Iesa (Jesus), son of Maryam (Mary). (it is) a statement of truth, about which they doubt (or dispute).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It befits not (the Majesty of) Allah that He should beget a son [this refers to the slander of Christians against Allah, by saying that 'Iesa (Jesus) is the son of Allah]. Glorified (and Exalted be He above all that they associate with Him). When He decrees a thing, He only says to it, ``Be!" and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
['Iesa (Jesus) said]: ``And verily Allah is my Lord and your Lord. So worship Him (Alone). That is the Straight Path. (Allah's Religion of Islamic Monotheism which He did ordain for all of His Prophets)." [Tafsir At-Tabari]\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
Then the sects differed [i.e. the Christians about 'Iesa (Jesus)], so woe unto the disbelievers [those who gave false witness by saying that 'Iesa (Jesus) is the son of Allah] from the meeting of a great Day (i.e. the Day of Resurrection, when they will be thrown in the blazing Fire).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How clearly will they (polytheists and disbelievers in the Oneness of Allah) see and hear, the Day when they will appear before Us! But the Zalimun (polytheists and wrong-doers) today are in plain error.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them (O Muhammad SAW) of the Day of grief and regrets, when the case has been decided, while (now) they are in a state of carelessness, and they believe not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Verily! We will inherit the earth and whatsoever is thereon. And to Us they all shall be returned,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention in the Book (the Quran) Ibrahim (Abraham). Verily! He was a man of truth, a Prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
When he said to his father: ``O my father! Why do you worship that which hears not, sees not and cannot avail you in anything?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
``O my father! Verily! There has come to me of knowledge that which came not unto you. So follow me. I will guide you to a Straight Path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
``O my father! Worship not Shaitan (Satan). Verily! Shaitan (Satan) has been a rebel against the Most Beneficent (Allah).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
``O my father! Verily! I fear lest a torment from the Most Beneficent (Allah) overtake you, so that you become a companion of Shaitan (Satan) (in the Hell-fire)." [Tafsir Al-Qurtubi]\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He (the father) said: ``Do you reject my gods, O Ibrahim (Abraham)? If you stop not (this), I will indeed stone you. So get away from me safely before I punish you."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
Ibrahim (Abraham) said: ``Peace be on you! I will ask Forgiveness of my Lord for you. Verily! He is unto me, Ever Most Gracious.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
``And I shall turn away from you and from those whom you invoke besides Allah. And I shall call on my Lord; and I hope that I shall not be unblest in my invocation to my Lord."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So when he had turned away from them and from those whom they worshipped besides Allah, We gave him Ishaque (Isaac) and Ya'qub (Jacob), and each one of them We made a Prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We gave them of Our Mercy (a good provision in plenty), and We granted them honour on the tongues (of all the nations, i.e. everybody remembers them with a good praise).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention in the Book (this Quran) Musa (Moses). Verily! He was chosen and he was a Messenger (and) a Prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And We called him from the right side of the Mount, and made him draw near to Us for a talk with him [Musa (Moses)].\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We bestowed on him his brother Harun (Aaron), (also) a Prophet, out of Our Mercy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Book (the Quran) Isma'il (Ishmael). Verily! He was true to what he promised, and he was a Messenger, (and) a Prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he used to enjoin on his family and his people As-Salat (the prayers) and the Zakat, and his Lord was pleased with him.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Book (the Quran) Idris (Enoch). Verily! He was a man of truth, (and) a Prophet.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to a high station.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
Those were they unto whom Allah bestowed His Grace from among the Prophets, of the offspring of Adam, and of those whom We carried (in the ship) with Nuh (Noah), and of the offspring of Ibrahim (Abraham) and Israel and from among those whom We guided and chose. When the Verses of the Most Beneficent (Allah) were recited unto them, they fell down prostrating and weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
Then, there has succeeded them a posterity who have given up As-Salat (the prayers) [i.e. made their Salat (prayers) to be lost, either by not offering them or by not offering them perfectly or by not offering them in their proper fixed times, etc.] and have followed lusts. So they will be thrown in Hell.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except those who repent and believe (in the Oneness of Allah and His Messenger Muhammad SAW), and work righteousness. Such will enter Paradise and they will not be wronged in aught.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
(They will enter) 'Adn (Eden) Paradise (everlasting Gardens), which the Most Beneficent (Allah) has promised to His slaves in the unseen: Verily! His Promise must come to pass.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They shall not hear therein (in Paradise) any Laghw (dirty, false, evil vain talk), but only Salam (salutations of peace). And they will have therein their sustenance, morning and afternoon. [See (V. 40:55)].\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Paradise which We shall give as an inheritance to those of Our slaves who have been Al-Muttaqun (pious and righteous persons - See V. 2:2).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
And we (angels) descend not except by the Command of your Lord (O Muhammad SAW). To Him belongs what is before us and what is behind us, and what is between those two, and your Lord is never forgetful,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth, and all that is between them, so worship Him (Alone) and be constant and patient in His worship. Do you know of any who is similar to Him? (of course none is similar or coequal or comparable to Him, and He has none as partner with Him). [There is nothing like unto Him and He is the All-Hearer, the All-Seer].\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And man (the disbeliever) says: ``When I am dead, shall I then be raised up alive?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does not man remember that We created him before, while he was nothing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
So by your Lord, surely, We shall gather them together, and (also) the Shayatin (devils) (with them), then We shall bring them round Hell on their knees.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then indeed We shall drag out from every sect all those who were worst in obstinate rebellion against the Most Beneficent (Allah).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
Then, verily, We know best those who are most worthy of being burnt therein.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you but will pass over it (Hell); this is with your Lord; a Decree which must be accomplished.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall save those who use to fear Allah and were dutiful to Him. And We shall leave the Zalimun (polytheists and wrongdoers, etc.) therein (humbled) to their knees (in Hell).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our Clear Verses are recited to them, those who disbelieve (the rich and strong among the pagans of Quraish who live a life of luxury) say to those who believe (the weak, poor companions of Prophet Muhammad SAW who have a hard life): ``Which of the two groups (i.e. believers and disbelievers) is best in (point of) position and as regards station (place of council for consultation)."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And how many a generation (past nations) have We destroyed before them, who were better in wealth, goods and outward appearance?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say (O Muhammad SAW) whoever is in error, the Most Beneficent (Allah) will extend (the rope) to him, until, when they see that which they were promised, either the torment or the Hour, they will come to know who is worst in position, and who is weaker in forces. [This is the answer for the Verse No. 19:73]\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And Allah increases in guidance those who walk aright [true believers in the Oneness of Allah who fear Allah much (abstain from all kinds of sins and evil deeds which He has forbidden), and love Allah much (perform all kinds of good deeds which He has ordained)]. And the righteous good deeds that last, are better with your Lord, for reward and better for resort.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Have you seen him who disbelieved in Our Ayat (this Quran and Muhammad SAW) and (yet) says: ``I shall certainly be given wealth and children [if I will be alive (again)],"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he known the unseen or has he taken a covenant from the Most Beneficent (Allah)?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
Nay! We shall record what he says, and We shall increase his torment (in the Hell);\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And We shall inherit from him (at his death) all that he talks of (i.e. wealth and children which We have bestowed upon him in this world), and he shall come to Us alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken (for worship) aliha (gods) besides Allah, that they might give them honour, power and glory (and also protect them from Allah's Punishment etc.).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Nay, but they (the so-called gods) will deny their worship of them, and become opponents to them (on the Day of Resurrection).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
See you not that We have sent the Shayatin (devils) against the disbelievers to push them to do evil.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So make no haste against them; We only count out to them a (limited) number (of the days of the life of this world and delay their term so that they may increase in evil and sins).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
The Day We shall gather the Muttaqun (pious - see V. 2:2) unto the Most Beneficent (Allah), like a delegate (presented before a king for honour).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And We shall drive the Mujrimun (polytheists, sinners, criminals, disbelievers in the Oneness of Allah, etc.) to Hell, in a thirsty state (like a thirsty herd driven down to water),\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
None shall have the power of intercession, but such a one as has received permission (or promise) from the Most Beneficent (Allah).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say: ``The Most Beneficent (Allah) has begotten a son (or offspring or children) [as the Jews say: 'Uzair (Ezra) is the son of Allah, and the Christians say that He has begotten a son ['Iesa (Christ)], and the pagan Arabs say that He has begotten daughters (angels, etc.)]."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Indeed you have brought forth (said) a terrible evil thing.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
Whereby the heavens are almost torn, and the earth is split asunder, and the mountains fall in ruins,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That they ascribe a son (or offspring or children) to the Most Beneficent (Allah).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
But it is not suitable for (the Majesty of) the Most Beneficent (Allah) that He should beget a son (or offspring or children).\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is none in the heavens and the earth but comes unto the Most Beneficent (Allah) as a slave.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
Verily, He knows each one of them, and has counted them a full counting.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And everyone of them will come to Him alone on the Day of Resurrection (without any helper, or protector or defender).\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Verily, those who believe [in the Oneness of Allah and in His Messenger (Muhammad SAW)] and work deeds of righteousness, the Most Beneficent (Allah) will bestow love for them (in the hearts of the believers).\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
So We have made this (the Quran) easy in your own tongue (O Muhammad SAW), only that you may give glad tidings to the Muttaqun (pious and righteous persons - See V. 2:2), and warn with it the Ludda (most quarrelsome) people.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many a generation before them have We destroyed! Can you (O Muhammad SAW) find a single one of them or hear even a whisper of them?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta-Ha. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down the Quran unto you (O Muhammad SAW) to cause you distress,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as a Reminder to those who fear (Allah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from Him (Allah) Who has created the earth and high heavens.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Beneficent (Allah) Istawa (rose over) the (Mighty) Throne (in a manner that suits His Majesty).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs all that is in the heavens and all that is on the earth, and all that is between them, and all that is under the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if you (O Muhammad SAW) speak (the invocation) aloud, then verily, He knows the secret and that which is yet more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah! La ilahla illa Huwa (none has the right to be worshipped but He)! To Him belong the Best Names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
And has there come to you the story of Musa (Moses)?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire, he said to his family: ``Wait! Verily, I have seen a fire, perhaps I can bring you some burning brand therefrom, or find some guidance at the fire."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
And when he came to it (the fire), he was called by name: ``O Musa (Moses)!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
``Verily! I am your Lord! So take off your shoes, you are in the sacred valley, Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
``And I have chosen you. So listen to that which is inspired to you.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
``Verily! I am Allah! La ilaha illa Ana (none has the right to be worshipped but I), so worship Me, and perform As-Salat (Iqamat-as-Salat) for My Remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
``Verily, the Hour is coming and My Will is to keep it hidden that every person may be rewarded for that which he strives.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
``Therefore, let not the one who believes not therein (i.e. in the Day of Resurrection, Reckoning, Paradise and Hell, etc.), but follows his own lusts, divert you therefrom, lest you perish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
``And what is that in your right hand, O Musa (Moses)?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said: ``This is my stick, whereon I lean, and wherewith I beat down branches for my sheep, and wherein I find other uses."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
(Allah) said: ``Cast it down, O Musa (Moses)!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
He cast it down, and behold! It was a snake, moving quickly.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
Allah said:"Grasp it, and fear not, We shall return it to its former state,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
``And press your (right) hand to your (left) side, it will come forth white (and shining), without any disease as another sign,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
``That We may show you (some) of Our Greater Signs.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
``Go to Fir'aun (Pharaoh)! Verily, he has transgressed (all bounds in disbelief and disobedience, and has behaved as an arrogant, and as a tyrant)."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
[Musa (Moses)] said: ``O my Lord! Open for me my chest (grant me self-confidence, contentment, and boldness).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
``And ease my task for me;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
``And make loose the knot (the defect) from my tongue, (i.e. remove the incorrectness from my speech) [That occurred as a result of a brand of fire which Musa (Moses) put in his mouth when he was an infant]. [Tafsir At-Tabari, Vol. 16, Page 159].\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
``That they understand my speech,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
``And appoint for me a helper from my family,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
``Harun (Aaron), my brother;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
``Increase my strength with him,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
``And let him share my task (of conveying Allah's Message and Prophethood),\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
``That we may glorify You much,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
``And remember You much,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
``Verily! You are of us Ever a Well-Seer."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
Allah said: ``You are granted your request, O Musa (Moses)!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
``And indeed We conferred a favour on you another time (before).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
``When We inspired your mother with that which We inspired.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
``Saying: 'Put him (the child) into the Tabut (a box or a case or a chest) and put it into the river (Nile), then the river shall cast it up on the bank, and there, an enemy of Mine and an enemy of his shall take him.' And I endued you with love from Me, in order that you may be brought up under My Eye,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
``When your sister went and said: 'Shall I show you one who will nurse him?' So We restored you to your mother, that she might cool her eyes and she should not grieve. Then you did kill a man, but We saved you from great distress and tried you with a heavy trial. Then you stayed a number of years with the people of Madyan (Midian). Then you came here according to the fixed term which I ordained (for you), O Musa (Moses)!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
``And I have Istana'tuka, for Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
``Go you and your brother with My Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and do not, you both, slacken and become weak in My Remembrance.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
``Go, both of you, to Fir'aun (Pharaoh), verily, he has transgressed (all bounds in disbelief and disobedience and behaved as an arrogant and as a tyrant).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
``And speak to him mildly, perhaps he may accept admonition or fear Allah."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They said: ``Our Lord! Verily! We fear lest he should hasten to punish us or lest he should transgress (all bounds against us)."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He (Allah) said: ``Fear not, verily! I am with you both, hearing and seeing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
``So go you both to him, and say: 'Verily, we are Messengers of your Lord, so let the Children of Israel go with us, and torment them not; indeed, we have come with a sign from your Lord! And peace will be upon him who follows the guidance!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
'Truly, it has been revealed to us that the torment will be for him who denies [believes not in the Oneness of Allah, and in His Messengers, etc.], and turns away.'(from the truth and obedience of Allah)"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
Fir'aun (Pharaoh) said: ``Who then, O Musa (Moses), is the Lord of you two?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
[Musa (Moses)] said: ``Our Lord is He Who gave to each thing its form and nature, then guided it aright."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
[Fir'aun (Pharaoh)] said: ``What about the generations of old?"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
[Musa (Moses)] said: ``The knowledge thereof is with my Lord, in a Record. My Lord is neither unaware nor He forgets, ``\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
Who has made earth for you like a bed (spread out); and has opened roads (ways and paths etc.) for you therein; and has sent down water (rain) from the sky. And We have brought forth with it various kinds of vegetation.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat and pasture your cattle, (therein); verily, in this are proofs and signs for men of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
Thereof (the earth) We created you, and into it We shall return you, and from it We shall bring you out once again.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And indeed We showed him [Fir'aun (Pharaoh)] all Our Signs and Evidences, but he denied and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He [Fir'aun (Pharaoh)] said: ``Have you come to drive us out of our land with your magic, O Musa (Moses)?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
``Then verily, we can produce magic the like thereof; so appoint a meeting between us and you, which neither we, nor you shall fail to keep, in an open wide place where both shall have a just and equal chance (and beholders could witness the competition)."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
[Musa (Moses)] said: ``Your appointed meeting is the day of the festival, and let the people assemble when the sun has risen (forenoon)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Fir'aun (Pharaoh) withdrew, devised his plot and then came back.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Musa (Moses) said to them: ``Woe unto you! Invent not a lie against Allah, lest He should destroy you completely by a torment. And surely, he who invents a lie (against Allah) will fail miserably."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
Then they debated with one another what they must do, and they kept their talk secret.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said: ``Verily! These are two magicians. Their object is to drive you out from your land with magic, and overcome your chiefs and nobles.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
``So devise your plot, and then assemble in line. And whoever overcomes this day will be indeed successful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said:"O Musa (Moses)! Either you throw first or we be the first to throw?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
[Musa (Moses)] said: ``Nay, throw you (first)!" Then behold, their ropes and their sticks, by their magic, appeared to him as though they moved fast.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
So Musa (Moses) conceived a fear in himself.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We (Allah) said: ``Fear not! Surely, you will have the upper hand.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
``And throw that which is in your right hand! It will swallow up that which they have made. That which they have made is only a magician's trick, and the magician will never be successful, no matter whatever amount (of skill) he may attain."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
So the magicians fell down prostrate. They said: ``We believe in the Lord of Harun (Aaron) and Musa (Moses)."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
[Fir'aun (Pharaoh)] said: ``Believe you in him [Musa (Moses)] before I give you permission? Verily! He is your chief who taught you magic. So I will surely cut off your hands and feet on opposite sides, and I will surely crucify you on the trunks of date-palms, and you shall surely know which of us [I (Fir'aun - Pharaoh) or the Lord of Musa (Moses) (Allah)] can give the severe and more lasting torment."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said: ``We prefer you not over the clear signs that have come to us, and to Him (Allah) Who created us. So decree whatever you desire to decree, for you can only decree (regarding) this life of the world.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
``Verily! We have believed in our Lord, that He may forgive us our faults, and the magic to which you did compel us. And Allah is better as regards reward in comparison to your [Fir'aun's (Pharaoh)] reward, and more lasting (as regards punishment in comparison to your punishment)."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Verily! Whoever comes to his Lord as a Mujrim (criminal, polytheist, disbeliever in the Oneness of Allah and His Messengers, sinner, etc.), then surely, for him is Hell, therein he will neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But whoever comes to Him (Allah) as a believer (in the Oneness of Allah, etc.), and has done righteous good deeds, for such are the high ranks (in the Hereafter),\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
'Adn (Edn) Paradise (everlasting Gardens), under which rivers flow, wherein they will abide forever: such is the reward of those who purify themselves [(by abstaining from all kinds of sins and evil deeds) which Allah has forbidden and by doing all that which Allah has ordained)].\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And indeed We inspired Musa (Moses) (saying): ``Travel by night with Ibadi (My slaves) and strike a dry path for them in the sea, fearing neither to be overtaken [by Fir'aun (Pharaoh)] nor being afraid (of drowning in the sea)."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Then Fir'aun (Pharaoh) pursued them with his hosts, but the sea-water completely overwhelmed them and covered them up.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Fir'aun (Pharaoh) led his people astray, and he did not guide them.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel! We delivered you from your enemy, and We made a covenant with you on the right side of the Mount, and We sent down to you Al-Manna and quails,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
(Saying) eat of the Taiyibat (good lawful things) wherewith We have provided you, and commit no oppression therein, lest My Anger should justly descend on you. And he on whom My Anger descends, he is indeed perished.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And verily, I am indeed Forgiving to him who repents, believes (in My Oneness, and associates none in worship with Me) and does righteous good deeds, and then remains constant in doing them, (till his death).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
``And what made you hasten from your people, O Musa (Moses)?"\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said: ``They are close on my footsteps, and I hastened to You, O my Lord, that You might be pleased."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
(Allah) said: ``Verily! We have tried your people in your absence, and As-Samiri has led them astray."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
Then Musa (Moses) returned to his people in a state of anger and sorrow. He said: ``O my people! Did not your Lord promise you a fair promise? Did then the promise seem to you long in coming? Or did you desire that wrath should descend from your Lord on you, so you broke your promise to me (i.e. disbelieving in Allah and worshipping the calf)?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said: ``We broke not the promise to you, of our own will, but we were made to carry the weight of the ornaments of the [Fir'aun's (Pharaoh)] people, then we cast them (into the fire), and that was what As-Samiri suggested."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
Then he took out (of the fire) for them a statue of a calf which seemed to low. They said: ``This is your ilah (god), and the ilah (god) of Musa (Moses), but [Musa (Moses)] has forgotten (his god).'"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Did they not see that it could not return them a word (for answer), and that it had no power either to harm them or to do them good?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And Harun (Aaron) indeed had said to them beforehand: ``O my people! You are being tried in this, and verily, your Lord is (Allah) the Most Beneficent, so follow me and obey my order."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said: ``We will not stop worshipping it (i.e. the calf), until Musa (Moses) returns to us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
[Musa (Moses)] said: ``O Harun (Aaron)! What stopped you when you saw them going astray;\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
``That you followed me not (according to my advice to you)? Have you then disobeyed my order?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
He [Harun (Aaron)] said: ``O son of my mother! Seize (me) not by my beard, nor by my head! Verily, I feared lest you should say: 'You have caused a division among the Children of Israel, and you have not respected my word!' ``\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
[Musa (Moses)] said: ``And what is the matter with you. O Samiri? (i.e. why did you do so?)"\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
(Samiri) said: ``I saw what they saw not, so I took a handful (of dust) from the hoof print of the messenger [Jibrael's (Gabriel) horse] and threw it [into the fire in which were put the ornaments of the Fir'aun's (Pharaoh) people, or into the calf]. Thus my inner-self suggested to me."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
Musa (Moses) said: ``Then go away! And verily, your (punishment) in this life will be that you will say: ``Touch me not (i.e. you will live alone exiled away from mankind); and verily (for a future torment), you have a promise that will not fail. And look at your ilah (god), to which you have been devoted. We will certainly burn it, and scatter its particles in the sea."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your Ilah (God) is only Allah, the One (La ilaha illa Huwa) (none has the right to be worshipped but He). He has full knowledge of all things.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus We relate to you (O Muhammad SAW) some information of what happened before. And indeed We have given you from Us a Reminder (this Quran).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoever turns away from it (this Quran i.e. does not believe in it, nor acts on its orders), verily, they will bear a heavy burden (of sins) on the Day of Resurrection,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
They will abide in that (state in the Fire of Hell), and evil indeed will it be that load for them on the Day of Resurrection;\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day when the Trumpet will be blown (the second blowing): that Day, We shall gather the Mujrimun (criminals, polytheists, sinners, disbelievers in the Oneness of Allah, etc.) Zurqa: (blue or blind eyed with black faces).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
In whispers will they speak to each other (saying): ``You stayed not longer than ten (days)."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know very well what they will say, when the best among them in knowledge and wisdom will say: ``You stayed no longer than a day!"\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
And they ask you concerning the mountains, say; ``My Lord will blast them and scatter them as particles of dust.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
``Then He shall leave it as a level smooth plain.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
``You will see therein nothing crooked or curved."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day mankind will follow strictly (the voice of) Allah's caller, no crookedness (that is without going to the right or left of that voice) will they show him (Allah's caller). And all voices will be humbled for the Most Beneficent (Allah), and nothing shall you hear but the low voice of their footsteps.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that day no intercession shall avail, except the one for whom the Most Beneficent (Allah) has given permission and whose word is acceptable to Him.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He (Allah) knows what happens to them (His creatures) in this world, and what will happen to them (in the Hereafter), and they will never compass anything of His Knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And (all) faces shall be humbled before (Allah), the Ever Living, the One Who sustains and protects all that exists. And he who carried (a burden of) wrongdoing (i.e. he who disbelieved in Allah, ascribed partners to Him, and did deeds of His disobedience), became indeed a complete failure (on that Day).\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
And he who works deeds of righteousness, while he is a believer (in Islamic Monotheism) then he will have no fear of injustice, nor of any curtailment (of his reward).\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
And thus We have sent it down as a Quran in Arabic, and have explained therein in detail the warnings, in order that they may fear Allah, or that it may cause them to have a lesson from it (or to have the honour for believing and acting on its teachings).\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Then High above all be Allah, the True King. And be not in haste (O Muhammad SAW) with the Quran before its revelation is completed to you, and say: ``My Lord! Increase me in knowledge."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And indeed We made a covenant with Adam before, but he forgot, and We found on his part no firm will-power.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And (remember) when We said to the angels: ``Prostrate yourselves to Adam." They prostrated (all) except Iblis (Satan), who refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said: ``O Adam! Verily, this is an enemy to you and to your wife. So let him not get you both out of Paradise, so that you be distressed in misery.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
Verily, you have (a promise from Us) that you will never be hungry therein nor naked.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
And you (will) suffer not from thirst therein nor from the sun's heat.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
Then Shaitan (Satan) whispered to him, saying: ``O Adam! Shall I lead you to the Tree of Eternity and to a kingdom that will never waste away?"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
Then they both ate of the tree, and so their private parts appeared to them, and they began to stick on themselves the leaves from Paradise for their covering. Thus did Adam disobey his Lord, so he went astray.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Then his Lord chose him, and turned to him with forgiveness, and gave him guidance.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
(Allah) said:"Get you down (from the Paradise to the earth), both of you, together, some of you are an enemy to some others. Then if there comes to you guidance from Me, then whoever follows My Guidance shall neither go astray, nor fall into distress and misery.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
``But whosoever turns away from My Reminder (i.e. neither believes in this Quran nor acts on its orders, etc.) verily, for him is a life of hardship, and We shall raise him up blind on the Day of Resurrection."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say:"O my Lord! Why have you raised me up blind, while I had sight (before)."\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
(Allah) will say: ``Like this, Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) came unto you, but you disregarded them (i.e. you left them, did not think deeply in them, and you turned away from them), and so this Day, you will be neglected (in the Hell-fire, away from Allah's Mercy)."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
And thus do We requite him who transgresses beyond bounds [i.e. commits the great sins and disobeys his Lord (Allah) and believes not in His Messengers, and His revealed Books, like this Quran, etc.], and believes not in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of his Lord, and the torment of the Hereafter is far more severe and more lasting.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a guidance for them (to know) how many generations We have destroyed before them, in whose dwellings they walk? Verily, in this are signs indeed for men of understanding.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And had it not been for a Word that went forth before from your Lord, and a term determined, (their punishment) must necessarily have come (in this world).\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So bear patiently (O Muhammad SAW) what they say, and glorify the praises of your Lord before the rising of the sun, and before its setting, and during some of the hours of the night, and at the sides of the day (an indication for the five compulsory congregational prayers), that you may become pleased with the reward which Allah shall give you.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And strain not your eyes in longing for the things We have given for enjoyment to various groups of them (polytheists and disbelievers in the Oneness of Allah), the splendour of the life of this world that We may test them thereby. But the provision (good reward in the Hereafter) of your Lord is better and more lasting.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And enjoin As-Salat (the prayer) on your family, and be patient in offering them [i.e. the Salat (prayers)]. We ask not of you a provision (i.e. to give Us something: money, etc.); We provide for you. And the good end (i.e. Paradise) is for the Muttaqun (pious - see V. 2:2).\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
They say: ``Why does he not bring us a sign (proof) from his Lord?" Has there not come to them the proof of that which is (written) in the former papers [Scriptures, i.e. the Taurat (Torah), and the Injeel (Gospel), etc. about the coming of the Prophet Muhammad SAW].\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And if We had destroyed them with a torment before this (i.e. Messenger Muhammad SAW and the Quran), they would surely have said: ``Our Lord! If only You had sent us a Messenger, we should certainly have followed Your Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), before we were humiliated and disgraced."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say (O Muhammad SAW): ``Each one (believer and disbeliever, etc.) is waiting, so wait you too, and you shall know who are they that are on the Straight and Even Path (i.e. Allah's Religion of Islamic Monotheism), and who are they that have let themselves be guided (on the Right Path).\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Draws near for mankind their reckoning, while they turn away in heedlessness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Comes not unto them an admonition (a chapter of the Quran) from their Lord as a recent revelation but they listen to it while they play,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
With their hearts occupied (with evil things) those who do wrong, conceal their private counsels, (saying): ``Is this (Muhammad SAW) more than a human being like you? Will you submit to magic while you see it?"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He (Muhammad SAW) said: ``My Lord knows (every) word (spoken) in the heavens and on earth. And He is the All-Hearer, the All-Knower."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Nay, they say:"These (revelations of the Quran which are inspired to Muhammad SAW) are mixed up false dreams! Nay, he has invented it! Nay, he is a poet! Let him then bring us an Ayah (sign as a proof) like the ones (Prophets) that were sent before (with signs)!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not one of the towns (populations), of those which We destroyed, believed before them (though We sent them signs), will they then believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent not before you (O Muhammad SAW) but men to whom We inspired, so ask the people of the Reminder [Scriptures - the Taurat (Torah), the Injeel (Gospel)] if you do not know.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
And We did not create them (the Messengers, with) bodies that ate not food, nor were they immortals,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We fulfilled to them the promise, and We saved them and those whom We willed, but We destroyed Al-Musrifun (i.e. extravagants in oppression, polytheism and in sin).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
Indeed, We have sent down for you (O mankind) a Book, (the Quran) in which there is Dhikrukum, (your Reminder or an honour for you i.e. honour for the one who follows the teaching of the Quran and acts on its orders). Will you not then understand?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a town (community), that were wrong-doers, have We destroyed, and raised up after them another people!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then, when they perceived (saw) Our Torment (coming), behold, they (tried to) flee from it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
Flee not, but return to that wherein you lived a luxurious life, and to your homes, in order that you may be questioned.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They cried: ``Woe to us! Certainly! We have been Zalimun (polytheists, wrong-doers and disbelievers in the Oneness of Allah, etc.)."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And that cry of theirs ceased not, till We made them as a field that is reaped, extinct (dead).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We created not the heavens and the earth and all that is between them for a (mere) play.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
Had We intended to take a pastime (i.e. a wife or a son, etc.), We could surely have taken it from Us, if We were going to do (that).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, We fling (send down) the truth (this Quran) against the falsehood (disbelief), so it destroys it, and behold, it (falsehood) is vanished. And woe to you for that (lie) which you ascribe (to Us) (against Allah by uttering that Allah has a wife and a son).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whosoever is in the heavens and on earth. And those who are near Him (i.e. the angels) are not too proud to worship Him, nor are they weary (of His worship).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They (i.e. the angels) glorify His Praises night and day, (and) they never slacken (to do so).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they taken (for worship) aliha (gods) from the earth who raise the dead?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been therein (in the heavens and the earth) gods besides Allah, then verily both would have been ruined. Glorified be Allah, the Lord of the Throne, (High is He) above what they attribute to Him!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He cannot be questioned as to what He does, while they will be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken for worship (other) aliha (gods) besides Him? Say: ``Bring your proof:" This (the Quran) is the Reminder for those with me and the Reminder for those before me. But most of them know not the Truth, so they are averse.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We did not send any Messenger before you (O Muhammad SAW) but We inspired him (saying): La ilaha illa Ana [none has the right to be worshipped but I (Allah)], so worship Me (Alone and none else)."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say: ``The Most Beneficent (Allah) has begotten a son (or children)." Glory to Him! They [those whom they call children of Allah i.e. the angels, 'Iesa (Jesus) son of Maryam (Mary), 'Uzair (Ezra), etc.], are but honoured slaves.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They speak not until He has spoken, and they act on His Command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them, and what is behind them, and they cannot intercede except for him with whom He is pleased. And they stand in awe for fear of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And if any of them should say: ``Verily, I am an ilah (a god) besides Him (Allah)," such a one We should recompense with Hell. Thus We recompense the Zalimun (polytheists and wrong-doers, etc.).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have not those who disbelieve known that the heavens and the earth were joined together as one united piece, then We parted them? And We have made from water every living thing. Will they not then believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have placed on the earth firm mountains, lest it should shake with them, and We placed therein broad highways for them to pass through, that they may be guided.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We have made the heaven a roof, safe and well guarded. Yet they turn away from its signs (i.e. sun, moon, winds, clouds, etc.).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And He it is Who has created the night and the day, and the sun and the moon, each in an orbit floating.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
And We granted not to any human being immortality before you (O Muhammad SAW), then if you die, would they live forever?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Everyone is going to taste death, and We shall make a trial of you with evil and with good, and to Us you will be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when those who disbelieve (in the Oneness of Allah) see you (O Muhammad SAW), they take you not except for mockery (saying): ``Is this the one who talks (badly) about your gods?" While they disbelieve at the mention of the Most Beneficent (Allah). [Tafsir. Al-Qurtubi].\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man is created of haste, I will show you My Ayat (torments, proofs, evidences, verses, lessons, signs, revelations, etc.). So ask Me not to hasten (them).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say: ``When will this promise (come to pass), if you are truthful."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only those who disbelieved knew (the time) when they will not be able to ward off the Fire from their faces, nor from their backs; and they will not be helped.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Nay, it (the Fire or the Day of Resurrection) will come upon them all of a sudden and will perplex them, and they will have no power to avert it, nor will they get respite.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Indeed (many) Messengers were mocked before you (O Muhammad SAW), but the scoffers were surrounded by that, whereat they used to mock.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: ``Who can guard and protect you in the night or in the day from the (punishment of the) Most Beneficent (Allah)?" Nay, but they turn away from the remembrance of their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they aliha (gods) who can guard them from Us? They have no power to help themselves, nor can they be protected from Us (i.e. from Our Torment).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, We gave the luxuries of this life to these men and their fathers until the period grew long for them. See they not that We gradually reduce the land (in their control) from its outlying borders? Is it then they who will overcome.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say (O Muhammad SAW): ``I warn you only by the revelation (from Allah and not by the opinion of the religious scholars and others). But the deaf (who follow the religious scholars and others blindly) will not hear the call, (even) when they are warned [(i.e. one should follow only the Quran and the Sunnah (legal ways, orders, acts of worship, statements of Prophet Muhammad SAW, as the Companions of the Prophet SAW did)].\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if a breath (minor calamity) of the Torment of your Lord touches them, they will surely cry: ``Woe unto us! Indeed we have been Zalimun (polytheists and wrong-doers, etc.).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We shall set up balances of justice on the Day of Resurrection, then none will be dealt with unjustly in anything. And if there be the weight of a mustard seed, We will bring it. And Sufficient are We as Reckoners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And indeed We granted to Musa (Moses) and Harun (Aaron) the criterion (of right and wrong), and a shining light [i.e. the Taurat (Torah)] and a Reminder for Al-Muttaqun (the pious - see V. 2:2).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord without seeing Him, while they are afraid of the Hour.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this is a blessed Reminder (the Quran) which We have sent down, will you then (dare to) deny it?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And indeed We bestowed aforetime on Ibrahim (Abraham) his (portion of) guidance, and We were Well-Acquainted with him (as to his Belief in the Oneness of Allah, etc.).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said to his father and his people: ``What are these images, to which you are devoted?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said:"We found our fathers worshipping them."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: ``Indeed you and your fathers have been in manifest error."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: ``Have you brought us the truth, or are you one of those who play about?"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said: ``Nay, your Lord is the Lord of the heavens and the earth, Who created them and of that I am one of the witnesses.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
``And by Allah, I shall plot a plan (to destroy) your idols after you have gone away and turned your backs."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he broke them to pieces, (all) except the biggest of them, that they might turn to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said: ``Who has done this to our aliha (gods)? He must indeed be one of the wrong-doers."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said: ``We heard a young man talking (against) them who is called Ibrahim (Abraham)."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said: ``Then bring him before the eyes of the people, that they may testify."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said: ``Are you the one who has done this to our gods, O Ibrahim (Abraham)?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
[Ibrahim (Abraham)] said: ``Nay, this one, the biggest of them (idols) did it. Ask them, if they can speak!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they turned to themselves and said: ``Verily, you are the Zalimun (polytheists and wrong-doers)."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then they turned to themselves (their first thought and said): ``Indeed you [Ibrahim (Abraham)] know well that these (idols) speak not!"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
[Ibrahim (Abraham)] said: ``Do you then worship besides Allah, things that can neither profit you, nor harm you?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
``Fie upon you, and upon that which you worship besides Allah! Have you then no sense?"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said: ``Burn him and help your aliha (gods), if you will be doing."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We (Allah) said: ``O fire! Be you coolness and safety for Ibrahim (Abraham)!"\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they wanted to harm him, but We made them the worst losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We rescued him and Lout (Lot) to the land which We have blessed for the 'Alamin (mankind and jinns).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed upon him Ishaque (Isaac), and (a grandson) Ya'qub (Jacob). Each one We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders, guiding (mankind) by Our Command, and We inspired in them the doing of good deeds, performing Salat (Iqamat-as-Salat), and the giving of Zakat and of Us (Alone) they were worshippers.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And (remember) Lout (Lot), We gave him Hukman (right judgement of the affairs and Prophethood) and (religious) knowledge, and We saved him from the town (folk) who practised Al-Khaba'ith (evil, wicked and filthy deeds, etc.). Verily, they were a people given to evil, and were Fasiqun (rebellious, disobedient, to Allah).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him to Our Mercy, truly, he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And (remember) Nuh (Noah), when he cried (to Us) aforetime. We listened to his invocation and saved him and his family from great distress.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
We helped him against people who denied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.). Verily, they were a people given to evil. So We drowned them all.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And (remember) Dawud (David) and Sulaiman (Solomon), when they gave judgement in the case of the field in which the sheep of certain people had pastured at night and We were witness to their judgement.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And We made Sulaiman (Solomon) to understand (the case), and to each of them We gave Hukman (right judgement of the affairs and Prophethood) and knowledge. And We subjected the mountains and the birds to glorify Our Praises along with Dawud (David), And it was We Who were the doers (of all these things).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the making of metal coats of mail (for battles), to protect you in your fighting. Are you then grateful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And to Sulaiman (Solomon) (We subjected) the wind strongly raging, running by his command towards the land which We had blessed. And of everything We are the All-Knower.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the Shayatin (devils) (from the jinns) were some who dived for him, and did other work besides that; and it was We Who guarded them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And (remember) Ayub (Job), when he cried to his Lord: ``Verily, distress has seized me, and You are the Most Merciful of all those who show mercy."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We answered his call, and We removed the distress that was on him, and We restored his family to him (that he had lost), and the like thereof along with them, as a mercy from Ourselves and a Reminder for all who worship Us.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And (remember) Isma'il (Ishmael), and Idris (Enoch) and Dhul-Kifl (Isaiah), all were from among As-Sabirin (the patient ones, etc.).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them to Our Mercy. Verily, they were of the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And (remember) Dhan-Nun (Jonah), when he went off in anger, and imagined that We shall not punish him (i.e. the calamites which had befallen him)! But he cried through the darkness (saying): La ilaha illa Anta [none has the right to be worshipped but You (O Allah)], Glorified (and Exalted) are You [above all that (evil) they associate with You]. Truly, I have been of the wrong-doers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We answered his call, and delivered him from the distress. And thus We do deliver the believers (who believe in the Oneness of Allah, abstain from evil and work righteousness).\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And (remember) Zakariya (Zachariah), when he cried to his Lord: ``O My Lord! Leave me not single (childless), though You are the Best of the inheritors."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered his call, and We bestowed upon him Yahya (John), and cured his wife (to bear a child) for him. Verily, they used to hasten on to do good deeds, and they used to call on Us with hope and fear, and used to humble themselves before Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And (remember) she who guarded her chastity [Virgin Maryam (Mary)], We breathed into (the sleeves of) her (shirt or garment) [through Our Ruh - Jibrael (Gabriel)], and We made her and her son ['Iesa (Jesus)] a sign for Al-'Alamin (the mankind and jinns).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Truly! This, your Ummah [Sharia or religion (Islamic Monotheism)] is one religion, and I am your Lord, therefore worship Me (Alone). [Tafsir Ibn Kathir]\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they have broken up and differed as regards their religion among themselves. (And) they all shall return to Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
So whoever does righteous good deeds while he is a believer (in the Oneness of Allah Islamic Monotheism), his efforts will not be rejected. Verily! We record it in his Book of deeds.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And a ban is laid on every town (population) which We have destroyed that they shall not return (to this world again, nor repent to Us).\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until, when Ya'juj and Ma'juj (Gog and Magog) are let loose (from their barrier), and they swiftly swarm from every mound.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And the true promise (Day of Resurrection) shall draw near (of fulfillment). Then (when mankind is resurrected from their graves), you shall see the eyes of the disbelievers fixedly stare in horror. (They will say): ``Woe to us! We were indeed heedless of this; nay, but we were Zalimun (polytheists and wrong-doers, etc.)."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Certainly! You (disbelievers) and that which you are worshipping now besides Allah, are (but) fuel for Hell! (Surely), you will enter it.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these (idols, etc.) been aliha (gods), they would not have entered there (Hell), and all of them will abide therein.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
Therein breathing out with deep sighs and roaring will be their portion, and therein they will hear not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Verily those for whom the good has preceded from Us, they will be removed far therefrom (Hell) [e.g. 'Iesa (Jesus), son of Maryam (Mary); 'Uzair (Ezra), etc.].\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They shall not hear the slightest sound of it (Hell), while they abide in that which their ownselves desire.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The greatest terror (on the Day of Resurrection) will not grieve them, and the angels will meet them, (with the greeting): ``This is your Day which you were promised."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
And (remember) the Day when We shall roll up the heavens like a scroll rolled up for books, as We began the first creation, We shall repeat it, (it is) a promise binding upon Us. Truly, We shall do it.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And indeed We have written in Zabur (Psalms) [i.e. all the revealed Holy Books the Taurat (Torah), the Injeel (Gospel), the Quran] after (We have already written in) Al-Lauh Al-Mahfuz (the Book, that is in the heaven with Allah), that My righteous slaves shall inherit the land (i.e. the land of Paradise).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Verily, in this (the Quran) there is a plain Message for people who worship Allah (i.e. the true, real believers of Islamic Monotheism who act practically on the Quran and the Sunnah legal ways of the Prophet SAW).\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
And We have sent you (O Muhammad SAW) not but as a mercy for the 'Alamin (mankind, jinns and all that exists).\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say (O Muhammad SAW): ``It is revealed to me that your Ilah (God) is only one Ilah (God - Allah). Will you then submit to His Will (become Muslims and stop worshipping others besides Allah)?"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they (disbelievers, idolaters, Jews, Christians, polytheists, etc.) turn away (from Islamic Monotheism) say (to them O Muhammad SAW): ``I give you a notice (of war as) to be known to us all alike. And I know not whether that which you are promised (i.e. the torment or the Day of Resurrection) is near or far."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
(Say O Muhammad SAW) Verily, He (Allah) knows that which is spoken aloud (openly) and that which you conceal.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
And I know not, perhaps it may be a trial for you, and an enjoyment for a while.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He (Muhammad SAW) said:"My Lord! Judge You in truth! Our Lord is the Most Beneficent, Whose Help is to be sought against that which you attribute (unto Allah that He has offspring, and unto Muhammad SAW that he is a sorcerer, and unto the Quran that it is poetry, etc.)!"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind! Fear your Lord and be dutiful to Him! Verily, the earthquake of the Hour (of Judgement) is a terrible thing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
The Day you shall see it, every nursing mother will forget her nursling, and every pregnant one will drop her load, and you shall see mankind as in a drunken state, yet they will not be drunken, but severe will be the Torment of Allah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And among mankind is he who disputes concerning Allah, without knowledge, and follows every rebellious (disobedient to Allah) Shaitan (devil) (devoid of each and every kind of good).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
For him (the devil) it is decreed that whosoever follows him, he will mislead him, and will drive him to the torment of the Fire. [Tafsir At-Tabari]\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O mankind! If you are in doubt about the Resurrection, then verily! We have created you (i.e. Adam) from dust, then from a Nutfah (mixed drops of male and female sexual discharge i.e. offspring of Adam), then from a clot (a piece of thick coagulated blood) then from a little lump of flesh, some formed and some unformed (miscarriage), that We may make (it) clear to you (i.e. to show you Our Power and Ability to do what We will). And We cause whom We will to remain in the wombs for an appointed term, then We bring you out as infants, then (give you growth) that you may reach your age of full strength. And among you there is he who dies (young), and among you there is he who is brought back to the miserable old age, so that he knows nothing after having known. And you see the earth barren, but when We send down water (rain) on it, it is stirred (to life), it swells and puts forth every lovely kind (of growth).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because Allah, He is the Truth, and it is He Who gives life to the dead, and it is He Who is Able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And surely, the Hour is coming, there is no doubt about it, and certainly, Allah will resurrect those who are in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among men is he who disputes about Allah, without knowledge or guidance, or a Book giving light (from Allah),\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Bending his neck in pride (far astray from the Path of Allah), and leading (others) too (far) astray from the Path of Allah. For him there is disgrace in this worldly life, and on the Day of Resurrection We shall make him taste the torment of burning (Fire).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
That is because of what your hands have sent forth, and verily, Allah is not unjust to (His) slaves.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among mankind is he who worships Allah as it were, upon the very edge (i.e. in doubt); if good befalls him, he is content therewith; but if a trial befalls him, he turns back on his face (i.e. reverts back to disbelief after embracing Islam). He loses both this world and the Hereafter. That is the evident loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calls besides Allah unto that which hurts him not, nor profits him. That is a straying far away.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calls unto him whose harm is nearer than his profit; certainly, and evil Maula (patron) and certainly an evil friend!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Truly, Allah will admit those who believe (in Islamic Monotheism) and do righteous good deeds (according to the Quran and the Sunnah) to Gardens underneath which rivers flow (in Paradise). Verily, Allah does what He wills.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whoever thinks that Allah will not help him (Muhammad SAW) in this world and in the Hereafter, let him stretch out a rope to the ceiling and let him strangle himself. Then let him see whether his plan will remove that whereat he rages!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Thus have We sent it (this Quran) down (to Muhammad SAW) as clear signs, evidences and proofs, and surely, Allah guides whom He wills.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Verily, those who believe (in Allah and in His Messenger Muhammad SAW), and those who are Jews, and the Sabians, and the Christians, and the Magians, and those who worship others besides Allah, truly, Allah will judge between them on the Day of Resurrection. Verily! Allah is Witness over all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
See you not that to Allah prostrates whoever is in the heavens and whoever is on the earth, and the sun, and the moon, and the stars, and the mountains, and the trees, and Ad-Dawab (moving living creatures, beasts, etc.), and many of mankind? But there are many (men) on whom the punishment is justified. And whomsoever Allah disgraces, none can honour him. Verily! Allah does what He wills.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These two opponents (believers and disbelievers) dispute with each other about their Lord; then as for those who disbelieve, garments of fire will be cut out for them, boiling water will be poured down over their heads.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
With it will melt or vanish away what is within their bellies, as well as (their) skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for them are hooked rods of iron (to punish them).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Every time they seek to get away therefrom, from anguish, they will be driven back therein, and (it will be) said to them: ``Taste the torment of burning!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Truly, Allah will admit those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, to Gardens underneath which rivers flow (in Paradise), wherein they will be adorned with bracelets of gold and pearls and their garments therein will be of silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
And they are guided (in this world) unto goodly speech (i.e. La ilaha ill-Allah, Alhamdu lillah, recitation of the Quran, etc.) and they are guided to the Path of Him (i.e. Allah's Religion of Islamic Monotheism), Who is Worthy of all praises.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Verily! Those who disbelieve and hinder (men) from the Path of Allah, and from Al-Masjid-al-Haram (at Makkah) which We have made (open) to (all) men, the dweller in it and the visitor from the country are equal there [as regards its sanctity and pilgrimage (Hajj and 'Umrah)]. And whoever inclines to evil actions therein or to do wrong (i.e. practise polytheism and leave Islamic Monotheism), him We shall cause to taste a painful torment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And (remember) when We showed Ibrahim (Abraham) the site of the (Sacred) House (the Ka'bah at Makkah) (saying): ``Associate not anything (in worship) with Me, [La ilaha ill-Allah (none has the right to be worshipped but Allah Islamic Monotheism], and sanctify My House for those who circumambulate it, and those who stand up for prayer, and those who bow (submit themselves with humility and obedience to Allah), and make prostration (in prayer, etc.);"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And proclaim to mankind the Hajj (pilgrimage). They will come to you on foot and on every lean camel, they will come from every deep and distant (wide) mountain highway (to perform Hajj).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness things that are of benefit to them (i.e. reward of Hajj in the Hereafter, and also some worldly gain from trade, etc.), and mention the Name of Allah on appointed days (i.e. 10th, 11th, 12th, and 13th day of Dhul-Hijjah), over the beast of cattle that He has provided for them (for sacrifice) (at the time of their slaughtering by saying: Bismillah, WAllahu-Akbar, Allahumma Minka wa Ilaik). Then eat thereof and feed therewith the poor who have a very hard time.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then let them complete the prescribed duties (Manasik of Hajj) for them, and perform their vows, and circumambulate the Ancient House (the Ka'bah at Makkah).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
That (Manasik prescribed duties of Hajj is the obligation that mankind owes to Allah), and whoever honours the sacred things of Allah, then that is better for him with his Lord. The cattle are lawful to you, except those (that will be) mentioned to you (as exceptions). So shun the abomination (worshipping) of idol, and shun lying speech (false statements)\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Hunafa' Lillah (i.e. to worship none but Allah), not associating partners (in worship, etc.) unto Him and whoever assigns partners to Allah, it is as if he had fallen from the sky, and the birds had snatched him, or the wind had thrown him to a far off place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
Thus it is [what has been mentioned in the above said Verses (27, 28, 29, 30, 31) is an obligation that mankind owes to Allah]. And whosoever honours the Symbols of Allah, then it is truly from the piety of the heart.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In them (cattle offered for sacrifice) are benefits for you for an appointed term, and afterwards they are brought for sacrifice unto the ancient House (the Haram - sacred territory of Makkah city).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And for every nation We have appointed religious ceremonies, that they may mention the Name of Allah over the beast of cattle that He has given them for food. And your Ilah (God) is One Ilah (God Allah), so you must submit to Him Alone (in Islam). And (O Muhammad SAW) give glad tidings to the Mukhbitin [those who obey Allah with humility and are humble from among the true believers of Islamic Monotheism],\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Whose hearts are filled with fear when Allah is mentioned; who patiently bear whatever may befall them (of calamities); and who perform As-Salat (Iqamat-as-Salat), and who spend (in Allah's Cause) out of what We have provided them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the Budn (cows, oxen, or camels driven to be offered as sacrifices by the pilgrims at the sanctuary of Makkah.) We have made for you as among the Symbols of Allah, therein you have much good. So mention the Name of Allah over them when they are drawn up in lines (for sacrifice). Then, when they are down on their sides (after slaughter), eat thereof, and feed the beggar who does not ask (men), and the beggar who asks (men). Thus have We made them subject to you that you may be grateful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
It is neither their meat nor their blood that reaches Allah, but it is piety from you that reaches Him. Thus have We made them subject to you that you may magnify Allah for His Guidance to you. And give glad tidings (O Muhammad SAW) to the Muhsinun (doers of good).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Truly, Allah defends those who believe. Verily! Allah likes not any treacherous ingrate to Allah [those who disobey Allah but obey Shaitan (Satan)].\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission to fight is given to those (i.e. believers against disbelievers), who are fighting them, (and) because they (believers) have been wronged, and surely, Allah is Able to give them (believers) victory\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who have been expelled from their homes unjustly only because they said: ``Our Lord is Allah." - For had it not been that Allah checks one set of people by means of another, monasteries, churches, synagogues, and mosques, wherein the Name of Allah is mentioned much would surely have been pulled down. Verily, Allah will help those who help His (Cause). Truly, Allah is All-Strong, All-Mighty.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
Those (Muslim rulers) who, if We give them power in the land, (they) order for Iqamat-as-Salat. [i.e. to perform the five compulsory congregational Salat (prayers) (the males in mosques)], to pay the Zakat and they enjoin Al-Ma'ruf (i.e. Islamic Monotheism and all that Islam orders one to do), and forbid Al-Munkar (i.e. disbelief, polytheism and all that Islam has forbidden) [i.e. they make the Quran as the law of their country in all the spheres of life]. And with Allah rests the end of (all) matters (of creatures).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
And if they belie you (O Muhammad SAW), so were belied the Prophets before them, (by) the people of Nuh (Noah), 'Ad and Thamud,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the people of Ibrahim (Abraham) and the people of Lout (Lot),\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the dwellers of Madyan (Midian); and belied was Musa (Moses), but I granted respite to the disbelievers for a while, then I seized them, and how (terrible) was My Punishment (against their wrong-doing).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
And many a township have We destroyed while it was given to wrong-doing, so that it lies in ruins (up to this day), and (many) a deserted well and lofty castles!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not travelled through the land, and have they hearts wherewith to understand and ears wherewith to hear? Verily, it is not the eyes that grow blind, but it is the hearts which are in the breasts that grow blind.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they ask you to hasten on the torment! And Allah fails not His Promise. And verily, a day with your Lord is as a thousand years of what you reckon.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And many a township did I give respite while it was given to wrong-doing. Then (in the end) I seized it (with punishment). And to Me is the (final) return (of all).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say (O Muhammad SAW): ``O mankind! I am (sent) to you only as a plain warner."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
So those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, for them is forgiveness and Rizqun Karim (generous provision, i.e. Paradise).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
But those who strive against Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), to frustrate and obstruct them, they will be dwellers of the Hell-fire.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never did We send a Messenger or a Prophet before you, but; when he did recite the revelation or narrated or spoke, Shaitan (Satan) threw (some falsehood) in it. But Allah abolishes that which Shaitan (Satan) throws in. Then Allah establishes His Revelations. And Allah is All-Knower, All-Wise:\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
That He (Allah) may make what is thrown in by Shaitan (Satan) a trial for those in whose hearts is a disease (of hypocrisy and disbelief) and whose hearts are hardened. And certainly, the Zalimun (polytheists and wrong-doers, etc.) are in an opposition far-off (from the truth against Allah's Messenger and the believers).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And that those who have been given knowledge may know that it (this Quran) is the truth from your Lord, and that they may believe therein, and their hearts may submit to it with humility. And verily, Allah is the Guide of those who believe, to the Straight Path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And those who disbelieve will not cease to be in doubt about it (this Quran) until the Hour comes suddenly upon them, or there comes to them the torment of the Day after which there will be no night (i.e. the Day of Resurrection).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The sovereignty on that Day will be that of Allah (the one Who has no partners). He will judge between them. So those who believed (in the Oneness of Allah Islamic Monotheism) and did righteous good deeds will be in Gardens of delight (Paradise).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And those who disbelieved and belied Our Verses (of this Quran), for them will be a humiliating torment (in Hell).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
Those who emigrated in the Cause of Allah and after that were killed or died, surely, Allah will provide a good provision for them. And verily, it is Allah Who indeed is the Best of those who make provision.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
Truly, He will make them enter an entrance with which they shall be well-pleased, and verily, Allah indeed is All-Knowing, Most Forbearing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That is so. And whoever has retaliated with the like of that which he was made to suffer, and then has again been wronged, Allah will surely help him. Verily! Allah indeed is Oft-Pardoning, Oft-Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah merges the night into the day, and He merges the day into the night. And verily, Allah is All-Hearer, All-Seer.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah He is the Truth (the only True God of all that exists, Who has no partners or rivals with Him), and what they (the polytheists) invoke besides Him, it is Batil (falsehood) And verily, Allah He is the Most High, the Most Great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
See you not that Allah sends down water (rain) from the sky, and then the earth becomes green? Verily, Allah is the Most Kind and Courteous, Well-Acquainted with all things.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs all that is in the heavens and all that is on the earth. And verily, Allah He is Rich (Free of all wants), Worthy of all praise.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
See you not that Allah has subjected to you (mankind) all that is on the earth, and the ships that sail through the sea by His Command? He withholds the heaven from falling on the earth except by His Leave. Verily, Allah is, for mankind, full of Kindness, Most Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
It is He, Who gave you life, and then will cause you to die, and will again give you life (on the Day of Resurrection). Verily! Man is indeed an ingrate.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every nation We have ordained religious ceremonies [e.g. slaughtering of the beast of cattle during the three days of stay at Mina (Makkah) during the Hajj (pilgrimage)] which they must follow; so let them (pagans) not dispute with you on the matter (i.e. to eat of the cattle which you slaughter, and not to eat of cattle which Allah kills by its natural death), but invite them to your Lord. Verily! You (O Muhammad SAW) indeed are on the (true) straight guidance. (i.e. the true religion of Islamic Monotheism).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they argue with you (as regards the slaughtering of the sacrifices), say; ``Allah knows best of what you do.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
``Allah will judge between you on the Day of Resurrection about that wherein you used to differ."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Know you not that Allah knows all that is in heaven and on earth? Verily, it is (all) in the Book (Al-Lauh Al-Mahfuz). Verily! That is easy for Allah.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship besides Allah others for which He has sent down no authority, and of which they have no knowledge and for the Zalimun (wrong-doers, polytheists and disbelievers in the Oneness of Allah) there is no helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our Clear Verses are recited to them, you will notice a denial on the faces of the disbelievers! They are nearly ready to attack with violence those who recite Our Verses to them. Say: ``Shall I tell you of something worse than that? The Fire (of Hell) which Allah has promised to those who disbelieve, and worst indeed is that destination!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O mankind! A similitude has been coined, so listen to it (carefully): Verily! Those on whom you call besides Allah, cannot create (even) a fly, even though they combine together for the purpose. And if the fly snatched away a thing from them, they would have no power to release it from the fly. So weak are (both) the seeker and the sought.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They have not estimated Allah His Rightful Estimate; Verily, Allah is All-Strong, All-Mighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses Messengers from angels and from men. Verily, Allah is All-Hearer, All-Seer.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is before them, and what is behind them. And to Allah return all matters (for decision).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O you who believe! Bow down, and prostrate yourselves, and worship your Lord and do good that you may be successful.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive hard in Allah's Cause as you ought to strive (with sincerity and with all your efforts that His Name should be superior). He has chosen you (to convey His Message of Islamic Monotheism to mankind by inviting them to His religion, Islam), and has not laid upon you in religion any hardship, it is the religion of your father Ibrahim (Abraham) (Islamic Monotheism). It is He (Allah) Who has named you Muslims both before and in this (the Quran), that the Messenger (Muhammad SAW) may be a witness over you and you be witnesses over mankind! So perform As-Salat (Iqamat-as-Salat), give Zakat and hold fast to Allah [i.e. have confidence in Allah, and depend upon Him in all your affairs] He is your Maula (Patron, Lord, etc.), what an Excellent Maula (Patron, Lord, etc.) and what an Excellent Helper!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Successful indeed are the believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who offer their Salat (prayers) with all solemnity and full submissiveness.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And those who turn away from Al-Laghw (dirty, false, evil vain talk, falsehood, and all that Allah has forbidden).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And those who pay the Zakat.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And those who guard their chastity (i.e. private parts, from illegal sexual acts)\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except from their wives or (the captives and slaves) that their right hands possess, for then, they are free from blame;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But whoever seeks beyond that, then those are the transgressors;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
Those who are faithfully true to their Amanat (all the duties which Allah has ordained, honesty, moral responsibility and trusts etc.) and to their covenants;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And those who strictly guard their (five compulsory congregational) Salawat (prayers) (at their fixed stated hours).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These are indeed the inheritors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who shall inherit the Firdaus (Paradise). They shall dwell therein forever.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
And indeed We created man (Adam) out of an extract of clay (water and earth).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Thereafter We made him (the offspring of Adam) as a Nutfah (mixed drops of the male and female sexual discharge) (and lodged it) in a safe lodging (womb of the woman).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We made the Nutfah into a clot (a piece of thick coagulated blood), then We made the clot into a little lump of flesh, then We made out of that little lump of flesh bones, then We clothed the bones with flesh, and then We brought it forth as another creation. So blessed be Allah, the Best of creators.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
After that, surely, you will die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then (again), surely, you will be resurrected on the Day of Resurrection.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And indeed We have created above you seven heavens (one over the other), and We are never unaware of the creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down from the sky water (rain) in (due) measure, and We gave it lodging in the earth, and verily, We are Able to take it away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then We brought forth for you therewith gardens of date-palms and grapes, wherein is much fruit for you, and whereof you eat.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And a tree (olive) that springs forth from Mount Sinai, that grows oil, and (it is a) relish for the eaters.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And Verily! In the cattle there is indeed a lesson for you. We give you to drink (milk) of that which is in their bellies. And there are, in them, numerous (other) benefits for you, and of them you eat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them, and on ships you are carried.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And indeed We sent Nuh (Noah) to his people, and he said: ``O my people! Worship Allah! You have no other Ilah (God) but Him (Islamic Monotheism). Will you not then be afraid (of Him i.e. of His Punishment because of worshipping others besides Him)?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the chiefs of those who disbelieved among his people said: ``He is no more than a human being like you, he seeks to make himself superior to you. Had Allah willed, He surely could have sent down angels; never did we hear such a thing among our fathers of old.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
``He is only a man in whom is madness, so wait for him a while."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
[Nuh (Noah)] said: ``O my Lord! Help me because they deny me."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So We inspired him (saying): ``Construct the ship under Our Eyes and under Our Revelation (guidance). Then, when Our Command comes, and the oven gushes forth water, take on board of each kind two (male and female), and your family, except those thereof against whom the Word has already gone forth. And address Me not in favour of those who have done wrong. Verily, they are to be drowned.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when you have embarked on the ship, you and whoever is with you, then say: ``All the praises and thanks be to Allah, Who has saved us from the people who are Zalimun (i.e. oppressors, wrong-doers, polytheists, those who join others in worship with Allah, etc.).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say: ``My Lord! Cause me to land at a blessed landing-place, for You are the Best of those who bring to land."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Verily, in this [what We did as regards drowning of the people of Nuh (Noah)], there are indeed Ayat (proofs, evidences, lessons, signs, etc. for men to understand), for sure We are ever putting (men) to the test.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them, We created another generation.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And We sent to them a Messenger from among themselves (saying): ``Worship Allah! You have no other Ilah (God) but Him. Will you not then be afraid (of Him i.e. of His Punishment because of worshipping others besides Him)?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And the chiefs of his people, who disbelieved and denied the Meeting in the Hereafter, and to whom We had given the luxuries and comforts of this life, said: ``He is no more than a human being like you, he eats of that which you eat, and drinks of what you drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
``If you were to obey a human being like yourselves, then verily! You indeed would be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
``Does he promise you that when you have died and have become dust and bones, you shall come out alive (resurrected)?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
``Far, very far is that which you are promised.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
``There is nothing but our life of this world! We die and we live! And we are not going to be resurrected!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
``He is only a man who has invented a lie against Allah, but we are not going to believe in him."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said: ``O my Lord! Help me because they deny me."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
(Allah) said: ``In a little while, they are sure to be regretful."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
So As-Saihah (torment - awful cry, etc.) overtook them with justice, and We made them as rubbish of dead plants. So away with the people who are Zalimun (polytheists, wrong-doers, disbelievers in the Oneness of Allah, disobedient to His Messengers, etc.).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then, after them, We created other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can anticipate their term, nor can they delay it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our Messengers in succession, every time there came to a nation their Messenger, they denied him, so We made them follow one another (to destruction), and We made them as Ahadith (the true stories for mankind to learn a lesson from them). So away with a people who believe not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Musa (Moses) and his brother Harun (Aaron), with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and manifest authority,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
To Fir'aun (Pharaoh) and his chiefs, but they behaved insolently and they were people self-exalting (by disobeying their Lord, and exalting themselves over and above the Messenger of Allah).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said: ``Shall we believe in two men like ourselves, and their people are obedient to us with humility (and we use them to serve us as we like)."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they denied them both [Musa (Moses) and Harun (Aaron)] and became of those who were destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And indeed We gave Musa (Moses) the Scripture, that they may be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Maryam (Mary) and his mother as a sign, And We gave them refuge on high ground, a place of rest, security and flowing streams.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O (you) Messengers! Eat of the Taiyibat [all kinds of Halal (legal) foods which Allah has made legal (meat of slaughtered eatable animals, milk products, fats, vegetables, fruits, etc.], and do righteous deeds. Verily! I am Well-Acquainted with what you do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And verily! This your religion (of Islamic Monotheism) is one religion, and I am your Lord, so keep your duty to Me.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But they (men) have broken their religion among them into sects, each group rejoicing in its belief.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them in their error for a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they think that We enlarge them in wealth and children,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We hasten unto them with good things (in this worldly life so that they will have no share of good things in the Hereafter)? Nay, but they perceive not.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Verily! Those who live in awe for fear of their Lord;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who believe in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who join not anyone (in worship) as partners with their Lord;\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give that (their charity) which they give (and also do other good deeds) with their hearts full of fear (whether their alms and charities, etc., have been accepted or not), because they are sure to return to their Lord (for reckoning).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
It is these who race for the good deeds, and they are foremost in them [e.g. offering the compulsory Salat (prayers) in their (early) stated, fixed times and so on].\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And We tax not any person except according to his capacity, and with Us is a Record which speaks the truth, and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Nay, but their hearts are covered (blind) from understanding this (the Quran), and they have other (evil) deeds, besides, which they are doing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until, when We grasp those of them who lead a luxurious life with punishment, behold! They make humble invocation with a loud voice.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Invoke not loudly this day! Certainly, you shall not be helped by Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
Indeed My Verses used to be recited to you, but you used to turn back on your heels (denying them, and with hatred to listen to them).\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
In pride (they Quraish pagans and polytheists of Makkah used to feel proud that they are the dwellers of Makkah sanctuary Haram), talking evil about it (the Quran) by night.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered over the Word (of Allah, i.e. what is sent down to the Prophet SAW), or has there come to them what had not come to their fathers of old?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or is it that they did not recognize their Messenger (Muhammad SAW) so they deny him?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or say they: ``There is madness in him?" Nay, but he brought them the truth [i.e. ``(A) Tauhid: Worshipping Allah Alone in all aspects (B) The Quran (C) The religion of Islam,"] but most of them (the disbelievers) are averse to the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
And if the truth had been in accordance with their desires, verily, the heavens and the earth, and whosoever is therein would have been corrupted! Nay, We have brought them their reminder, but they turn away from their reminder.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or is it that you (O Muhammad SAW) ask them for some wages? But the recompense of your Lord is better, and He is the Best of those who give sustenance.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And certainly, you (O Muhammad SAW) call them to a Straight Path (true religion Islamic Monotheism).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And verily, those who believe not in the Hereafter are indeed deviating far astray from the Path (true religion Islamic Monotheism).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
And though We had mercy on them and removed the distress which is on them, still they would obstinately persist in their transgression, wandering blindly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
And indeed We seized them with punishment, but they humbled not themselves to their Lord, nor did they invoke (Allah) with submission to Him.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until, when We open for them the gate of severe punishment, then lo! They will be plunged into destruction with deep regrets, sorrows and in despair.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He, Who has created for you (the sense of) hearing (ears), sight (eyes), and hearts (understanding). Little thanks you give.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And it is He Who has created you on the earth, and to Him you shall be gathered back.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And it is He Who gives life and causes death, and His is the alternation of night and day. Will you not then understand?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Nay, but they say the like of what the men of old said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They said: ``When we are dead and have become dust and bones, shall we be resurrected indeed?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
``Verily, this we have been promised, we and our fathers before (us)! This is only the tales of the ancients!"\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: ``Whose is the earth and whosoever is therein? If you know!"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say: ``It is Allah's!" Say: ``Will you not then remember?"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: ``Who is (the) Lord of the seven heavens, and (the) Lord of the Great Throne?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say: ``Allah." Say: ``Will you not then fear Allah (believe in His Oneness, obey Him, believe in the Resurrection and Recompense for each and every good or bad deed)."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say ``In Whose Hand is the sovereignty of everything (i.e. treasures of each and everything)? And He protects (all), while against Whom there is no protector, (i.e. if Allah saves anyone none can punish or harm him, and if Allah punishes or harms anyone none can save him), if you know." [Tafsir Al-Qurtubi, Vol. 12, Page 145]\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say: ``(All that belongs) to Allah." Say: ``How then are you deceived and turn away from the truth?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Nay, but We have brought them the truth (Islamic Monotheism), and verily, they (disbelievers) are liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
No son (or offspring or children) did Allah beget, nor is there any ilah (god) along with Him; (if there had been many gods), behold, each god would have taken away what he had created, and some would have tried to overcome others! Glorified be Allah above all that they attribute to Him!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
All-Knower of the unseen and the seen! Exalted be He over all that they associate as partners to Him!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say (O Muhammad SAW): `` My Lord! If You would show me that with which they are threatened (torment),\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
``My Lord! Then (save me from Your Punishment), and put me not amongst the people who are the Zalimun (polytheists and wrong-doing)."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And indeed We are Able to show you (O Muhammad SAW) that with which We have threatened them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with that which is better. We are Best-Acquainted with the things they utter.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say: ``My Lord! I seek refuge with You from the whisperings (suggestions) of the Shayatin (devils).\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
``And I seek refuge with You, My Lord! lest they may attend (or come near) me."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death comes to one of them (those who join partners with Allah), he says: ``My Lord! Send me back,\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
``So that I may do good in that which I have left behind!" No! It is but a word that he speaks, and behind them is Barzakh (a barrier) until the Day when they will be resurrected.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
Then, when the Trumpet is blown, there will be no kinship among them that Day, nor will they ask of one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then, those whose scales (of good deeds) are heavy, - these, they are the successful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
And those whose scales (of good deeds) are light, they are those who lose their ownselves, in Hell will they abide.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire will burn their faces, and therein they will grin, with displaced lips (disfigured).\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
``Were not My Verses (this Quran) recited to you, and then you used to deny them?"\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: ``Our Lord! Our wretchedness overcame us, and we were (an) erring people.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
``Our Lord! Bring us out of this; if ever we return (to evil), then indeed we shall be Zalimun: (polytheists, oppressors, unjust, and wrong-doers, etc.)."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He (Allah) will say: ``Remain you in it with ignominy! And speak you not to Me!"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Verily! There was a party of My slaves, who used to say: ``Our Lord! We believe, so forgive us, and have mercy on us, for You are the Best of all who show mercy!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you took them for a laughingstock, so much so that they made you forget My Remembrance while you used to laugh at them!\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Verily! I have rewarded them this Day for their patience, they are indeed the ones that are successful.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He (Allah) will say: ``What number of years did you stay on earth?"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say: ``We stayed a day or part of a day. Ask of those who keep account."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He (Allah) will say: ``You stayed not but a little, if you had only known!\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
``Did you think that We had created you in play (without any purpose), and that you would not be brought back to Us?"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So Exalted be Allah, the True King, La ilaha illa Huwa (none has the right to be worshipped but He), the Lord of the Supreme Throne!\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And whoever invokes (or worships), besides Allah, any other ilah (god), of whom he has no proof, then his reckoning is only with his Lord. Surely! Al-Kafirun (the disbelievers in Allah and in the Oneness of Allah, polytheists, pagans, idolaters, etc.) will not be successful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say (O Muhammad SAW): ``My Lord! Forgive and have mercy, for You are the Best of those who show mercy!"\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen (This is) a Surah (chapter of the Quran) which We have sent down and which We have enjoined, (ordained its legal laws) and in it We have revealed manifest Ayat (proofs, evidences, verses, lessons, signs, revelations lawful and unlawful things, and set boundries of Islamic Religion), that you may remember.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The woman and the man guilty of illegal sexual intercourse, flog each of them with a hundred stripes. Let not pity withhold you in their case, in a punishment prescribed by Allah, if you believe in Allah and the Last Day. And let a party of the believers witness their punishment. (This punishment is for unmarried persons guilty of the above crime but if married persons commit it, the punishment is to stone them to death, according to Allah's Law).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The adulterer marries not but an adulteress or a Mushrikah and the adulteress none marries her except an adulterer or a Muskrik [and that means that the man who agrees to marry (have a sexual relation with) a Mushrikah (female polytheist, pagan or idolatress) or a prostitute, then surely he is either an adulterer, or a Mushrik (polytheist, pagan or idolater, etc.) And the woman who agrees to marry (have a sexual relation with) a Mushrik (polytheist, pagan or idolater) or an adulterer, then she is either a prostitute or a Mushrikah (female polytheist, pagan, or idolatress, etc.)]. Such a thing is forbidden to the believers (of Islamic Monotheism).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse chaste women, and produce not four witnesses, flog them with eighty stripes, and reject their testimony forever, they indeed are the Fasiqun (liars, rebellious, disobedient to Allah).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Except those who repent thereafter and do righteous deeds, (for such) verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And for those who accuse their wives, but have no witnesses except themselves, let the testimony of one of them be four testimonies (i.e. testifies four times) by Allah that he is one of those who speak the truth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth (testimony) (should be) the invoking of the Curse of Allah on him if he be of those who tell a lie (against her).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But it shall avert the punishment (of stoning to death) from her, if she bears witness four times by Allah, that he (her husband) is telling a lie.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth (testimony) should be that the Wrath of Allah be upon her if he (her husband) speaks the truth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And had it not been for the Grace of Allah and His Mercy on you (He would have hastened the punishment upon you)! And that Allah is the One Who accepts repentance, the All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Verily! Those who brought forth the slander (against 'Aishah, the wife of the Prophet SAW) are a group among you. Consider it not a bad thing for you. Nay, it is good for you. Unto every man among them will be paid that which he had earned of the sin, and as for him among them who had the greater share therein, his will be a great torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why then, did not the believers, men and women, when you heard it (the slander) think good of their own people and say: ``This (charge) is an obvious lie?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not produce four witnesses? Since they (the slanderers) have not produced witnesses! Then with Allah they are the liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Had it not been for the Grace of Allah and His Mercy unto you in this world and in the Hereafter, a great torment would have touched you for that whereof you had spoken.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you were propagating it with your tongues, and uttering with your mouths that whereof you had no knowledge, you counted it a little thing, while with Allah it was very great.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why did you not, when you heard it, say? ``It is not right for us to speak of this. Glory be to You (O Allah) this is a great lie."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah forbids you from it and warns you not to repeat the like of it forever, if you are believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah makes the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) plain to you, and Allah is All-Knowing, All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Verily, those who like that (the crime of) illegal sexual intercourse should be propagated among those who believe, they will have a painful torment in this world and in the Hereafter. And Allah knows and you know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
And had it not been for the Grace of Allah and His Mercy on you, (Allah would have hastened the punishment upon you). And that Allah is full of kindness, Most Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O you who believe! Follow not the footsteps of Shaitan (Satan). And whosoever follows the footsteps of Shaitan (Satan), then, verily he commands Al-Fahsha' [i.e. to commit indecency (illegal sexual intercourse, etc.)], and Al-Munkar [disbelief and polytheism (i.e. to do evil and wicked deeds; to speak or to do what is forbidden in Islam, etc.)]. And had it not been for the Grace of Allah and His Mercy on you, not one of you would ever have been pure from sins. But Allah purifies (guides to Islam) whom He wills, and Allah is All-Hearer, All-Knower.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And let not those among you who are blessed with graces and wealth swear not to give (any sort of help) to their kinsmen, Al-Masakin (the poor), and those who left their homes for Allah's Cause. Let them pardon and forgive. Do you not love that Allah should forgive you? And Allah is Oft-Forgiving, Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Verily, those who accuse chaste women, who never even think of anything touching their chastity and are good believers, are cursed in this life and in the Hereafter, and for them will be a great torment,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day when their tongues, their hands, and their legs or feet will bear witness against them as to what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day Allah will pay them the recompense of their deeds in full, and they will know that Allah, He is the Manifest Truth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Bad statements are for bad people (or bad women for bad men) and bad people for bad statements (or bad men for bad women). Good statements are for good people (or good women for good men) and good people for good statements (or good men for good women), such (good people) are innocent of (each and every) bad statement which they say, for them is Forgiveness, and Rizqun Karim (generous provision i.e. Paradise).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O you who believe! Enter not houses other than your own, until you have asked permission and greeted those in them, that is better for you, in order that you may remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you find no one therein, still, enter not until permission has been given. And if you are asked to go back, go back, for it is purer for you, and Allah is All-Knower of what you do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no sin on you that you enter (without taking permission) houses uninhabited (i.e. not possessed by anybody), (when) you have any interest in them. And Allah has knowledge of what you reveal and what you conceal.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Tell the believing men to lower their gaze (from looking at forbidden things), and protect their private parts (from illegal sexual acts, etc.). That is purer for them. Verily, Allah is All-Aware of what they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And tell the believing women to lower their gaze (from looking at forbidden things), and protect their private parts (from illegal sexual acts, etc.) and not to show off their adornment except only that which is apparent (like palms of hands or one eye or both eyes for necessity to see the way, or outer dress like veil, gloves, head-cover, apron, etc.), and to draw their veils all over Juyubihinna (i.e. their bodies, faces, necks and bosoms, etc.) and not to reveal their adornment except to their husbands, their fathers, their husband's fathers, their sons, their husband's sons, their brothers or their brother's sons, or their sister's sons, or their (Muslim) women (i.e. their sisters in Islam), or the (female) slaves whom their right hands possess, or old male servants who lack vigour, or small children who have no sense of the shame of sex. And let them not stamp their feet so as to reveal what they hide of their adornment. And all of you beg Allah to forgive you all, O believers, that you may be successful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And marry those among you who are single (i.e. a man who has no wife and the woman who has no husband) and (also marry) the Salihun (pious, fit and capable ones) of your (male) slaves and maid-servants (female slaves). If they be poor, Allah will enrich them out of His Bounty. And Allah is All-Sufficent for His creatures' needs, All-Knowing (about the state of the people).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And let those who find not the financial means for marriage keep themselves chaste, until Allah enriches them of His Bounty. And such of your slaves as seek a writing (of emancipation), give them such writing, if you know that they are good and trustworthy. And give them something yourselves out of the wealth of Allah which He has bestowed upon you. And force not your maids to prostitution, if they desire chastity, in order that you may make a gain in the (perishable) goods of this worldly life. But if anyone compels them (to prostitution), then after such compulsion, Allah is Oft-Forgiving, Most Merciful (to those women, i.e. He will forgive them because they have been forced to do this evil action unwillingly).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And indeed We have sent down for you Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) that make things plain, and the example of those who passed away before you, and an admonition for those who are Al-Muttaqun (the pious - see V. 2:2).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth. The parable of His Light is as (if there were) a niche and within it a lamp, the lamp is in glass, the glass as it were a brilliant star, lit from a blessed tree, an olive, neither of the east (i.e. neither it gets sun-rays only in the morning) nor of the west (i.e. nor it gets sun-rays only in the afternoon, but it is exposed to the sun all day long), whose oil would almost glow forth (of itself), though no fire touched it. Light upon Light! Allah guides to His Light whom He wills. And Allah sets forth parables for mankind, and Allah is All-Knower of everything.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
In houses (mosques), which Allah has ordered to be raised (to be cleaned, and to be honoured), in them His Name is glorified in the mornings and in the afternoons or the evenings,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
Men whom neither trade nor sale diverts them from the Remembrance of Allah (with heart and tongue), nor from performing As-Salat (Iqamat-as-Salat), nor from giving the Zakat. They fear a Day when hearts and eyes will be overturned (from the horror of the torment of the Day of Resurrection).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may reward them according to the best of their deeds, and add even more for them out of His Grace. And Allah provides without measure to whom He wills.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
As for those who disbelieve, their deeds are like a mirage in a desert. The thirsty one thinks it to be water, until he comes up to it, he finds it to be nothing, but he finds Allah with him, Who will pay him his due (Hell). And Allah is Swift in taking account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or [the state of a disbeliever] is like the darkness in a vast deep sea, overwhelmed with a great wave topped by a great wave, topped by dark clouds, darkness, one above another, if a man stretches out his hand, he can hardly see it! And he for whom Allah has not appointed light, for him there is no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
See you not (O Muhammad SAW) that Allah, He it is Whom glorify whosoever is in the heavens and the earth, and the birds with wings out-spread (in their flight). Of each one He (Allah) knows indeed his Salat (prayer) and his glorification, [or everyone knows his Salat (prayer) and his glorification], and Allah is All-Aware of what they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And to Allah belongs the sovereignty of the heavens and the earth, and to Allah is the return (of all).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
See you not that Allah drives the clouds gently, then joins them together, then makes them into a heap of layers, and you see the rain comes forth from between them. And He sends down from the sky hail (like) mountains, (or there are in the heaven mountains of hail from where He sends down hail), and strike therewith whom He will, and averts it from whom He wills. The vivid flash of its (clouds) lightning nearly blinds the sight. [Tafsir At-Tabari].\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah causes the night and the day to succeed each other (i.e. if the day is gone, the night comes, and if the night is gone, the day comes, and so on). Truly, in these things is indeed a lesson for those who have insight.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah has created every moving (living) creature from water. Of them there are some that creep on their bellies, some that walk on two legs, and some that walk on four. Allah creates what He wills. Verily! Allah is Able to do all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have indeed sent down (in this Quran) manifest Ayat (proofs, evidences, verses, lessons, signs, revelations, lawful and unlawful things, and the set boundries of Islamic religion, etc. that make things clear showing the Right Path of Allah). And Allah guides whom He wills to a Straight Path (i.e. to Allah's religion of Islamic Monotheism).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
They (hypocrites) say: ``We have believed in Allah and in the Messenger (Muhammad SAW), and we obey," then a party of them turn away thereafter, such are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to Allah (i.e. His Words, the Quran) and His Messenger (SAW), to judge between them, lo! a party of them refuse (to come) and turn away.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if the right is with them, they come to him willingly with submission.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there a disease in their hearts? Or do they doubt or fear lest Allah and His Messenger (SAW) should wrong them in judgement. Nay, it is they themselves who are the Zalimun (polytheists, hypocrites and wrong-doers, etc.).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The only saying of the faithful believers, when they are called to Allah (His Words, the Quran) and His Messenger (SAW), to judge between them, is that they say: ``We hear and we obey." And such are the prosperous ones (who will live forever in Paradise).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
And whosoever obeys Allah and His Messenger (SAW), fears Allah, and keeps his duty (to Him), such are the successful ones.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They swear by Allah their strongest oaths, that if only you would order them, they would leave (their homes for fighting in Allah's Cause). Say: ``Swear you not; (this) obedience (of yours) is known (to be false). Verily, Allah knows well what you do."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: ``Obey Allah and obey the Messenger, but if you turn away, he (Messenger Muhammad SAW) is only responsible for the duty placed on him (i.e. to convey Allah's Message) and you for that placed on you. If you obey him, you shall be on the right guidance. The Messenger's duty is only to convey (the message) in a clear way (i.e. to preach in a plain way)."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised those among you who believe, and do righteous good deeds, that He will certainly grant them succession to (the present rulers) in the earth, as He granted it to those before them, and that He will grant them the authority to practise their religion, that which He has chosen for them (i.e. Islam). And He will surely give them in exchange a safe security after their fear (provided) they (believers) worship Me and do not associate anything (in worship) with Me. But whoever disbelieved after this, they are the Fasiqun (rebellious, disobedient to Allah).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
And perform As-Salat (Iqamat-as-Salat), and give Zakat and obey the Messenger (Muhammad SAW) that you may receive mercy (from Allah).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Consider not that the disbelievers can escape in the land. Their abode shall be the Fire, and worst indeed is that destination.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O you who believe! Let your legal slaves and slave-girls, and those among you who have not come to the age of puberty ask your permission (before they come to your presence) on three occasions; before Fajr (morning) prayer, and while you put off your clothes for the noonday (rest), and after the 'Isha' (late-night) prayer. (These) three times are of privacy for you, other than these times there is no sin on you or on them to move about, attending (helping) you each other. Thus Allah makes clear the Ayat (the Verses of this Quran, showing proofs for the legal aspects of permission for visits, etc.) to you. And Allah is All-Knowing, All-Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the children among you come to puberty, then let them (also) ask for permission, as those senior to them (in age). Thus Allah makes clear His Ayat (Commandments and legal obligations) for you. And Allah is All-Knowing, All-Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
And as for women past child-bearing who do not expect wed-lock, it is no sin on them if they discard their (outer) clothing in such a way as not to show their adornment. But to refrain (i.e. not to discard their outer clothing) is better for them. And Allah is All-Hearer, All-Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no restriction on the blind, nor any restriction on the lame, nor any restriction on the sick, nor on yourselves, if you eat from your houses, or the houses of your fathers, or the houses of your mothers, or the houses of your brothers, or the houses of your sisters, or the houses of your father's brothers, or the houses of your father's sisters, or the houses of your mother's brothers, or the houses of your mother's sisters, or (from that) whereof you hold keys, or (from the house) of a friend. No sin on you whether you eat together or apart. But when you enter the houses, greet one another with a greeting from Allah (i.e. say: As-Salamu 'Alaikum - peace be on you) blessed and good. Thus Allah makes clear the Ayat (these Verses or your religious symbols and signs, etc.) to you that you may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The true believers are only those, who believe in (the Oneness of) Allah and His Messenger (Muhammad SAW), and when they are with him on some common matter, they go not away until they have asked his permission. Verily! Those who ask your permission, those are they who (really) believe in Allah and His Messenger. So if they ask your permission for some affairs of theirs, give permission to whom you will of them, and ask Allah for their forgiveness. Truly, Allah is Oft-Forgiving, Most Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Make not the calling of the Messenger (Muhammad SAW) among you as your calling of one another. Allah knows those of you who slip away under shelter (of some excuse without taking the permission to leave, from the Messenger SAW). And let those who oppose the Messenger's (Muhammad SAW) commandment (i.e. his Sunnah legal ways, orders, acts of worship, statements, etc.) (among the sects) beware, lest some Fitnah (disbelief, trials, afflictions, earthquakes, killing, overpowered by a tyrant, etc.) befall them or a painful torment be inflicted on them.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Certainly, to Allah belongs all that is in the heavens and the earth. Surely, He knows your condition and (He knows) the Day when they will be brought back to Him, then He will inform them of what they did. And Allah is All-Knower of everything.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed be He Who sent down the criterion (of right and wrong, i.e. this Quran) to His slave (Muhammad SAW) that he may be a warner to the 'Alamin (mankind and jinns).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to Whom belongs the dominion of the heavens and the earth, and Who has begotten no son (children or offspring) and for Whom there is no partner in the dominion. He has created everything, and has measured it exactly according to its due measurements.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet they have taken besides Him other aliha (gods) that created nothing but are themselves created, and possess neither hurt nor benefit for themselves, and possess no power (of causing) death, nor (of giving) life, nor of raising the dead.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
Those who disbelieve say: ``This (the Quran) is nothing but a lie that he (Muhammad SAW) has invented, and others have helped him at it, so that they have produced an unjust wrong (thing) and a lie."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say: ``Tales of the ancients, which he has written down, and they are dictated to him morning and afternoon."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say: ``It (this Quran) has been sent down by Him (Allah) (the Real Lord of the heavens and earth) Who knows the secret of the heavens and the earth. Truly, He is Oft-Forgiving, Most Merciful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say: ``Why does this Messenger (Muhammad SAW) eat food, and walk about in the markets (like ourselves). Why is not an angel sent down to him to be a warner with him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
``Or (why) has not a treasure been granted to him, or why has he not a garden whereof he may eat?" And the Zalimun (polytheists and wrong-doers, etc.) say: ``You follow none but a man bewitched."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
See how they coin similitudes for you, so they have gone astray, and they cannot find a (Right) Path.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed be He Who, if He will, will assign you better than (all) that, - Gardens under which rivers flow (Paradise) and will assign you palaces (i.e. in Paradise).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Nay, they deny the Hour (the Day of Resurrection), and for those who deny the Hour, We have prepared a flaming Fire (i.e. Hell).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it (Hell) sees them from a far place, they will hear its raging and its roaring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they shall be thrown into a narrow place thereof, chained together, they will exclaim therein for destruction.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
Exclaim not today for one destruction, but exclaim for many destructions.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: (O Muhammad SAW) ``Is that (torment) better or the Paradise of Eternity promised to the Muttaqun (pious and righteous persons - see V. 2:2)?" It will be theirs as a reward and as a final destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
For them there will be therein all that they desire, and they will abide (there forever). It is a promise binding upon your Lord that must be fulfilled.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on the Day when He will gather them together and that which they worship besides Allah [idols, angels, pious men, saints, 'Iesa (Jesus) - son of Maryam (Mary), etc.]. He will say: ``Was it you who misled these My slaves or did they (themselves) stray from the (Right) Path?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say: ``Glorified be You! It was not for us to take any Auliya' (Protectors, Helpers, etc.) besides You, but You gave them and their fathers comfort till they forgot the warning, and became a lost people (doomed to total loss).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
Thus they (false gods all deities other than Allah) will give you (polytheists) the lie regarding what you say (that they are gods besides Allah), then you can neither avert (the punishment), nor get help. And whoever among you does wrong (i.e. sets up rivals to Allah), We shall make him taste a great torment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And We never sent before you (O Muhammad SAW) any of the Messengers but verily, they ate food and walked in the markets. And We have made some of you as a trial for others: will you have patience? And your Lord is Ever All-Seer (of everything).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who expect not for a Meeting with Us (i.e. those who deny the Day of Resurrection and the life of the Hereafter), say: ``Why are not the angels sent down to us, or why do we not see our Lord?" Indeed they think too highly of themselves, and are scornful with great pride.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
On the Day they will see the angels, no glad tidings will there be for the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.) that day. And they (angels) will say: ``All kinds of glad tidings are forbidden for you," [None will be allowed to enter Paradise except the one who said: La ilaha ill-Allah, ``(none has the right to be worshipped but Allah) and acted practically on its legal orders and obligations].\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We shall turn to whatever deeds they (disbelievers, polytheists, sinners, etc.) did, and We shall make such deeds as scattered floating particles of dust.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The dwellers of Paradise (i.e. those who deserved it through their Faith and righteousness) will, on that Day, have the best abode, and have the fairest of places for repose.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
And (remember) the Day when the heaven shall be rent asunder with clouds, and the angels will be sent down, with a grand descending.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The sovereignty on that Day will be the true (sovereignty), belonging to the Most Beneficent (Allah), and it will be a hard Day for the disbelievers (those who disbelieve in the Oneness of Allah Islamic Monotheism).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
And (remember) the Day when the Zalim (wrong-doer, oppressor, polytheist, etc.) will bite at his hands, he will say: ``Oh! Would that I had taken a path with the Messenger (Muhammad SAW).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
``Ah! Woe to me! Would that I had never taken so-and-so as a friend!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
``He indeed led me astray from the Reminder (this Quran) after it had come to me. And Shaitan (Satan) is ever a deserter to man in the hour of need."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Messenger (Muhammad SAW) will say: ``O my Lord! Verily, my people deserted this Quran (neither listened to it, nor acted on its laws and orders).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Thus have We made for every Prophet an enemy among the Mujrimun (disbelievers, polytheists, criminals, etc.). But Sufficient is your Lord as a Guide and Helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And those who disbelieve say: ``Why is not the Quran revealed to him all at once?" Thus (it is sent down in parts), that We may strengthen your heart thereby. And We have revealed it to you gradually, in stages. (It was revealed to the Prophet SAW in 23 years.).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And no example or similitude do they bring (to oppose or to find fault in you or in this Quran), but We reveal to you the truth (against that similitude or example), and the better explanation thereof.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be gathered to Hell (prone) on their faces, such will be in an evil state, and most astray from the (Straight) Path.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
And indeed We gave Musa (Moses) the Scripture [the Taurat (Torah)], and placed his brother Harun (Aaron) with him as a helper;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
And We said: ``Go you both to the people who have denied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.)." Then We destroyed them with utter destruction.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And Nuh's (Noah) people, when they denied the Messengers We drowned them, and We made them as a sign for mankind. And We have prepared a painful torment for the Zalimun (polytheists and wrong-doers, etc).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And (also) 'Ad and Thamud, and the dwellers of Ar-Rass, and many generations in between.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
And for each of them We put forward examples (as proofs and lessons, etc.), and each (of them) We brought to utter ruin (because of their disbelief and evil deeds).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And indeed they have passed by the town [of Prophet Lout (Lot)] on which was rained the evil rain. Did they (disbelievers) not then see it (with their own eyes)? Nay! But they used not to expect for any resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see you (O Muhammad SAW), they treat you only as a mockery (saying):"Is this the one whom Allah has sent as a Messenger?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
``He would have nearly misled us from our aliha (gods), had it not been that we were patient and constant in their worship!" And they will know when they see the torment, who it is that is most astray from the (Right) Path!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you (O Muhammad SAW) seen him who has taken as his ilah (god) his own desire? Would you then be a Wakil (a disposer of his affairs or a watcher) over him?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or do you think that most of them hear or understand? They are only like cattle; nay, they are even farther astray from the Path. (i.e. even worst than cattle).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Have you not seen how your Lord spread the shadow. If He willed, He could have made it still then We have made the sun its guide [i.e. after the sunrise, it (the shadow) squeezes and vanishes at midnoon and then again appears in the afternoon with the decline of the sun, and had there been no sun light, there would have been no shadow].\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We withdraw it to Us a gradual concealed withdrawal.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He Who makes the night a covering for you, and the sleep (as) repose, and makes the day Nushur (i.e. getting up and going about here and there for daily work, etc. after one's sleep at night or like resurrection after one's death).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He Who sends the winds as heralds of glad tidings, going before His Mercy (rain), and We send down pure water from the sky,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That We may give life thereby to a dead land, and We give to drink thereof many of the cattle and men that We had created.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And indeed We have distributed it (rain or water) amongst them in order that they may remember the Grace of Allah, but most men refuse (or deny the Truth or Faith) and accept nothing but disbelief or ingratitude.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
And had We willed, We would have raised a warner in every town.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So obey not the disbelievers, but strive against them (by preaching) with the utmost endeavour, with it (the Quran).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He Who has let free the two seas (kinds of water), one palatable and sweet, and the other salt and bitter, and He has set a barrier and a complete partition between them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He Who has created man from water, and has appointed for him kindred by blood, and kindred by marriage. And your Lord is Ever All-Powerful to do what He will.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And they (disbelievers, polytheists, etc.) worship besides Allah, that which can neither profit them nor harm them, and the disbeliever is ever a helper (of the Satan) against his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We have sent you (O Muhammad SAW) only as a bearer of glad tidings and a warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: ``No reward do I ask of you for this (that which I have brought from my Lord and its preaching, etc.), save that whosoever wills, may take a Path to his Lord.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And put your trust (O Muhammad SAW) in the Ever Living One Who dies not, and glorify His Praises, and Sufficient is He as the All-Knower of the sins of His slaves;\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
Who created the heavens and the earth and all that is between them in six Days. Then He Istawa (rose over) the Throne (in a manner that suits His Majesty). The Most Beneficent (Allah)! Ask Him (O Prophet Muhammad SAW), (concerning His Qualities, His rising over His Throne, His creations, etc.), as He is Al-Khabir (The All-Knower of everything i.e. Allah).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said to them: ``Prostrate to the Most Beneficent (Allah)! They say: ``And what is the Most Beneficent? Shall we fall down in prostration to that which you (O Muhammad SAW) command us?" And it increases in them only aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed be He Who has placed in the heaven big stars, and has placed therein a great lamp (sun), and a moon giving light.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And He it is Who has put the night and the day in succession, for such who desires to remember or desires to show his gratitude.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the slaves of the Most Beneficent (Allah) are those who walk on the earth in humility and sedateness, and when the foolish address them (with bad words) they reply back with mild words of gentleness.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And those who spend the night before their Lord, prostrate and standing.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And those who say: ``Our Lord! Avert from us the torment of Hell. Verily! Its torment is ever an inseparable, permanent punishment."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Evil indeed it (Hell) is as an abode and as a place to dwell.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those, who, when they spend, are neither extravagant nor niggardly, but hold a medium (way) between those (extremes).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who invoke not any other ilah (god) along with Allah, nor kill such life as Allah has forbidden, except for just cause, nor commit illegal sexual intercourse and whoever does this shall receive the punishment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
The torment will be doubled to him on the Day of Resurrection, and he will abide therein in disgrace;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Except those who repent and believe (in Islamic Monotheism), and do righteous deeds, for those, Allah will change their sins into good deeds, and Allah is Oft-Forgiving, Most Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whosoever repents and does righteous good deeds, then verily, he repents towards Allah with true repentance.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who do not witness falsehood, and if they pass by some evil play or evil talk, they pass by it with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when they are reminded of the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord, fall not deaf and blind thereat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who say: ``Our Lord! Bestow on us from our wives and our offspring who will be the comfort of our eyes, and make us leaders for the Muttaqun" (pious - see V. 2:2 and the footnote of V. 3:164)."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those will be rewarded with the highest place (in Paradise) because of their patience. Therein they shall be met with greetings and the word of peace and respect.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiding therein; excellent it is as an abode, and as a place to dwell.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say (O Muhammad SAW to the disbelievers): ``My Lord pays attention to you only because of your invocation to Him. But now you have indeed denied (Him). So the torment will be yours for ever (inseparable permanent punishment)."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta-Sin-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are the Verses of the manifest Book [this Quran, which was promised by Allah in the Taurat (Torah) and the Injeel (Gospel), makes things clear].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
It may be that you (O Muhammad SAW) are going to kill yourself with grief, that they do not become believers [in your Risalah (Messengership) and in your Message of Islamic Monotheism].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We could send down to them from the heaven a sign, to which they would bend their necks in humility.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
And never comes there unto them a Reminder as a recent revelation from the Most Beneficent (Allah), but they turn away therefrom.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
So they have indeed denied (the truth - this Quran), then the news of what they mocked at, will come to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Do they not observe the earth, how much of every good kind We cause to grow therein?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Verily, in this is an Ayah (proof or sign), yet most of them (polytheists, pagans, etc., who do not believe in Resurrection) are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And verily, your Lord! He is truly the All-Mighty, the Most Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And (remember) when your Lord called Musa (Moses) (saying): ``Go to the people who are Zalimun (polytheists and wrong-doing),\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
The people of Fir'aun (Pharaoh). Will they not fear Allah and become righteous?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: ``My Lord! Verily, I fear that they will belie me,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
``And my breast straitens, and my tongue expresses not well. So send for Harun (Aaron) (to come along with me).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
``And they have a charge of crime against me, and I fear they will kill me."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
Allah said: ``Nay! Go you both with Our Signs. Verily! We shall be with you, listening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
``And when you both come to Fir'aun (Pharaoh), say: 'We are the Messengers of the Lord of the 'Alamin (mankind, jinns and all that exists),\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
``So allow the Children of Israel to go with us.' ``\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
[Fir'aun (Pharaoh)] said [to Musa (Moses)]: ``Did we not bring you up among us as a child? And you did dwell many years of your life with us.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
``And you did your deed, which you did (i.e. the crime of killing a man). And you are one of the ingrates."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Musa (Moses) said: ``I did it then, when I was an ignorant (as regards my Lord and His Message).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
``So I fled from you when I feared you. But my Lord has granted me Hukman (i.e. religious knowledge, right judgement of the affairs and Prophethood), and appointed me as one of the Messengers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
``And this is the past favour with which you reproach me, that you have enslaved the Children of Israel."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Fir'aun (Pharaoh) said: ``And what is the Lord of the 'Alamin (mankind, jinns and all that exists)?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
Musa (Moses) said: ``Lord of the heavens and the earth, and all that is between them, if you seek to be convinced with certainty."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
Fir'aun (Pharaoh) said to those around: ``Do you not hear (what he says)?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
Musa (Moses) said: ``Your Lord and the Lord of your ancient fathers!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
Fir'aun (Pharaoh) said: ``Verily, your Messenger who has been sent to you is a madman!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
Musa (Moses) said: ``Lord of the east and the west, and all that is between them, if you did but understand!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
Fir'aun (Pharaoh) said: ``If you choose an ilah (god) other than me, I will certainly put you among the prisoners."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
Musa (Moses) said: ``Even if I bring you something manifest (and convincing)?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
Fir'aun (Pharaoh) said: ``Bring it forth then, if you are of the truthful!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So [Musa (Moses)] threw his stick, and behold, it was a serpent, manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew out his hand, and behold, it was white to all beholders!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
[Fir'aun (Pharaoh)] said to the chiefs around him: ``Verily! This is indeed a well-versed sorcerer.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
``He wants to drive you out of your land by his sorcery, then what is it your counsel, and what do you command?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: ``Put him off and his brother (for a while), and send callers to the cities\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
``To bring up to you every well-versed sorcerer."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the sorcerers were assembled at a fixed time on a day appointed.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said to the people: ``Are you (too) going to assemble?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
``That we may follow the sorcerers [who were on Fir'aun's (Pharaoh) religion of disbelief] if they are the winners."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
So when the sorcerers arrived, they said to Fir'aun (Pharaoh): ``Will there surely be a reward for us if we are the winners?"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: ``Yes, and you shall then verily be of those brought near (to myself)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Musa (Moses) said to them: ``Throw what you are going to throw!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they threw their ropes and their sticks, and said: ``By the might of Fir'aun (Pharaoh), it is we who will certainly win!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Musa (Moses) threw his stick, and behold, it swallowed up all the falsehoods which they showed!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
And the sorcerers fell down prostrate.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
Saying: ``We believe in the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
``The Lord of Musa (Moses) and Harun (Aaron)."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
[Fir'aun (Pharaoh)] said: ``You have believed in him before I give you leave. Surely, he indeed is your chief, who has taught you magic! So verily, you shall come to know. Verily, I will cut off your hands and your feet on opposite sides, and I will crucify you all."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: ``No harm! Surely, to our Lord (Allah) we are to return;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
``Verily! We really hope that our Lord will forgive us our sins, as we are the first of the believers [in Musa (Moses) and in the Monotheism which he has brought from Allah]."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We inspired Musa (Moses), saying: ``Take away My slaves by night, verily, you will be pursued."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Fir'aun (Pharaoh) sent callers to (all) the cities.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
(Saying): ``Verily! These indeed are but a small band.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
``And verily, they have done what has enraged us;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
``But we are host all assembled, amply fore-warned."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So, We expelled them from gardens and springs,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
Treasures, and every kind of honourable place.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Thus [We turned them (Pharaoh's people) out] and We caused the Children of Israel to inherit them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
So they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two hosts saw each other, the companions of Musa (Moses) said: ``We are sure to be overtaken."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
[Musa (Moses)] said: ``Nay, verily! With me is my Lord, He will guide me."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We inspired Musa (Moses) (saying): ``Strike the sea with your stick." And it parted, and each separate part (of that sea water) became like the huge, firm mass of a mountain.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
Then We brought near the others [Fir'aun's (Pharaoh) party] to that place.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Musa (Moses) and all those with him.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Verily! In this is indeed a sign (or a proof), yet most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And verily, your Lord! He is truly the All-Mighty, the Most Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the story of Ibrahim (Abraham).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said to his father and his people: ``What do you worship?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said: ``We worship idols, and to them we are ever devoted."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said: ``Do they hear you, when you call (on them)?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
``Or do they benefit you or do they harm (you)?"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said: ``Nay, but we found our fathers doing so."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: ``Do you observe that which you have been worshipping,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
``You and your ancient fathers?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
``Verily! They are enemies to me, save the Lord of the 'Alamin (mankind, jinns and all that exists);\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
``Who has created me, and it is He Who guides me;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
``And it is He Who feeds me and gives me to drink.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
``And when I am ill, it is He who cures me.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
``And Who will cause me to die, and then will bring me to life (again);\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
``And Who, I hope will forgive me my faults on the Day of Recompense, (the Day of Resurrection),"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord! Bestow Hukman (religious knowledge, right judgement of the affairs and Prophethood) on me, and join me with the righteous;\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And grant me an honourable mention in later generations;\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And make me one of the inheritors of the Paradise of Delight;\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father, verily he is of the erring;\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And disgrace me not on the Day when (all the creatures) will be resurrected;\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day whereon neither wealth nor sons will avail,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
Except him who brings to Allah a clean heart [clean from Shirk (polytheism) and Nifaq (hypocrisy)].\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise will be brought near to the Muttaqun (pious - see V. 2:2).\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And the (Hell) Fire will be placed in full view of the erring.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said to them: ``Where are those (the false gods whom you used to set up as rivals with Allah) that you used to worship\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
``Instead of Allah? Can they help you or (even) help themselves?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then they will be thrown on their faces into the (Fire), They and the Ghawun (devils, and those who were in error).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And the whole hosts of Iblis (Satan) together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
They will say while contending therein,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
By Allah, we were truly in a manifest error,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
When We held you (false gods) as equals (in worship) with the Lord of the 'Alamin (mankind, jinns and all that exists);\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
And none has brought us into error except the Mujrimun [Iblis (Satan) and those of human beings who commit crimes, murderers, polytheists, oppressors, etc.].\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
Now we have no intercessors,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
Nor a close friend (to help us).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
(Alas!) If we only had a chance to return (to the world), we shall truly be among the believers!\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Verily! In this is indeed a sign, yet most of them are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And verily, your Lord! He is truly the All-Mighty, the Most Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Nuh (Noah) belied the Messengers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their brother Nuh (Noah) said to them: ``Will you not fear Allah and obey Him?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
``I am a trustworthy Messenger to you.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
``No reward do I ask of you for it (my Message of Islamic Monotheism), my reward is only from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
``So keep your duty to Allah, fear Him and obey me."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said: ``Shall we believe in you, when the meanest (of the people) follow you?"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: ``And what knowledge have I of what they used to do?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
``Their account is only with my Lord, if you could (but) know.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
``And I am not going to drive away the believers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am only a plain warner."\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: ``If you cease not, O Nuh (Noah)! You will surely be among those stoned (to death)."\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: ``My Lord! Verily, my people have belied me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
Therefore judge You between me and them, and save me and those of the believers who are with me."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
And We saved him and those with him in the laden ship.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then We drowned the rest (disbelievers) thereafter.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And verily! Your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
'Ad (people) belied the Messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said to them: ``Will you not fear Allah and obey Him?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
``Verily! I am a trustworthy Messenger to you.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
``No reward do I ask of you for it (my Message of Islamic Monotheism), my reward is only from the Lord of the 'Alamin (mankind, jinns, and all that exists).\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
``Do you build high palaces on every high place, while you do not live in them?\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
``And do you get for yourselves palaces (fine buildings) as if you will live therein for ever.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
``And when you seize, seize you as tyrants?\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
``And keep your duty to Him, fear Him Who has aided you with all (good things) that you know.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
``He has aided you with cattle and children.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
``And gardens and springs.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
``Verily, I fear for you the torment of a Great Day."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said: ``It is the same to us whether you preach or be not of those who preach.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
``This is no other than the false-tales and religion of the ancients, [Tafsir At-Tabari, Vol. 19, Page 97]\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
``And we are not going to be punished."\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they belied him, and We destroyed them. Verily! In this is indeed a sign, yet most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And verily! Your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamud (people) belied the Messenger.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Salih (Saleh) said to them: ``Will you not fear Allah and obey Him?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
``I am a trustworthy Messenger to you.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
``No reward do I ask of you for it (my Message of Islamic Monotheism), my reward is only from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
``Will you be left secure in that which you have here?\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
``In gardens and springs.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
And green crops (fields etc.) and date-palms with soft spadix.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
``And you carve houses out of mountains with great skill.\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
``And follow not the command of Al-Musrifun [i.e. their chiefs, leaders who were polytheists, criminals and sinners],\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
``Who make mischief in the land, and reform not."\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said: ``You are only of those bewitched!\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
``You are but a human being like us. Then bring us a sign if you are of the truthful."\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: ``Here is a she-camel; it has a right to drink (water), and you have a right to drink (water) (each) on a day, known.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
``And touch her not with harm, lest the torment of a Great Day seize you."\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they killed her, and then they became regretful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So the torment overtook them. Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And verily! Your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The prople of Lout (Lot) (those dwelt in the towns of Sodom in Palestine) belied the Messengers.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lout (Lot) said to them: ``Will you not fear Allah and obey Him?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
``Verily! I am a trustworthy Messenger to you.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
``No reward do I ask of you for it (my Message of Islamic Monotheism), my reward is only from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
``Go you in unto the males of the 'Alamin (mankind),\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
``And leave those whom Allah has created for you to be your wives? Nay, you are a trespassing people!"\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: ``If you cease not. O Lout (Lot)! Verily, you will be one of those who are driven out!"\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: ``I am, indeed, of those who disapprove with severe anger and fury your (this evil) action (of sodomy).\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
``My Lord! Save me and my family from what they do."\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We saved him and his family, all,\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except an old woman (his wife) among those who remained behind.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Then afterward We destroyed the others.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained on them a rain (of torment). And how evil was the rain of those who had been warned.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And verily! Your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The dwellers of Al-Aiyka [near Madyan (Midian)] belied the Messengers.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shu'aib (Shuaib) said to them: ``Will you not fear Allah (and obey Him)?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
``I am a trustworthy Messenger to you.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
``So fear Allah, keep your duty to Him, and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
``No reward do I ask of you for it (my Message of Islamic Monotheism), my reward is only from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
``Give full measure, and cause no loss (to others).\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
``And weigh with the true and straight balance.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
``And defraud not people by reducing their things, nor do evil, making corruption and mischief in the land.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
``And fear Him Who created you and the generations of the men of old."\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: ``You are only one of those bewitched!\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
``You are but a human being like us and verily, we think that you are one of the liars!\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
``So cause a piece of the heaven to fall on us, if you are of the truthful!"\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said: ``My Lord is the Best Knower of what you do."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they belied him, so the torment of the day of shadow (a gloomy cloud) seized them, indeed that was the torment of a Great Day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And verily! Your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And truly, this (the Quran) is a revelation from the Lord of the 'Alamin (mankind, jinns and all that exists),\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
Which the trustworthy Ruh [Jibrael (Gabriel)] has brought down;\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon your heart (O Muhammad SAW) that you may be (one) of the warners,\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In the plain Arabic language.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And verily, it (the Quran, and its revelation to Prophet Muhammad SAW) is (announced) in the Scriptures [i.e. the Taurat (Torah) and the Injeel (Gospel)] of former people.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a sign to them that the learned scholars (like 'Abdullah bin Salam who embraced Islam) of the Children of Israel knew it (as true)?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And if We had revealed it (this Quran) unto any of the non-Arabs,\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had recited it unto them, they would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus have We caused it (the denial of the Quran) to enter the hearts of the Mujrimun (criminals, polytheists, sinners, etc.).\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they see the painful torment;\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
It shall come to them of a sudden, while they perceive it not;\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say: ``Can we be respited?"\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Would they then wish for Our Torment to be hastened on?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Tell Me, if We do let them enjoy for years,\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And afterwards comes to them that (punishment) which they had been promised!\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
All that with which they used to enjoy shall not avail them.\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And never did We destroy a township, but it had its warners\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
By way of reminder, and We have never been unjust.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
And it is not the Shayatin (devils) who have brought it (this Quran) down,\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
Neither would it suit them, nor they can (produce it).\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Verily, they have been removed far from hearing it.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So invoke not with Allah another ilah (god) lest you be among those who receive punishment.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn your tribe (O Muhammad SAW) of near kindred.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And be kind and humble to the believers who follow you.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
Then if they disobey you, say: ``I am innocent of what you do."\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put your trust in the All-Mighty, the Most Merciful,\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who sees you (O Muhammad SAW) when you stand up (alone at night for Tahajjud prayers).\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And your movements among those who fall prostrate (along with you to Allah in the five compulsory congregational prayers).\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Verily! He, only He, is the All-Hearer, the All-Knower.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you (O people!) upon whom the Shayatin (devils) descend?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every lying (one who tells lies), sinful person.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
Who gives ear (to the devils and they pour what they may have heard of the unseen from the angels), and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
As for the poets, the erring follow them,\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
See you not that they speak about every subject (praising others right or wrong) in their poetry?\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And that they say what they do not do.\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those who believe (in the Oneness of Allah Islamic Monotheism), and do righteous deeds, and remember Allah much, and reply back (in poetry) to the unjust poetry (which the pagan poets utter against the Muslims). And those who do wrong will come to know by what overturning they will be overturned.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta-Sin. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. These are the Verses of the Quran, and (it is) a Book (that makes things) clear;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guide (to the Right Path); and glad tidings for the believers [who believe in the Oneness of Allah (i.e. Islamic Monotheism)].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Those who perform As-Salat (Iqamat-as-Salat) and give Zakat and they believe with certainty in the Hereafter (resurrection, recompense of their good and bad deeds, Paradise and Hell, etc.).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Verily, those who believe not in the Hereafter, We have made their deeds fair-seeming to them, so they wander about blindly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
They are those for whom there will be an evil torment (in this world). And in the Hereafter they will be the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
And verily, you (O Muhammad SAW) are receiving the Quran from the One, All-Wise, All-Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
(Remember) when Musa (Moses) said to his household: ``Verily! I have seen a fire, I will bring you from there some information, or I will bring you a burning brand, that you may warm yourselves."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when he came to it, he was called: ``Blessed is whosoever is in the fire, and whosoever is round about it! And glorified be Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
``O Musa (Moses)! Verily! It is I, Allah, the All-Mighty, the All-Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
``And throw down your stick!" But when he saw it moving as if it were a snake, he turned in flight, and did not look back. (It was said): ``O Musa (Moses)! Fear not, verily! The Messengers fear not in front of Me.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
``Except him who has done wrong and afterwards has changed evil for good, then surely, I am Oft-Forgiving, Most Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
``And put your hand into your bosom, it will come forth white without hurt. (These are) among the nine signs (you will take) to Fir'aun (Pharaoh) and his people, they are a people who are the Fasiqun (rebellious, disobedient to Allah).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) came to them, clear to see, they said: ``This is a manifest magic."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they belied them (those Ayat) wrongfully and arrogantly, though their ownselves were convinced thereof [i.e. those (Ayat) are from Allah, and Musa (Moses) is the Messenger of Allah in truth, but they disliked to obey Musa (Moses), and hated to believe in his Message of Monotheism]. So see what was the end of the Mufsidun (disbelievers, disobedient to Allah, evil-doers, liars.).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And indeed We gave knowledge to Dawud (David) and Sulaiman (Solomon), and they both said: ``All the praises and thanks be to Allah, Who has preferred us above many of His believing slaves!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Sulaiman (Solomon) inherited (the knowledge of) Dawud (David). He said: ``O mankind! We have been taught the language of birds, and on us have been bestowed all things. This, verily, is an evident grace (from Allah)."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And there were gathered before Sulaiman (Solomon) his hosts of jinns and men, and birds, and they all were set in battle order (marching forwards).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Till, when they came to the valley of the ants, one of the ants said: ``O ants! Enter your dwellings, lest Sulaiman (Solomon) and his hosts crush you, while they perceive not."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
So he [Sulaiman (Solomon)] smiled, amused at her speech and said: ``My Lord! Inspire and bestow upon me the power and ability that I may be grateful for Your Favours which You have bestowed on me and on my parents, and that I may do righteous good deeds that will please You, and admit me by Your Mercy among Your righteous slaves."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
He inspected the birds, and said: ``What is the matter that I see not the hoopoe? Or is he among the absentees?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
``I will surely punish him with a severe torment, or slaughter him, unless he brings me a clear reason."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But the hoopoe stayed not long, he (came up and) said: ``I have grasped (the knowledge of a thing) which you have not grasped and I have come to you from Saba' (Sheba) with true news.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
``I found a woman ruling over them, and she has been given all things that could be possessed by any ruler of the earth, and she has a great throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
``I found her and her people worshipping the sun instead of Allah, and Shaitan (Satan) has made their deeds fair-seeming to them, and has barred them from (Allah's) Way, so they have no guidance,"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
Al-La (this word has two interpretations) (A) [As Shaitan (Satan) has barred them from Allah's Way] so that they do not worship (prostrate before) Allah, or (B) So that they may worship (prostrate before) Allah, Who brings to light what is hidden in the heavens and the earth, and knows what you conceal and what you reveal. [Tafsir At-Tabari, Vol. 19, Page 149]\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah, La ilaha illa Huwa (none has the right to be worshipped but He), the Lord of the Supreme Throne!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
[Sulaiman (Solomon)] said: ``We shall see whether you speak the truth or you are (one) of the liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
``Go you with this letter of mine, and deliver it to them, then draw back from them, and see what (answer) they return."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said: ``O chiefs! Verily! Here is delivered to me a noble letter,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
``Verily! It is from Sulaiman (Solomon), and verily! It (reads): In the Name of Allah, the Most Beneficent, the Most Merciful;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
``Be you not exalted against me, but come to me as Muslims (true believers who submit to Allah with full submission)' ``\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: ``O chiefs! Advise me in (this) case of mine. I decide no case till you are present with me."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: ``We have great strength, and great ability for war, but it is for you to command; so think over what you will command."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: ``Verily! Kings, when they enter a town (country), they despoil it, and make the most honourable amongst its people low. And thus they do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
``But verily! I am going to send him a present, and see with what (answer) the messengers return."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
So when (the messengers with the present) came to Sulaiman (Solomon), he said: ``Will you help me in wealth? What Allah has given me is better than that which He has given you! Nay, you rejoice in your gift!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
[Then Sulaiman (Solomon) said to the chief of her messengers who brought the present]: ``Go back to them. We verily shall come to them with hosts that they cannot resist, and we shall drive them out from there in disgrace, and they will be abased."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said: ``O chiefs! Which of you can bring me her throne before they come to me surrendering themselves in obedience?"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An Ifrit (strong) from the jinns said: ``I will bring it to you before you rise from your place (council). And verily, I am indeed strong, and trustworthy for such work."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
One with whom was knowledge of the Scripture said: ``I will bring it to you within the twinkling of an eye!" then when [Sulaiman (Solomon)] saw it placed before him, he said: ``This is by the Grace of my Lord to test me whether I am grateful or ungrateful! And whoever is grateful, truly, his gratitude is for (the good of) his ownself, and whoever is ungrateful, (he is ungrateful only for the loss of his ownself). Certainly! My Lord is Rich (Free of all wants), Bountiful."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said: ``Disguise her throne for her that we may see whether she will be guided (to recognise her throne), or she will be one of those not guided."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So when she came, it was said (to her): ``Is your throne like this?" She said: ``(It is) as though it were the very same." And [Sulaiman (Solomon) said]: ``Knowledge was bestowed on us before her, and we were submitted to Allah (in Islam as Muslims before her)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And that which she used to worship besides Allah has prevented her (from Islam), for she was of a disbelieving people.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her: ``Enter As-Sarh" [(a glass surface with water underneath it) or a palace], but when she saw it, she thought it was a pool, and she (tucked up her clothes) uncovering her legs, Sulaiman (Solomon) said: ``Verily, it is Sarh [(a glass surface with water underneath it) or a palace] paved smooth with slab of glass." She said: ``My Lord! Verily, I have wronged myself, and I submit (in Islam, together with Sulaiman (Solomon), to Allah, the Lord of the 'Alamin (mankind, jinns and all that exists)."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And indeed We sent to Thamud their brother Salih (Saleh), saying: ``Worship Allah (Alone and none else). Then look! They became two parties (believers and disbelievers) quarreling with each other."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said: ``O my people! Why do you seek to hasten the evil (torment) before the good (Allah's Mercy)? Why seek you not the Forgiveness of Allah, that you may receive mercy?"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: ``We augur ill omen from you and those with you." He said: ``Your ill omen is with Allah; nay, but you are a people that are being tested."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were in the city nine men (from the sons of their chiefs), who made mischief in the land, and would not reform.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: ``Swear one to another by Allah that we shall make a secret night attack on him and his household, and afterwards we will surely say to his near relatives: 'We witnessed not the destruction of his household, and verily! We are telling the truth.'"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
So they plotted a plot, and We planned a plan, while they perceived not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Then see how was the end of their plot! Verily! We destroyed them and their nation, all together.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
These are their houses in utter ruin, for they did wrong. Verily, in this is indeed an Ayah (a lesson or a sign) for people who know.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed, and used to fear Allah, and keep their duty to Him.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And (remember) Lout (Lot)! When he said to his people. Do you commit Al-Fahishah (evil, great sin, every kind of unlawful sexual intercourse, sodomy, etc.) while you see (one another doing evil without any screen, etc.)?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
``Do you approach men in your lusts rather than women? Nay, but you are a people who behave senselessly."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
There was no other answer given by his people except that they said: ``Drive out the family of Lout (Lot) from your city. Verily, these are men who want to be clean and pure!"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So We saved him and his family, except his wife. We destined her to be of those who remained behind.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained down on them a rain (of stones). So evil was the rain of those who were warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say (O Muhammad SAW): ``Praise and thanks be to Allah, and peace be on His slaves whom He has chosen (for His Message)! Is Allah better, or (all) that you ascribe as partners (to Him)?" (Of course, Allah is Better).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Is not He (better than your gods) Who created the heavens and the earth, and sends down for you water (rain) from the sky, whereby We cause to grow wonderful gardens full of beauty and delight? It is not in your ability to cause the growth of their trees. Is there any ilah (god) with Allah? Nay, but they are a people who ascribe equals (to Him)!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Is not He (better than your gods) Who has made the earth as a fixed abode, and has placed rivers in its midst, and has placed firm mountains therein, and has set a barrier between the two seas (of salt and sweet water). Is there any ilah (god) with Allah? Nay, but most of them know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Is not He (better than your gods) Who responds to the distressed one, when he calls Him, and Who removes the evil, and makes you inheritors of the earth, generations after generations. Is there any ilah (god) with Allah? Little is that you remember!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Is not He (better than your gods) Who guides you in the darkness of the land and the sea, and Who sends the winds as heralds of glad tidings, going before His Mercy (rain)? Is there any ilah (god) with Allah? High Exalted be Allah above all that they associate as partners (to Him)!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Is not He (better than your so-called gods) Who originates creation, and shall thereafter repeat it, and Who provides for you from heaven and earth? Is there any ilah (god) with Allah? Say, ``Bring forth your proofs, if you are truthful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: ``None in the heavens and the earth knows the Ghaib (unseen) except Allah, nor can they perceive when they shall be resurrected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Nay, they have no knowledge of the Hereafter. Nay, they are in doubt about it. Nay, they are blind about it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
And those who disbelieve say: ``When we have become dust, we and our fathers, shall we really be brought forth (again)?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
``Indeed we were promised this, we and our forefathers before, Verily, these are nothing but tales of ancients."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say to them (O Muhammad SAW) ``Travel in the land and see how has been the end of the criminals (those who denied Allah's Messengers and disobeyed Allah)."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And grieve you not for them, nor be straitened (in distress) because of what they plot.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they (the disbelievers in the Oneness of Allah) say: ``When (will) this promise (be fulfilled), if you are truthful?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: ``Perhaps that which you wish to hasten on, may be close behind you.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
``Verily, your Lord is full of Grace for mankind, yet most of them do not give thanks."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And verily, your Lord knows what their breasts conceal and what they reveal.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And there is nothing hidden in the heaven and the earth, but is in a Clear Book (i.e. Al-Lauh Al-Mahfuz).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Verily, this Quran narrates to the Children of Israel most of that about which they differ.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And truly, it (this Quran) is a guide and a mercy to the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Verily, your Lord will decide between them (various sects) by His Judgement. And He is the All-Mighty, the All-Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So put your trust in Allah; surely, you (O Muhammad SAW) are on manifest truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Verily, you cannot make the dead to hear (i.e. benefit them and similarly the disbelievers), nor can you make the deaf to hear the call, when they flee, turning their backs.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor can you lead the blind out of their error, you can only make to hear those who believe in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and who have submitted (themselves to Allah in Islam as Muslims).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word (of torment) is fulfilled against them, We shall bring out from the earth a beast to them, which will speak to them because mankind believed not with certainty in Our Ayat (Verses of the Quran and Prophet Muhammad SAW).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And (remember) the Day when We shall gather out of every nation a troop of those who denied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and (then) they (all) shall be gathered (and driven to the place of reckoning),\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Till, when they come (before their Lord at the place of reckoning), He will say: ``Did you deny My Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) when you comprehended them not in knowledge, or what (else) was it that you used to do?"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word (of torment) will be fulfilled against them, because they have done wrong, and they will be unable to speak (in order to defend themselves).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
See they not that We have made the night for them to rest therein, and the day sight-giving? Verily, in this are Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) for the people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And (remember) the Day on which the Trumpet will be blown and all who are in the heavens and all who are on the earth, will be terrified except him whom Allah will (exempt). And all shall come to Him humbled.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you will see the mountains and think them solid, but they shall pass away as the passing away of the clouds. The Work of Allah, Who perfected all things, verily! He is Well-Acquainted with what you do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoever brings a good deed (i.e. Belief in the Oneness of Allah along with every deed of righteousness), will have better than its worth, and they will be safe from the terror on that Day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whoever brings an evil (deed) (i.e. Shirk polytheism, disbelief in the Oneness of Allah and every evil sinful deed), they will be cast down (prone) on their faces in the Fire. (And it will be said to them) ``Are you being recompensed anything except what you used to do?"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
I (Muhammad SAW) have been commanded only to worship the Lord of this city (Makkah), Him Who has sanctified it and His is everything. And I am commanded to be from among the Muslims (those who submit to Allah in Islam).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And to recite the Quran, so whosoever receives guidance, receives it for the good of his ownself, and whosoever goes astray, say (to him): ``I am only one of the warners."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say [(O Muhammad SAW) to these polytheists and pagans etc.]: ``All the praises and thanks be to Allah. He will show you His Ayat (signs, in yourselves, and in the universe or punishments, etc.), and you shall recognise them. And your Lord is not unaware of what you do."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta-Sin-Mim [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are Verses of the manifest Book (that makes clear truth from falsehood, good from evil, etc.).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We recite to you some of the news of Musa (Moses) and Fir'aun (Pharaoh) in truth, for a people who believe (those who believe in this Quran, and in the Oneness of Allah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Verily, Fir'aun (Pharaoh) exalted himself in the land and made its people sects, weakening (oppressing) a group (i.e. Children of Israel) among them, killing their sons, and letting their females live. Verily, he was of the Mufsidun (i.e. those who commit great sins and crimes, oppressors, tyrants, etc.).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We wished to do a favour to those who were weak (and oppressed) in the land, and to make them rulers and to make them the inheritors,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And to establish them in the land, and We let Fir'aun (Pharaoh) and Haman and their hosts receive from them that which they feared.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired the mother of Musa (Moses), (saying): ``Suckle him [Musa (Moses)], but when you fear for him, then cast him into the river and fear not, nor grieve. Verily! We shall bring him back to you, and shall make him one of (Our) Messengers."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Then the household of Fir'aun (Pharaoh) picked him up, that he might become for them an enemy and a (cause of) grief. Verily! Fir'aun (Pharaoh), Haman and their hosts were sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And the wife of Fir'aun (Pharaoh) said: ``A comfort of the eye for me and for you. Kill him not, perhaps he may be of benefit to us, or we may adopt him as a son." And they perceive not (the result of that).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And the heart of the mother of Musa (Moses) became empty [from every thought, except the thought of Musa (Moses)]. She was very near to disclose his (case, i.e. the child is her son), had We not strengthened her heart (with Faith), so that she might remain as one of the believers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said to his [Musa's (Moses)] sister: ``Follow him." So she (his sister) watched him from a far place secretly, while they perceived not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had already forbidden (other) foster suckling mothers for him, until she (his sister came up and) said: ``Shall I direct you to a household who will rear him for you, and sincerely they will look after him in a good manner?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So did We restore him to his mother, that she might be delighted, and that she might not grieve, and that she might know that the Promise of Allah is true. But most of them know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he attained his full strength, and was perfect (in manhood), We bestowed on him Hukman (Prophethood, right judgement of the affairs) and religious knowledge [of the religion of his forefathers i.e. Islamic Monotheism]. And thus do We reward the Muhsinun (i.e. good doers - see the footnote of V. 9:120).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city at a time of unawareness of its people, and he found there two men fighting, - one of his party (his religion - from the Children of Israel), and the other of his foes. The man of his (own) party asked him for help against his foe, so Musa (Moses) struck him with his fist and killed him. He said: ``This is of Shaitan's (Satan) doing, verily, he is a plain misleading enemy."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said: ``My Lord! Verily, I have wronged myself, so forgive me." Then He forgave him. Verily, He is the Oft-Forgiving, the Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: ``My Lord! For that with which You have favoured me, I will never more be a helper for the Mujrimun (criminals, disobedient to Allah, polytheists, sinners, etc.)!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
So he became afraid, looking about in the city (waiting as to what will be the result of his crime of killing), when behold, the man who had sought his help the day before, called for his help (again). Musa (Moses) said to him: ``Verily, you are a plain misleader!"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
Then when he decided to seize the man who was an enemy to both of them, the man said: ``O Musa (Moses)! Is it your intention to kill me as you killed a man yesterday? Your aim is nothing but to become a tyrant in the land, and not to be one of those who do right."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And there came a man running, from the farthest end of the city. He said: ``O Musa (Moses)! Verily, the chiefs are taking counsel together about you, to kill you, so escape. Truly, I am to you of those who give sincere advice."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he escaped from there, looking about in a state of fear. He said: ``My Lord! Save me from the people who are Zalimun (polytheists and wrong-doers)!"\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he went towards (the land of) Madyan (Midian) he said: ``It may be that my Lord guides me to the Right Way."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he arrived at the water of Madyan (Midian) he found there a group of men watering (their flocks), and besides them he found two women who were keeping back (their flocks). He said: ``What is the matter with you?" They said: ``We cannot water (our flocks) until the shepherds take (their flocks). And our father is a very old man."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he watered (their flocks) for them, then he turned back to shade, and said: ``My Lord! Truly, I am in need of whatever good that You bestow on me!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then there came to him one of the two women, walking shyly. She said: ``Verily, my father calls you that he may reward you for having watered (our flocks) for us." So when he came to him and narrated the story, he said: ``Fear you not. You have escaped from the people who are Zalimun (polytheists, disbelievers, and wrong-doers)."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
And said one of them (the two women): ``O my father! Hire him! Verily, the best of men for you to hire is the strong, the trustworthy."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: ``I intend to wed one of these two daughters of mine to you, on condition that you serve me for eight years, but if you complete ten years, it will be (a favour) from you. But I intend not to place you under a difficulty. If Allah will, you will find me one of the righteous."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
He [Musa (Moses)] said: ``That (is settled) between me and you whichever of the two terms I fulfill, there will be no injustice to me, and Allah is Surety over what we say."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
Then, when Musa (Moses) had fulfilled the term, and was travelling with his family, he saw a fire in the direction of Tur (Mount). He said to his family: ``Wait, I have seen a fire; perhaps I may bring to you from there some information, or a burning fire-brand that you may warm yourselves."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
So when he reached it (the fire), he was called from the right side of the valley, in the blessed place from the tree: ``O Musa (Moses)! Verily! I am Allah, the Lord of the 'Alamin (mankind, jinns and all that exists)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
``And throw your stick!" But when he saw it moving as if it were a snake, he turned in flight, and looked not back. (It was said): ``O Musa (Moses)! Draw near, and fear not. Verily, you are of those who are secure.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
``Put your hand in your bosom, it will come forth white without a disease, and draw your hand close to your side to be free from fear (that which you suffered from the snake, and also by that your hand will return to its original state). these are two Burhan (signs, miracles, evidences, proofs) from your Lord to Fir'aun (Pharaoh) and his chiefs. Verily, they are the people who are Fasiqun (rebellious, disobedient to Allah).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said: ``My Lord! I have killed a man among them, and I fear that they will kill me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
``And my brother Harun (Aaron) he is more eloquent in speech than me so send him with me as a helper to confirm me. Verily! I fear that they will belie me."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
Allah said: ``We will strengthen your arm through your brother, and give you both power, so they shall not be able to harm you, with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), you two as well as those who follow you will be the victors."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
Then when Musa (Moses) came to them with Our Clear Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they said: ``This is nothing but invented magic. Never did we hear of this among our fathers of old."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Musa (Moses) said: ``My Lord knows best him who came with guidance from Him, and whose will be the happy end in the Hereafter. Verily, the Zalimun (wrong-doers, polytheists and disbelievers in the Oneness of Allah) will not be successful."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
Fir'aun (Pharaoh) said: ``O chiefs! I know not that you have an ilah (a god) other than me, so kindle for me (a fire), O Haman, to bake (bricks out of) clay, and set up for me a Sarhan (a lofty tower, or palace, etc.) in order that I may look at (or look for) the Ilah (God) of Musa (Moses); and verily, I think that he [Musa (Moses)] is one of the liars."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his hosts were arrogant in the land, without right, and they thought that they would never return to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
So We seized him and his hosts, and We threw them all into the sea (and drowned them). So behold (O Muhammad SAW) what was the end of the Zalimun [wrong-doers, polytheists and those who disbelieved in the Oneness of their Lord (Allah), or rejected the advice of His Messenger Musa (Moses)].\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders inviting to the Fire, and on the Day of Resurrection, they will not be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We made a curse to follow them in this world, and on the Day of Resurrection, they will be among Al-Maqbuhun (those who are prevented to receive Allah's Mercy or any good, despised or destroyed, etc.).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And indeed We gave Musa (Moses), after We had destroyed the generations of old, the Scripture [the Taurat (Torah)] as an enlightenment for mankind, and a guidance and a mercy, that they might remember (or receive admonition).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And you (O Muhammad SAW) were not on the western side (of the Mount), when We made clear to Musa (Moses) the commandment, and you were not among those present.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We created generations [after generations i.e. after Musa (Moses)], and long were the ages that passed over them. And you (O Muhammad SAW) were not a dweller among the people of Madyan (Midian), reciting Our Verses to them. But it is We Who kept sending (Messengers).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
And you (O Muhammad SAW) were not at the side of the Tur (Mount) when We did call, [it is said that Allah called the followers of Muhammad SAW, and they answered His Call, or that Allah called Musa (Moses)]. But (you are sent) as a mercy from your Lord, to give warning to a people to whom no warner had come before you, in order that they may remember or receive admonition. [Tafsir At-Tabari, Vol. 20, Page 81].\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
And if (We had) not (sent you to the people of Makkah) in case a calamity should seize them for (the deeds) that their hands have sent forth, they should have said: ``Our Lord! Why did You not send us a Messenger? We should then have followed Your Ayat (Verses of the Quran) and should have been among the believers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when the truth (i.e. Muhammad SAW with his Message) has come to them from Us, they say: ``Why is he not given the like of what was given to Musa (Moses)? Did they not disbelieve in that which was given to Musa (Moses) of old? They say: ``Two kinds of magic [the Taurat (Torah) and the Quran] each helping the other!" And they say: ``Verily! In both we are disbelievers."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say (to them, O Muhammad SAW): ``Then bring a Book from Allah, which is a better guide than these two [the Taurat (Torah) and the Quran], that I may follow it, if you are truthful."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they answer you not (i.e. do not believe in your doctrine of Islamic Monotheism, nor follow you), then know that they only follow their own lusts. And who is more astray than one who follows his own lusts, without guidance from Allah? Verily! Allah guides not the people who are Zalimun (wrong-doers, disobedient to Allah, and polytheists).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And indeed now We have conveyed the Word (this Quran in which is the news of everything to them), in order that they may remember (or receive admonition).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Scripture [i.e. the Taurat (Torah) and the Injeel (Gospel), etc.] before it, - they believe in it (the Quran).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is recited to them, they say: ``We believe in it. Verily, it is the truth from our Lord. Indeed even before it we have been from those who submit themselves to Allah in Islam as Muslims (like 'Abdullah bin Salam and Salman Al-Farisi, etc.).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These will be given their reward twice over, because they are patient, and repel evil with good, and spend (in charity) out of what We have provided them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear Al-Laghw (dirty, false, evil vain talk), they withdraw from it and say: ``To us our deeds, and to you your deeds. Peace be to you. We seek not the ignorant."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Verily! You (O Muhammad SAW) guide not whom you like, but Allah guides whom He wills. And He knows best those who are the guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say: ``If we follow the guidance with you, we would be snatched away from our land." Have We not established for them a secure sanctuary (Makkah), to which are brought fruits of all kinds, a provision from Ourselves, but most of them know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a town (population) have We destroyed, which were thankless for its means of livelihood (disobeyed Allah, and His Messengers, by doing evil deeds and crimes)! And those are their dwellings, which have not been inhabited after them except a little. And verily! We have been the inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
And never will your Lord destroy the towns (populations) until He sends to their mother town a Messenger reciting to them Our Verses. And never would We destroy the towns unless the people thereof are Zalimun (polytheists, wrong-doers, disbelievers in the Oneness of Allah, oppressors and tyrants).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatever you have been given is an enjoyment of the life of (this) world and its adornment, and that (Hereafter) which is with Allah is better and will remain forever. Have you then no sense?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Is he whom We have promised an excellent promise (Paradise), which he will find true, like him whom We have made to enjoy the luxuries of the life of (this) world, then on the Day of Resurrection, he will be among those brought up (to be punished in the Hell-fire)?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
And (remember) the Day when He will call to them, and say: ``Where are My (so-called) partners whom you used to assert?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those about whom the Word will have come true (to be punished) will say: ``Our Lord! These are they whom we led astray. We led them astray, as we were astray ourselves. We declare our innocence (from them) before You. It was not us they worshipped."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said (to them): ``Call upon your (so-called) partners (of Allah), and they will call upon them, but they will give no answer to them, and they will see the torment. (They will then wish) if only they had been guided!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And (remember) the Day (Allah) will call to them, and say: ``What answer gave you to the Messengers?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Then the news of a good answer will be obscured to them on that day, and they will not be able to ask one another.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But as for him who repented (from polytheism and sins, etc.), believed (in the Oneness of Allah, and in His Messenger Muhammad SAW), and did righteous deeds (in the life of this world), then he will be among those who are successful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
And your Lord creates whatsoever He wills and chooses, no choice have they (in any matter). Glorified be Allah, and exalted above all that they associate as partners (with Him).\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And your Lord knows what their breasts conceal, and what they reveal.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah; La ilaha illa Huwa (none has the right to be worshipped but He). His is all praise, in the first (i.e. in this world) and in the last (i.e. in the Hereafter). And for Him is the Decision, and to Him shall you (all) be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say (O Muhammad SAW): ``Tell me! If Allah made night continuous for you till the Day of Resurrection, who is an ilah (a god) besides Allah who could bring you light? Will you not then hear?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say (O Muhammad SAW): ``Tell me! If Allah made day continuous for you till the Day of Resurrection, who is an ilah (a god) besides Allah who could bring you night wherein you rest? Will you not then see?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is out of His Mercy that He has put for you night and day, that you may rest therein (i.e. during the night) and that you may seek of His Bounty (i.e. during the day), and in order that you may be grateful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
And (remember) the Day when He (your Lord Allah) will call them (those who worshipped others along with Allah), and will say: ``Where are My (so-called) partners, whom you used to assert?"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We shall take out from every nation a witness, and We shall say: ``Bring your proof." Then they shall know that the truth is with Allah (Alone), and the lies (false gods) which they invented will disappear from them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Verily, Qarun (Korah) was of Musa's (Moses) people, but he behaved arrogantly towards them. And We gave him of the treasures, that of which the keys would have been a burden to a body of strong men. When his people said to him: ``Do not be glad (with ungratefulness to Allah's Favours). Verily! Allah likes not those who are glad (with ungratefulness to Allah's Favours).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
But seek, with that (wealth) which Allah has bestowed on you, the home of the Hereafter, and forget not your portion of legal enjoyment in this world, and do good as Allah has been good to you, and seek not mischief in the land. Verily, Allah likes not the Mufsidun (those who commit great crimes and sins, oppressors, tyrants, mischief-makers, corrupts).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said: ``This has been given to me only because of knowledge I possess." Did he not know that Allah had destroyed before him generations, men who were stronger than him in might and greater in the amount (of riches) they had collected. But the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.) will not be questioned of their sins (because Allah knows them well, so they will be punished without account).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So he went forth before his people in his pomp. Those who were desirous of the life of the world, said: ``Ah, would that we had the like of what Qarun (Korah) has been given? Verily! He is the owner of a great fortune."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who had been given (religious) knowledge said: ``Woe to you! The Reward of Allah (in the Hereafter) is better for those who believe and do righteous good deeds, and this none shall attain except those who are patient (in following the truth)."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
So We caused the earth to swallow him and his dwelling place. Then he had no group or party to help him against Allah, nor was he one of those who could save themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had desired (for a position like) his position the day before, began to say: ``Know you not that it is Allah Who enlarges the provision or restricts it to whomsoever He pleases of His slaves. Had it not been that Allah was Gracious to us, He could have caused the earth to swallow us up (also)! Know you not that the disbelievers will never be successful.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That home of the Hereafter (i.e. Paradise), We shall assign to those who rebel not against the truth with pride and oppression in the land nor do mischief by committing crimes. And the good end is for the Muttaqun (pious - see V. 2:2).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whosoever brings good (Islamic Monotheism along with righteous deeds), he shall have the better thereof, and whosoever brings evil (polytheism along with evil deeds) then, those who do evil deeds will only be requited for what they used to do.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Verily, He Who has given you (O Muhammad SAW) the Quran (i.e. ordered you to act on its laws and to preach it to others) will surely bring you back to the Ma'ad (place of return, either to Makkah or to Paradise after your death, etc.). Say (O Muhammad SAW): ``My Lord is Aware of him who brings guidance, and he who is in manifest error."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And you were not expecting that the Book (this Quran) would be sent down to you, but it is a mercy from your Lord. So never be a supporter of the disbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let them not turn you (O Muhammad SAW) away from (preaching) the Ayat (revelations and verses) of Allah after they have been sent down to you, and invite (men) to (believe in) your Lord [i.e. in the Oneness (Tauhid) of Allah (1) Oneness of the Lordship of Allah; (2) Oneness of the worship of Allah; (3) Oneness of the Names and Qualities of Allah], and be not of Al-Mushrikun (those who associate partners with Allah, e.g. polytheists, pagans, idolaters, those who disbelieve in the Oneness of Allah and deny the Prophethood of Messenger Muhammad SAW).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And invoke not any other ilah (god) along with Allah, La ilaha illa Huwa (none has the right to be worshipped but He). Everything will perish save His Face. His is the Decision, and to Him you (all) shall be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do people think that they will be left alone because they say: ``We believe," and will not be tested.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
And We indeed tested those who were before them. And Allah will certainly make (it) known (the truth of) those who are true, and will certainly make (it) known (the falsehood of) those who are liars, (although Allah knows all that before putting them to test).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or those who do evil deeds think that they can outstrip Us (i.e. escape Our Punishment)? Evil is that which they judge!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoever hopes for the Meeting with Allah, then Allah's Term is surely coming. and He is the All-Hearer, the All-Knower.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whosoever strives, he strives only for himself. Verily, Allah is free of all wants from the 'Alamin (mankind, jinns, and all that exists).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
Those who believe [in the Oneness of Allah (Monotheism) and in Messenger Muhammad SAW, and do not apostate because of the harm they receive from the polytheists], and do righteous good deeds, surely, We shall remit from them their evil deeds and shall reward them according to the best of that which they used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
And We have enjoined on man to be good and dutiful to his parents, but if they strive to make you join with Me (in worship) anything (as a partner) of which you have no knowledge, then obey them not. Unto Me is your return, and I shall tell you what you used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And for those who believe (in the Oneness of Allah and other items of Faith) and do righteous good deeds, surely, We shall make them enter in (the enterance of) the righteous (i.e. in Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Of mankind are some who say: ``We believe in Allah," but if they are made to suffer for the sake of Allah, they consider the trial of mankind as Allah's punishment, and if victory comes from your Lord, (the hypocrites) will say: ``Verily! We were with you (helping you)." Is not Allah Best Aware of what is in the breast of the 'Alamin (mankind and jinns).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
Verily, Allah knows those who believe, and verily, He knows the hypocrites [i.e. Allah will test the people with good and hard days to discriminate the good from the wicked (although Allah knows all that before putting them to test)].\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And those who disbelieve say to those who believe: ``Follow our way and we will verily bear your sins," never will they bear anything of their sins. Surely, they are liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
And verily, they shall bear their own loads, and other loads besides their own, and verily, they shall be questioned on the Day of Resurrection about that which they used to fabricate.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And indeed We sent Nuh (Noah) to his people, and he stayed among them a thousand years less fifty years [inviting them to believe in the Oneness of Allah (Monotheism), and discard the false gods and other deities], and the Deluge overtook them while they were Zalimun (wrong-doers, polytheists, disbelievers, etc.).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
Then We saved him and those with him in the ship, and made it (the ship) as an Ayah (a lesson, a warning, etc.) for the 'Alamin (mankind, jinns and all that exists).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And (remember) Ibrahim (Abraham) when he said to his people: ``Worship Allah (Alone), and fear Him, that is better for you if you did but know.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
``You worship besides Allah only idols, and you only invent falsehood. Verily, those whom you worship besides Allah have no power to give you provision, so seek your provision from Allah (Alone), and worship Him (Alone), and be grateful to Him. To Him (Alone) you will be brought back.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
``And if you deny, then nations before you have denied (their Messengers). And the duty of the Messenger is only to convey (the Message) plainly."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
See they not how Allah originates creation, then repeats it. Verily, that is easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: ``Travel in the land and see how (Allah) originated creation, and then Allah will bring forth (resurrect) the creation of the Hereafter (i.e. resurrection after death). Verily, Allah is Able to do all things."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whom He will, and shows mercy to whom He will, and to Him you will be returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
And you cannot escape in the earth or in the heaven. And besides Allah you have neither any Wali (Protector or Guardian) nor any Helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
And those who disbelieve in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah and the Meeting with Him, it is they who have no hope of My Mercy, and it is they who will (have) a painful torment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
So nothing was the answer of [Ibrahim's (Abraham)] people except that they said: ``Kill him or burn him." Then Allah saved him from the fire. Verily, in this are indeed signs for a people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And [Ibrahim (Abraham)] said: ``You have taken (for worship) idols instead of Allah, and the love between you is only in the life of this world, but on the Day of Resurrection, you shall disown each other, and curse each other, and your abode will be the Fire, and you shall have no helper."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
So Lout (Lot) believed in him [Ibrahim's (Abraham) Message of Islamic Monotheism]. He [Ibrahim (Abraham)] said: ``I will emigrate for the sake of my Lord. Verily, He is the All-Mighty, the All-Wise."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We bestowed on him [Ibrahim (Abraham)], Ishaque (Isaac) and Ya'qub (Jacob), and ordained among his offspring Prophethood and the Book [i.e. the Taurat (Torah) (to Musa - Moses), the Injeel (Gospel) (to 'Iesa - Jesus), the Quran (to Muhammad SAW), all from the offspring of Ibrahim (Abraham)], and We granted him his reward in this world, and verily, in the Hereafter he is indeed among the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And (remember) Lout (Lot), when he said to his people: ``You commit Al-Fahishah (sodomy the worst sin) which none has preceded you in (committing) it in the 'Alamin (mankind and jinns)."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
``Verily, you do sodomy with men, and rob the wayfarer (travellers, etc.)! And practise Al-Munkar (disbelief and polytheism and every kind of evil wicked deed) in your meetings." But his people gave no answer except, that they said: ``Bring Allah's Torment upon us if you are one of the truthful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said: ``My Lord! Give me victory over the people who are Mufsidun (those who commit great crimes and sins, oppressors, tyrants, mischief-makers, corrupts).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our Messengers came to Ibrahim (Abraham) with the glad tidings they said: ``Verily, we are going to destroy the people of this [Lout's (Lot's)] town (i.e. the town of Sodom in Palestine) truly, its people have been Zalimun [wrong-doers, polytheists and disobedient to Allah, and have also belied their Messenger Lout (Lot)]."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
Ibrahim (Abraham) said: ``But there is Lout (Lot) in it." They said:"We know better who is there, we will verily save him [Lout (Lot)] and his family, except his wife, she will be of those who remain behind (i.e. she will be destroyed along with those who will be destroyed from her folk)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our Messengers came to Lout (Lot), he was grieved because of them, and felt straitened on their account. They said: ``Have no fear, and do not grieve! Truly, we shall save you and your family, except your wife, she will be of those who remain behind (i.e. she will be destroyed along with those who will be destroyed from her folk).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
Verily, we are about to bring down on the people of this town a great torment from the sky, because they have been rebellious (against Allah's Command)."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And indeed We have left thereof an evident Ayah (a lesson and a warning and a sign the place where the Dead Sea is now in Palestine) for a folk who understand.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to (the people of) Madyan (Midian), We sent their brother Shu'aib (Shuaib). He said: ``O my people! Worship Allah, and hope for (the reward of good deeds by worshipping Allah Alone, on) the last Day, and commit no mischief on the earth as Mufsidun (those who commit great crimes, oppressors, tyrants, mischief-makers, corrupts).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
And they belied him [Shu'aib (Shuaib)], so the earthquake seized them, and they lay (dead), prostrate in their dwellings.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And 'Ad and Thamud (people)! And indeed (their destruction) is clearly apparent to you from their (ruined) dwellings. Shaitan (Satan) made their deeds fair-seeming to them, and turned them away from the (Right) Path, though they were intelligent.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And (We destroyed also) Qarun (Korah), Fir'aun (Pharaoh), and Haman. And indeed Musa (Moses) came to them with clear Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), but they were arrogant in the land, yet they could not outstrip Us (escape Our punishment).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So We punished each (of them) for his sins, of them were some on whom We sent Hasiban (a violent wind with shower of stones) [as the people of Lout (Lot)], and of them were some who were overtaken by As-Saihah [torment - awful cry, etc. (as Thamud or Shu'aib's people)], and of them were some whom We caused the earth to swallow [as Qarun (Korah)], and of them were some whom We drowned [as the people of Nuh (Noah), or Fir'aun (Pharaoh) and his people]. It was not Allah Who wronged them, but they wronged themselves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who take Auliya' (protectors and helpers) other than Allah is as the likeness of a spider, who builds (for itself) a house, but verily, the frailest (weakest) of houses is the spider's house; if they but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Verily, Allah knows what things they invoke instead of Him. He is the All-Mighty, the All-Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And these similitudes We put forward for mankind, but none will understand them except those who have knowledge (of Allah and His Signs, etc.).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
(Allah says to His Prophet Muhammad SAW): ``Allah (Alone) created the heavens and the earth with truth (and none shared Him in their creation)." Verily! Therein is surely a sign for those who believe.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite (O Muhammad SAW) what has been revealed to you of the Book (the Quran), and perform As-Salat (Iqamat-as-Salat). Verily, As-Salat (the prayer) prevents from Al-Fahsha' (i.e. great sins of every kind, unlawful sexual intercourse, etc.) and Al-Munkar (i.e. disbelief, polytheism, and every kind of evil wicked deed, etc.) and the remembering (praising, etc.) of (you by) Allah (in front of the angels) is greater indeed [than your remembering (praising, etc.) Allah in prayers, etc.]. And Allah knows what you do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And argue not with the people of the Scripture (Jews and Christians), unless it be in (a way) that is better (with good words and in good manner, inviting them to Islamic Monotheism with His Verses), except with such of them as do wrong, and say (to them): ``We believe in that which has been revealed to us and revealed to you; our Ilah (God) and your Ilah (God) is One (i.e. Allah), and to Him we have submitted (as Muslims)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And thus We have sent down the Book (i.e. this Quran) to you (O Muhammad SAW), and those whom We gave the Scripture [the Taurat (Torah) and the Injeel (Gospel) aforetime] believe therein as also do some of these (who are present with you now like 'Abdullah bin Salam) and none but the disbelievers reject Our Ayat [(proofs, signs, verses, lessons, etc., and deny Our Oneness of Lordship and Our Oneness of worship and Our Oneness of Our Names and Qualities: i.e. Islamic Monotheism)].\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
Neither did you (O Muhammad SAW) read any book before it (this Quran), nor did you write any book (whatsoever) with your right hand. In that case, indeed, the followers of falsehood might have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Nay, but they, the clear Ayat [i.e. the description and the qualities of Prophet Muhammad SAW written like verses in the Taurat (Torah) and the Injeel (Gospel)] are preserved in the breasts of those who have been given knowledge (from the people of the Scriptures). And none but the Zalimun (polytheists and wrongdoers, etc.) deny Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they say: ``Why are not signs sent down to him from his Lord? Say: ``The signs are only with Allah, and I am only a plain warner."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Is it not sufficient for them that We have sent down to you the Book (the Quran) which is recited to them? Verily, herein is mercy and a reminder (or an admonition) for a people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say (to them O Muhammad SAW): ``Sufficient is Allah for a witness between me and you. He knows what is in the heavens and on earth." And those who believe in Batil (all false deities other than Allah), and disbelieve in Allah and (in His Oneness), it is they who are the losers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they ask you to hasten on the torment (for them), and had it not been for a term appointed, the torment would certainly have come to them. And surely, it will come upon them suddenly while they perceive not!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They ask you to hasten on the torment. And verily! Hell, of a surety, will encompass the disbelievers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day when the torment (Hell-fire) shall cover them from above them and from underneath their feet, and it will be said: ``Taste what you used to do."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My slaves who believe! Certainly, spacious is My earth. Therefore worship Me (Alone)."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Everyone shall taste the death. Then unto Us you shall be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, to them We shall surely give lofty dwellings in Paradise, underneath which rivers flow, to live therein forever. Excellent is the reward of the workers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Those who are patient, and put their trust (only) in their Lord (Allah).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And so many a moving (living) creature there is, that carries not its own provision! Allah provides for it and for you. And He is the All-Hearer, the All-Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If you were to ask them: ``Who has created the heavens and the earth and subjected the sun and the moon?" They will surely reply: ``Allah." How then are they deviating (as polytheists and disbelievers)?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah enlarges the provision for whom He wills of His slaves, and straitens it for whom (He wills). Verily, Allah is the All-Knower of everything.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
If you were to ask them: ``Who sends down water (rain) from the sky, and gives life therewith to the earth after its death?" They will surely reply: ``Allah." Say: ``All the praises and thanks be to Allah!" Nay! Most of them have no sense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
And this life of the world is only amusement and play! Verily, the home of the Hereafter, that is the life indeed (i.e. the eternal life that will never end), if they but knew\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
And when they embark on a ship, they invoke Allah, making their Faith pure for Him only, but when He brings them safely to land, behold, they give a share of their worship to others.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
So that they become ingrate for that which We have given them, and that they take their enjoyment (as a warning and a threat), but they will come to know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Have they not seen that We have made (Makkah) a sanctuary secure, and that men are being snatched away from all around them? Then do they believe in Batil (falsehood - polytheism, idols and all deities other than Allah), and deny (become ingrate for) the Graces of Allah?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does more wrong than he who invents a lie against Allah or denies the truth (Muhammad SAW and his doctrine of Islamic Monotheism and this Quran), when it comes to him? Is there not a dwelling in Hell for disbelievers (in the Oneness of Allah and in His Messenger Muhammad SAW)?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
As for those who strive hard in Us (Our Cause), We will surely guide them to Our Paths (i.e. Allah's Religion - Islamic Monotheism). And verily, Allah is with the Muhsinun (good doers)."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In the nearer land (Syria, Iraq, Jordan, and Palestine), and they, after their defeat, will be victorious.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
Within three to nine years. The decision of the matter, before and after (these events) is only with Allah, (before the defeat of Romans by the Persians, and after, i.e. the defeat of the Persians by the Romans). And on that Day, the believers (i.e. Muslims) will rejoice (at the victory given by Allah to the Romans against the Persians),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
With the help of Allah, He helps whom He wills, and He is the All-Mighty, the Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
(It is) a Promise of Allah (i.e. Allah will give victory to the Romans against the Persians), and Allah fails not in His Promise, but most of men know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know only the outside appearance of the life of the world (i.e. the matters of their livelihood, like irrigating or sowing or reaping, etc.), and they are heedless of the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Do they not think deeply (in their ownselves) about themselves (how Allah created them from nothing, and similarly He will resurrect them)? Allah has created not the heavens and the earth, and all that is between them, except with truth and for an appointed term. And indeed many of mankind deny the Meeting with their Lord. [See Tafsir At-Tabari, Part 21, Page 24].\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Do they not travel in the land, and see what was the end of those before them? They were superior to them in strength, and they tilled the earth and populated it in greater numbers than these (pagans) have done, and there came to them their Messengers with clear proofs. Surely, Allah wronged them not, but they used to wrong themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then evil was the end of those who did evil, because they belied the Ayat (proofs, evidences, verses, lessons, signs, revelations, Messengers, etc.) of Allah and made mock of them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah (Alone) originates the creation, then He will repeat it, then to Him you will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And on the Day when the Hour will be established, the Mujrimun (disbelievers, sinners, criminals, polytheists, etc.) will be plunged into destruction with deep regrets, sorrows, and despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
No intercessor will they have from those whom they made equal with Allah (partners i.e. their so-called associate gods), and they will (themselves) reject and deny their partners.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
And on the Day when the Hour will be established, that Day shall (all men) be separated (i.e. the believers will be separated from the disbelievers).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
Then as for those who believed (in the Oneness of Allah Islamic Monotheism) and did righteous good deeds, such shall be honoured and made to enjoy luxurious life (forever) in a Garden of delight (Paradise).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
And as for those who disbelieved and belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, Allah's Messengers, Resurrection, etc.), and the Meeting of the Hereafter, such shall be brought forth to the torment (in the Hell-fire).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glorify Allah [above all that (evil) they associate with Him (O believers)], when you come up to the evening [i.e. offer the (Maghrib) sunset and ('Isha') night prayers], and when you enter the morning [i.e. offer the (Fajr) morning prayer].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
And His is all the praises and thanks in the heavens and the earth, and (glorify Him) in the afternoon (i.e. offer 'Asr prayer) and when you come up to the time, when the day begins to decline (i.e. offer Zuhr prayer). (Ibn 'Abbas said: ``These are the five compulsory congregational prayers mentioned in the Quran)."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings out the living from the dead, and brings out the dead from the living. And He revives the earth after its death. And thus shall you be brought out (resurrected).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And among His Signs is this, that He created you (Adam) from dust, and then [Hawwa' (Eve) from Adam's rib, and then his offspring from the semen, and], - behold you are human beings scattered!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And among His Signs is this, that He created for you wives from among yourselves, that you may find repose in them, and He has put between you affection and mercy. Verily, in that are indeed signs for a people who reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And among His Signs is the creation of the heavens and the earth, and the difference of your languages and colours. Verily, in that are indeed signs for men of sound knowledge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And among His Signs is the sleep that you take by night and by day, and your seeking of His Bounty. Verily, in that are indeed signs for a people who listen.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And among His Signs is that He shows you the lightning, by way of fear and hope, and He sends down water (rain) from the sky, and therewith revives the earth after its death. Verily, in that are indeed signs for a people who understand.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And among His Signs is that the heaven and the earth stand by His Command, then afterwards when He will call you by single call, behold, you will come out from the earth (i.e. from your graves for reckoning and recompense).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs whatever is in the heavens and the earth. All are obedient to Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And He it is Who originates the creation, then will repeat it (after it has been perished), and this is easier for Him. His is the highest description (i.e. none has the right to be worshipped but He, and there is nothing comparable unto Him) in the heavens and in the earth. And He is the All-Mighty, the All-Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He sets forth for you a parable from your ownselves, - Do you have partners among those whom your right hands possess (i.e. your slaves) to share as equals in the wealth We have bestowed on you? Whom you fear as you fear each other? Thus do We explain the signs in detail to a people who have sense.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Nay, but those who do wrong follow their own lusts without knowledge, Then who will guide him whom Allah has sent astray? And for such there will be no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So set you (O Muhammad SAW) your face towards the religion of pure Islamic Monotheism Hanifa (worship none but Allah Alone) Allah's Fitrah (i.e. Allah's Islamic Monotheism), with which He has created mankind. No change let there be in Khalq-illah (i.e. the Religion of Allah Islamic Monotheism), that is the straight religion, but most of men know not. [Tafsir At-Tabari, Vol 21, Page 41]\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
(Always) Turning in repentance to Him (only), and be afraid and dutiful to Him; and perform As-Salat (Iqamat-as-Salat) and be not of Al-Mushrikun (the disbelievers in the Oneness of Allah, polytheists, idolaters, etc.).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Of those who split up their religion (i.e. who left the true Islamic Monotheism), and became sects, [i.e. they invented new things in the religion (Bid'ah), and followed their vain desires], each sect rejoicing in that which is with it.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when harm touches men, they cry sincerely only to their Lord (Allah), turning to Him in repentance, but when He gives them a taste of His Mercy, behold! a party of them associate partners in worship with their Lord.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
So as to be ungrateful for the graces which We have bestowed on them. Then enjoy (your short life); but you will come to know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We revealed to them a Scripture, which speaks of that which they have been associating with Him?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We cause mankind to taste of mercy, they rejoice therein, but when some evil afflicts them because of (evil deeds and sins) that their (own) hands have sent forth, lo! They are in despair!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that Allah enlarges the provision for whom He wills and straitens (it for whom He wills). Verily, in that are indeed signs for a people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give to the kindred his due, and to Al-Miskin (the poor) and to the wayfarer. That is best for those who seek Allah's Countenance, and it is they who will be successful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And that which you give in gift (to others), in order that it may increase (your wealth by expecting to get a better one in return) from other people's property, has no increase with Allah, but that which you give in Zakat seeking Allah's Countenance then those, they shall have manifold increase.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
Allah is He Who created you, then provided food for you, then will cause you to die, then (again) He will give you life (on the Day of Resurrection). Is there any of your (so-called) partners (of Allah) that do anything of that? Glory be to Him! And Exalted be He above all that (evil) they associate (with Him).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Evil (sins and disobedience of Allah, etc.) has appeared on land and sea because of what the hands of men have earned (by oppression and evil deeds, etc.), that Allah may make them taste a part of that which they have done, in order that they may return (by repenting to Allah, and begging His Pardon).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say (O Muhammad SAW): ``Travel in the land and see what was the end of those before (you)! Most of them were Mushrikun (the disbelievers in the Oneness of Allah, polytheists, idolaters, etc.)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So set you (O Muhammad SAW) your face to (the obedience of Allah, your Lord) the straight and right religion (Islamic Monotheism), before there comes from Allah a Day which none can avert it. On that Day men shall be divided [(in two groups), a group in Paradise and a group in Hell].\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whosoever disbelieves will suffer from his disbelief, and whosoever does righteous good deeds (by practising Islamic Monotheism), then such will prepare a good place (in Paradise) for themselves (and will be saved by Allah from His Torment).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
That He may reward those who believe (in the Oneness of Allah Islamic Monotheism), and do righteous good deeds, out of His Bounty. Verily, He likes not the disbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And among His Signs is this, that He sends the winds as glad tidings, giving you a taste of His Mercy (i.e. rain), and that the ships may sail at His Command, and that you may seek of His Bounty, in order that you may be thankful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
And indeed We did send Messengers before you (O Muhammad SAW) to their own peoples. They came to them with clear proofs, then, We took vengeance on those who committed crimes (disbelief, setting partners in worship with Allah, sins, etc.), and (as for) the believers it was incumbent upon Us to help (them).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
Allah is He Who sends the winds, so they raise clouds, and spread them along the sky as He wills, and then break them into fragments, until you see rain drops come forth from their midst! Then when He has made them fall on whom of His slaves as He will, lo! they rejoice!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
And verily before that (rain), just before it was sent down upon them, they were in despair!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Look then at the effects (results) of Allah's Mercy, how He revives the earth after its death. Verily! That (Allah) Who revived the earth after its death shall indeed raise the dead (on the Day of Resurrection), and He is Able to do all things.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We send a wind [which would spoil the green growth (tilth) brought up by the previous rain], and they see (their tilth) turn yellow, behold, they then after their being glad, would become unthankful (to their Lord Allah as) disbelievers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
So verily, you (O Muhammad SAW) cannot make the dead to hear (i.e. the disbelievers, etc.), nor can you make the deaf to hear the call, when they show their backs, turning away.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
And you (O Muhammad SAW) cannot guide the blind from their straying; you can make to hear only those who believe in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and have submitted to Allah in Islam (as Muslims).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah is He Who created you in (a state of) weakness, then gave you strength after weakness, then after strength gave (you) weakness and grey hair. He creates what He wills. And it is He Who is the All-Knowing, the All-Powerful (i.e. Able to do all things).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And on the Day that the Hour will be established, the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.) will swear that they stayed not but an hour, thus were they ever deluded [away from the truth (i.e. they used to tell lies and take false oaths, and turn away from the truth) in this life of the world)].\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
And those who have been bestowed with knowledge and faith will say: ``Indeed you have stayed according to the Decree of Allah, until the Day of Resurrection, so this is the Day of Resurrection, but you knew not."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So on that Day no excuse of theirs will avail those who did wrong (by associating partners in worship with Allah, and by denying the Day of Resurrection), nor will they be allowed (then) to return to seek Allah's Pleasure (by having Islamic Faith with righteous deeds and by giving up polytheism, sins and crimes with repentance).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
And indeed We have set forth for mankind, in this Quran every kind of parable. But if you (O Muhammad SAW) bring to them any sign or proof, (as an evidence for the truth of your Prophethood), the disbelievers are sure to say (to the believers): ``You follow nothing but falsehood, and magic."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus does Allah seal up the hearts of those who know not [the proofs and evidence of the Oneness of Allah i.e. those who try not to understand true facts that which you (Muhammad SAW) have brought to them].\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So be patient (O Muhammad SAW). Verily, the Promise of Allah is true, and let not those who have no certainty of faith, discourage you from conveying Allah's Message (which you are obliged to convey)\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are Verses of the Wise Book (the Quran).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A guide and a mercy for the Muhsinun (good-doers)\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who perform As-Salat (Iqamat-as- Salat) and give Zakat and they have faith in the Hereafter with certainty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Such are on guidance from their Lord, and such are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And of mankind is he who purchases idle talks (i.e. music, singing, etc.) to mislead (men) from the Path of Allah without knowledge, and takes it (the Path of Allah, the Verses of the Quran) by way of mockery. For such there will be a humiliating torment (in the Hell-fire).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our Verses (of the Quran) are recited to such a one, he turns away in pride, as if he heard them not, as if there were deafness in his ear. So announce to him a painful torment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Verily, those who believe (in Islamic Monotheism) and do righteous good deeds, for them are Gardens of delight (Paradise).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
To abide therein. It is a Promise of Allah in truth. And He is the All-Mighty, the All-Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He has created the heavens without any pillars, that you see and has set on the earth firm mountains, lest it should shake with you. And He has scattered therein moving (living) creatures of all kinds. And We send down water (rain) from the sky, and We cause (plants) of every goodly kind to grow therein.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is the creation of Allah. So show Me that which those (whom you worship), besides Him have created. Nay, the Zalimun (polytheists, wrong-doers and those who do not believe in the Oneness of Allah) are in plain error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And indeed We bestowed upon Luqman Al-Hikmah (wisdom and religious understanding, etc.) saying: ``Give thanks to Allah," and whoever gives thanks, he gives thanks for (the good of) his ownself. And whoever is unthankful, then verily, Allah is All-Rich (Free of all wants), Worthy of all praise.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And (remember) when Luqman said to his son when he was advising him: ``O my son! Join not in worship others with Allah. Verily! Joining others in worship with Allah is a great Zulm (wrong) indeed.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined on man (to be dutiful and good) to his parents. His mother bore him in weakness and hardship upon weakness and hardship, and his weaning is in two years give thanks to Me and to your parents, unto Me is the final destination.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they (both) strive with you to make you join in worship with Me others that of which you have no knowledge, then obey them not, but behave with them in the world kindly, and follow the path of him who turns to Me in repentance and in obedience. Then to Me will be your return, and I shall tell you what you used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
``O my son! If it be (anything) equal to the weight of a grain of mustard seed, and though it be in a rock, or in the heavens or in the earth, Allah will bring it forth. Verily, Allah is Subtle (in bringing out that grain), Well-Aware (of its place).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
``O my son! Aqim-is-Salat (perform As-Salat), enjoin (people) for Al-Ma'ruf (Islamic Monotheism and all that is good), and forbid (people) from Al-Munkar (i.e. disbelief in the Oneness of Allah, polytheism of all kinds and all that is evil and bad), and bear with patience whatever befall you. Verily! These are some of the important commandments ordered by Allah with no exemption.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
``And turn not your face away from men with pride, nor walk in insolence through the earth. Verily, Allah likes not each arrogant boaster.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
``And be moderate (or show no insolence) in your walking, and lower your voice. Verily, the harshest of all voices is the voice (braying) of the ass."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
See you not (O men) that Allah has subjected for you whatsoever is in the heavens and whatsoever is in the earth, and has completed and perfected His Graces upon you, (both) apparent (i.e. Islamic Monotheism, and the lawful pleasures of this world, including health, good looks, etc.) and hidden [i.e. One's Faith in Allah (of Islamic Monotheism) knowledge, wisdom, guidance for doing righteous deeds, and also the pleasures and delights of the Hereafter in Paradise, etc.]? Yet of mankind is he who disputes about Allah without knowledge or guidance or a Book giving light!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said to them: ``Follow that which Allah has sent down", they say: ``Nay, we shall follow that which we found our fathers (following)." (Would they do so) even if Shaitan (Satan) invites them to the torment of the Fire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
And whosoever submits his face (himself) to Allah [i.e. (follows Allah's Religion of Islamic Monotheism), worships Allah (Alone) with sincere Faith in the (1) Oneness of His Lordship, (2) Oneness of His worship, and (3) Oneness of His Names and Qualities], while he is a Muhsin (good-doer i.e. performs good deeds totally for Allah's sake without any show-off or to gain praise or fame etc. and does them in accordance with the Sunnah of Allah's Messenger Muhammad SAW), then he has grasped the most trustworthy hand-hold [La ilaha ill-Allah (none has the right to be worshipped but Allah)]. And to Allah return all matters for decision.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whoever disbelieved, let not his disbelief grieve you (O Muhammad SAW),. to Us is their return, and We shall inform them what they have done. Verily, Allah is the All-Knower of what is in the breasts (of men).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We let them enjoy for a little while, then in the end We shall oblige them to (enter) a great torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And if you (O Muhammad SAW) ask them: ``Who has created the heavens and the earth," they will certainly say: ``Allah." Say: ``All the praises and thanks be to Allah!" But most of them know not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah belongs whatsoever is in the heavens and the earth. Verily, Allah, He is Al-Ghani (Rich, Free of all wants), Worthy of all praise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if all the trees on the earth were pens and the sea (were ink wherewith to write), with seven seas behind it to add to its (supply), yet the Words of Allah would not be exhausted. Verily, Allah is All-Mighty, All-Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
The creation of you all and the resurrection of you all are only as (the creation and resurrection of) a single person. Verily, Allah is All-Hearer, All-Seer.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
See you not (O Muhammad SAW) that Allah merges the night into the day (i.e. the decrease in the hours of the night are added in the hours of the day), and merges the day into the night (i.e. the decrease in the hours of day are added in the hours of night), and has subjected the sun and the moon, each running its course for a term appointed; and that Allah is All-Aware of what you do.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because Allah, He is the Truth, and that which they invoke besides Him is Al-Batil (falsehood, Satan and all other false deities), and that Allah, He is the Most High, the Most Great.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
See you not that the ships sail through the sea by Allah's Grace? that He may show you of His Signs? Verily, in this are signs for every patient, grateful (person).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And when a wave covers them like shades (i.e. like clouds or the mountains of sea-water), they invoke Allah, making their invocations for Him only. But when He brings them safe to land, there are among them those that stop in the middle, between (Belief and disbelief). But none denies Our Signs except every perfidious ungrateful.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind! Be afraid of your Lord (by keeping your duty to Him and avoiding all evil), and fear a Day when no father can avail aught for his son, nor a son avail aught for his father. Verily, the Promise of Allah is true, let not then this (worldly) present life deceive you, nor let the chief deceiver (Satan) deceive you about Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Verily, Allah! With Him (Alone) is the knowledge of the Hour, He sends down the rain, and knows that which is in the wombs. No person knows what he will earn tomorrow, and no person knows in what land he will die. Verily, Allah is All-Knower, All-Aware (of things).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif-Lam-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The revelation of the Book (this Quran) is from the Lord of the 'Alamin (mankind, jinns and all that exists) in which there is not doubt!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or say they: ``He (Muhammad SAW) has fabricated it?" Nay, it is the truth from your Lord, that you may warn a people to whom no warner has come before you (O Muhammad SAW), in order that they may be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
Allah it is He Who has created the heavens and the earth, and all that is between them in six Days. Then He Istawa (rose over) the Throne (in a manner that suits His Majesty). You (mankind) have none, besides Him, as a Wali (protector or helper etc.) or an intercessor. Will you not then remember (or be admonished)?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He arranges (every) affair from the heavens to the earth, then it (affair) will go up to Him, in one Day, the space whereof is a thousand years of your reckoning (i.e. reckoning of our present world's time).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
That is He, the All-Knower of the unseen and the seen, the All-Mighty, the Most Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
Who made everything He has created good, and He began the creation of man from clay.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then He made his offspring from semen of worthless water (male and female sexual discharge).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He fashioned him in due proportion, and breathed into him the soul (created by Allah for that person), and He gave you hearing (ears), sight (eyes) and hearts. Little is the thanks you give!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say: ``When we are (dead and become) lost in the earth, shall we indeed be recreated anew?" Nay, but they deny the Meeting with their Lord!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: ``The angel of death, who is set over you, will take your souls, then you shall be brought to your Lord."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
And if you only could see when the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.) shall hang their heads before their Lord (saying): ``Our Lord! We have now seen and heard, so send us back (to the world), we will do righteous good deeds. Verily! We now believe with certainty."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And if We had willed, surely! We would have given every person his guidance, but the Word from Me took effect (about evil-doers), that I will fill Hell with jinn and mankind together.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
Then taste you (the torment of the Fire) because of your forgetting the Meeting of this Day of yours, (and) surely! We too will forget you, so taste you the abiding torment for what you used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), who, when they are reminded of them fall down prostrate, and glorify the Praises of their Lord, and they are not proud.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides forsake their beds, to invoke their Lord in fear and hope, and they spend (charity in Allah's Cause) out of what We have bestowed on them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No person knows what is kept hidden for them of joy as a reward for what they used to do.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Is then he who is a believer like him who is Fasiq (disbeliever and disobedient to Allah)? Not equal are they.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, for them are Gardens (Paradise) as an entertainment, for what they used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
And as for those who are Fasiqun (disbelievers and disobedient to Allah), their abode will be the Fire, every time they wish to get away therefrom, they will be put back thereto, and it will be said to them: ``Taste you the torment of the Fire which you used to deny."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And verily, We will make them taste of the near torment (i.e. the torment in the life of this world, i.e. disasters, calamities, etc.) prior to the supreme torment (in the Hereafter), in order that they may (repent and) return (i.e. accept Islam).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who does more wrong than he who is reminded of the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of his Lord, then he turns aside therefrom? Verily, We shall exact retribution from the Mujrimun (criminals, disbelievers, polytheists, sinners, etc.).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
And indeed We gave Musa (Moses) the Scripture [the Taurat (Torah)]. So be not you in doubt of meeting him [i.e. when you met Musa (Moses) during the night of Al-Isra' and Al-Mi'raj over the heavens]. And We made it [the Taurat (Torah)] a guide to the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We made from among them (Children of Israel), leaders, giving guidance under Our Command, when they were patient and used to believe with certainty in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Verily, your Lord will judge between them on the Day of Resurrection, concerning that wherein they used to differ.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a guidance for them, how many generations We have destroyed before them in whose dwellings they do walk about? Verily, therein indeed are signs. Would they not then listen?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen how We drive water (rain clouds) to the dry land without any vegetation, and therewith bring forth crops providing food for their cattle and themselves? Will they not then see?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They say: ``When will this Al-Fath (Decision) be (between us and you, i.e. the Day of Resurrection), if you are telling the truth?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say: ``On the Day of Al-Fath (Decision), no profit will it be to those who disbelieve if they (then) believe! Nor will they be granted a respite."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn aside from them (O Muhammad SAW) and await, verily they (too) are awaiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet (Muhammad SAW)! Keep your duty to Allah, and obey not the disbelievers and the hypocrites (i.e., do not follow their advices). Verily! Allah is Ever AllKnower, AllWise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow that which is inspired in you from your Lord. Verily, Allah is WellAcquainted with what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put your trust in Allah, and Sufficient is Allah as a Wakil (Trustee, or Disposer of affairs).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has not put for any man two hearts inside his body. Neither has He made your wives whom you declare to be like your mothers' backs, your real mothers. [AzZihar is the saying of a husband to his wife, ``You are to me like the back of my mother" i.e. You are unlawful for me to approach.], nor has He made your adopted sons your real sons. That is but your saying with your mouths. But Allah says the truth, and He guides to the (Right) Way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them (adopted sons) by (the names of) their fathers, that is more just with Allah. But if you know not their father's (names, call them) your brothers in faith and Mawalikum (your freed slaves). And there is no sin on you if you make a mistake therein, except in regard to what your hearts deliberately intend. And Allah is Ever OftForgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is closer to the believers than their ownselves, and his wives are their (believers') mothers (as regards respect and marriage). And blood relations among each other have closer personal ties in the Decree of Allah (regarding inheritance) than (the brotherhood of) the believers and the Muhajirun (emigrants from Makkah, etc.), except that you do kindness to those brothers (when the Prophet SAW joined them in brotherhood ties). This has been written in the (Allah's Book of Divine) Decrees (AlLauh AlMahfuz)."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And (remember) when We took from the Prophets their covenant, and from you (O Muhammad SAW), and from Nuh (Noah), Ibrahim (Abraham), Musa (Moses), and 'Iesa (Jesus), son of Maryam (Mary). We took from them a strong covenant.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That He may ask the truthfuls (Allah's Messengers and His Prophets) about their truth (i.e. the conveyance of Allah's Message that which they were charged with). And He has prepared for the disbelievers a painful torment (Hell-fire).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O you who believe! Remember Allah's Favour to you, when there came against you hosts, and We sent against them a wind and forces that you saw not [i.e. troops of angels during the battle of AlAhzab (the Confederates)]. And Allah is Ever AllSeer of what you do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you from above you and from below you, and when the eyes grew wild and the hearts reached to the throats, and you were harbouring doubts about Allah.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There, the believers were tried and shaken with a mighty shaking.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when the hypocrites and those in whose hearts is a disease (of doubts) said: ``Allah and His Messenger (SAW) promised us nothing but delusions!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said: ``O people of Yathrib (AlMadinah)! There is no stand (possible) for you (against the enemy attack!) Therefore go back!" And a band of them ask for permission of the Prophet (SAW) saying: ``Truly, our homes lie open (to the enemy)." And they lay not open. They but wished to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if the enemy had entered from all sides (of the city), and they had been exhorted to AlFitnah (i.e. to renegade from Islam to polytheism) they would surely have committed it and would have hesitated thereupon but little.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And indeed they had already made a covenant with Allah not to turn their backs, and a covenant with Allah must be answered for.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say (O Muhammad SAW to these hypocrites who ask your permission to run away from you): ``Flight will not avail you if you flee from death or killing, and then you will enjoy no more than a little while!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: ``Who is he who can protect you from Allah if He intends to harm you, or intends mercy on you?" And they will not find, besides Allah, for themselves any Wali (protector, supporter, etc.) or any helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Allah already knows those among you who keep back (men) from fighting in Allah's Cause, and those who say to their brethren ``Come here towards us," while they (themselves) come not to the battle except a little.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Being miserly towards you (as regards help and aid in Allah's Cause). Then when fear comes, you will see them looking to you, their eyes revolving like (those of) one over whom hovers death, but when the fear departs, they will smite you with sharp tongues, miserly towards (spending anything in any) good (and only covetous of booty and wealth). Such have not believed. Therefore Allah makes their deeds fruitless, and that is ever easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think that AlAhzab (the Confederates) have not yet withdrawn, and if AlAhzab (the Confederates) should come (again), they would wish they were in the deserts (wandering) among the bedouins, seeking news about you (from a far place); and if they (happen) to be among you, they would not fight but little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Indeed in the Messenger of Allah (Muhammad SAW) you have a good example to follow for him who hopes in (the Meeting with) Allah and the Last Day and remembers Allah much.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the believers saw AlAhzab (the Confederates), they said: ``This is what Allah and His Messenger (Muhammad SAW) had promised us, and Allah and His Messenger (Muhammad SAW) had spoken the truth, and it only added to their faith and to their submissiveness (to Allah).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers are men who have been true to their covenant with Allah [i.e. they have gone out for Jihad (holy fighting), and showed not their backs to the disbelievers], of them some have fulfilled their obligations (i.e. have been martyred), and some of them are still waiting, but they have never changed [i.e. they never proved treacherous to their covenant which they concluded with Allah] in the least.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That Allah may reward the men of truth for their truth (i.e. for their patience at the accomplishment of that which they covenanted with Allah), and punish the hypocrites if He will or accept their repentance by turning to them in Mercy. Verily, Allah is OftForgiving, Most Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah drove back those who disbelieved in their rage, they gained no advantage (booty, etc.). Allah sufficed for the believers in the fighting (by sending against the disbelievers a severe wind and troops of angels). And Allah is Ever AllStrong, AllMighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And those of the people of the Scripture who backed them (the disbelievers) Allah brought them down from their forts and cast terror into their hearts, (so that) a group (of them) you killed, and a group (of them) you made captives.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He caused you to inherit their lands, and their houses, and their riches, and a land which you had not trodden (before). And Allah is Able to do all things.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet (Muhammad SAW)! Say to your wives: If you desire the life of this world, and its glitter, Then come! I will make a provision for you and set you free in a handsome manner (divorce).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you desire Allah and His Messenger, and the home of the Hereafter, then verily, Allah has prepared for AlMuhsinat (gooddoers) amongst you an enormous reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O wives of the Prophet! Whoever of you commits an open illegal sexual intercourse, the torment for her will be doubled, and that is ever easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whosoever of you is obedient to Allah and His Messenger SAW, and does righteous good deeds, We shall give her, her reward twice over, and We have prepared for her Rizqan Karima (a noble provision Paradise).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O wives of the Prophet! You are not like any other women. If you keep your duty (to Allah), then be not soft in speech, lest he in whose heart is a disease (of hypocrisy, or evil desire for adultery, etc.) should be moved with desire, but speak in an honourable manner.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay in your houses, and do not display yourselves like that of the times of ignorance, and perform As-Salat (IqamatasSalat), and give Zakat and obey Allah and His Messenger. Allah wishes only to remove ArRijs (evil deeds and sins, etc.) from you, O members of the family (of the Prophet SAW), and to purify you with a thorough purification.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember (O you the members of the Prophet's family, the Graces of your Lord), that which is recited in your houses of the Verses of Allah and AlHikmah (i.e. Prophet's Sunnah legal ways, etc. so give your thanks to Allah and glorify His Praises for this Quran and the Sunnah). Verily, Allah is Ever Most Courteous, WellAcquainted with all things.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Verily, the Muslims (those who submit to Allah in Islam) men and women, the believers men and women (who believe in Islamic Monotheism), the men and the women who are obedient (to Allah), the men and women who are truthful (in their speech and deeds), the men and the women who are patient (in performing all the duties which Allah has ordered and in abstaining from all that Allah has forbidden), the men and the women who are humble (before their Lord Allah), the men and the women who give Sadaqat (i.e. Zakat, and alms, etc.), the men and the women who observe Saum (fast) (the obligatory fasting during the month of Ramadan, and the optional Nawafil fasting), the men and the women who guard their chastity (from illegal sexual acts) and the men and the women who remember Allah much with their hearts and tongues (while sitting, standing, lying, etc. for more than 300 times extra over the remembrance of Allah during the five compulsory congregational prayers) or praying extra additional Nawafil prayers of night in the last part of night, etc.) Allah has prepared for them forgiveness and a great reward (i.e. Paradise).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for a believer, man or woman, when Allah and His Messenger have decreed a matter that they should have any option in their decision. And whoever disobeys Allah and His Messenger, he has indeed strayed in a plain error.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And (remember) when you said to him (Zaid bin Harithah, the freedslave of the Prophet SAW) on whom Allah has bestowed Grace (by guiding him to Islam) and you (O Muhammad SAW too) have done favour (by manumitting him) ``Keep your wife to yourself, and fear Allah." But you did hide in yourself (i.e. what Allah has already made known to you that He will give her to you in marriage) that which Allah will make manifest, you did fear the people (i.e., Muhammad SAW married the divorced wife of his manumitted slave) whereas Allah had a better right that you should fear Him. So when Zaid had accomplished his desire from her (i.e. divorced her), We gave her to you in marriage, so that (in future) there may be no difficulty to the believers in respect of (the marriage of) the wives of their adopted sons when the latter have no desire to keep them (i.e. they have divorced them). And Allah's Command must be fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no blame on the Prophet (SAW) in that which Allah has made legal for him. That has been Allah's Way with those who have passed away of (the Prophets of) old. And the Command of Allah is a decree determined.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Those who convey the Message of Allah and fear Him, and fear none save Allah. And Sufficient is Allah as a Reckoner.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad (SAW) is not the father of any man among you, but he is the Messenger of Allah and the last (end) of the Prophets. And Allah is Ever AllAware of everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O you who believe! Remember Allah with much remembrance.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And glorify His Praises morning and afternoon [the early morning (Fajr) and 'Asr prayers].\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
He it is Who sends Salat (His blessings) on you, and His angels too (ask Allah to bless and forgive you), that He may bring you out from darkness (of disbelief and polytheism) into light (of Belief and Islamic Monotheism). And He is Ever Most Merciful to the believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting on the Day they shall meet Him will be ``Salam: Peace (i.e. the angels will say to them: Salamu 'Alaikum)!" And He has prepared for them a generous reward (i.e. Paradise).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet (MuhammadSAW)! Verily, We have sent you as witness, and a bearer of glad tidings, and a warner,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And as one who invites to Allah [Islamic Monotheism, i.e. to worship none but Allah (Alone)] by His Leave, and as a lamp spreading light (through your instructions from the Quran and the Sunnah the legal ways of the Prophet SAW).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And announce to the believers (in the Oneness of Allah and in His Messenger Muhammad SAW) the glad tidings, that they will have from Allah a Great Bounty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And obey not the disbelievers and the hypocrites, and harm them not (till you are ordered). And put your trust in Allah, and Sufficient is Allah as a Wakil (Trustee, or Disposer of affairs).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O you who believe! When you marry believing women, and then divorce them before you have sexual intercourse with them, no 'Iddah [divorce prescribed period, see (V. 65:4)] have you to count in respect of them. So give them a present, and set them free i.e. divorce, in a handsome manner.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet (Muhammad SAW)! Verily, We have made lawful to you your wives, to whom you have paid their Mahr (bridal money given by the husband to his wife at the time of marriage), and those (captives or slaves) whom your right hand possesses - whom Allah has given to you, and the daughters of your 'Amm (paternal uncles) and the daughters of your 'Ammah (paternal aunts) and the daughters of your Khal (maternal uncles) and the daughters of your Khalah (maternal aunts) who migrated (from Makkah) with you, and a believing woman if she offers herself to the Prophet, and the Prophet wishes to marry her; a privilege for you only, not for the (rest of) the believers. Indeed We know what We have enjoined upon them about their wives and those (captives or slaves) whom their right hands possess, - in order that there should be no difficulty on you. And Allah is Ever OftForgiving, Most Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
You (O Muhammad SAW) can postpone (the turn of) whom you will of them (your wives), and you may receive whom you will. And whomsoever you desire of those whom you have set aside (her turn temporarily), it is no sin on you (to receive her again), that is better; that they may be comforted and not grieved, and may all be pleased with what you give them. Allah knows what is in your hearts. And Allah is Ever AllKnowing, Most Forbearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
It is not lawful for you (to marry other) women after this, nor to change them for other wives even though their beauty attracts you, except those (captives or slaves) whom your right hand possesses. And Allah is Ever a Watcher over all things.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O you who believe! Enter not the Prophet's houses, except when leave is given to you for a meal, (and then) not (so early as) to wait for its preparation. But when you are invited, enter, and when you have taken your meal, disperse, without sitting for a talk. Verily, such (behaviour) annoys the Prophet, and he is shy of (asking) you (to go), but Allah is not shy of (telling you) the truth. And when you ask (his wives) for anything you want, ask them from behind a screen, that is purer for your hearts and for their hearts. And it is not (right) for you that you should annoy Allah's Messenger, nor that you should ever marry his wives after him (his death). Verily! With Allah that shall be an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you reveal anything or conceal it, verily, Allah is Ever AllKnower of everything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It is no sin on them (the Prophet's wives, if they appear unveiled) before their fathers, or their sons, or their brothers, or their brother's sons, or the sons of their sisters, or their own (believing) women, or their (female) slaves, and keep your duty to Allah. Verily, Allah is Ever AllWitness over everything.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Allah sends His Salat (Graces, Honours, Blessings, Mercy, etc.) on the Prophet (Muhammad SAW) and also His angels too (ask Allah to bless and forgive him). O you who believe! Send your Salat on (ask Allah to bless) him (Muhammad SAW), and (you should) greet (salute) him with the Islamic way of greeting (salutation i.e. AsSalamu 'Alaikum).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Verily, those who annoy Allah and His Messenger (SAW) Allah has cursed them in this world, and in the Hereafter, and has prepared for them a humiliating torment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who annoy believing men and women undeservedly, bear on themselves the crime of slander and plain sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Tell your wives and your daughters and the women of the believers to draw their cloaks (veils) all over their bodies (i.e. screen themselves completely except the eyes or one eye to see the way). That will be better, that they should be known (as free respectable women) so as not to be annoyed. And Allah is Ever OftForgiving, Most Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites, and those in whose hearts is a disease (evil desire for adultery, etc.), and those who spread false news among the people in AlMadinah, cease not, We shall certainly let you overpower them, then they will not be able to stay in it as your neighbours but a little while.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed, wherever found, they shall be seized and killed with a (terrible) slaughter.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
That was the Way of Allah in the case of those who passed away of old, and you will not find any change in the Way of Allah.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask you concerning the Hour, say: ``The knowledge of it is with Allah only. What do you know? It may be that the Hour is near!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Verily, Allah has cursed the disbelievers, and has prepared for them a flaming Fire (Hell).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Wherein they will abide for ever, and they will find neither a Wali (a protector) nor a helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On the Day when their faces will be turned over in the Fire, they will say: ``Oh, would that we had obeyed Allah and obeyed the Messenger (Muhammad SAW)."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say: ``Our Lord! Verily, we obeyed our chiefs and our great ones, and they misled us from the (Right) Way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord! give them double torment and curse them with a mighty curse!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O you who believe! Be not like those who annoyed Musa (Moses), but Allah cleared him of that which they alleged, and he was honourable before Allah.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O you who believe! Keep your duty to Allah and fear Him, and speak (always) the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will direct you to do righteous good deeds and will forgive you your sins. And whosoever obeys Allah and His Messenger (SAW) he has indeed achieved a great achievement (i.e. he will be saved from the Hell-fire and made to enter Paradise).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
Truly, We did offer AlAmanah (the trust or moral responsibility or honesty and all the duties which Allah has ordained) to the heavens and the earth, and the mountains, but they declined to bear it and were afraid of it (i.e. afraid of Allah's Torment). But man bore it. Verily, he was unjust (to himself) and ignorant (of its results).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
So that Allah will punish the hypocrites, men and women, and the men and women who are AlMushrikun (the polytheists, idolaters, pagans, disbelievers in the Oneness of Allah, and in His Messenger Muhammad SAW). And Allah will pardon (accept the repentance of) the true believers of the Islamic Monotheism, men and women. And Allah is Ever OftForgiving, Most Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen All the praises and thanks be to Allah, to Whom belongs all that is in the heavens and all that is in the earth. His is all the praises and thanks in the Hereafter, and He is the AllWise, the AllAware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows that which goes into the earth and that which comes forth from it, and that which descend from the heaven and that which ascends to it. And He is the Most Merciful, the OftForgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
Those who disbelieve say: ``The Hour will not come to us." Say: ``Yes, by my Lord, it will come to you." (Allah, He is) the AllKnower of the unseen, not even the weight of an atom (or a small ant) or less than that or greater, escapes from His Knowledge in the heavens or in the earth, but it is in a Clear Book (AlLauh AlMahfuz).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may recompense those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds. Those, theirs is forgiveness and Rizqun Karim (generous provision, i.e. Paradise).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who strive against Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) to frustrate them, those, for them will be a severe painful torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And those who have been given knowledge see that what is revealed to you (O Muhammad SAW) from your Lord is the truth, and guides to the Path of the Exalted in Might, Owner of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
Those who disbelieve say: ``Shall we direct you to a man (Muhammad SAW) who will tell you (that) when you have become fully disintegrated into dust with full dispersion, then, you will be created (again) anew?"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Has he (Muhammad SAW) invented a lie against Allah, or is there a madness in him? Nay, but those who disbelieve in the Hereafter are (themselves) in a torment, and in far error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
See they not what is before them and what is behind them, of the heaven and the earth? If We will, We shall sink the earth with them, or cause a piece of the heaven to fall upon them. Verily, in this is a sign for every faithful believer that [believes in the Oneness of Allah], and turns to Allah (in all affairs with humility and in repentance).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And indeed We bestowed grace on David from Us (saying): ``O you mountains. Glorify (Allah) with him! And you birds (also)! And We made the iron soft for him."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
Saying: ``Make you perfect coats of mail, balancing well the rings of chain armour, and work you (men) righteousness. Truly, I am AllSeer of what you do."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And to Solomon (We subjected) the wind, its morning (stride from sunrise till midnoon) was a month's (journey), and its afternoon (stride from the midday decline of the sun to sunset) was a month's (journey i.e. in one day he could travel two months' journey). And We caused a fount of (molten) brass to flow for him, and there were jinns that worked in front of him, by the Leave of his Lord, and whosoever of them turned aside from Our Command, We shall cause him to taste of the torment of the blazing Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They worked for him what he desired, (making) high rooms, images, basins as large as reservoirs, and (cooking) cauldrons fixed (in their places). ``Work you, O family of Dawud (David), with thanks!" But few of My slaves are grateful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
Then when We decreed death for him [Sulaiman (Solomon)], nothing informed them (jinns) of his death except a little worm of the earth, which kept (slowly) gnawing away at his stick, so when he fell down, the jinns saw clearly that if they had known the unseen, they would not have stayed in the humiliating torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
Indeed there was for Saba' (Sheba) a sign in their dwelling place, - two gardens on the right hand and on the left (and it was said to them) ``Eat of the provision of your Lord, and be grateful to Him, a fair land and an OftForgiving Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away (from the obedience of Allah), so We sent against them Sail Al'Arim (flood released from the dam), and We converted their two gardens into gardens producing bitter bad fruit, and tamarisks, and some few lotetrees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
Like this We requited them because they were ungrateful disbelievers. And never do We requit in such a way except those who are ungrateful, (disbelievers).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We placed between them and the towns which We had blessed, towns easy to be seen, and We made the stages (of journey) between them easy (saying): ``Travel in them safely both by night and day."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: ``Our Lord! Make the stages between our journey longer," and they wronged themselves, so We made them as tales (in the land), and We dispersed them all, totally. Verily, in this are indeed signs for every steadfast grateful (person).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And indeed Iblis (Satan) did prove true his thought about them, and they followed him, all except a group of true believers (in the Oneness of Allah).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And he (Iblis Satan) had no authority over them, except that We might test him, who believes in the Hereafter from him who is in doubt about it. And your Lord is a Hafiz over everything. (AllKnower of everything i.e. He keeps record of each and every person as regards deeds, and then He will reward them accordingly).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say: (O Muhammad SAW to those polytheists, pagans, etc.) ``Call upon those whom you assert (to be associate gods) besides Allah, they possess not even the weight of an atom (or a small ant), either in the heavens or on the earth, nor have they any share in either, nor there is for Him any supporter from among them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
Intercession with Him profits not, except for him whom He permits. Until when fear is banished from their (angels') hearts, they (angels) say: ``What is it that your Lord has said?" They say: ``The truth. And He is the Most High, the Most Great."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say (O Muhammad SAW to these polytheists, pagans, etc.) ``Who gives you provision from the heavens and the earth?" Say: ``Allah, And verily, (either) we or you are rightly guided or in a plain error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say (O Muhammad SAW to these polytheists, pagans, etc.) ``You will not be asked about our sins, nor shall we be asked of what you do."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: ``Our Lord will assemble us all together (on the Day of Resurrection), then He will judge between us with truth. And He is the (Most Trustworthy) AllKnowing Judge."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say (O Muhammad SAW to these polytheists and pagans): ``Show me those whom you have joined to Him as partners. Nay (there are not at all any partners with Him)! But He is Allah (Alone), the AllMighty, the AllWise."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And We have not sent you (O Muhammad SAW) except as a giver of glad tidings and a warner to all mankind, but most of men know not.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say: ``When is this promise (i.e. the Day of Resurrection will be fulfilled) if you are truthful?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say (O Muhammad SAW): ``The appointment to you is for a Day, which you cannot put back for an hour (or a moment) nor put forward."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And those who disbelieve say: ``We believe not in this Quran nor in that which was before it," but if you could see when the Zalimun (polytheists and wrongdoers, etc.) will be made to stand before their Lord, how they will cast the (blaming) word one to another! Those who were deemed weak will say to those who were arrogant: ``Had it not been for you, we should certainly have been believers!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
And those who were arrogant will say to those who were deemed weak: ``Did we keep you back from guidance after it had come to you? Nay, but you were Mujrimun (polytheists, sinners, criminals, disobedient to Allah, etc.).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were deemed weak will say to those who were arrogant: ``Nay, but it was your plotting by night and day, when you ordered us to disbelieve in Allah and set up rivals to Him!" And each of them (parties) will conceal their own regrets (for disobeying Allah during this worldly life), when they behold the torment. And We shall put iron collars round the necks of those who disbelieved. Are they requited aught except what they used to do?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And We did not send a warner to a township, but those who were given the worldly wealth and luxuries among them said: ``We believe not in the (Message) with which you have been sent."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they say: ``We are more in wealth and in children, and we are not going to be punished."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say (O Muhammad SAW): ``Verily, my Lord enlarges and restricts the provision to whom He pleases, but most men know not."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And it is not your wealth, nor your children that bring you nearer to Us (i.e. pleases Allah), but only he (will please Us) who believes (in the Islamic Monotheism), and does righteous deeds; as for such, there will be twofold reward for what they did, and they will reside in the high dwellings (Paradise) in peace and security.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And those who strive against Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), to frustrate them, will be brought to the torment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: ``Truly, my Lord enlarges the provision for whom He wills of His slaves, and (also) restricts (it) for him, and whatsoever you spend of anything (in Allah's Cause), He will replace it. And He is the Best of providers."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And (remember) the Day when He will gather them all together, and then will say to the angels: ``Was it you that these people used to worship?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They (angels) will say: ``Glorified be You! You are our Wali (Lord) instead of them. Nay, but they used to worship the jinns; most of them were believers in them."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
So Today (i.e. the Day of Resurrection), none of you can profit or harm one another. And We shall say to those who did wrong [i.e. worshipped others (like angels, jinns, prophets, saints, righteous persons, etc.) along with Allah]: ``Taste the torment of the Fire which you used to belie.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when Our Clear Verses are recited to them, they say: ``This (Muhammad SAW) is naught but a man who wishes to hinder you from that which your fathers used to worship." And they say: ``This is nothing but an invented lie." And those who disbelieve say of the truth when it has come to them (i.e. Prophet Muhammad SAW when Allah sent him as a Messenger with proofs, evidences, verses, lessons, signs, etc.): ``This is nothing but evident magic!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We had not given them Scriptures which they could study, nor sent to them before you (O Muhammad SAW) any warner (Messenger).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And those before them belied; these have not received one tenth (1/10th) of what We had granted to those (of old), yet they belied My Messengers, then how (terrible) was My denial (punishment)!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say (to them O Muhammad SAW): ``I exhort you on one (thing) only: that you stand up for Allah's sake in pairs and singly, and reflect (within yourselves the life history of the Prophet SAW): there is no madness in your companion (Muhammad SAW), he is only a warner to you in face of a severe torment."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say (O Muhammad SAW): ``Whatever wage I might have asked of you is yours. My wage is from Allah only. and He is Witness over all things."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say (O Muhammad SAW): ``Verily! My Lord sends down Inspiration and makes apparent the truth (i.e. this Revelation that had come to me), the AllKnower of the Ghaib (unseen).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say (O Muhammad SAW): ``The truth (the Quran and Allah's Inspiration) has come, and AlBatil [falsehood - Iblis (Satan)] can neither create anything nor resurrect (anything)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: ``If (even) I go astray, I shall stray only to my own loss. But if I remain guided, it is because of the Inspiration of my Lord to me. Truly, He is AllHearer, Ever Near (to all things)."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
And if you could but see, when they will be terrified with no escape (for them), and they will be seized from a near place.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they will say (in the Hereafter): ``We do believe (now);" but how could they receive (Faith and the acceptance of their repentance by Allah) from a place so far off (i.e. to return to the worldly life again).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
Indeed they did disbelieve (in the Oneness of Allah, Islam, the Quran and Muhammad SAW) before (in this world), and they (used to) conjecture about the unseen [i.e. the Hereafter, Hell, Paradise, Resurrection and the Promise of Allah, etc. (by saying) all that is untrue], from a far place.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a barrier will be set between them and that which they desire [i.e. At-Taubah (turning to Allah in repentance) and the accepting of Faith etc.], as was done in the past with the people of their kind. Verily, they have been in grave doubt.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen All the praises and thanks be to Allah, the (only) Originator [or the (only) Creator] of the heavens and the earth, Who made the angels messengers with wings, - two or three or four. He increases in creation what He wills. Verily, Allah is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever of mercy (i.e. of good), Allah may grant to mankind, none can withhold it, and whatever He may withhold, none can grant it thereafter. And He is the AllMighty, the AllWise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O mankind! Remember the Grace of Allah upon you! Is there any creator other than Allah who provides for you from the sky (rain) and the earth? La ilaha illa Huwa (none has the right to be worshipped but He). How then are you turning away (from Him)?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they belie you (O Muhammad SAW), so were Messengers belied before you. And to Allah return all matters (for decision).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O mankind! Verily, the Promise of Allah is true. So let not this present life deceive you, and let not the chief deceiver (Satan) deceive you about Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Surely, Shaitan (Satan) is an enemy to you, so take (treat) him as an enemy. He only invites his Hizb (followers) that they may become the dwellers of the blazing Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve, theirs will be a severe torment; and those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, theirs will be forgiveness and a great reward (i.e. Paradise).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Is he, then, to whom the evil of his deeds made fairseeming, so that he considers it as good (equal to one who is rightly guided)? Verily, Allah sends astray whom He wills, and guides whom He wills. So destroy not yourself (O Muhammad SAW) in sorrow for them. Truly, Allah is the AllKnower of what they do!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And it is Allah Who sends the winds, so that they raise up the clouds, and We drive them to a dead land, and revive therewith the earth after its death. As such (will be) the Resurrection!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whosoever desires honour, power and glory then to Allah belong all honour, power and glory [and one can get honour, power and glory only by obeying and worshipping Allah (Alone)]. To Him ascend (all) the goodly words, and the righteous deeds exalt it (the goodly words i.e. the goodly words are not accepted by Allah unless and until they are followed by good deeds), but those who plot evils, theirs will be severe torment. And the plotting of such will perish.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah did create you (Adam) from dust, then from Nutfah (male and female discharge semen drops i.e. Adam's offspring), then He made you pairs (male and female). And no female conceives or gives birth, but with His Knowledge. And no aged man is granted a length of life, nor is a part cut off from his life (or another man's life), but is in a Book (AlLauh AlMahfuz) Surely, that is easy for Allah.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And the two seas (kinds of water) are not alike, this fresh sweet, and pleasant to drink, and that saltish and bitter. And from them both you eat fresh tender meat (fish), and derive the ornaments that you wear. And you see the ships cleaving (the seawater as they sail through it), that you may seek of His Bounty, and that you may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He merges the night into the day (i.e. the decrease in the hours of the night are added to the hours of the day), and He merges the day into the night (i.e. the decrease in the hours of the day are added to the hours of the night). And He has subjected the sun and the moon, each runs its course for a term appointed. Such is Allah your Lord; His is the kingdom. And those, whom you invoke or call upon instead of Him, own not even a Qitmir (the thin membrane over the datestone).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you invoke (or call upon) them, they hear not your call, and if (in case) they were to hear, they could not grant it (your request) to you. And on the Day of Resurrection, they will disown your worshipping them. And none can inform you (O Muhammad SAW) like Him Who is the AllKnower (of each and everything).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O mankind! it is you who stand in need of Allah, but Allah is Rich (Free of all wants and needs), Worthy of all praise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He will, He could destroy you and bring about a new creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And that is not hard for Allah.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And no bearer of burdens shall bear another's burden, and if one heavily laden calls another to (bear) his load, nothing of it will be lifted even though he be near of kin. You (O Muhammad SAW) can warn only those who fear their Lord unseen, and perform As-Salat (IqamatasSalat). And he who purifies himself (from all kinds of sins), then he purifies only for the benefit of his ownself. And to Allah is the (final) Return (of all).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not alike are the blind (disbelievers in Islamic Monotheism) and the seeing (believers in Islamic Monotheism).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor are (alike) the darkness (disbelief) and the light (Belief in Islamic Monotheism).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor are (alike) the shade and the sun's heat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor are (alike) the living (believers) and the dead (disbelievers). Verily, Allah makes whom He will hear, but you cannot make hear those who are in graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You (O Muhammad SAW) are only a warner (i.e. your duty is to convey Allah's Message to mankind but the guidance is in Allah's Hand).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Verily! We have sent you with the truth, a bearer of glad tidings, and a warner. And there never was a nation but a warner had passed among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they belie you, those before them also belied. Their Messengers came to them with clear signs, and with the Scriptures, and the book giving light.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I took hold of those who disbelieved, and how terrible was My denial (punishment)!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
See you not that Allah sends down water (rain) from the sky, and We produce therewith fruits of varying colours, and among the mountains are streaks white and red, of varying colours and (others) very black.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And of men and AdDawab (moving living creatures, beasts, etc.), and cattle, in like manner of various colours. It is only those who have knowledge among His slaves that fear Allah. Verily, Allah is AllMighty, OftForgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Verily, those who recite the Book of Allah (this Quran), and perform AsSalat (IqamatasSalat), and spend (in charity) out of what We have provided for them, secretly and openly, hope for a (sure) tradegain that will never perish.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
That He may pay them their wages in full, and give them (even) more, out of His Grace. Verily! He is OftForgiving, Most Ready to appreciate (good deeds and to recompense).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And what We have inspired in you (O Muhammad SAW), of the Book (the Quran), it is the (very) truth [that you (Muhammad SAW) and your followers must act on its instructions], confirming that which was (revealed) before it. Verily! Allah is indeed AllAware, and AllSeer of His slaves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We gave the Book the Quran) for inheritance to such of Our slaves whom We chose (the followers of Muhammad SAW). Then of them are some who wrong their ownselves, and of them are some who follow a middle course, and of them are some who are, by Allah's Leave, foremost in good deeds. That (inheritance of the Quran), that is indeed a great grace.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
'Adn (Eden) Paradise (everlasting Gardens) will they enter, therein will they be adorned with bracelets of gold and pearls, and their garments there will be of silk (i.e. in Paradise).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say: ``All the praises and thanks be to Allah, Who has removed from us (all) grief. Verily, our Lord is indeed OftForgiving, Most Ready to appreciate (good deeds and to recompense).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
Who, out of His Grace, has lodged us in a home that will last forever; there, toil will touch us not, nor weariness will touch us."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
But those who disbelieve, (in the Oneness of Allah - Islamic Monotheism) for them will be the Fire of Hell. Neither it will have a complete killing effect on them so that they die, nor shall its torment be lightened for them. Thus do We requite every disbeliever!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
Therein they will cry: ``Our Lord! Bring us out, we shall do righteous good deeds, not (the evil deeds) that we used to do." (Allah will reply): ``Did We not give you lives long enough, so that whosoever would receive admonition, - could receive it? And the warner came to you. So taste you (the evil of your deeds). For the Zalimun (polytheists and wrongdoers, etc.) there is no helper."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Verily, Allah is the AllKnower of the unseen of the heavens and the earth. Verily! He is the AllKnower of that is in the breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
He it is Who has made you successors generations after generations in the earth, so whosoever disbelieves (in Islamic Monotheism) on him will be his disbelief. And the disbelief of the disbelievers adds nothing but hatred with their Lord. And the disbelief of the disbelievers adds nothing but loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say (O Muhammad SAW): ``Tell me or inform me (what) do you think about your (socalled) partnergods to whom you call upon besides Allah, show me, what they have created of the earth? Or have they any share in the heavens? Or have We given them a Book, so that they act on clear proof therefrom? Nay, the Zalimun (polytheists and wrongdoers, etc.) promise one another nothing but delusions."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Verily! Allah grasps the heavens and the earth lest they move away from their places, and if they were to move away from their places, there is not one that could grasp them after Him. Truly, He is Ever Most Forbearing, OftForgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by Allah their most binding oath, that if a warner came to them, they would be more guided than any of the nations (before them), yet when a warner (Muhammad SAW) came to them, it increased in them nothing but flight (from the truth),\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
(They took to flight because of their) arrogance in the land and their plotting of evil. But the evil plot encompasses only him who makes it. Then, can they expect anything (else), but the Sunnah (way of dealing) of the peoples of old? So no change will you find in Allah's Sunnah (way of dealing), and no turning off will you find in Allah's Sunnah (way of dealing).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not travelled in the land, and seen what was the end of those before them, and they were superior to them in power? Allah is not such that anything in the heavens or in the earth escapes Him. Verily, He is AllKnowing, AllOmnipotent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
And if Allah were to punish men for that which they earned, He would not leave a moving (living) creature on the surface of the earth, but He gives them respite to an appointed term, and when their term comes, then verily, Allah is Ever AllSeer of His slaves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya-Sin. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Quran, full of wisdom (i.e. full of laws, evidences, and proofs),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Truly, you (O Muhammad SAW) are one of the Messengers,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On a Straight Path (i.e. on Allah's religion of Islamic Monotheism).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
(This is) a Revelation sent down by the AllMighty, the Most Merciful,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
In order that you may warn a people whose forefathers were not warned, so they are heedless.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Indeed the Word (of punishment) has proved true against most of them, so they will not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Verily! We have put on their necks iron collars reaching to chins, so that their heads are forced up.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have put a barrier before them, and a barrier behind them, and We have covered them up, so that they cannot see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
It is the same to them whether you warn them or you warn them not, they will not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You can only warn him who follows the Reminder (the Quran), and fears the Most Beneficent (Allah) unseen. Bear you to such one the glad tidings of forgiveness, and a generous reward (i.e. Paradise).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Verily, We give life to the dead, and We record that which they send before (them), and their traces [their footsteps and walking on the earth with their legs to the mosques for the five compulsory congregational prayers, Jihad (holy fighting in Allah's Cause) and all other good and evil they did, and that which they leave behind], and all things We have recorded with numbers (as a record) in a Clear Book.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And put forward to them a similitude; the (story of the) dwellers of the town, [It is said that the town was Antioch (Antakiya)], when there came Messengers to them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We sent to them two Messengers, they belied them both, so We reinforced them with a third, and they said: ``Verily! We have been sent to you as Messengers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They (people of the town) said: ``You are only human beings like ourselves, and the Most Beneficent (Allah) has revealed nothing, you are only telling lies."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
The Messengers said: ``Our Lord knows that we have been sent as Messengers to you,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
``And our duty is only to convey plainly (the Message)."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They (people) said: ``For us, we see an evil omen from you, if you cease not, we will surely stone you, and a painful torment will touch you from us."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They (Messengers) said: ``Your evil omens be with you! (Do you call it ``evil omen") because you are admonished? Nay, but you are a people Musrifun (transgressing all bounds by committing all kinds of great sins, and by disobeying Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And there came running from the farthest part of the town, a man, saying: ``O my people! Obey the Messengers;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
``Obey those who ask no wages of you (for themselves), and who are rightly guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
``And why should I not worship Him (Allah Alone) Who has created me and to Whom you shall be returned.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
``Shall I take besides Him aliha (gods), if the Most Beneficent (Allah) intends me any harm, their intercession will be of no use for me whatsoever, nor can they save me?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
``Then verily, I should be in plain error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
Verily! I have believed in your Lord, so listen to me!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said (to him when the disbelievers killed him): ``Enter Paradise." He said: ``Would that my people knew!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
``That my Lord (Allah) has forgiven me, and made me of the honoured ones!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We sent not against his people after him a host from heaven, nor do We send (such a thing).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was but one Saihah (shout, etc.) and lo! They (all) were silent (dead-destroyed).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Alas for mankind! There never came a Messenger to them but they used to mock at him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Do they not see how many of the generations We have destroyed before them? Verily, they will not return to them.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
And surely, all, everyone of them will be brought before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign for them is the dead land. We gave it life, and We brought forth from it grains, so that they eat thereof.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We have made therein gardens of date-palms and grapes, and We have caused springs of water to gush forth therein.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
So that they may eat of the fruit thereof, and their hands made it not. Will they not, then, give thanks?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory be to Him, Who has created all the pairs of that which the earth produces, as well as of their own (human) kind (male and female), and of that which they know not.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign for them is the night, We withdraw therefrom the day, and behold, they are in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs on its fixed course for a term (appointed). That is the Decree of the All-Mighty, the All-Knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon, We have measured for it mansions (to traverse) till it returns like the old dried curved date stalk.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not for the sun to overtake the moon, nor does the night outstrip the day. They all float, each in an orbit.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And an Ayah (sign) for them is that We bore their offspring in the laden ship [of Nuh (Noah)].\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them of the like thereunto, so on them they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We will, We shall drown them, and there will be no shout (or helper) for them (to hear their cry for help) nor will they be saved.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Unless it be a mercy from Us, and as an enjoyment for a while.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
And when it is said to them: ``Beware of that which is before you (worldly torments), and that which is behind you (torments in the Hereafter), in order that you may receive Mercy (i.e. if you believe in Allah's Religion Islamic Monotheism, and avoid polytheism, and obey Allah with righteous deeds).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
And never came an Ayah from among the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord to them, but they did turn away from it.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them: ``Spend of that with which Allah has provided you," those who disbelieve say to those who believe: ``Shall we feed those whom, if Allah willed, He (Himself) would have fed? You are only in a plain error."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say: ``When will this promise (i.e. Resurrection) be fulfilled, if you are truthful?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await only but a single Saihah (shout, etc.), which will seize them while they are disputing!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
Then they will not be able to make bequest, nor they will return to their family.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Trumpet will be blown (i.e. the second blowing) and behold! From the graves they will come out quickly to their Lord.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say: ``Woe to us! Who has raised us up from our place of sleep." (It will be said to them): ``This is what the Most Beneficent (Allah) had promised, and the Messengers spoke truth!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It will be but a single Saihah (shout, etc.), so behold! They will all be brought up before Us!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
This Day (Day of Resurrection), none will be wronged in anything, nor will you be requited anything except that which you used to do.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Verily, the dwellers of the Paradise, that Day, will be busy in joyful things.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their wives will be in pleasant shade, reclining on thrones.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
They will have therein fruits (of all kinds) and all that they ask for.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
(It will be said to them): Salamun (peace be on you), a Word from the Lord (Allah), Most Merciful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
(It will be said): ``And O you Al-Mujrimun (criminals, polytheists, sinners, disbelievers in the Islamic Monotheism, wicked evil ones, etc.)! Get you apart this Day (from the believers).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Did I not ordain for you, O Children of Adam, that you should not worship Shaitan (Satan). Verily, he is a plain enemy to you.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
And that you should worship Me [Alone Islamic Monotheism, and set up not rivals, associate-gods with Me]. That is a Straight Path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
And indeed he (Satan) did lead astray a great multitude of you. Did you not, then, understand?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is Hell which you were promised!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Burn therein this Day, for that you used to disbelieve.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
This Day, We shall seal up their mouths, and their hands will speak to Us, and their legs will bear witness to what they used to earn. (It is said that one's left thigh will be the first to bear the witness). [Tafsir At-Tabari, Vol. 22, Page 24]\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And if it had been Our Will, We would surely have wiped out (blinded) their eyes, so that they would struggle for the Path, how then would they see?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if it had been Our Will, We could have transformed them (into animals or lifeless objects) in their places. Then they should have been unable to go forward (move about) nor they could have turned back. [As it happened with the Jews see Verse 7:166 The Quran].\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And he whom We grant long life, We reverse him in creation (weakness after strength). Will they not then understand?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We have not taught him (Muhammad SAW) poetry, nor is it meet for him. This is only a Reminder and a plain Quran.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
That he or it (Muhammad SAW or the Quran) may give warning to him who is living (a healthy minded the believer), and that Word (charge) may be justified against the disbelievers (dead, as they reject the warnings).\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Do they not see that We have created for them of what Our Hands have created, the cattle, so that they are their owners.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And We have subdued them unto them so that some of them they have for riding and some they eat.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And they have (other) benefits from them (besides), and they get (milk) to drink, will they not then be grateful?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And they have taken besides Allah aliha (gods), hoping that they might be helped (by those so called gods).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They cannot help them, but they will be brought forward as a troop against those who worshipped them (at the time of Reckoning).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So let not their speech, then, grieve you (O Muhammad SAW). Verily, We know what they conceal and what they reveal.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Does not man see that We have created him from Nutfah (mixed male and female discharge semen drops). Yet behold! He (stands forth) as an open opponent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he puts forth for Us a parable, and forgets his own creation. He says: ``Who will give life to these bones when they have rotted away and became dust?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: (O Muhammad SAW) ``He will give life to them Who created them for the first time! And He is the All-Knower of every creation!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
He, Who produces for you fire out of the green tree, when behold! You kindle therewith.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He, Who created the heavens and the earth Able to create the like of them? Yes, indeed! He is the All-Knowing Supreme Creator.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
Verily, His Command, when He intends a thing, is only that He says to it, ``Be!" and it is!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So Glorified is He and Exalted above all that they associate with Him, and in Whose Hands is the dominion of all things, and to Him you shall be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those (angels) ranged in ranks (or rows).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
By those (angels) who drive the clouds in a good way.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
By those (angels) who bring the Book and the Quran from Allah to mankind [Tafsir Ibn Kathir].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Verily your Ilah (God) is indeed One (i.e. Allah);\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and of the earth, and all that is between them, and Lord of every point of the sun's risings. (None has the right to be worshipped but Allah).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
Verily! We have adorned the near heaven with the stars (for beauty).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And to guard against every rebellious devil.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot listen to the higher group (angels) for they are pelted from every side.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Outcast, and theirs is a constant (or painful) torment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except such as snatch away something by stealing and they are pursued by a flaming fire of piercing brightness.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Then ask them (i.e. these polytheists, O Muhammad SAW): ``Are they stronger as creation, or those (others like the heavens and the earth and the mountains, etc.) whom We have created?" Verily, We created them of a sticky clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Nay, you (O Muhammad SAW) wondered (at their insolence) while they mock (at you and at the Quran).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And when they are reminded, they pay no attention.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And when they see an Ayah (a sign, a proof, or an evidence) from Allah, they mock at it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say: ``This is nothing but evident magic!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
``When we are dead and have become dust and bones, shall we (then) verily be resurrected?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
``And also our fathers of old?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say (O Muhammad SAW): ``Yes, and you shall then be humiliated."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It will be a single Zajrah [shout (i.e. the second blowing of the Trumpet)], and behold, they will be staring!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will say: ``Woe to us! This is the Day of Recompense!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
(It will be said): ``This is the Day of Judgement which you used to deny."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
(It will be said to the angels): ``Assemble those who did wrong, together with their companions (from the devils) and what they used to worship.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
``Instead of Allah, and lead them on to the way of flaming Fire (Hell);\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
``But stop them, verily they are to be questioned.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
``What is the matter with you? Why do you not help one another (as you used to do in the world)?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Nay, but that Day they shall surrender,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And they will turn to one another and question one another.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say: ``It was you who used to come to us from the right side [i.e. from the right side of one of us and beautify for us every evil, order us for polytheism, and stop us from the truth i.e. Islamic Monotheism and from every good deed]."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will reply: ``Nay, you yourselves were not believers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
``And we had no authority over you. Nay! But you were transgressing people (disobedient, polytheists, and disbelievers).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
``So now the Word of our Lord has been justified against us, that we shall certainly (have to) taste (the torment).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
``So we led you astray because we were ourselves astray."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
Then verily, that Day, they will (all) share in the torment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Certainly, that is how We deal with Al-Mujrimun (polytheists, sinners, criminals, the disobedient to Allah, etc.).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Truly, when it was said to them: La ilaha ill-Allah ``(none has the right to be worshipped but Allah)," they puffed themselves up with pride (i.e. denied it).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And (they) said: ``Are we going to abandon our aliha (gods) for the sake of a mad poet?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Nay! he (Muhammad SAW) has come with the truth (i.e. Allah's Religion - Islamic Monotheism and this Quran) and he confirms the Messengers (before him who brought Allah's religion - Islamic Monotheism).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Verily, you (pagans of Makkah) are going to taste the painful torment;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
And you will be requited nothing except for what you used to do (evil deeds, sins, and Allah's disobedience which you used to do in this world);\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Save the chosen slaves of Allah (faithful, obedient, true believers of Islamic Monotheism).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them there will be a known provision (in Paradise).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits; and they shall be honoured,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In the Gardens of delight (Paradise),\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
Facing one another on thrones,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
Round them will be passed a cup of pure wine;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White, delicious to the drinkers,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Neither they will have Ghoul (any kind of hurt, abdominal pain, headache, a sin, etc.) from that, nor will they suffer intoxication therefrom.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them will be chaste females, restraining their glances (desiring none except their husbands), with wide and beautiful eyes.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
(Delicate and pure) as if they were (hidden) eggs (well) preserved.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then they will turn to one another, mutually questioning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
A speaker of them will say: ``Verily, I had a companion (in the world),\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
Who used to say: ``Are you among those who believe (in resurrection after death).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
``(That) when we die and become dust and bones, shall we indeed (be raised up) to receive reward or punishment (according to our deeds)?"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
(The man) said: ``Will you look down?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
So he looked down and saw him in the midst of the Fire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He said: ``By Allah! You have nearly ruined me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
``Had it not been for the Grace of my Lord, I would certainly have been among those brought forth (to Hell)."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
(Allah informs about that true believer that he said): ``Are we then not to die (any more)?\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
``Except our first death, and we shall not be punished? (after we have entered Paradise)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Truly, this is the supreme success!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this let the workers work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is that (Paradise) better entertainment or the tree of Zaqqum (a horrible tree in Hell)?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
Truly We have made it (as) a trail for the Zalimun (polytheists, disbelievers, wrong-doers, etc.).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Verily, it is a tree that springs out of the bottom of Hell-fire,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
The shoots of its fruit-stalks are like the heads of Shayatin (devils);\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
Truly, they will eat thereof and fill their bellies therewith.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then on the top of that they will be given boiling water to drink so that it becomes a mixture (of boiling water and Zaqqum in their bellies).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then thereafter, verily, their return is to the flaming fire of Hell.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
Verily, they found their fathers on the wrong path;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they (too) made haste to follow in their footsteps!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And indeed most of the men of old went astray before them;\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And indeed We sent among them warners (Messengers);\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Then see what was the end of those who were warned (but heeded not).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Except the chosen slaves of Allah (faithful, obedient, and true believers of Islamic Monotheism).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And indeed Nuh (Noah) invoked Us, and We are the Best of those who answer (the request).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We rescued him and his family from the great distress (i.e. drowning),\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And, his progeny, them We made the survivors (i.e. Shem, Ham and Japheth).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And left for him (a goodly remembrance) among generations to come in later times:\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Salamun (peace) be upon Nuh (Noah) (from Us) among the 'Alamin (mankind, jinns and all that exists)!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Verily, thus We reward the Muhsinun (good-doers - see V. 2:112).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Verily, he [Nuh (Noah)] was one of Our believing slaves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We drowned the other (disbelievers and polytheists, etc.).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And, verily, among those who followed his [Nuh's (Noah)] way (Islamic Monotheism) was Ibrahim (Abraham).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord with a pure heart [attached to Allah Alone and none else, worshipping none but Allah Alone true Islamic Monotheism, pure from the filth of polytheism].\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
When he said to his father and to his people: ``What is it that which you worship?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
``Is it a falsehood aliha (gods) other than Allah that you seek?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
``Then what do you think about the Lord of the 'Alamin (mankind, jinns, and all that exists)?"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then he cast a glance at the stars (to deceive them),\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And he said: ``Verily, I am sick (with plague. He did this trick to remain in their temple of idols to destroy them and not to accompany them to the pagan's feast)."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So they turned away from him, and departed (for fear of the disease).\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their aliha (gods) and said: ``Will you not eat (of the offering before you)?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
``What is the matter with you that you speak not?"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he turned upon them, striking (them) with (his) right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then they (the worshippers of idols) came, towards him, hastening.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: ``Worship you that which you (yourselves) carve?\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
``While Allah has created you and what you make!"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said: ``Build for him a building (it is said that the building was like a furnace) and throw him into the blazing fire!"\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
So they plotted a plot against him, but We made them the lowest.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And he said (after his rescue from the fire): ``Verily, I am going to my Lord. He will guide me!"\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
``My Lord! Grant me (offspring) from the righteous."\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So We gave him the glad tidings of a forbearing boy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And, when he (his son) was old enough to walk with him, he said: ``O my son! I have seen in a dream that I am slaughtering you (offer you in sacrifice to Allah), so look what you think!" He said: ``O my father! Do that which you are commanded, Insha' Allah (if Allah will), you shall find me of As-Sabirin (the patient ones, etc.)."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then, when they had both submitted themselves (to the Will of Allah), and he had laid him prostrate on his forehead (or on the side of his forehead for slaughtering);\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
And We called out to him: ``O Abraham!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
You have fulfilled the dream (vision)!" Verily! Thus do We reward the Muhsinun (good-doers - see V. 2:112).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Verily, that indeed was a manifest trial\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a great sacrifice (i.e. a ram);\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left for him (a goodly remembrance) among generations (to come) in later times.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Salamun (peace) be upon Ibrahim (Abraham)!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus indeed do We reward the Muhsinun (good-doers - see V. 2:112).\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Verily, he was one of Our believing slaves.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the glad tidings of Ishaque (Isaac) a Prophet from the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
We blessed him and Ishaque (Isaac), and of their progeny are (some) that do right, and some that plainly wrong themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And, indeed We gave Our Grace to Musa (Moses) and Harun (Aaron).\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And We saved them and their people from the great distress;\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And helped them, so that they became the victors;\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the clear Scripture;\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And guided them to the Right Path;\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left for them (a goodly remembrance) among generations (to come) in later times;\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Salamun (peace) be upon Musa (Moses) and Harun (Aaron)!"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Verily, thus do We reward the Muhsinun (good-doers - see V. 2:112).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Verily! They were two of Our believing slaves.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And verily, Iliyas (Elias) was one of the Messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
When he said to his people: ``Will you not fear Allah?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
``Will you call upon Ba'l (a well- known idol of his nation whom they used to worship) and forsake the Best of creators,\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
``Allah, your Lord and the Lord of your forefathers?"\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they denied him [Iliyas (Elias)], so they will certainly be brought forth (to the punishment),\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except the chosen slaves of Allah.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left for him (a goodly remembrance) among generations (to come) in later times;\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Salamun (peace) be upon Ilyasin (Elias)!"\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Verily, thus do We reward the Muhsinun (good-doers, who perform good deeds totally for Allah's sake only - see V. 2:112).\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
Verily, he was one of Our believing slaves.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And verily, Lout (Lot) was one of the Messengers.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
When We saved him and his family, all,\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except an old woman (his wife) who was among those who remained behind.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We destroyed the rest [i.e. the towns of Sodom at the place of the Dead Sea (now) in Palestine]. [See the ``Book of History" by Ibn Kathir].\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
Verily, you pass by them in the morning.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night; will you not then reflect?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And, verily, Yunus (Jonah) was one of the Messengers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he ran to the laden ship,\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
He (agreed to) cast lots, and he was among the losers,\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then a (big) fish swallowed him and he had done an act worthy of blame.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Had he not been of them who glorify Allah,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have indeed remained inside its belly (the fish) till the Day of Resurrection.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We cast him forth on the naked shore while he was sick,\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused a plant of gourd to grow over him.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him to a hundred thousand (people) or even more.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed; so We gave them enjoyment for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now ask them (O Muhammad SAW): ``Are there (only) daughters for your Lord and sons for them?"\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or did We create the angels females while they were witnesses?\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Verily, it is of their falsehood that they (Quraish pagans) say:\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
``Allah has begotten off spring or children (i.e. angels are the daughters of Allah)?" And, verily, they are liars!\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Has He (then) chosen daughters rather than sons?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you? How do you decide?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will you not then remember?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or is there for you a plain authority?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then bring your Book if you are truthful!\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have invented a kinship between Him and the jinns, but the jinns know well that they have indeed to appear (before Him) (i.e. they will be brought for accounts).\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Glorified is Allah! (He is Free) from what they attribute unto Him!\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except the slaves of Allah, whom He choses (for His Mercy i.e. true believers of Islamic Monotheism who do not attribute false things unto Allah).\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
So, verily you (pagans) and those whom you worship (idols).\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Cannot lead astray [turn away from Him (Allah) anyone of the believers],\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except those who are predestined to burn in Hell!\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
There is not one of us (angels) but has his known place (or position);\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
Verily, we (angels), we stand in rows for the prayers (as you Muslims stand in rows for your prayers);\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
Verily, we (angels), we are they who glorify (Allah's Praises i.e. perform prayers).\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And indeed they (Arab pagans) used to say;\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
``If we had a reminder as had the men of old (before the coming of Prophet Muhammad SAW as a Messenger of Allah).\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
``We would have indeed been the chosen slaves of Allah (true believers of Islamic Monotheism)!"\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But (now that the Quran has come) they disbelieve therein (i.e. in the Quran and in Prophet Muhammad SAW, and all that which he brought, the Divine Revelation), so they will come to know!\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And, verily, Our Word has gone forth of old for Our slaves, the Messengers,\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That they verily would be made triumphant.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And that Our hosts, they verily would be the victors.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So turn away (O Muhammad SAW) from them for a while,\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch them and they shall see (the punishment)!\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Do they seek to hasten on Our Torment?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
Then, when it descends into their courtyard (i.e. near to them), evil will be the morning for those who had been warned!\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So turn (O Muhammad SAW) away from them for a while,\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And watch and they shall see (the torment)!\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Glorified be your Lord, the Lord of Honour and Power! (He is free) from what they attribute unto Him!\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace be on the Messengers!\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And all the praise and thanks be to Allah, Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad [These letters (Sad etc.) are one of the miracles of the Quran and none but Allah (Alone) knows their meanings]. By the Quran full of reminding.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Nay, those who desbelieve are in false pride and opposition.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation We have destroyed before them, and they cried out when there was no longer time for escape!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they (Arab pagans) wonder that a warner (Prophet Muhammad SAW) has come to them from among themselves! And the disbelievers say: ``This (Prophet Muhammad SAW) is a sorcerer, a liar.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
``Has he made the aliha (gods) (all) into One Ilah (God - Allah). Verily, this is a curious thing!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the leaders among them went about (saying): ``Go on, and remain constant to your aliha (gods)! Verily, This is a thing designed (against you)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
``We have not heard (the like) of this among the people of these later days. This is nothing but an invention!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
``Has the Reminder been sent down to him (alone) from among us?" Nay! but they are in doubt about My Reminder (this Quran)! Nay, but they have not tasted (My) Torment!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or have they the treasures of the Mercy of your Lord, the All-Mighty, the Real Bestower?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or is it that the dominion of the heavens and the earth and all that is between them is theirs? If so, let them ascend up with means (to the heavens)!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
(As they denied Allah's Message) they will be a defeated host like the confederates of the old times (who were defeated).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them (were many who) belied Messengers, the people of Nuh (Noah); and 'Ad; and Fir'aun (Pharaoh) the man of stakes (with which he used to punish the people),\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And Thamud, and the people of Lout (Lot), and the dwellers of the wood; such were the confederates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Not one of them but belied the Messengers, therefore My Torment was justified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
And these only wait for a single Saihah [shout (i.e. the blowing of the Trumpet by the angel Israfil Sarafil)] there will be no pause or ending thereto [till everything will perish except Allah (the only God full of Majesty, Bounty and Honour)].\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: ``Our Lord! Hasten to us Qittana (i.e. our Record of good and bad deeds so that we see it) before the Day of Reckoning!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Be patient (O Muhammad SAW) of what they say, and remember Our slave Dawud (David), endued with power. Verily, he was ever oft-returning in all matters and in repentance (toward Allah).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Verily, We made the mountains to glorify Our Praises with him [Dawud (David)] in the 'Ashi (i.e. after the mid-day till sunset) and Ishraq (i.e. after the sunrise till mid-day).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And (so did) the birds assembled: all with him [Dawud (David)] did turn (to Allah i.e. glorified His Praises).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We made his kingdom strong and gave him Al-Hikmah (Prophethood, etc.) and sound judgement in speech and decision.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And has the news of the litigants reached you? When they climbed over the wall into (his) Mihrab (a praying place or a private room,).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered in upon Dawud (David), he was terrified of them, they said: ``Fear not! (We are) two litigants, one of whom has wronged the other, therefore judge between us with truth, and treat us not with injustice, and guide us to the Right Way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Verily, this my brother (in religion) has ninety nine ewes, while I have (only) one ewe, and he says: ``Hand it over to me, and he overpowered me in speech."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
[Dawud (David)] said (immediately without listening to the opponent): ``He has wronged you in demanding your ewe in addition to his ewes. And, verily, many partners oppress one another, except those who believe and do righteous good deeds, and they are few." And Dawud (David) guessed that We have tried him and he sought Forgiveness of his Lord, and he fell down prostrate and turned (to Allah) in repentance.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him that, and verily, for him is a near access to Us, and a good place of (final) return (Paradise).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
O Dawud (David)! Verily! We have placed you as a successor on earth, so judge you between men in truth (and justice) and follow not your desire for it will mislead you from the Path of Allah. Verily! Those who wander astray from the Path of Allah (shall) have a severe torment, because they forgot the Day of Reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We created not the heaven and the earth and all that is between them without purpose! That is the consideration of those who disbelieve! Then woe to those who disbelieve (in Islamic Monotheism) from the Fire!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We treat those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, as Mufsidun (those who associate partners in worship with Allah and commit crimes) on earth? Or shall We treat the Muttaqun (pious - see V. 2:2), as the Fujjar (criminals, disbelievers, wicked, etc)?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
(This is) a Book (the Quran) which We have sent down to you, full of blessings that they may ponder over its Verses, and that men of understanding may remember.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And to Dawud (David) We gave Sulaiman (Solomon). How excellent (a) slave! Verily, he was ever oft-returning in repentance (to Us)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When there were displayed before him, in the afternoon, well trained horses of the highest breed [for Jihad (holy fighting in Allah's Cause)].\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
And he said: ``Alas! I did love the good (these horses) instead of remembering my Lord (in my 'Asr prayer)" till the time was over, and (the sun) had hidden in the veil (of night).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Then he said ``Bring them (horses) back to me." Then he began to pass his hand over their legs and their necks (till the end of the display).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And, indeed We did try Sulaiman (Solomon) and We placed on his throne Jasadan (a devil, so he lost his kingdom for a while) but he did return (to his throne and kingdom by the Grace of Allah and he did return) to Allah with obedience and in repentance.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: ``My Lord! Forgive me, and bestow upon me a kingdom such as shall not belong to any other after me: Verily, You are the Bestower."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So, We subjected to him the wind, it blew gently to his order whithersoever he willed,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And also the Shayatin (devils) from the jinns (including) every kind of builder and diver,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And also others bound in fetters.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
[Saying of Allah to Sulaiman (Solomon)]: ``This is Our gift, so spend you or withhold, no account will be asked."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And verily, he enjoyed a near access to Us, and a good final return (Paradise).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember Our slave Ayub (Job), when he invoked his Lord (saying): ``Verily! Shaitan (Satan) has touched me with distress (by losing my health) and torment (by losing my wealth)!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(Allah said to him): ``Strike the ground with your foot: This is a spring of water to wash in, cool and a (refreshing) drink."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We gave him (back) his family, and along with them the like thereof, as a Mercy from Us, and a Reminder for those who understand.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
``And take in your hand a bundle of thin grass and strike therewith (your wife), and break not your oath. Truly! We found him patient. How excellent (a) slave! Verily, he was ever oft-returning in repentance (to Us)!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember Our slaves, Ibrahim (Abraham), Ishaque (Isaac), and Ya'qub (Jacob), (all) owners of strength (in worshipping Us) and (also) of religious understanding.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Verily, We did choose them by granting them (a good thing, i.e.) the remembrance of the home [in the Hereafter and they used to make the people remember it, and also they used to invite the people to obey Allah and to do good deeds for the Hereafter].\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
And they are with Us, verily, of the chosen and the best!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Isma'il (Ishmael), Al-Yasa'a (Elisha), and Dhul-Kifl (Isaiah), all are among the best.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a Reminder, and verily, for the Muttaqun (pious and righteous persons - see V. 2:2) is a good final return (Paradise),\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
'Adn (Edn) Paradise (everlasting Gardens), whose doors will be open for them, [It is said (in Tafsir At-Tabari, Part 23, Page 174) that one can speak to the doors, just one tells it to open and close, and it will open or close as it is ordered].\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Therein they will recline; therein they will call for fruits in abundance and drinks;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And beside them will be chaste females (virgins) restraining their glances only for their husbands, (and) of equal ages.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This it is what you (Al-Muttaqun - the pious) are promised for the Day of Reckoning!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
(It will be said to them)! Verily, this is Our Provision which will never finish;\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This is so! And for the Taghun (transgressors, disobedient to Allah and His Messenger - disbelievers in the Oneness of Allah, criminals, etc.), will be an evil final return (Fire),\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell! Where they will burn, and worst (indeed) is that place to rest!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
This is so! Then let them taste it, a boiling fluid and dirty wound discharges.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other torments of similar kind, all together!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
This is a troop entering with you (in Hell), no welcome for them! Verily, they shall burn in the Fire!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
(The followers of the misleaders will say): ``Nay, you (too)! No welcome for you! It is you (misleaders) who brought this upon us (because you misled us in the world), so evil is this place to stay in!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say: ``Our Lord! Whoever brought this upon us, add to him a double torment in the Fire!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say: ``What is the matter with us that we see not men whom we used to count among the bad ones?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Did we take them as an object of mockery, or have (our) eyes failed to perceive them?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Verily, that is the very truth, the mutual dispute of the people of the Fire!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say (O Muhammad SAW): ``I am only a warner and there is no Ilah (God) except Allah (none has the right to be worshipped but Allah) the One, the Irresistible,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
``The Lord of the heavens and the earth and all that is between them, the All-Mighty, the Oft-Forgiving."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: ``That (this Quran) is a great news,\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
``From which you turn away!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
``I had no knowledge of the chiefs (angels) on high when they were disputing and discussing (about the creation of Adam).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
``Only this has been inspired to me, that I am a plain warner."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
(Remember) when your Lord said to the angels: ``Truly, I am going to create man from clay".\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
So when I have fashioned him and breathed into him (his) soul created by Me, then you fall down prostrate to him."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So the angels prostrated themselves, all of them:\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Except Iblis (Satan) he was proud and was one of the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
(Allah) said: ``O Iblis (Satan)! What prevents you from prostrating yourself to one whom I have created with Both My Hands. Are you too proud (to fall prostrate to Adam) or are you one of the high exalted?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
[Iblis (Satan)] said: ``I am better than he, You created me from fire, and You created him from clay."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
(Allah) said: ``Then get out from here, for verily, you are outcast.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
``And verily!, My Curse is on you till the Day of Recompense."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
[Iblis (Satan)] said: ``My Lord! Give me then respite till the Day the (dead) are resurrected."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
(Allah) said: ``Verily! You are of those allowed respite\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
``Till the Day of the time appointed."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
[Iblis (Satan)] said: ``By Your Might, then I will surely mislead them all,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
``Except Your chosen slaves amongst them (faithful, obedient, true believers of Islamic Monotheism)."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
(Allah) said: ``The Truth is, and the Truth I say,\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
That I will fill Hell with you [Iblis (Satan)] and those of them (mankind) that follow you, together."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say (O Muhammad SAW): ``No wage do I ask of you for this (the Quran), nor am I one of the Mutakallifun (those who pretend and fabricate things which do not exist).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
``It (this Quran) is only a Reminder for all the 'Alamin (mankind and jinns).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
``And you shall certainly know the truth of it after a while.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of this Book (the Quran) is from Allah, the All-Mighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Verily, We have sent down the Book to you (O Muhammad SAW) in truth: So worship Allah (Alone) by doing religious deeds sincerely for Allah's sake only, (and not to show-off, and not to set up rivals with Him in worship).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Surely, the religion (i.e. the worship and the obedience) is for Allah only. And those who take Auliya' (protectors and helpers) besides Him (say): ``We worship them only that they may bring us near to Allah." Verily, Allah will judge between them concerning that wherein they differ. Truly, Allah guides not him who is a liar, and a disbeliever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Had Allah willed to take a son (or offspring or children), He could have chosen whom He pleased out of those whom He created. But glory be to Him! (He is above such things). He is Allah, the One, the Irresistible.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He has created the heavens and the earth with truth. He makes the night to go in the day and makes the day to go in the night. And He has subjected the sun and the moon. Each running (on a fixed course) for an appointed term. Verily, He is the All-Mighty, the Oft-Forgiving.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you (all) from a single person (Adam); then made from him his wife [Hawwa' (Eve)]. And He has sent down for you of cattle eight pairs (of the sheep, two, male and female; of the goats, two, male and female; of the oxen, two, male and female; and of the camels, two, male and female). He creates you in the wombs of your mothers, creation after creation in three veils of darkness, such is Allah your Lord. His is the kingdom, La ilaha illa Huwa (none has the right to be worshipped but He). How then are you turned away?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve, then verily, Allah is not in need of you, He likes not disbelief for His slaves. And if you are grateful (by being believers), He is pleased therewith for you. No bearer of burdens shall bear the burden of another. Then to your Lord is your return, so He will inform you what you used to do. Verily, He is the All-Knower of that which is in (men's) breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when some hurt touches man, he cries to his Lord (Allah Alone), turning to Him in repentance, but when He bestows a favour upon him from Himself, he forgets that for which he cried for before, and he sets up rivals to Allah, in order to mislead others from His Path. Say: ``Take pleasure in your disbelief for a while: surely, you are (one) of the dwellers of the Fire!"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is one who is obedient to Allah, prostrating himself or standing (in prayer) during the hours of the night, fearing the Hereafter and hoping for the Mercy of his Lord (like one who disbelieves)? Say: ``Are those who know equal to those who know not?" It is only men of understanding who will remember (i.e. get a lesson from Allah's Signs and Verses).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say (O Muhammad SAW): ``O My slaves who believe (in the Oneness of Allah Islamic Monotheism), be afraid of your Lord (Allah) and keep your duty to Him. Good is (the reward) for those who do good in this world, and Allah's earth is spacious (so if you cannot worship Allah at a place, then go to another)! Only those who are patient shall receive their rewards in full, without reckoning."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say (O Muhammad SAW): ``Verily, I am commanded to worship Allah (Alone) by obeying Him and doing religious deeds sincerely for Allah's sake only and not to show off, and not to set up rivals with Him in worship;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
``And I am commanded (this) in order that I may be the first of those who submit themselves to Allah (in Islam) as Muslims."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say (O Muhammad SAW): ``Verily, if I disobey my Lord, I am afraid of the torment of a great Day."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say (O Muhammad SAW) ``Allah Alone I worship by doing religious deeds sincerely for His sake only and not to show-off, and not to set up rivals with Him in worship."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
So worship what you like besides Him. Say (O Muhammad SAW): ``The losers are those who will lose themselves and their families on the Day of Resurrection. Verily, that will be a manifest loss!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They shall have coverings of Fire, above them and covering (of Fire) beneath them; with this Allah does frighten His slaves: ``O My slaves, therefore fear Me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
Those who avoid At-Taghut (false deities) by not worshipping them and turn to Allah in repentance, for them are glad tidings; so announce the good news to My slaves,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Those who listen to the Word [good advice La ilaha ill-Allah (none has the right to be worshipped but Allah) and Islamic Monotheism, etc.] and follow the best thereof (i.e. worship Allah Alone, repent to Him and avoid Taghut, etc.) those are (the ones) whom Allah has guided and those are men of understanding (like Zaid bin 'Amr bin Nufail, Salman Al-Farisi and Abu Dhar Al-Ghifari). [Tafsir Al-Qurtubi, Vol. 12, P. 244]\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Is, then one against whom the Word of punishment justified (equal to the one who avoids evil). Will you (O Muhammad SAW) rescue him who is in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who fear Allah and keep their duty to their Lord (Allah), for them are built lofty rooms; one above another under which rivers flow (i.e. Paradise). (This is) the Promise of Allah: and Allah does not fail in (His) Promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
See you not, that Allah sends down water (rain) from the sky, and causes it to penetrate the earth, (and then makes it to spring up) as water-springs and afterward thereby produces crops of different colours, and afterward they wither and you see them turn yellow, then He makes them dry and broken pieces. Verily, in this, is a Reminder for men of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is he whose breast Allah has opened to Islam, so that he is in light from His Lord (as he who is non-Muslim)? So, woe to those whose hearts are hardened against remembrance of Allah! They are in plain error!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has sent down the best statement, a Book (this Quran), its parts resembling each other in goodness and truth, oft-repeated. The skins of those who fear their Lord shiver from it (when they recite it or hear it). Then their skin and their heart soften to the remembrance of Allah. That is the guidance of Allah. He Guides therewith whom He pleases and whomever Allah sends astray, for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he then, who will confront with his face the awful torment on the Day of Resurrection (as he who enters peacefully in Paradise)? And it will be said to the Zalimun (polytheists and wrong-doers, etc.): ``Taste what you used to earn!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them belied, and so the torment came on them from directions they perceived not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah made them to taste the disgrace in the present life, but greater is the torment of the Hereafter if they only knew!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And indeed We have put forth for men, in this Quran every kind of similitude in order that they may remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
An Arabic Quran, without any crookedness (therein) in order that they may avoid all evil which Allah has ordered them to avoid, fear Him and keep their duty to Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah puts forth a similitude: a (slave) man belonging to many partners (like those who worship others along with Allah) disputing with one another, and a (slave) man belonging entirely to one master, (like those who worship Allah Alone). Are those two equal in comparison? All the praises and thanks be to Allah! But most of them know not.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Verily, you (O Muhammad SAW) will die and verily, they (too) will die.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then, on the Day of Resurrection, you will be disputing before your Lord.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Then, who does more wrong than one who utters a lie against Allah, and denies the truth [this Quran, the Prophet (Muhammad SAW), the Islamic Monotheism, the Resurrection and the reward or punishment according to good or evil deeds] when it comes to him! Is there not in Hell an abode for the disbelievers?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And he (Muhammad SAW) who has brought the truth (this Quran and Islamic Monotheism) and (those who) believed therein (i.e. the true believers of Islamic Monotheism), those are Al- Muttaqun (the pious and righteous persons - see V. 2:2).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have all that they will desire with their Lord. That is the reward of Muhsinun (good-doers - see V. 2:112).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
So that Allah may remit from them the evil of what they did and give them the reward, according to the best of what they used to do.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah Sufficient for His slave? Yet they try to frighten you with those (whom they worship) besides Him! And whom Allah sends astray, for him there will be no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And whomsoever Allah guides, for him there will be no misleader. Is not Allah All-Mighty, Possessor of Retribution?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And verily, if you ask them: ``Who created the heavens and the earth?" Surely, they will say: ``Allah (has created them)." Say: ``Tell me then, the things that you invoke besides Allah, if Allah intended some harm for me, could they remove His harm, or if He (Allah) intended some mercy for me, could they withhold His Mercy?" Say: ``Sufficient for me is Allah; in Him those who trust (i.e. believers) must put their trust."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: (O Muhammad SAW) ``O My people! Work according to your way, I am working (according to my way). Then you will come to know,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
``To whom comes a disgracing torment, and on whom descends an everlasting torment."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Verily, We have sent down to you (O Muhammad SAW) the Book (this Quran) for mankind in truth. So whosoever accepts the guidance, it is only for his ownself, and whosoever goes astray, he goes astray only for his (own) loss. And you (O Muhammad SAW) are not a Wakil (trustee or disposer of affairs, or keeper) over them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
It is Allah Who takes away the souls at the time of their death, and those that die not during their sleep. He keeps those (souls) for which He has ordained death and sends the rest for a term appointed. Verily, in this are signs for a people who think deeply.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Have they taken others as intercessors besides Allah? Say: ``Even if they have power over nothing whatever and have no intelligence?"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: ``To Allah belongs all intercession. His is the Sovereignty of the heavens and the earth, then to Him you shall be brought back."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah Alone is mentioned, the hearts of those who believe not in the Hereafter are filled with disgust (from the Oneness of Allah and when those (whom they obey or worship) besides Him [like all false deities other than Allah, it may be a Messenger like 'Iesa (Jesus) - son of Maryam (Mary), 'Uzair (Ezra), an angel, a pious man, a jinn, or any other creature even idols, graves of religious people, saints, priests, monks, etc.] are mentioned, behold, they rejoice!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say (O Muhammad SAW): ``O Allah! Creator of the heavens and the earth! All-Knower of the Ghaib (unseen) and the seen. You will judge between your slaves about that wherein they used to differ."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And those who did wrong (the polytheists and disbelievers in the Oneness of Allah), if they had all that is in earth and therewith as much again, they verily, would offer it to ransom themselves therewith on the Day of Resurrection from the evil torment, and there will become apparent to them from Allah, what they had not been reckoning.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And the evils of that which they earned will become apparent to them, and they will be encircled by that which they used to mock at!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When harm touches man, he calls to Us (for help), then when We have (rescued him from that harm and) changed it into a favour from Us, he says: ``Only because of knowledge (that I possess) I obtained it." Nay, it is only a trial, but most of them know not!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Verily, those before them said it, yet (all) that they had earned availed them not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
So, the evil results of that which they earned overtook them. And those who did wrong of these [people to whom you (Muhammad SAW) have been sent], will also be overtaken by the evil results (torment) for that which they earned, and they will never be able to escape.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah enlarges the provision for whom He wills, and straitens it (for whom He wills). Verily, in this are signs for the folk who believe!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: ``O 'Ibadi (My slaves) who have transgressed against themselves (by committing evil deeds and sins)! Despair not of the Mercy of Allah, verily Allah forgives all sins. Truly, He is Oft-Forgiving, Most Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
``And turn in repentance and in obedience with true Faith (Islamic Monotheism) to your Lord and submit to Him, (in Islam), before the torment comes upon you, then you will not be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
``And follow the best of that which is sent down to you from your Lord (i.e. this Quran, do what it orders you to do and keep away from what it forbids), before the torment comes on you suddenly while you perceive not!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest a person should say: ``Alas, my grief that I was undutiful to Allah (i.e. I have not done what Allah has ordered me to do), and I was indeed among those who mocked [at the truth! i.e. La ilaha ill-Allah (none has the right to be worshipped but Allah), the Quran, and Muhammad SAW and at the faithful believers, etc.]\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or (lest) he should say: ``If only Allah had guided me, I should indeed have been among the Muttaqun (pious and righteous persons - see V. 2:2)."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or (lest) he should say when he sees the torment: ``If only I had another chance (to return to the world) then I should indeed be among the Muhsinun (good-doers - see V. 2:112)."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
Yes! Verily, there came to you My Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and you denied them, and were proud and were among the disbelievers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And on the Day of Resurrection you will see those who lied against Allah (i.e. attributed to Him sons, partners, etc.) their faces will be black. Is there not in Hell an abode for the arrogant ones?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah will deliver those who are the Muttaqun (pious - see V. 2:2) to their places of success (Paradise). Evil shall touch them not, nor shall they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of all things, and He is the Wakil (Trustee, Disposer of affairs, Guardian, etc.) over all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the keys of the heavens and the earth. And those who disbelieve in the Ayat (proofs, evidences, verses, signs, revelations, etc.) of Allah, such are they who will be the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say (O Muhammad SAW to the polytheists, etc.): ``Do you order me to worship other than Allah O you fools?"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And indeed it has been revealed to you (O Muhammad SAW), as it was to those (Allah's Messengers) before you: ``If you join others in worship with Allah, (then) surely (all) your deeds will be in vain, and you will certainly be among the losers."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Nay! But worship Allah (Alone and none else), and be among the grateful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They made not a just estimate of Allah such as is due to Him. And on the Day of Resurrection the whole of the earth will be grasped by His Hand and the heavens will be rolled up in His Right Hand. Glorified is He, and High is He above all that they associate as partners with Him!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Trumpet will be blown, and all who are in the heavens and all who are on the earth will swoon away, except him whom Allah will. Then it will blown a second time and behold, they will be standing, looking on (waiting).\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will shine with the light of its Lord (Allah, when He will come to judge among men) and the Book will be placed (open) and the Prophets and the witnesses will be brought forward, and it will be judged between them with truth, and they will not be wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And each person will be paid in full of what he did; and He is Best Aware of what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And those who disbelieved will be driven to Hell in groups, till, when they reach it, the gates thereof will be opened (suddenly like a prison at the arrival of the prisoners). And its keepers will say, ``Did not the Messengers come to you from yourselves, reciting to you the Verses of your Lord, and warning you of the Meeting of this Day of yours?" They will say: ``Yes, but the Word of torment has been justified against the disbelievers!"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said (to them): ``Enter you the gates of Hell, to abide therein. And (indeed) what an evil abode of the arrogant!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who kept their duty to their Lord will be led to Paradise in groups, till, when they reach it, and its gates will be opened (before their arrival for their reception) and its keepers will say: Salamun 'Alaikum (peace be upon you)! You have done well, so enter here to abide therein."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they will say: ``All the praises and thanks be to Allah Who has fulfilled His Promise to us and has made us inherit (this) land. We can dwell in Paradise where we will; how excellent a reward for the (pious good) workers!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you will see the angels surrounding the Throne (of Allah) from all round, glorifying the praises of their Lord (Allah). And they (all the creatures) will be judged with truth, and it will be said. All the praises and thanks be to Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Book (this Quran) is from Allah the All-Mighty, the All-Knower.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The Forgiver of sin, the Acceptor of repentance, the Severe in punishment, the Bestower (of favours), La ilaha illa Huwa (none has the right to be worshipped but He), to Him is the final return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None disputes in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah but those who disbelieve. So let not their ability of going about here and there through the land (for their purposes) deceive you [O Muhammad SAW, their ultimate end will be the Fire of Hell]!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The people of Nuh (Noah) and the confederates after them denied (their Messengers) before these, and every (disbelieving) nation plotted against their Messenger to seize him, and disputed by means of falsehood to refute therewith the truth. So I seized them (with punishment), and how (terrible) was My punishment!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus has the Word of your Lord been justified against those who disbelieved, that they will be the dwellers of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those (angels) who bear the Throne (of Allah) and those around it glorify the praises of their Lord, and believe in Him, and ask forgiveness for those who believe (in the Oneness of Allah) (saying): ``Our Lord! You comprehend all things in mercy and knowledge, so forgive those who repent and follow Your Way, and save them from the torment of the blazing Fire!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
``Our Lord! And make them enter the 'Adn (Eden) Paradise (everlasting Gardens) which you have promised them, and to the righteous among their fathers, their wives, and their offspring! Verily, You are the All-Mighty, the All-Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
``And save them from (the punishment, because of what they did of) the sins, and whomsoever You save from (the punishment, because of what they did of) the sins (i.e. excuse them) that Day, him verily, You have taken into mercy." And that is the supreme success.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Those who disbelieve will be addressed (at the time of entering into the Fire): ``Allah's aversion was greater towards you (in the worldly life when you used to reject the Faith) than your aversion towards one another (now in the Fire of Hell, as you are now enemies to one another), when you were called to the Faith but you used to refuse."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say: ``Our Lord! You have made us to die twice (i.e. we were dead in the loins of our fathers and dead after our deaths in this world), and You have given us life twice (i.e. life when we were born and life when we are Resurrected)! Now we confess our sins, then is there any way to get out (of the Fire)?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(It will be said): ``This is because, when Allah Alone was invoked (in worship, etc.) you disbelieved, but when partners were joined to Him, you believed! So the judgement is only with Allah, the Most High, the Most Great!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He, Who shows you His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) and sends down (rain with which grows) provision for you from the sky. And none remembers but those who turn (to Allah) in obedience and in repentance (by begging His Pardon and by worshipping and obeying Him Alone and none else).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So, call you (O Muhammad SAW and the believers) upon (or invoke) Allah making (your) worship pure for Him (Alone) (by worshipping none but Him and by doing religious deeds sincerely for Allah's sake only and not to show-off and not to set up rivals with Him in worship). However much the disbelievers (in the Oneness of Allah) may hate (it).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
(He is Allah) Owner of High Ranks and Degrees, the Owner of the Throne. He sends the Inspiration by His Command to any of His slaves He wills, that he (the person who receives inspiration) may warn (men) of the Day of Mutual Meeting (i.e. The Day of Resurrection).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day when they will (all) come out, nothing of them will be hidden from Allah. Whose is the kingdom this Day? (Allah Himself will reply to His Question): It is Allah's the One, the Irresistible!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
This Day shall every person be recompensed for what he earned. No injustice (shall be done to anybody). Truly, Allah is Swift in reckoning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them (O Muhammad SAW) of the Day that is drawing near (i.e. the Day of Resurrection), when the hearts will be choking the throats, and they can neither return them (hearts) to their chests nor can they throw them out. There will be no friend, nor an intercessor for the Zalimun (polytheists and wrong-doers, etc.), who could be given heed to.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
Allah knows the fraud of the eyes, and all that the breasts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
And Allah judges with truth, while those to whom they invoke besides Him, cannot judge anything. Certainly, Allah! He is the All-Hearer, the All-Seer.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not travelled in the land and seen what was the end of those who were before them? They were superior to them in strength, and in the traces (which they left) in the land. But Allah seized them with punishment for their sins. And none had they to protect them from Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because there came to them their Messengers with clear evidences, proofs and signs but they disbelieved (in them). So Allah seized them with punishment. Verily, He is All-Strong, Severe in punishment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And indeed We sent Musa (Moses) with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), and a manifest authority,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
To Fir'aun (Pharaoh), Haman and Qarun (Korah), but they called (him): ``A sorcerer, a liar!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
Then, when he brought them the Truth from Us, they said: ``Kill the sons of those who believe with him and let their women live", but the plots of disbelievers are nothing but errors!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
Fir'aun (Pharaoh) said: ``Leave me to kill Musa (Moses), and let him call his Lord (to stop me from killing him)! I fear that he may change your religion, or that he may cause mischief to appear in the land!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Musa (Moses) said: ``Verily, I seek refuge in my Lord and your Lord from every arrogant who believes not in the Day of Reckoning!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And a believing man of Fir'aun's (Pharaoh) family, who hid his faith said: ``Would you kill a man because he says: My Lord is Allah, and he has come to you with clear signs (proofs) from your Lord? And if he is a liar, upon him will be (the sin of) his lie; but if he is telling the truth, then some of that (calamity) wherewith he threatens you will befall on you." Verily, Allah guides not one who is a Musrif (a polytheist, or a murderer who shed blood without a right, or those who commit great sins, oppressor, transgressor), a liar!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
``O my people! Yours is the kingdom this day, you are uppermost in the land. But who will save us from the Torment of Allah, should it befall us?" Fir'aun (Pharaoh) said: ``I show you only that which I see (correct), and I guide you only to the path of right policy!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And he who believed said: ``O my people! Verily, I fear for you a fate like that day (of disaster) of the Confederates (of old)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
``Like the fate of the people of Nuh (Noah), and 'Ad, and Thamud and those who came after them. And Allah wills no injustice for (His) slaves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
``And, O my people! Verily! I fear for you the Day when there will be mutual calling (between the people of Hell and of Paradise)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
A Day when you will turn your backs and flee having no protector from Allah, And whomsoever Allah sends astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
And indeed Yusuf (Joseph) did come to you, in times gone by, with clear signs, but you ceased not to doubt in that which he did bring to you, till when he died you said: ``No Messenger will Allah send after him." Thus Allah leaves astray him who is a Musrif (a polytheist, oppressor, a criminal, sinner who commit great sins) and a Murtab (one who doubts Allah's Warning and His Oneness).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who dispute about the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, without any authority that has come to them, it is greatly hateful and disgusting to Allah and to those who believe. Thus does Allah seal up the heart of every arrogant, tyrant. (So they cannot guide themselves to the Right Path).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Fir'aun (Pharaoh) said: ``O Haman! Build me a tower that I may arrive at the ways,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
``The ways of the heavens, and I may look upon the Ilah (God) of Musa (Moses) but verily, I think him to be a liar." Thus it was made fair-seeming, in Fir'aun's (Pharaoh) eyes, the evil of his deeds, and he was hindered from the (Right) Path, and the plot of Fir'aun (Pharaoh) led to nothing but loss and destruction (for him).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And the man who believed said: ``O my people! Follow me, I will guide you to the way of right conduct [i.e. guide you to Allah's religion of Islamic Monotheism with which Musa (Moses) has been sent].\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
``O my people! Truly, this life of the world is nothing but a (quick passing) enjoyment, and verily, the Hereafter that is the home that will remain forever."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
``Whosoever does an evil deed, will not be requited except the like thereof, and whosoever does a righteous deed, whether male or female and is a true believer (in the Oneness of Allah), such will enter Paradise, where they will be provided therein (with all things in abundance) without limit.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
``And O my people! How is it that I call you to salvation while you call me to the Fire!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
``You invite me to disbelieve in Allah (and in His Oneness), and to join partners in worship with Him; of which I have no knowledge, and I invite you to the All-Mighty, the Oft-Forgiving!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
``No doubt you call me to (worship) one who cannot grant (me) my request (or respond to my invocation) in this world or in the Hereafter. And our return will be to Allah, and Al-Musrifun (i.e. polytheists and arrogants, those who commit great sins, the transgressors of Allah's set limits)! They shall be the dwellers of the Fire!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
``And you will remember what I am telling you, and my affair I leave it to Allah. Verily, Allah is the All-Seer of (His) slaves."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So Allah saved him from the evils that they plotted (against him), while an evil torment encompassed Fir'aun's (Pharaoh) people.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire; they are exposed to it, morning and afternoon, and on the Day when the Hour will be established (it will be said to the angels): ``Cause Fir'aun's (Pharaoh) people to enter the severest torment!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And, when they will dispute in the Fire, the weak will say to those who were arrogant; ``Verily! We followed you, can you then take from us some portion of the Fire?"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were arrogant will say: ``We are all (together) in this (Fire)! Verily Allah has judged between (His) slaves!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say to the keepers (angels) of Hell: ``Call upon your Lord to lighten for us the torment for a day!"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say: ``Did there not come to you, your Messengers with (clear) evidences and signs? They will say: ``Yes." They will reply: ``Then call (as you like)! And the invocation of the disbelievers is nothing but in error!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Verily, We will indeed make victorious Our Messengers and those who believe (in the Oneness of Allah Islamic Monotheism) in this world's life and on the Day when the witnesses will stand forth, (i.e. Day of Resurrection),\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The Day when their excuses will be of no profit to Zalimun (polytheists, wrong-doers and disbelievers in the Oneness of Allah). Theirs will be the curse, and theirs will be the evil abode (i.e. painful torment in Hell-fire).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And, indeed We gave Musa (Moses) the guidance, and We caused the Children of Israel to inherit the Scripture [i.e. the Taurat (Torah)],\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guide and a reminder for men of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
So be patient (O Muhammad SAW). Verily, the Promise of Allah is true, and ask forgiveness for your fault, and glorify the praises of your Lord in the Ashi (i.e. the time period after the midnoon till sunset) and in the Ibkar (i.e. the time period from early morning or sunrise till before midnoon) [it is said that, that means the five compulsory congregational Salat (prayers) or the 'Asr and Fajr prayers].\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Verily, those who dispute about the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah, without any authority having come to them, there is nothing else in their breasts except pride [to accept you (Muhammad SAW) as a Messenger of Allah and to obey you]. They will never have it (i.e. Prophethood which Allah has bestowed upon you). So seek refuge in Allah (O Muhammad SAW from the arrogants). Verily, it is He Who is the All-Hearer, the All-Seer.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
The creation of the heavens and the earth is indeed greater than the creation of mankind, yet most of mankind know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
And not equal are the blind and those who see, nor are (equal) those who believe (in the Oneness of Allah Islamic Monotheism), and do righteous good deeds, and those who do evil. Little do you remember!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Verily, the Hour (Day of Judgement) is surely coming, therein is no doubt, yet most men believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord said: ``Invoke Me, [i.e. believe in My Oneness (Islamic Monotheism)] (and ask Me for anything) I will respond to your (invocation). Verily! Those who scorn My worship [i.e. do not invoke Me, and do not believe in My Oneness, (Islamic Monotheism)] they will surely enter Hell in humiliation!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
Allah, it is He Who has made the night for you that you may rest therein and the day for you to see. Truly, Allah is full of Bounty to mankind, yet most of mankind give no thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
That is Allah, your Lord, the Creator of all things, La ilaha illa Huwa (none has the right to be worshipped but He), where then you are turning away (from Allah, by worshipping others instead of Him)!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus were turned away those who used to deny the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
Allah, it is He Who has made for you the earth as a dwelling place and the sky as a canopy, and has given you shape and made your shapes good (looking) and has provided you with good things. That is Allah, your Lord, then blessed be Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Ever Living, La ilaha illa Huwa (none has the right to be worshipped but He), so invoke Him making your worship pure for Him Alone (by worshipping Him Alone, and none else, and by doing righteous deeds sincerely for Allah's sake only, and not to show off, and not to set up rivals with Him in worship). All the praises and thanks be to Allah, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say (O Muhammad SAW): ``I have been forbidden to worship those whom you worship besides Allah, since there have come to me evidences from my Lord, and I am commanded to submit (in Islam) to the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
He, it is Who has created you (Adam) from dust, then from a Nutfah [mixed semen drops of male and female discharge (i.e. Adam's offspring)] then from a clot (a piece of coagulated blood), then brings you forth as children, then (makes you grow) to reach the age of full strength, and afterwards to be old (men and women), though some among you die before, and that you reach an appointed term, in order that you may understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
He it is Who gives life and causes death. And when He decides upon a thing He says to it only: ``Be!" and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
See you not those who dispute about the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of Allah? How are they turning away (from the truth, i.e. Islamic Monotheism to the falsehood of polytheism)?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who deny the Book (this Quran), and that with which We sent Our Messengers (i.e. to worship none but Allah Alone sincerely, and to reject all false deities and to confess resurrection after the death for recompense) they will come to know (when they will be cast into the Fire of Hell).\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When iron collars will be rounded over their necks, and the chains, they shall be dragged along.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
In the boiling water, then they will be burned in the Fire.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it will be said to them: ``Where are (all) those whom you used to join in worship as partners\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
``Besides Allah" They will say: ``They have vanished from us: Nay, we did not invoke (worship) anything before." Thus Allah leads astray the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
That was because you had been exulting in the earth without any right (by worshipping others instead of Allah and by committing crimes), and that you used to rejoice extremely (in your error).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Hell to abide therein, and (indeed) what an evil abode of the arrogant!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be patient (O Muhammad SAW), verily, the Promise of Allah is true, and whether We show you (O Muhammad SAW in this world) some part of what We have promised them, or We cause you to die, then it is to Us they all shall be returned.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
And, indeed We have sent Messengers before you (O Muhammad SAW); of some of them We have related to you their story and of some We have not related to you their story, and it was not given to any Messenger that he should bring a sign except by the Leave of Allah. So, when comes the Commandment of Allah, the matter will be decided with truth, and the followers of falsehood will then be lost.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
Allah, it is He Who has made cattle for you, that you may ride on some of them and of some you eat.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And you have (many other) benefits from them, and that you may reach by their means a desire that is in your breasts (i.e. carry your goods, loads, etc.), and on them and on ships you are carried.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His Signs and Proofs (of His Oneness in all the above mentioned things). Which, then of the Signs and Proofs of Allah do you deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not travelled through the earth and seen what was the end of those before them? They were more numerous than them and mightier in strength, and in the traces (they have left behind them) in the land, yet all that they used to earn availed them not.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
Then when their Messengers came to them with clear proofs, they were glad (and proud) with that which they had of the knowledge (of worldly things): And that at which they used to mock, surrounded them (i.e. the punishment).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
So when they saw Our punishment, they said: ``We believe in Allah Alone and reject (all) that we used to associate with Him as (His) partners.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
Then their Faith (in Islamic Monotheism) could not avail them when they saw Our punishment. (Like) this has been the way of Allah in dealing with His slaves. And there the disbelievers lost utterly (when Our Torment covered them).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings.]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A revelation from Allah, the Most Beneficent, the Most Merciful.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book whereof the Verses are explained in detail; A Quran in Arabic for people who know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Giving glad tidings [of Paradise to the one who believes in the Oneness of Allah (i.e. Islamic Monotheism) and fears Allah much (abstains from all kinds of sins and evil deeds) and loves Allah much (performing all kinds of good deeds which He has ordained)], and warning (of punishment in the Hell Fire to the one who disbelieves in the Oneness of Allah), but most of them turn away, so they listen not.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say: ``Our hearts are under coverings (screened) from that to which you invite us, and in our ears is deafness, and between us and you is a screen, so work you (on your way); verily, we are working (on our way)."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say (O Muhammad SAW): ``I am only a human being like you. It is inspired in me that your Ilah (God) is One Ilah (God - Allah), therefore take Straight Path to Him (with true Faith Islamic Monotheism) and obedience to Him, and seek forgiveness of Him. And woe to Al-Mushrikun (the disbelievers in the Oneness of Allah, polytheists, idolaters, etc. - see V. 2:105).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who give not the Zakat and they are disbelievers in the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Truly, those who believe (in the Oneness of Allah Islamic Monotheism, and in His Messenger Muhammad SAW) and do righteous good deeds, for them will be an endless reward that will never stop (i.e. Paradise).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say (O Muhammad SAW): ``Do you verily disbelieve in Him Who created the earth in two Days and you set up rivals (in worship) with Him? That is the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He placed therein (i.e. the earth) firm mountains from above it, and He blessed it, and measured therein its sustenance (for its dwellers) in four Days equal (i.e. all these four 'days' were equal in the length of time), for all those who ask (about its creation).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He Istawa (rose over) towards the heaven when it was smoke, and said to it and to the earth: ``Come both of you willingly or unwillingly." They both said: ``We come, willingly."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
Then He completed and finished from their creation (as) seven heavens in two Days and He made in each heaven its affair. And We adorned the nearest (lowest) heaven with lamps (stars) to be an adornment as well as to guard (from the devils by using them as missiles against the devils). Such is the Decree of Him the All-Mighty, the All-Knower.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, then say (O Muhammad SAW): ``I have warned you of a Sa'iqah (a destructive awful cry, torment, hit, a thunderbolt) like the Sa'iqah which overtook 'Ad and Thamud (people)."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When the Messengers came to them, from before them and behind them (saying): ``Worship none but Allah" They said: ``If our Lord had so willed, He would surely have sent down the angels. So indeed! We disbelieve in that with which you have been sent."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for 'Ad, they were arrogant in the land without right, and they said: ``Who is mightier than us in strength?" See they not that Allah, Who created them was mightier in strength than them. And they used to deny Our Ayat (proofs, evidences, verses, lessons, revelations, etc.)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
So We sent upon them furious wind in days of evil omen (for them) that We might give them a taste of disgracing torment in this present worldly life, but surely the torment of the Hereafter will be more disgracing, and they will never be helped.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for Thamud, We showed and made clear to them the Path of Truth (Islamic Monotheism) through Our Messenger, (i.e. showed them the way of success), but they preferred blindness to guidance, so the Sa'iqah (a destructive awful cry, torment, hit, a thunderbolt) of disgracing torment seized them, because of what they used to earn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We saved those who believed and used to fear Allah, keep their duty to Him and avoid evil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And (remember) the Day that the enemies of Allah will be gathered to the Fire, so they will be collected there (the first and the last).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Till, when they reach it (Hell-fire), their hearing (ears) and their eyes, and their skins will testify against them as to what they used to do.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say to their skins, ``Why do you testify against us?" They will say: ``Allah has caused us to speak, as He causes all things to speak, and He created you the first time, and to Him you are made to return."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
And you have not been hiding against yourselves, lest your ears, and your eyes, and your skins testify against you, but you thought that Allah knew not much of what you were doing.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
And that thought of yours which you thought about your Lord, has brought you to destruction, and you have become (this Day) of those utterly lost!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Then, if they have patience, yet the Fire will be a home for them, and if they beg for to be excused, yet they are not of those who will ever be excused.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We have assigned them (devils) intimate companions (in this world), who have made fair-seeming to them, what was before them (evil deeds which they were doing in the present worldly life and disbelief in the Reckoning and the Resurrection, etc.) and what was behind them (denial of the matters in the coming life of the Hereafter as regards punishment or reward, etc.). And the Word (i.e. the torment) is justified against them as it was justified against those who were among the previous generations of jinns and men that had passed away before them. Indeed they (all) were the losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
And those who disbelieve say: ``Listen not to this Quran, and make noise in the midst of its (recitation) that you may overcome."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
But surely, We shall cause those who disbelieve to taste a severe torment, and certainly, We shall requite them the worst of what they used to do.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the recompense of the enemies of Allah: The Fire, therein will be for them the eternal home, a (deserving) recompense for that they used to deny Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And those who disbelieve will say: ``Our Lord! Show us those among jinns and men who led us astray, we shall crush them under our feet, so that they become the lowest."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Verily, those who say: ``Our Lord is Allah (Alone)," and then they Istaqamu, on them the angels will descend (at the time of their death) (saying): ``Fear not, nor grieve! But receive the glad tidings of Paradise which you have been promised!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
``We have been your friends in the life of this world and are (so) in the Hereafter. Therein you shall have (all) that your inner-selves desire, and therein you shall have (all) for which you ask for.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
``An entertainment from (Allah), the Oft-Forgiving, Most Merciful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than he who [says: ``My Lord is Allah (believes in His Oneness)," and then stands straight (acts upon His Order), and] invites (men) to Allah's (Islamic Monotheism), and does righteous deeds, and says: ``I am one of the Muslims."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
The good deed and the evil deed cannot be equal. Repel (the evil) with one which is better (i.e. Allah ordered the faithful believers to be patient at the time of anger, and to excuse those who treat them badly), then verily! he, between whom and you there was enmity, (will become) as though he was a close friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none is granted it (the above quality) except those who are patient, and none is granted it except the owner of the great portion (of the happiness in the Hereafter i.e. Paradise and in this world of a high moral character).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if an evil whisper from Shaitan (Satan) tries to turn you away (O Muhammad SAW) (from doing good, etc.), then seek refuge in Allah. Verily, He is the All-Hearer, the All-Knower.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And from among His Signs are the night and the day, and the sun and the moon. Prostrate not to the sun nor to the moon, but prostrate to Allah Who created them, if you (really) worship Him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they are too proud (to do so), then there are those who are with your Lord (angels) glorify Him night and day, and never are they tired.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And among His Signs (in this), that you see the earth barren, but when We send down water (rain) to it, it is stirred to life and growth (of vegetations). Verily, He Who gives it life, surely, (He) is Able to give life to the dead (on the Day of Resurrection). Indeed! He is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Verily, those who turn away from Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc. by attacking, distorting and denying them), are not hidden from Us. Is he who is cast into the Fire better or he who comes secure on the Day of Resurrection? Do what you will. Verily! He is All-Seer of what you do (this is a severe threat to the disbelievers).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Verily, those who disbelieved in the Reminder (i.e. the Quran) when it came to them (shall receive the punishment). And verily, it is an honourable respected Book (because it is Allah's Speech, and He has protected it from corruption, etc.). (See V. 15:9]\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot come to it from before it or behind it (it is) sent down by the All-Wise, Worthy of all praise (Allah).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing is said to you (O Muhammad SAW) except what was said to the Messengers before you. Verily, your Lord is the Possessor of forgiveness, and (also) the Possessor of painful punishment.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And if We had sent this as a Quran in a foreign language other than Arabic, they would have said: ``Why are not its Verses explained in detail (in our language)? What! (A Book) not in Arabic and (the Messenger) an Arab?" Say: ``It is for those who believe, a guide and a healing. And as for those who disbelieve, there is heaviness (deafness) in their ears, and it (the Quran) is blindness for them. They are those who are called from a place far away (so they neither listen nor understand).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And indeed We gave Musa (Moses) the Scripture, but dispute arose therein. And had it not been for a Word that went forth before from your Lord, (the torment would have overtaken them) and the matter would have been settled between them. But truly, they are in grave doubt thereto (i.e. about the Quran). [Tafsir Al-Qurtubi, Vol. 15, Page 370]\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whosoever does righteous good deed it is for (the benefit of) his ownself, and whosoever does evil, it is against his ownself, and your Lord is not at all unjust to (His) slaves.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
(The learned men) refer to Him (Alone) the knowledge of the Hour. No fruit comes out of its sheath, nor does a female conceive (within her womb), nor brings forth (young), except by His Knowledge. And on the Day when He will call unto them (polytheists) (saying): ``Where are My (so-called) partners (whom you did invent)?" They will say: ``We inform You that none of us bears witness to it (that they are Your partners)!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And those whom they used to invoke before will fail them, and they will perceive that they have no place of refuge (from Allah's punishment).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man (the disbeliever) does not get tired of asking good (things from Allah), but if an evil touches him, then he gives up all hope and is lost in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And truly, if We give him a taste of mercy from us, after some adversity (severe poverty or disease, etc.) has touched him, he is sure to say: ``This is for me (due to my merit), I think not that the Hour will be established. But if I am brought back to my Lord, Surely, there will be for me the best (wealth, etc.) with Him. Then, We verily, will show to the disbelievers what they have done and We shall make them taste a severe torment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We show favour to man, he withdraws and turns away, but when evil touches him, then he has recourse to long supplications.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say: ``Tell me, if it (the Quran) is from Allah, and you disbelieve in it, who is more astray than one who is in opposition far away (from Allah's Right Path and His obedience).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We will show them Our Signs in the universe, and in their ownselves, until it becomes manifest to them that this (the Quran) is the truth. Is it not sufficient in regard to your Lord that He is a Witness over all things?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Verily! They are in doubt concerning the Meeting with their Lord? (i.e. Resurrection after their deaths, and their return to their Lord). Verily! He it is Who is surrounding all things!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
'Ain-Sin-Qaf. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Likewise Allah, the All-Mighty, the All-Wise inspires you (O Muhammad SAW) as (He inspired) those before you.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs all that is in the heavens and all that is in the earth, and He is the Most High, the Most Great.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
Nearly the heavens might rent asunder from above them (by His Majesty), and the angels glorify the praises of their Lord, and ask for forgiveness for those on the earth, verily, Allah is the Oft-Forgiving, the Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And as for those who take as Auliya' (guardians, supporters, helpers, protectors, etc.) others besides Him [i.e. they take false deities other than Allah (as) protectors, and they worship them] Allah is Hafiz (Protector) over them (i.e. takes care of their deeds and will recompense them), and you (O Muhammad SAW) are not a Wakil (guardian or a disposer of their affairs) over them (to protect their deeds, etc.).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus We have inspired unto you (O Muhammad SAW) a Quran (in Arabic) that you may warn the Mother of the Towns (Makkah) and all around it. And warn of the Day of Assembling, of which there is no doubt, when a party will be in Paradise (those who believed in Allah and followed what Allah's Messenger SAW brought them) and a party in the blazing Fire (Hell) (those who disbelieved in Allah and followed not what Allah's Messenger SAW brought them).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
And if Allah had willed, He could have made them one nation, but He admits whom He wills to His Mercy. And the Zalimun (polytheists and wrong-doers, etc.) will have neither a Wali (protector) nor a helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they taken (for worship) Auliya' (guardians, supporters, helpers, protectors, etc.) besides Him? But Allah, He Alone is the Wali (Protector, etc.). And it is He Who gives life to the dead, and He is Able to do all things.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And in whatsoever you differ, the decision thereof is with Allah (He is the ruling Judge). (And say O Muhammad SAW to these polytheists:) Such is Allah, my Lord in Whom I put my trust, and to Him I turn in all of my affairs and in repentance.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Creator of the heavens and the earth. He has made for you mates from yourselves, and for the cattle (also) mates. By this means He creates you (in the wombs). There is nothing like unto Him, and He is the All-Hearer, the All-Seer.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belong the keys of the heavens and the earth, He enlarges provision for whom He wills, and straitens (it for whom He wills). Verily! He is the All-Knower of everything.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He (Allah) has ordained for you the same religion (Islam) which He ordained for Nuh (Noah), and that which We have inspired in you (O Muhammad SAW), and that which We ordained for Ibrahim (Abraham), Musa (Moses) and 'Iesa (Jesus) saying you should establish religion (i.e. to do what it orders you to do practically), and make no divisions in it (religion) (i.e. various sects in religion). Intolerable for the Mushrikun, is that to which you (O Muhammad SAW) call them. Allah chooses for Himself whom He wills, and guides unto Himself who turns to Him in repentance and in obedience.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they divided not till after knowledge had come to them, through selfish transgression between themselves. And had it not been for a Word that went forth before from your Lord for an appointed term, the matter would have been settled between them. And verily, those who were made to inherit the Scripture [i.e. the Taurah (Torah) and the Injeel (Gospel)] after them (i.e. Jews and Christians) are in grave doubt concerning it (i.e. Allah's true religion Islam or the Quran).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
So unto this (religion of Islam, alone and this Quran) then invite (people) (O Muhammad SAW), and Istaqim [(i.e. stand firm and straight on Islamic Monotheism by performing all that is ordained by Allah (good deeds, etc.), and by abstaining from all that is forbidden by Allah (sins and evil deeds, etc.)], as you are commanded, and follow not their desires but say: ``I believe in whatsoever Allah has sent down of the Book [all the holy Books, this Quran and the Books of the old from the Taurat (Torah), or the Injeel (Gospel) or the Pages of Ibrahim (Abraham)] and I am commanded to do justice among you, Allah is our Lord and your Lord. For us our deeds and for you your deeds. There is no dispute between us and you. Allah will assemble us (all), and to Him is the final return.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who dispute concerning Allah (His Religion of Islamic Monotheism, with which Muhammad SAW has been sent), after it has been accepted (by the people), of no use is their dispute before their Lord, and on them is wrath, and for them will be a severe torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah Who has sent down the Book (the Quran) in truth, and the Balance (i.e. to act justly). And what can make you know that perhaps the Hour is close at hand?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who believe not therein seek to hasten it, while those who believe are fearful of it, and know that it is the very truth. Verily, those who dispute concerning the Hour are certainly in error far away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is very Gracious and Kind to His slaves. He gives provisions to whom He wills. And He is the All-Strong, the All-Mighty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whosoever desires (with his deeds) the reward of the Hereafter, We give him increase in his reward, and whosoever desires the reward of this world (with his deeds), We give him thereof (what is written for him), and he has no portion in the Hereafter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or have they partners with Allah (false gods), who have instituted for them a religion which Allah has not allowed. And had it not been for a decisive Word (gone forth already), the matter would have been judged between them. And verily, for the Zalimun (polytheists and wrong-doers), there is a painful torment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see (on the Day of Resurrection), the Zalimun (polytheists and wrong-doers, etc.) fearful of that which they have earned, and it (Allah's Torment) will surely befall them, while those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous deeds (will be) in the flowering meadows of the Gardens (Paradise), having what they wish from their Lord. That is the supreme Grace, (Paradise).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is (the Paradise) whereof Allah gives glad tidings to His slaves who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds. Say (O Muhammad SAW): ``No reward do I ask of you for this except to be kind to me for my kinship with you." And whoever earns a good righteous deed, We shall give him an increase of good in respect thereof. Verily, Allah is Oft-Forgiving, Most Ready to appreciate (the deeds of those who are obedient to Him).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or say they: ``He has invented a lie against Allah?" If Allah willed, He could have sealed your heart (so that you forget all that you know of the Quran). And Allah wipes out falsehood, and establishes the truth (Islam) by His Word (this Qur'an). Verily, He knows well what (the secrets) are in the breasts (of mankind).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And He it is Who accepts repentance from His slaves, and forgives sins, and He knows what you do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answers (the invocation of) those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, and gives them increase of His Bounty. And as for the disbelievers, theirs will be a severe torment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And if Allah were to enlarge the provision for His slaves, they would surely rebel in the earth, but He sends down by measure as He wills. Verily! He is in respect of His slaves, the Well-Aware, the All-Seer (of things that benefit them).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And He it is Who sends down the rain after they have despaired, and spreads abroad His Mercy. And He is the Wali (Helper, Supporter, Protector, etc.), Worthy of all Praise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And among His Ayat (proofs, evidences, lessons, signs, etc.) is the creation of the heavens and the earth, and whatever moving (living) creatures He has dispersed in them both. And He is All-Potent over their assembling (i.e. resurrecting them on the Day of Resurrection after their death, and dispersion of their bodies) whenever He will.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
And whatever of misfortune befalls you, it is because of what your hands have earned. And He pardons much. (See the Quran Verse 35:45).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
And you cannot escape from Allah (i.e. His Punishment) in the earth, and besides Allah you have neither any Wali (guardian or a protector) nor any helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And among His Signs are the ships, in the sea, like mountains.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He wills, He causes the wind to cease, then they would become motionless on the back (of the sea). Verily, in this are signs for everyone patient and grateful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He may destroy them (by drowning) because of that which their (people) have earned. And He pardons much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And those who dispute (polytheists, etc. with Our Messenger Muhammad SAW) as regards Our Ayat (proofs, signs, verses, etc. of Islamic Monotheism) may know that there is no place of refuge for them (from Allah's punishment).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
So whatever you have been given is but a passing enjoyment for this worldly life, but that which is with Allah (Paradise) is better and more lasting for those who believe (in the Oneness of Allah Islamic Monotheism) and put their trust in their Lord (concerning all of their affairs).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid the greater sins, and Al-Fawahish (illegal sexual intercourse, etc.), and when they are angry, they forgive\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who answer the Call of their Lord [i.e. to believe that He is the only One Lord (Allah), and to worship none but Him Alone], and perform As-Salat (Iqamat-as-Salat), and who (conduct) their affairs by mutual consultation, and who spend of what We have bestowed on them;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when an oppressive wrong is done to them, they take revenge.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The recompense for an evil is an evil like thereof, but whoever forgives and makes reconciliation, his reward is due from Allah. Verily, He likes not the Zalimun (oppressors, polytheists, and wrong-doers, etc.).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And indeed whosoever takes revenge after he has suffered wrong, for such there is no way (of blame) against them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The way (of blame) is only against those who oppress men and wrongly rebel in the earth, for such there will be a painful torment.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And verily, whosoever shows patience and forgives that would truly be from the things recommended by Allah.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
And whomsoever Allah sends astray, for him there is no Wali (protector) after Him. And you will see the Zalimun (polytheists, wrong-doers, oppressors, etc.) when they behold the torment, they will say: ``Is there any way of return (to the world)?"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And you will see them brought forward to it (Hell) made humble by disgrace, (and) looking with stealthy glance. And those who believe will say: ``Verily, the losers are they who lose themselves and their families on the Day of Resurrection. Verily, the Zalimun [i.e. Al-Kafirun (disbelievers in Allah, in His Oneness and in His Messenger SAW, polytheists, wrong-doers, etc.)] will be in a lasting torment.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And they will have no Auliya' (protectors) to help them other than Allah. And he whom Allah sends astray, for him there is no way.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer the Call of your Lord (i.e. accept the Islamic Monotheism, O mankind, and jinns) before there comes from Allah a Day which cannot be averted. You will have no refuge on that Day nor there will be for you any denying (of your crimes as they are all recorded in the Book of your deeds).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away (O Muhammad SAW from the Islamic Monotheism, which you have brought to them). We have not sent you (O Muhammad SAW) as a Hafiz (protector) over them (i.e. to take care of their deeds and to recompense them). Your duty is to convey (the Message). And verily, when We cause man to taste of Mercy from Us, he rejoices thereat, but when some ill befalls them because of the deeds which their hands have sent forth, then verily, man (becomes) ingrate!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To Allah belongs the kingdom of the heavens and the earth. He creates what He wills. He bestows female (offspring) upon whom He wills, and bestows male (offspring) upon whom He wills.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He bestows both males and females, and He renders barren whom He wills. Verily, He is the All-Knower and is Able to do all things.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It is not given to any human being that Allah should speak to him unless (it be) by Inspiration, or from behind a veil, or (that) He sends a Messenger to reveal what He wills by His Leave. Verily, He is Most High, Most Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And thus We have sent to you (O Muhammad SAW) Ruhan (an Inspiration, and a Mercy) of Our Command. You knew not what is the Book, nor what is Faith? But We have made it (this Quran) a light wherewith We guide whosoever of Our slaves We will. And verily, you (O Muhammad SAW) are indeed guiding (mankind) to the Straight Path (i.e. Allah's religion of Islamic Monotheism).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The Path of Allah, to Whom belongs all that is in the heavens and all that is in the earth. Verily, all the matters at the end go to Allah (for decision).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the manifest Book (that makes things clear, i.e. this Quran).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
We verily, have made it a Quran in Arabic, that you may be able to understand (its meanings and its admonitions).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And Verily, it (this Quran) is in the Mother of the Book (i.e. Al-Lauh Al-Mahfuz), before Us, indeed Exalted, full of Wisdom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We then (warn you not and) take away the Reminder (this Quran) from you, because you are a people Musrifun\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
And how many a Prophet have We sent amongst the men of old.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And never came there a Prophet to them but they used to mock at him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
Then We destroyed men stronger (in power) than these, and the example of the ancients has passed away (before them).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And indeed if you ask them, ``Who has created the heavens and the earth?" They will surely say: ``The All-Mighty, the All-Knower created them."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
Who has made for you the earth like a bed, and has made for you roads therein, in order that you may find your way,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And Who sends down water (rain) from the sky in due measure. Then We revive a dead land therewith, and even so you will be brought forth (from the dead),\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And Who has created all the pairs and has appointed for you ships and cattle on which you ride,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
In order that you may mount firmly on their backs, and then may remember the Favour of your Lord when you mount thereon, and say: ``Glory to Him who has subjected this to us, and we could never have it (by our efforts)."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And verily, to Our Lord we indeed are to return!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they assign to some of His slaves a share with Him (by pretending that He has children, and considering them as equals or co-partners in worship with Him). Verily, man is indeed a manifest ingrate!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or has He taken daughters out of what He has created, and He has selected for you sons?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And if one of them is informed of the news of (the birth of) that which he set forth as a parable to the Most Beneficent (Allah) (i.e. of a girl), his face becomes dark, gloomy, and he is filled with grief!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
(Do they then like for Allah) a creature who is brought up in adornments (wearing silk and gold ornaments, i.e. women), and in dispute cannot make herself clear?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they make the angels who themselves are slaves to the Most Beneficent (Allah) females. Did they witness their creation? Their evidence will be recorded, and they will be questioned!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they said: ``If it had been the Will of the Most Beneficent (Allah), we should not have worshipped them (false deities)." They have no knowledge whatsoever of that. They do nothing but lie!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them any Book before this (the Quran), to which they are holding fast?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay! They say: ``We found our fathers following a certain way and religion, and we guide ourselves by their footsteps."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And similarly, We sent not a warner before you (O Muhammad SAW) to any town (people) but the luxurious ones among them said: ``We found our fathers following a certain way and religion, and we will indeed follow their footsteps."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
(The warner) said: ``Even if I bring you better guidance than that which you found your fathers following?" They said: ``Verily, We disbelieve in that with which you have been sent."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We took revenge of them, then see what was the end of those who denied (Islamic Monotheism).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And (remember) when Ibrahim (Abraham) said to his father and his people: ``Verily, I am innocent of what you worship,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
``Except Him (i.e. I worship none but Allah Alone) Who did create me, and verily, He will guide me."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it [i.e. La ilaha ill-Allah (none has the right to be worshipped but Allah Alone)] a Word lasting among his offspring (True Monotheism), that they may turn back (i.e. to repent to Allah or receive admonition).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Nay, but I gave (the good things of this life) to these (polytheists) and their fathers to enjoy, till there came to them the truth (the Quran), and a Messenger (Muhammad SAW) making things clear.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the truth (this Quran) came to them, they (the disbelievers in this Quran) said: ``This is magic, and we disbelieve therein."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they say: ``Why is not this Quran sent down to some great man of the two towns (Makkah and Ta'if)?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who would portion out the Mercy of your Lord? It is We Who portion out between them their livelihood in this world, and We raised some of them above others in ranks, so that some may employ others in their work. But the Mercy (Paradise) of your Lord (O Muhammad SAW) is better than the (wealth of this world) which they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that all mankind would have become of one community (all disbelievers, desiring worldly life only), We would have provided for those who disbelieve in the Most Beneficent (Allah), silver roofs for their houses, and elevators (and stair-ways, etc. of silver) whereby they ascend,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And for their houses, doors (of silver), and thrones (of silver) on which they could recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And adornments of gold. Yet all this (i.e. the roofs, doors, stairs, elevators, thrones etc. of their houses) would have been nothing but an enjoyment of this world. And the Hereafter with your Lord is only for the Muttaqun.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And whosoever turns away (blinds himself) from the remembrance of the Most Beneficent (Allah) (i.e. this Quran and worship of Allah), We appoint for him Shaitan (Satan - devil) to be a Qarin (an intimate companion) to him.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And verily, they (Satans / devils) hinder them from the Path (of Allah), but they think that they are guided aright!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Till, when (such a one) comes to Us, he says [to his Qarin (Satan / devil companion)] ``Would that between me and you were the distance of the two easts (or the east and west)" a worst (type of) companion (indeed)!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
It will profit you not this Day (O you who turn away from Allah's remembrance and His worship, etc.) as you did wrong, (and) that you will be sharers (you and your Qarin) in the punishment.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Can you (O Muhammad SAW) make the deaf to hear, or can you guide the blind or him who is in manifest error?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
And even if We take you (O Muhammad SAW) away, We shall indeed take vengeance on them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or (if) We show you that wherewith We threaten them, then verily, We have perfect command over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold you (O Muhammad SAW) fast to that which is inspired in you. Verily, you are on a Straight Path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And verily, this (the Quran) is indeed a Reminder for you (O Muhammad SAW) and your people (Quraish people, or your followers), and you will be questioned (about it).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask (O Muhammad SAW) those of Our Messengers whom We sent before you: ``Did We ever appoint aliha (gods) to be worshipped besides the Most Beneficent (Allah)?"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And indeed We did send Musa (Moses) with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) to Fir'aun (Pharaoh) and his chiefs (inviting them to Allah's Religion of Islam) He said: ``Verily, I am a Messenger of the Lord of the 'Alamin (mankind, jinns and all that exists)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he came to them with Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) behold! They laughed at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And not an Ayah (sign, etc.) We showed them but it was greater than its fellow, and We seized them with torment, in order that they might turn [from their polytheism to Allah's Religion (Islamic Monotheism)].\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said [to Musa (Moses)]: ``O you sorcerer! Invoke your Lord for us according to what He has covenanted with you. Verily, We shall guide ourselves (aright)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We removed the torment from them, behold! They broke their covenant (that they will believe if We remove the torment for them).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Fir'aun (Pharaoh) proclaimed among his people, saying: ``O my people! Is not mine the dominion of Egypt, and these rivers flowing underneath me. See you not then?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
``Am I not better than this one [Musa (Moses)], who is Mahin [has no honour nor any respect, and is weak and despicable] and can scarcely express himself clearly?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
``Why then are not golden bracelets bestowed on him, or angels sent along with him?"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Thus he [Fir'aun (Pharaoh)] befooled and misled his people, and they obeyed him. Verily, they were ever a people who were Fasiqun (rebellious, disobedient to Allah).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So when they angered Us, We punished them, and drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them a precedent (as a lesson for those coming after them), and an example to later generations.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Maryam (Mary) is quoted as an example [i.e. 'Iesa (Jesus) is worshipped like their idols), behold! Your people cry aloud (laugh out at the example).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And say: ``Are our aliha (gods) better or is he ['Iesa (Jesus)]?" They quoted not the above example except for argument. Nay! But they are a quarrelsome people. [(See VV. 21:97-101) - The Quran.]\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He ['Iesa (Jesus)] was not more than a slave. We granted Our Favour to him, and We made him an example to the Children of Israel (i.e. his creation without a father).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And if it were Our Will, We would have [destroyed you (mankind) all, and] made angels to replace you on the earth. [Tafsir At-Tabari, Vol: 25, Page 89].\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And he ['Iesa (Jesus), son of Maryam (Mary)] shall be a known sign for (the coming of) the Hour (Day of Resurrection) [i.e. 'Iesa's (Jesus) descent on the earth]. Therefore have no doubt concerning it (i.e. the Day of Resurrection). And follow Me (Allah) (i.e. be obedient to Allah and do what He orders you to do, O mankind)! This is the Straight Path (of Islamic Monotheism, leading to Allah and to His Paradise).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And let not Shaitan (Satan) hinder you (from the right religion, i.e. Islamic Monotheism), Verily, he (Satan) to you is a plain enemy.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when 'Iesa (Jesus) came with (Our) clear Proofs, he said: ``I have come to you with Al-Hikmah (Prophethood), and in order to make clear to you some of the (points) in which you differ, therefore fear Allah and obey me,\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
``Verily, Allah! He is my Lord (God) and your Lord (God). So worship Him (Alone). This is the (only) Straight Path (i.e. Allah's religion of true Islamic Monotheism)."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the sects from among themselves differed. So woe to those who do wrong (by ascribing things to 'Iesa (Jesus) that are not true) from the torment of a painful Day (i.e. the Day of Resurrection)!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Do they only wait for the Hour that it shall come upon them suddenly, while they perceive not?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Friends on that Day will be foes one to another except Al-Muttaqun (pious - see V. 2:2).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
(It will be said to the true believers of Islamic Monotheism): My worshippers! No fear shall be on you this Day, nor shall you grieve,\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
(You) who believed in Our Ayat (proofs, verses, lessons, signs, revelations, etc.) and were Muslims (i.e. who submit totally to Allah's Will, and believe in the Oneness of Allah - Islamic Monotheism).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter Paradise, you and your wives, in happiness.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Trays of gold and cups will be passed round them, (there will be) therein all that the one's inner-selves could desire, all that the eyes could delight in, and you will abide therein forever.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
This is the Paradise which you have been made to inherit because of your deeds which you used to do (in the life of the world).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Therein for you will be fruits in plenty, of which you will eat (as you desire).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Verily, the Mujrimun (criminals, sinners, disbelievers, etc.) will be in the torment of Hell to abide therein forever.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
(The torment) will not be lightened for them, and they will be plunged into destruction with deep regrets, sorrows and in despair therein.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We wronged them not, but they were the Zalimun (polytheists, wrong-doers, etc.).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they will cry: ``O Malik (Keeper of Hell)! Let your Lord make an end of us." He will say: ``Verily you shall abide forever."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
Indeed We have brought the truth (Muhammad SAW with the Quran), to you, but most of you have a hatred for the truth.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or have they plotted some plan? Then We too are planning.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We hear not their secrets and their private counsel? (Yes We do) and Our Messengers (appointed angels in charge of mankind) are by them, to record.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say (O Muhammad SAW): ``If the Most Beneficent (Allah) had a son (or children as you pretend), then I am the first of Allah's worshippers [who deny and refute this claim of yours (and the first to believe in Allah Alone and testify that He has no children)]." [Tafsir At-Tabari].\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glorified be the Lord of the heavens and the earth, the Lord of the Throne! Exalted be He from all that they ascribe (to Him).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them (alone) to speak nonsense and play until they meet the Day of theirs, which they have been promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
It is He (Allah) Who is the only Ilah (God to be worshipped) in the heaven and the only Ilah (God to be worshipped) on the earth. And He is the All-Wise, the All-Knower.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blessed be He to Whom belongs the kingdom of the heavens and the earth, and all that is between them, and with Whom is the knowledge of the Hour, and to Whom you (all) will be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those whom they invoke instead of Him have no power of intercession; except those who bear witness to the truth (i.e. believed in the Oneness of Allah, and obeyed His Orders), and they know (the facts about the Oneness of Allah).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if you ask them who created them, they will surely say: ``Allah". How then are they turned away (from the worship of Allah, Who created them)?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
(Allah has knowledge) of (Prophet Muhammad's) saying: ``O my Lord! Verily, these are a people who believe not!"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
So turn away from them (O Muhammad SAW), and say: Salam (peace)! But they will come to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the manifest Book (this Quran) that makes things clear,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We sent it (this Quran) down on a blessed night [(i.e. night of Qadr, Surah No: 97) in the month of Ramadan,, the 9th month of the Islamic calendar]. Verily, We are ever warning [mankind that Our Torment will reach those who disbelieve in Our Oneness of Lordship and in Our Oneness of worship].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
Therein (that night) is decreed every matter of ordainments.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
Amran (i.e. a Command or this Quran or the Decree of every matter) from Us. Verily, We are ever sending (the Messengers),\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
(As) a Mercy from your Lord. Verily! He is the All-Hearer, the All-Knower.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
The Lord of the heavens and the earth and all that is between them, if you (but) have a faith with certainty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
La ilaha illa Huwa (none has the right to be worshipped but He). It is He Who gives life and causes death, your Lord and the Lord of your fore-fathers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Nay! They play in doubt.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
Then wait you for the Day when the sky will bring forth a visible smoke.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Covering the people, this is a painful torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
(They will say): ``Our Lord! Remove the torment from us, really we shall become believers!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How can there be for them an admonition (at the time when the torment has reached them), when a Messenger explaining things clearly has already come to them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Then they had turned away from him (Messenger Muhammad SAW) and said: ``One (Muhammad SAW) taught (by a human being), a madman!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Verily, We shall remove the torment for a while. Verily! You will revert.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
On the Day when We shall seize you with the greatest grasp. Verily, We will exact retribution.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And indeed We tried before them Fir'aun's (Pharaoh) people, when there came to them a noble Messenger [i.e. Musa (Moses)],\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying: ``Restore to me the slaves of Allah (i.e. the Children of Israel). Verily! I am to you a Messenger worthy of all trust,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
``And exalt not (yourselves) against Allah. Truly, I have come to you with a manifest authority.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
``And truly, I seek refuge in my Lord and your Lord, lest you stone me (or call me a sorcerer or kill me).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
``But if you believe me not, then keep away from me and leave me alone."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
(But they were aggressive), so he [Musa (Moses)] called upon his Lord (saying): ``These are indeed the people who are Mujrimun (disbelievers, polytheists, sinners, criminals, etc.)."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
(Allah said): ``Depart you with My slaves by night. Surely, you will be pursued.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
``And leave the sea as it is (quiet and divided). Verily, They are a host to be drowned."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many of gardens and springs do they [Fir'aun's (Pharaoh) people] left.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And green crops (fields etc.) and goodly places,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And comforts of life wherein they used to take delight!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Thus (it was)! And We made other people inherit them (i.e. We made the Children of Israel to inherit the kingdom of Egypt).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And the heavens and the earth wept not for them, nor were they given a respite.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And indeed We saved the Children of Israel from the humiliating torment,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Fir'aun (Pharaoh); Verily! He was arrogant and was of the Musrifun (those who transgress beyond bound in spending and other things and commit great sins).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We chose them (the Children of Israel) above the 'Alamin (mankind, and jinns) [during the time of Musa (Moses)] with knowledge,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And granted them signs in which there was a plain trial.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Verily, these (Quraish) people are saying:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
``There is nothing but our first death, and we shall not be resurrected.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
``Then bring back our fore-fathers, if you speak the truth!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better or the people of Tubba' and those before them? We destroyed them because they were indeed Mujrimun (disbelievers, polytheists, sinners, criminals, etc.).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We created not the heavens and the earth, and all that is between them, for mere play,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not except with truth (i.e. to examine and test those who are obedient and those who are disobedient and then reward the obedient ones and punish the disobedient ones), but most of them know not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Verily, the Day of Judgement (when Allah will judge between the creatures) is the time appointed for all of them,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The Day when Maulan (a near relative) cannot avail Maulan (a near relative) in aught, and no help can they receive,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except him on whom Allah has Mercy. Verily, He is the All-Mighty, the Most Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Verily, the tree of Zaqqum,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Will be the food of the sinners,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like boiling oil, it will boil in the bellies,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the boiling of scalding water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
(It will be said) ``Seize him and drag him into the midst of blazing Fire,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
``Then pour over his head the torment of boiling water,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
``Taste you (this)! Verily, you were (pretending to be) the mighty, the generous!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
``Verily! This is that whereof you used to doubt!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Verily! The Muttaqun (pious - see V. 2:2), will be in place of Security (Paradise).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Among Gardens and Springs;\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Dressed in fine silk and (also) in thick silk, facing each other,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
So (it will be), and We shall marry them to Houris (female fair ones) with wide, lovely eyes.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They will call therein for every kind of fruit in peace and security;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They will never taste death therein except the first death (of this world), and He will save them from the torment of the blazing Fire,\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
As a Bounty from your Lord! That will be the supreme success!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
Certainly, We have made this (Quran) easy in your tongue, in order that they may remember.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Wait then (O Muhammad SAW); Verily, they (too) are waiting.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book (this Quran) is from Allah, the All-Mighty, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Verily, in the heavens and the earth are signs for the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in your creation, and what He scattered (through the earth) of moving (living) creatures are signs for people who have Faith with certainty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of night and day, and the provision (rain) that Allah sends down from the sky, and revives therewith the earth after its death, and in the turning about of the winds (i.e. sometimes towards the east or north, and sometimes towards the south or west etc., sometimes bringing glad tidings of rain etc., and sometimes bringing the torment), are signs for a people who understand.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the Ayat (proofs, evidences, verses, lessons, revelations, etc.) of Allah, which We recite to you (O Muhammad SAW) with truth. Then in which speech after Allah and His Ayat will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every sinful liar,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who hears the Verses of Allah (being) recited to him, yet persists with pride as if he heard them not. So announce to him a painful torment!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he learns something of Our Verses (this Quran), he makes them a jest. For such there will be a humiliating torment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
In front of them there is Hell, and that which they have earned will be of no profit to them, nor (will be of any profit to them) those whom they have taken as Auliya' (protectors, helpers, etc.) besides Allah. And theirs will be a great torment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This (Quran) is a guidance. And those who disbelieve in the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) of their Lord, for them there is a painful torment of Rijz (a severe kind of punishment).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
Allah it is He Who has subjected to you the sea, that ships may sail through it by His Command, and that you may seek of His Bounty, and that you may be thankful,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And has subjected to you all that is in the heavens and all that is in the earth; it is all as a favour and kindness from Him. Verily, in it are signs for a people who think deeply.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Say (O Muhammad SAW) to the believers to forgive those who (harm them and) hope not for the Days of Allah (i.e. His Recompense), that He may recompense people according to what they have earned (i.e. to punish these disbelievers, who harm the believers).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whosoever does a good deed, it is for his ownself, and whosoever does evil, it is against (his ownself). Then to your Lord you will be made to return.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And indeed We gave the Children of Israel the Scripture, and the understanding of the Scripture and its laws, and the Prophethood; and provided them with good things, and preferred them above the 'Alamin (mankind and jinns) (of their time, during that period),\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And gave them clear proofs in matters [by revealing to them the Taurat (Torah)]. And they differed not until after the knowledge came to them, through envy among themselves. Verily, Your Lord will judge between them on the Day of Resurrection about that wherein they used to differ.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We have put you (O Muhammad SAW) on a plain way of (Our) commandment [like the one which We commanded Our Messengers before you (i.e. legal ways and laws of the Islamic Monotheism)]. So follow you that (Islamic Monotheism and its laws), and follow not the desires of those who know not. [Tafsir At-Tabari Vol. 25, Page 146].\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Verily, they can avail you nothing against Allah (if He wants to punish you). Verily, the Zalimun (polytheists, wrong-doers, etc.) are Auliya' (protectors, helpers, etc.) to one another, but Allah is the Wali (Helper, Protector, etc.) of the Muttaqun (pious - see V. 2:2).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This (Quran) is a clear insight and evidence for mankind, and a guidance and a mercy for people who have Faith with certainty.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Or do those who earn evil deeds think that We shall hold them equal with those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, in their present life and after their death? Worst is the judgement that they make.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah has created the heavens and the earth with truth, in order that each person may be recompensed what he has earned, and they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Have you seen him who takes his own lust (vain desires) as his ilah (god), and Allah knowing (him as such), left him astray, and sealed his hearing and his heart, and put a cover on his sight. Who then will guide him after Allah? Will you not then remember?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say: ``There is nothing but our life of this world, we die and we live and nothing destroys us except Ad-Dahr (the time). And they have no knowledge of it, they only conjecture.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our Clear Verses are recited to them, their argument is no other than that they say: ``Bring back our (dead) fathers, if you are truthful!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say (to them): ``Allah gives you life, then causes you to die, then He will assemble you on the Day of Resurrection about which there is no doubt. But most of mankind know not."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And to Allah belongs the kingdom of the heavens and the earth. And on the Day that the Hour will be established, on that Day the followers of falsehood (polytheists, disbelievers, worshippers of false deities, etc.) shall lose (everything).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And you will see each nation humbled to their knees (kneeling), each nation will be called to its Record (of deeds). This Day you shall be recompensed for what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This Our Record speaks about you with truth. Verily, We were recording what you used to do (i.e. Our angels used to record your deeds).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
Then, as for those who believed (in the Oneness of Allah Islamic Monotheism) and did righteous good deeds, their Lord will admit them to His Mercy. That will be the evident success.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as for those who disbelieved (it will be said to them): ``Were not Our Verses recited to you? But you were proud, and you were a people who were Mujrimun (polytheists, disbelievers, sinners, criminals)."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said: ``Verily! Allah's Promise is the truth, and there is no doubt about the coming of the Hour," you said; ``We know not what is the Hour, we do not think it but as a conjecture, and we have no firm convincing belief (therein)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evil of what they did will appear to them, and they will be completely encircled by that which they used to mock at!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said: ``This Day We will forget you as you forgot the Meeting of this Day of yours. And your abode is the Fire, and there is none to help you."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
This, because you took the revelations of Allah (this Quran) in mockery, and the life of the world deceived you. So this Day, they shall not be taken out from there (Hell), nor shall they be Yusta'tabun (i.e. they shall not return to the worldly life, so that they repent to Allah, and beg His Pardon for their sins).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
So all the praises and thanks are to Allah, the Lord of the heavens and the Lord of the earth, and the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And His (Alone) is the Majesty in the heavens and the earth, and He is the All-Mighty, the All-Wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha-Mim. [These letters are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of the Book (this Quran) is from Allah, the All-Mighty, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We created not the heavens and the earth and all that is between them except with truth, and for an appointed term. But those who disbelieve turn away from that whereof they are warned.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say (O Muhammad SAW to these pagans): ``Think! All that you invoke besides Allah show me! What have they created of the earth? Or have they a share in (the creation of) the heavens? Bring me a Book (revealed before this), or some trace of knowledge (in support of your claims), if you are truthful!"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than one who calls (invokes) besides Allah, such as will not answer him till the Day of Resurrection, and who are (even) unaware of their calls (invocations) to them?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when mankind are gathered (on the Day of Resurrection), they (false deities) will become enemies for them and will deny their worshipping.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our Clear Verses are recited to them, the disbelievers say of the truth (this Quran), when it reaches them: ``This is plain magic!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or say they: ``He (Muhammad SAW) has fabricated it." Say: ``If I have fabricated it, still you have no power to support me against Allah. He knows best of what you say among yourselves concerning it (i.e. this Quran)! Sufficient is He for a witness between me and you! And He is the Oft-Forgiving, the Most Merciful."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say (O Muhammad SAW):"I am not a new thing among the Messengers (of Allah) (i.e. I am not the first Messenger) nor do I know what will be done with me or with you. I only follow that which is revealed to me, and I am but a plain warner."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say: ``Tell me! If this (Quran) is from Allah, and you deny it, and a witness from among the Children of Israel ('Abdullah bin Salam) testifies that this Quran is from Allah [like the Taurat (Torah)], so he believed (embraced Islam) while you are too proud (to believe)." Verily! Allah guides not the people who are Zalimun (polytheists, disbelievers and wrong-doing).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And those who disbelieve (strong and wealthy) say of those who believe (weak and poor): ``Had it (Islamic Monotheism to which Muhammad SAW is inviting mankind) been a good thing, they (weak and poor) would not have preceded us thereto!" And when they have not let themselves be guided by it (this Quran), they say: ``This is an ancient lie!"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before this was the Scripture of Musa (Moses) as a guide and a mercy. And this is a confirming Book (the Quran) in the Arabic language, to warn those who do wrong, and as glad tidings to the Muhsinun (good-doers - see V. 2:112).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Verily, those who say: ``Our Lord is (only) Allah," and thereafter Istaqamu (i.e. stood firm and straight on the Islamic Faith of Monotheism by abstaining from all kinds of sins and evil deeds which Allah has forbidden and by performing all kinds of good deeds which He has ordained), on them shall be no fear, nor shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Such shall be the dwellers of Paradise, abiding therein (forever), a reward for what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have enjoined on man to be dutiful and kind to his parents. His mother bears him with hardship and she brings him forth with hardship, and the bearing of him, and the weaning of him is thirty (30) months, till when he attains full strength and reaches forty years, he says: ``My Lord! Grant me the power and ability that I may be grateful for Your Favour which You have bestowed upon me and upon my parents, and that I may do righteous good deeds, such as please You, and make my off-spring good. Truly, I have turned to You in repentance, and truly, I am one of the Muslims (submitting to Your Will)."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
They are those from whom We shall accept the best of their deeds and overlook their evil deeds. (They shall be) among the dwellers of Paradise, a promise of truth, which they have been promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But he who says to his parents: ``Fie upon you both! Do you hold out the promise to me that I shall be raised up (again) when generations before me have passed away (without rising)?" While they (father and mother) invoke Allah for help (and rebuke their son): ``Woe to you! Believe! Verily, the Promise of Allah is true." But he says: ``This is nothing but the tales of the ancient."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
They are those against whom the Word (of torment) is justified among the previous generations of jinns and mankind that have passed away. Verily! They are ever the losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for all, there will be degrees according to that which they did, that He (Allah) may recompense them in full for their deeds. And they will not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
On the Day when those who disbelieve (in the Oneness of Allah Islamic Monotheism) will be exposed to the Fire (it will be said): ``You received your good things in the life of the world, and you took your pleasure therein. Now this Day you shall be recompensed with a torment of humiliation, because you were arrogant in the land without a right, and because you used to rebel and disobey (Allah).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And remember (Hud) the brother of 'Ad, when he warned his people in Al-Ahqaf (the curved sand-hills in the southern part of Arabian Peninsula). And surely, there have passed away warners before him and after him (saying): ``Worship none but Allah; truly, I fear for you the torment of a mighty Day."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: ``Have you come to turn us away from our aliha (gods)? Then bring us that with which you threaten us, if you are one of the truthful!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said: ``The knowledge (of the time of its coming) is with Allah only, and I convey to you that wherewith I have been sent, but I see that you are a people given to ignorance!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they saw it as a dense cloud coming towards their valleys, they said: ``This is a cloud bringing us rain!" Nay, but it is that (torment) which you were asking to be hastened! a wind wherein is a painful torment!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
Destroying everything by the Command of its Lord! So they became such that nothing could be seen except their dwellings! Thus do We recompense the people who are Mujrimun (polytheists, disbelievers, sinners, etc.)!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And indeed We had firmly established them with that wherewith We have not established you (O Quraish)! And We had assigned them the (faculties of) hearing (ears), seeing (eyes), and hearts, but their hearing (ears), seeing (eyes), and their hearts availed them nothing since they used to deny the Ayat (Allah's Prophets and their Prophethood, proofs, evidences, verses, signs, revelations, etc.) of Allah, and they were completely encircled by that which they used to mock at!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And indeed We have destroyed towns (populations) round about you, and We have (repeatedly) shown (them) the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) in various ways that they might return (to the truth and believe in the Oneness of Allah - Islamic Monotheism).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Then why did those whom they had taken for aliha (gods) besides Allah, as a way of approach (to Allah) not help them? Nay, but they vanished completely from them (when there came the torment). And that was their lie, and their inventions which they had been inventing (before their destruction).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And (remember) when We sent towards you (Muhammad SAW) Nafran (three to ten persons) of the jinns, (quietly) listening to the Quran, when they stood in the presence thereof, they said: ``Listen in silence!" And when it was finished, they returned to their people, as warners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said: ``O our people! Verily! We have heard a Book (this Quran) sent down after Musa (Moses), confirming what came before it, it guides to the truth and to a Straight Path (i.e. Islam).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people! Respond (with obedience) to Allah's Caller (i.e. Allah's Messenger Muhammad SAW), and believe in him (i.e. believe in that which Muhammad SAW has brought from Allah and follow him). He (Allah) will forgive you of your sins, and will save you from a painful torment (i.e. Hell-fire).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
And whosoever does not respond to Allah's Caller, he cannot escape on earth, and there will be no Auliya' (protectors) for him besides Allah (from Allah's Punishment). Those are in manifest error.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Do they not see that Allah, Who created the heavens and the earth, and was not wearied by their creation, is Able to give life to the dead? Yes, He surely is Able to do all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the Day when those who disbelieve will be exposed to the Fire (it will be said to them): ``Is this not the truth?" They will say: ``Yes, By our Lord!" He will say: ``Then taste the torment, because you used to disbelieve!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Therefore be patient (O Muhammad SAW) as did the Messengers of strong will and be in no haste about them (disbelievers). On the Day when they will see that (torment) with which they are promised (i.e. threatened, it will be) as if they had not stayed more than an hour in a single day. (O mankind! This Quran is sufficient as) a clear Message (or proclamation to save yourself from destruction). But shall any be destroyed except the people who are Al-Fasiqun (the rebellious, disobedient to Allah).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve [in the Oneness of Allah, and in the Message of Prophet Muhammad SAW], and hinder (men) from the Path of Allah (Islamic Monotheism), He will render their deeds vain.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
But those who believe and do righteous good deeds, and believe in that which is sent down to Muhammad (SAW), for it is the truth from their Lord, He will expiate from them their sins, and will make good their state.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehood, while those who believe follow the truth from their Lord. Thus does Allah set forth their parables for mankind.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
So, when you meet (in fight Jihad in Allah's Cause), those who disbelieve smite at their necks till when you have killed and wounded many of them, then bind a bond firmly (on them, i.e. take them as captives). Thereafter (is the time) either for generosity (i.e. free them without ransom), or ransom (according to what benefits Islam), until the war lays down its burden. Thus [you are ordered by Allah to continue in carrying out Jihad against the disbelievers till they embrace Islam (i.e. are saved from the punishment in the Hell-fire) or at least come under your protection], but if it had been Allah's Will, He Himself could certainly have punished them (without you). But (He lets you fight), in order to test you, some with others. But those who are killed in the Way of Allah, He will never let their deeds be lost,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and set right their state.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And admit them to Paradise which He has made known to them (i.e. they will know their places in Paradise more than they used to know their houses in the world).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O you who believe! If you help (in the cause of) Allah, He will help you, and make your foothold firm.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But those who disbelieve (in the Oneness of Allah Islamic Monotheism), for them is destruction, and (Allah) will make their deeds vain.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they hate that which Allah has sent down (this Quran and Islamic laws, etc.), so He has made their deeds fruitless.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not travelled through the earth, and seen what was the end of those before them? Allah destroyed them completely and a similar (fate awaits) the disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the Maula (Lord, Master, Helper, Protector, etc.) of those who believe, and the disbelievers have no Maula (lord, master, helper, protector, etc.).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Certainly! Allah will admit those who believe (in the Oneness of Allah Islamic Monotheism) and do righteous good deeds, to Gardens under which rivers flow (Paradise), while those who disbelieve enjoy themselves and eat as cattle eat, and the Fire will be their abode.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And many a town, stronger than your town (Makkah) (O Muhammad SAW) which has driven you out We have destroyed. And there was none to help them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is he who is on a clear proof from his Lord, like those for whom their evil deeds that they do are beautified for them, while they follow their own lusts (evil desires)?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
The description of Paradise which the Muttaqun (pious - see V. 2:2) have been promised is that in it are rivers of water the taste and smell of which are not changed; rivers of milk of which the taste never changes; rivers of wine delicious to those who drink; and rivers of clarified honey (clear and pure) therein for them is every kind of fruit; and forgiveness from their Lord. (Are these) like those who shall dwell for ever in the Fire, and be given, to drink, boiling water, so that it cuts up their bowels?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And among them are some who listen to you (O Muhammad SAW) till, when they go out from you, they say to those who have received knowledge: ``What has he said just now? Such are men whose hearts Allah has sealed, and they follow their lusts (evil desires).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
While as for those who accept guidance, He increases their guidance, and bestows on them their piety.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Do they then await (anything) other than the Hour, that it should come upon them suddenly? But some of its portents (indications and signs) have already come, and when it (actually) is on them, how can they benefit then by their reminder?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
So know (O Muhammad SAW) that La ilaha ill-Allah (none has the right to be worshipped but Allah), and ask forgiveness for your sin, and also for (the sin of) believing men and believing women. And Allah knows well your moving about, and your place of rest (in your homes).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say: ``Why is not a Surah (chapter of the Quran) sent down (for us)? But when a decisive Surah (explaining and ordering things) is sent down, and fighting (Jihad - holy fighting in Allah's Cause) is mentioned (i.e. ordained) therein, you will see those in whose hearts is a disease (of hypocrisy) looking at you with a look of one fainting to death. But it was better for them (hypocrites, to listen to Allah and to obey Him).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Obedience (to Allah) and good words (were better for them). And when the matter (preparation for Jihad) is resolved on, then if they had been true to Allah, it would have been better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Would you then, if you were given the authority, do mischief in the land, and sever your ties of kinship?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Such are they whom Allah has cursed, so that He has made them deaf and blinded their sight.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Do they not then think deeply in the Quran, or are their hearts locked up (from understanding it)?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Verily, those who have turned back (have apostated) as disbelievers after the guidance has been manifested to them, Shaitan (Satan) has beautified for them (their false hopes), and (Allah) prolonged their term (age).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
This is because they said to those who hate what Allah has sent down: ``We will obey you in part of the matter," but Allah knows their secrets.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
Then how (will it be) when the angels will take their souls at death, smiting their faces and their backs?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they followed that which angered Allah, and hated that which pleased Him. So He made their deeds fruitless.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do those in whose hearts is a disease (of hypocrisy), think that Allah will not bring to light all their hidden ill-wills?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
Had We willed, We could have shown them to you, and you should have known them by their marks, but surely, you will know them by the tone of their speech! And Allah knows all your deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And surely, We shall try you till We test those who strive hard (for the Cause of Allah) and the patient ones, and We shall test your facts (i.e. the one who is a liar, and the one who is truthful).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Verily, those who disbelieve, and hinder (men) from the Path of Allah (i.e. Islam), and oppose the Messenger (SAW) (by standing against him and hurting him), after the guidance has been clearly shown to them, they will not hurt Allah in the least, but He will make their deeds fruitless,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O you who believe! Obey Allah, and obey the Messenger (Muhammad SAW) and render not vain your deeds.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Verily, those who disbelieve, and hinder (men) from the Path of Allah (i.e. Islam); then die while they are disbelievers, Allah will not forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So be not weak and ask not for peace (from the enemies of Islam), while you are having the upper hand. Allah is with you, and will never decrease the reward of your good deeds.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of this world is but play and pastime, but if you believe (in the Oneness of Allah Islamic Monotheism), and fear Allah, and avoid evil, He will grant you your wages, and will not ask you your wealth.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He were to ask you of it, and press you, you would covetously withhold, and He will bring out all your (secret) ill-wills.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Behold! You are those who are called to spend in the Cause of Allah, yet among you are some who are niggardly. And whoever is niggardly, it is only at the expense of his ownself. But Allah is Rich (Free of all wants), and you (mankind) are poor. And if you turn away (from Islam and the obedience of Allah), He will exchange you for some other people, and they will not be your likes.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Verily, We have given you (O Muhammad SAW) a manifest victory.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive you your sins of the past and the future, and complete His Favour on you, and guide you on the Straight Path;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And that Allah may help you with strong help.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
He it is Who sent down As-Sakinah (calmness and tranquillity) into the hearts of the believers, that they may grow more in Faith along with their (present) Faith. And to Allah belong the hosts of the heavens and the earth, and Allah is Ever All-Knower, All-Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
That He may admit the believing men and the believing women to Gardens under which rivers flow (i.e. Paradise), to abide therein forever, and to expiate from them their sins, and that is with Allah, a supreme success,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And that He may punish the Munafiqun (hypocrites), men and women, and also the Mushrikun men and women, who think evil thoughts about Allah, for them is a disgraceful torment, and the Anger of Allah is upon them, and He has cursed them and prepared Hell for them, and worst indeed is that destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
And to Allah belong the hosts of the heavens and the earth. And Allah is Ever All-Knower, All-Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Verily, We have sent you (O Muhammad SAW) as a witness, as a bearer of glad tidings, and as a warner.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
In order that you (O mankind) may believe in Allah and His Messenger (SAW), and that you assist and honour him (SAW), and (that you) glorify (Allah's) praises morning and afternoon.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Verily, those who give Bai'a (pledge) to you (O Muhammad SAW) they are giving Bai'a (pledge) to Allah. The Hand of Allah is over their hands. Then whosoever breaks his pledge, breaks only to his own harm, and whosoever fulfills what he has covenanted with Allah, He will bestow on him a great reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
Those of the bedouins who lagged behind will say to you: ``Our possessions and our families occupied us, so ask forgiveness for us." They say with their tongues what is not in their hearts. Say: ``Who then has any power at all (to intervene) on your behalf with Allah, if He intends you hurt or intends you benefit? Nay, but Allah is Ever All-Aware of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
``Nay, but you thought that the Messenger (SAW) and the believers would never return to their families; and that was made fair-seeming in their hearts, and you did think an evil thought and you became a useless people going for destruction."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And whosoever does not believe in Allah and His Messenger (Muhammad SAW), then verily, We have prepared for the disbelievers a blazing Fire.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And to Allah belongs the sovereignty of the heavens and the earth, He forgives whom He wills, and punishes whom He wills. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who lagged behind will say, when you set forth to take the spoils, ``Allow us to follow you," They want to change Allah's Words. Say: ``You shall not follow us; thus Allah has said beforehand." Then they will say: ``Nay, you envy us." Nay, but they understand not except a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say (O Muhammad SAW) to the bedouins who lagged behind: ``You shall be called to fight against a people given to great warfare, then you shall fight them, or they shall surrender. Then if you obey, Allah will give you a fair reward, but if you turn away as you did turn away before, He will punish you with a painful torment."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
No blame or sin is there upon the blind, nor is there blame or sin upon the lame, nor is there blame or sin upon the sick (that they go not forth to war). And whosoever obeys Allah and His Messenger (Muhammad SAW), He will admit him to Gardens beneath which rivers flow (Paradise); and whosoever turns back, He will punish him with a painful torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Indeed, Allah was pleased with the believers when they gave their Bai'a (pledge) to you (O Muhammad SAW) under the tree, He knew what was in their hearts, and He sent down As-Sakinah (calmness and tranquillity) upon them, and He rewarded them with a near victory,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And abundant spoils that they will capture. And Allah is Ever All-Mighty, All-Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you abundant spoils that you will capture, and He has hastened for you this, and He has restrained the hands of men from you, that it may be a sign for the believers, and that He may guide you to a Straight Path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And other (victories and much booty there are, He promises you) which are not yet within your power, indeed Allah compasses them, And Allah is Ever Able to do all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And if those who disbelieve fight against you, they certainly would have turned their backs, then they would have found neither a Wali (protector) nor a helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
That has been the Way of Allah already with those who passed away before. And you will not find any change in the Way of Allah.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And He it is Who has withheld their hands from you and your hands from them in the midst of Makkah, after He had made you victors over them. And Allah is Ever the All-Seer of what you do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are the ones who disbelieved (in the Oneness of Allah Islamic Monotheism), and hindered you from Al-Masjid-al-Haram (the sacred mosque of Makkah) and the sacrificial animals, detained from reaching their place of sacrifice. Had there not been believing men and believing women whom you did not know, that you may kill them, and on whose account a sin would have been committed by you without (your) knowledge, that Allah might bring into His Mercy whom He will, if they (the believers and the disbelievers) should have been apart, We verily had punished those of them who disbelieved, with painful torment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When those who disbelieve had put in their hearts pride and haughtiness the pride and haughtiness of the time of ignorance, then Allah sent down His Sakinah (calmness and tranquillity) upon His Messenger (SAW) and upon the believers, and made them stick to the word of piety (i.e. none has the right to be worshipped but Allah), and they were well entitled to it and worthy of it. And Allah is the All-Knower of everything.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Indeed Allah shall fulfil the true vision which He showed to His Messenger (SAW) [i.e. the Prophet SAW saw a dream that he has entered Makkah along with his companions, having their (head) hair shaved and cut short] in very truth. Certainly, you shall enter Al-Masjid-al-Haram; if Allah wills, secure, (some) having your heads shaved, and (some) having your head hair cut short, having no fear. He knew what you knew not, and He granted besides that a near victory.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
He it is Who has sent His Messenger (Muhammad SAW) with guidance and the religion of truth (Islam), that He may make it (Islam) superior over all religions. And All-Sufficient is Allah as a Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad (SAW) is the Messenger of Allah, and those who are with him are severe against disbelievers, and merciful among themselves. You see them bowing and falling down prostrate (in prayer), seeking Bounty from Allah and (His) Good Pleasure. The mark of them (i.e. of their Faith) is on their faces (foreheads) from the traces of (their) prostration (during prayers). This is their description in the Taurat (Torah). But their description in the Injeel (Gospel) is like a (sown) seed which sends forth its shoot, then makes it strong, it then becomes thick, and it stands straight on its stem, delighting the sowers that He may enrage the disbelievers with them. Allah has promised those among them who believe (i.e. all those who follow Islamic Monotheism, the religion of Prophet Muhammad SAW till the Day of Resurrection) and do righteous good deeds, forgiveness and a mighty reward (i.e. Paradise).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O you who believe! Do not put (yourselves) forward before Allah and His Messenger (SAW), and fear Allah. Verily! Allah is All-Hearing, All-Knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O you who believe! Raise not your voices above the voice of the Prophet (SAW), nor speak aloud to him in talk as you speak aloud to one another, lest your deeds may be rendered fruitless while you perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Verily! Those who lower their voices in the presence of Allah's Messenger (SAW), they are the ones whose hearts Allah has tested for piety. For them is forgiveness and a great reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Verily! Those who call you from behind the dwellings, most of them have no sense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And if they had patience till you could come out to them, it would have been better for them. And Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O you who believe! If a rebellious evil person comes to you with a news, verify it, lest you harm people in ignorance, and afterwards you become regretful to what you have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that, among you there is the Messenger of Allah (SAW). If he were to obey you (i.e. follow your opinions and desires) in much of the matter, you would surely be in trouble, but Allah has endeared the Faith to you and has beautified it in your hearts, and has made disbelief, wickedness and disobedience (to Allah and His Messenger SAW) hateful to you. These! They are the rightly guided ones,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
(This is) a Grace from Allah and His Favour. And Allah is All-Knowing, All-Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two parties or groups among the believers fall to fighting, then make peace between them both, but if one of them rebels against the other, then fight you (all) against the one that which rebels till it complies with the Command of Allah; then if it complies, then make reconciliation between them justly, and be equitable. Verily! Allah loves those who are equitable.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are nothing else than brothers (in Islamic religion). So make reconciliation between your brothers, and fear Allah, that you may receive mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O you who believe! Let not a group scoff at another group, it may be that the latter are better than the former; nor let (some) women scoff at other women, it may be that the latter are better than the former, nor defame one another, nor insult one another by nicknames. How bad is it, to insult one's brother after having Faith [i.e. to call your Muslim brother (a faithful believer) as: ``O sinner", or ``O wicked", etc.]. And whosoever does not repent, then such are indeed Zalimun (wrong-doers, etc.).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O you who believe! Avoid much suspicions, indeed some suspicions are sins. And spy not, neither backbite one another. Would one of you like to eat the flesh of his dead brother? You would hate it (so hate backbiting). And fear Allah. Verily, Allah is the One Who accepts repentance, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind! We have created you from a male and a female, and made you into nations and tribes, that you may know one another. Verily, the most honourable of you with Allah is that (believer) who has At-Taqwa [i.e. one of the Muttaqun (pious - see V. 2:2). Verily, Allah is All-Knowing, All-Aware.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The bedouins say: ``We believe." Say: ``You believe not but you only say, 'We have surrendered (in Islam),' for Faith has not yet entered your hearts. But if you obey Allah and His Messenger (SAW), He will not decrease anything in reward for your deeds. Verily, Allah is Oft-Forgiving, Most Merciful."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
Only those are the believers who have believed in Allah and His Messenger, and afterward doubt not but strive with their wealth and their lives for the Cause of Allah. Those! They are the truthful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say: ``Will you inform Allah about your religion? While Allah knows all that is in the heavens and all that is in the earth, and Allah is All-Aware of everything.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They regard as favour upon you (O Muhammad SAW) that they have embraced Islam. Say: ``Count not your Islam as a favour upon me. Nay, but Allah has conferred a favour upon you, that He has guided you to the Faith, if you indeed are true.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Verily, Allah knows the unseen of the heavens and the earth. And Allah is the All-Seer of what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. [These letters (Qaf, etc.) are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. By the Glorious Quran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Nay, they wonder that there has come to them a warner (Muhammad SAW) from among themselves. So the disbelievers say: ``This is a strange thing!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
``When we are dead and have become dust (shall we be resurrected?) That is a far return."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know that which the earth takes of them (their dead bodies), and with Us is a Book preserved (i.e. the Book of Decrees).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Nay, but they have denied the truth (this Quran) when it has come to them, so they are in a confused state (can not differentiate between right and wrong).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not looked at the heaven above them, how We have made it and adorned it, and there are no rifts in it?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth! We have spread it out, and set thereon mountains standing firm, and have produced therein every kind of lovely growth (plants).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
An insight and a Reminder for every slave turning to Allah (i.e. the one who believes in Allah and performs deeds of His obedience, and always begs His pardon).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We send down blessed water (rain) from the sky, then We produce therewith gardens and grain (every kind of harvests) that are reaped.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And tall date-palms, with ranged clusters;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
A provision for (Allah's) slaves. And We give life therewith to a dead land. Thus will be the resurrection (of the dead).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Denied before them (i.e. these pagans of Makkah who denied you, O Muhammad SAW) the people of Nuh (Noah), and the dwellers of Rass, and the Thamud,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And 'Ad, and Fir'aun (Pharaoh), and the brethren of Lout (Lot),\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the dwellers of the Wood, and the people of Tubba'; everyone of them denied (their) Messengers, so My Threat took effect.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Were We then tired with the first creation? Nay, They are in confused doubt about a new creation (i.e. Resurrection)?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
And indeed We have created man, and We know what his ownself whispers to him. And We are nearer to him than his jugular vein (by Our Knowledge).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
(Remember!) that the two receivers (recording angels) receive (each human being after he or she has attained the age of puberty), one sitting on the right and one on the left (to note his or her actions).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Not a word does he (or she) utter, but there is a watcher by him ready (to record it).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the stupor of death will come in truth: ``This is what you have been avoiding!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet will be blown, that will be the Day whereof warning (had been given) (i.e. the Day of Resurrection).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every person will come forth along with an (angel) to drive (him), and an (angel) to bear witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
(It will be said to the sinners): ``Indeed you were heedless of this, now We have removed your covering, and sharp is your sight this Day!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his companion (angel) will say: ``Here is (this Record) ready with me!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
(And it will be said): ``Both of you throw (Order from Allah to the two angels) into Hell, every stubborn disbeliever (in the Oneness of Allah, in His Messengers, etc.).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
``Hinderer of good, transgressor, doubter,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
``Who set up another ilah (god) with Allah, then (both of you) cast him in the severe torment."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His companion (Satan devil)] will say: ``Our Lord! I did not push him to transgress, (in disbelief, oppression, and evil deeds) but he was himself in error far astray."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
Allah will say: ``Dispute not in front of Me, I had already, in advance, sent you the threat.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The Sentence that comes from Me cannot be changed, and I am not unjust (to the least) to the slaves."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On the Day when We will say to Hell: ``Are you filled?" It will say: ``Are there any more (to come)?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise will be brought near to the Muttaqun (pious - see V. 2:2) not far off.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
(It will be said): ``This is what you were promised, - (it is) for those oft-returning (to Allah) in sincere repentance, and those who preserve their covenant with Allah (by obeying Him in all what He has ordered, and worship none but Allah Alone, i.e. follow Allah's Religion, Islamic Monotheism).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
``Who feared the Most Beneficent (Allah) in the Ghaib (unseen): (i.e. in this worldly life before seeing and meeting Him), and brought a heart turned in repentance (to Him - and absolutely free from each and every kind of polytheism),\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
``Enter you therein in peace and security; this is a Day of eternal life!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
There they will have all that they desire, and We have more (for them, i.e. a glance at the All-Mighty, All-Majestic).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And how many a generation We have destroyed before them, who were stronger in power than them, and (when Our Torment came) they ran for a refuge in the land! Could they find any place of refuge (for them to save themselves from destruction)?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Verily, therein is indeed a reminder for him who has a heart or gives ear while he is heedful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And indeed We created the heavens and the earth and all between them in six Days and nothing of fatigue touched Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So bear with patience (O Muhammad SAW) all that they say, and glorify the Praises of your Lord, before the rising of the sun and before (its) setting (i.e. the Fajr, Zuhr, and 'Asr prayers).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And during a part of the night (also), glorify His praises (i.e. Maghrib and 'Isha prayers), and (so likewise) after the prayers [As-Sunnah, Nawafil optional and additional prayers, and also glorify, praise and magnify Allah - Subhan Allah, Alhamdu lillah, Allahu-Akbar].\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen on the Day when the caller will call from a near place,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day when they will hear As-Saihah (shout, etc.) in truth, that will be the Day of coming out (from the graves i.e. the Day of Resurrection).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Verily, We it is Who give life and cause death; and to Us is the final return,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
On the Day when the earth shall be cleft, from off them, (they will come out) hastening forth. That will be a gathering, quite easy for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We know of best what they say; and you (O Muhammad SAW) are not a tyrant over them (to force them to Belief). But warn by the Quran, him who fears My Threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By (the winds) that scatter dust.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And (the clouds) that bear heavy weight of water;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And (the ships) that float with ease and gentleness;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And those (angels) who distribute (provisions, rain, and other blessings) by (Allah's) Command;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Verily, that which you are promised (i.e. Resurrection in the Hereafter and receiving the reward or punishment of good or bad deeds, etc.) is surely true.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And verily, the Recompense is sure to happen.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven full of paths,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Certainly, you have different ideas (about Muhammad SAW and the Quran).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Turned aside therefrom (i.e. from Muhammad SAW and the Quran) is he who is turned aside (by the Decree and Preordainment of Allah).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Cursed be the liars,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Who are under a cover of heedlessness (think not about the gravity of the Hereafter),\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask; ``When will be the Day of Recompense?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
(It will be) a Day when they will be tried (i.e. burnt) over the Fire!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
``Taste you your trial (burning)! This is what you used to ask to be hastened!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Verily, the Muttaqun (pious - see V. 2:2) will be in the midst of Gardens and Springs (in the Paradise),\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Taking joy in the things which their Lord has given them. Verily, they were before this Muhsinun (good-doers - see V. 2:112).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep but little by night [invoking their Lord (Allah) and praying, with fear and hope].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And in the hours before dawn, they were (found) asking (Allah) for forgiveness,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their properties there was the right of the beggar, and the Mahrum (the poor who does not ask the others).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And on the earth are signs for those who have Faith with certainty,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And also in your ownselves. Will you not then see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is your provision, and that which you are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
Then, by the Lord of the heaven and the earth, it is the truth (i.e. what has been promised to you), just as it is the truth that you can speak.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Has the story reached you, of the honoured guests [three angels; Jibrael (Gabriel) along with another two] of Ibrahim (Abraham)?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came in to him, and said, ``Salam, (peace be upon you)!" He answered; ``Salam, (peace be upon you)," and said: ``You are a people unknown to me,"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he turned to his household, so brought out a roasted calf [as the property of Ibrahim (Abraham) was mainly cows].\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And placed it before them, (saying): ``Will you not eat?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived a fear of them (when they ate not). They said: ``Fear not." And they gave him glad tidings of an intelligent son, having knowledge (about Allah and His religion of True Monotheism).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
Then his wife came forward with a loud voice, she smote her face, and said: ``A barren old woman!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said: ``Even so says your Lord. Verily, He is the All-Wise, the All-Knower."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
[Ibrahim (Abraham)] said: ``Then for what purpose you have come, O Messengers?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said: ``We have been sent to a people who are Mujrimun (polytheists, sinners, criminals, disbelievers in Allah);\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
To send down upon them stones of baked clay.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
Marked by your Lord for the Musrifun (polytheists, criminals, sinners those who trespass Allah's set limits in evil-doings by committing great sins).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We brought out from therein the believers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But We found not there any household of the Muslims except one [i.e. Lout (Lot) and his two daughters].\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We have left there a sign (i.e. the place of the Dead Sea, well-known in Palestine) for those who fear the painful torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Musa (Moses) (too, there is a sign). When We sent him to Fir'aun (Pharaoh) with a manifest authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But [Fir'aun (Pharaoh)] turned away (from Belief in might) along with his hosts, and said: ``A sorcerer, or a madman."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We took him and his hosts, and dumped them into the sea, while he was to be blamed.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in 'Ad (there is also a sign) when We sent against them the barren wind;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It spared nothing that it reached, but blew it into broken spreads of rotten ruins.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamud (there is also a sign), when they were told: ``Enjoy yourselves for a while!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they insolently defied the Command of their Lord, so the Sa'iqah overtook them while they were looking.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
Then they were unable to rise up, nor could they help themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
(So were) the people of Nuh (Noah) before them. Verily, they were a people who were Fasiqun (rebellious, disobedient to Allah).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
With power did We construct the heaven. Verily, We are Able to extend the vastness of space thereof.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And We have spread out the earth, how Excellent Spreader (thereof) are We!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of everything We have created pairs, that you may remember (the Grace of Allah).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
So flee to Allah (from His Torment to His Mercy Islamic Monotheism), verily, I (Muhammad SAW) am a plain warner to you from Him.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And set not up (or worship) any other ilahan (god) along with Allah [Glorified be He (Alone), Exalted above all that they associate as partners with Him]. Verily, I (Muhammad SAW) am a plain warner to you from Him.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Likewise, no Messenger came to those before them, but they said: ``A sorcerer or a madman!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they (the people of the past) transmitted this saying to these (Quraish pagans)? Nay, they are themselves a people transgressing beyond bounds (in disbelief)!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away (O Muhammad SAW) from them (Quraish pagans) you are not to be blamed (as you have conveyed Allah's Message).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And remind (by preaching the Quran, O Muhammad SAW) for verily, the reminding profits the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
And I (Allah) created not the jinns and humans except they should worship Me (Alone).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I seek not any provision from them (i.e. provision for themselves or for My creatures) nor do I ask that they should feed Me (i.e. feed themselves or My creatures).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Verily, Allah is the All-Provider, Owner of Power, the Most Strong.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
And verily, for those who do wrong, there is a portion of torment like to the evil portion of torment (which came for) their likes (of old), so let them not ask Me to hasten on!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Then, woe to those who disbelieve (in Allah and His Oneness Islamic Monotheism) from (that) their Day which they have been promised (for their punishment).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And by the Book Inscribed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In parchment unrolled.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And by the Bait-ul-Ma'mur (the house over the heavens parable to the Ka'bah at Makkah, continuously visited by the angels);\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And by the roof raised high (i.e. the heaven).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And by the sea kept filled (or it will be fire kindled on the Day of Resurrection).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Verily, the Torment of your Lord will surely come to pass,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
There is none that can avert it;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day when the heaven will shake with a dreadful shaking,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains will move away with a (horrible) movement.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Then woe that Day to the beliers;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Who are playing in falsehood.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
The Day when they will be pushed down by force to the Fire of Hell, with a horrible, forceful pushing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
This is the Fire which you used to belie.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic, or do you not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Taste you therein its heat, and whether you are patient of it or impatient of it, it is all the same. You are only being requited for what you used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Verily, the Muttaqun (pious - see V. 2:2) will be in Gardens (Paradise), and Delight.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Enjoying in that which their Lord has bestowed on them, and (the fact that) their Lord saved them from the torment of the blazing Fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
``Eat and drink with happiness because of what you used to do."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
They will recline (with ease) on thrones arranged in ranks. And We shall marry them to Houris (female, fair ones) with wide lovely eyes.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believe and whose offspring follow them in Faith, to them shall We join their offspring, and We shall not decrease the reward of their deeds in anything. Every person is a pledge for that which he has earned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We shall provide them with fruit and meat, such as they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
There they shall pass from hand to hand a (wine) cup, free from any Laghw (dirty, false, evil vague talk between them), and free from sin (because it will be legal for them to drink).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
And there will go round boy-servants of theirs, to serve them as if they were preserved pearls.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And some of them draw near to others, questioning.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
Saying: ``Aforetime, we were afraid with our families (from the punishment of Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
``But Allah has been gracious to us, and has saved us from the torment of the Fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
``Verily, We used to invoke Him (Alone and none else) before. Verily, He is Al-Barr (the Most Subtle, Kind, Courteous, and Generous), the Most Merciful."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore, remind and preach (mankind, O Muhammad SAW of Islamic Monotheism). By the Grace of Allah, you are neither a soothsayer, nor a madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say: ``(Muhammad SAW is) a poet! We await for him some calamity by time!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say (O Muhammad SAW to them): ``Wait! I am with you, among the waiters!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Do their minds command them this [i.e. to tell a lie against you (Muhammad SAW)] or are they people exceeding the bounds (i.e. from Belief in Allah to disbelief).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say: ``He (Muhammad SAW) has forged it (this Quran)?" Nay! They believe not!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Let them then produce a recital like unto it (the Quran) if they are truthful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Were they created by nothing, or were they themselves the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? Nay, but they have no firm Belief.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or are with them the treasures of your Lord? Or are they the tyrants with the authority to do as they like?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they a stairway (to heaven), by means of which they listen (to the talks of the angels)? Then let their listener produce some manifest proof.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or has He (Allah) only daughters and you have sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or is it that you (O Muhammad SAW) ask a wage from them (for your preaching of Islamic Monotheism) so that they are burdened with a load of debt?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or that the Ghaib (unseen) is with them, and they write it down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or do they intend a plot (against you O Muhammad SAW)? But those who disbelieve (in the Oneness of Allah Islamic Monotheism) are themselves in a plot!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they an ilah (a god) other than Allah? Glorified be Allah from all that they ascribe as partners (to Him)\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And if they were to see a piece of the heaven falling down, they would say: ``Clouds gathered in heaps!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them alone till they meet their Day, in which they will sink into a fainting (with horror).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day when their plotting shall not avail them at all nor will they be helped (i.e. they will receive their torment in Hell).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And verily, for those who do wrong, there is another punishment (i.e. the torment in this world and in their graves) before this, but most of them know not. [Tafsir At-Tabari, Vol. 27, Page 36].\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
So wait patiently (O Muhammad SAW) for the Decision of your Lord, for verily, you are under Our Eyes, and glorify the Praises of your Lord when you get up from sleep.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And in the night time, also glorify His Praises, and at the setting of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it goes down, (or vanishes).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your companion (Muhammad SAW) has neither gone astray nor has erred.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor does he speak of (his own) desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is only an Inspiration that is inspired.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
He has been taught (this Quran) by one mighty in power [Jibrael (Gabriel)].\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
Dhu Mirrah (free from any defect in body and mind), Fastawa [then he (Jibrael - Gabriel) rose and became stable]. [Tafsir At-Tabari].\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he [Jibrael (Gabriel)] was in the highest part of the horizon,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he [Jibrael (Gabriel)] approached and came closer,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
And was at a distance of two bows' length or (even) nearer,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
So did (Allah) convey the Inspiration to His slave [Muhammad SAW through Jibrael (Gabriel)].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The (Prophet's) heart lied not (in seeing) what he (Muhammad SAW) saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will you then dispute with him (Muhammad SAW) about what he saw [during the Mi'raj: (Ascent of the Prophet SAW over the seven heavens)].\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And indeed he (Muhammad SAW) saw him [Jibrael (Gabriel)] at a second descent (i.e. another time).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
Near Sidrat-ul-Muntaha [lote-tree of the utmost boundary (beyond which none can pass)],\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Near it is the Paradise of Abode.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When that covered the lote-tree which did cover it!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight (of Prophet Muhammad SAW) turned not aside (right or left), nor it transgressed beyond (the) limit (ordained for it).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Indeed he (Muhammad SAW) did see, of the Greatest Signs, of his Lord (Allah).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have you then considered Al-Lat, and Al-'Uzza (two idols of the pagan Arabs).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat (another idol of the pagan Arabs), the other third?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Is it for you the males and for Him the females?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That indeed is a division most unfair!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are but names which you have named, you and your fathers, for which Allah has sent down no authority. They follow but a guess and that which they themselves desire, whereas there has surely come to them the Guidance from their Lord!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or shall man have what he wishes?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
But to Allah belongs the last (Hereafter) and the first (the world).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And there are many angels in the heavens, whose intercession will avail nothing except after Allah has given leave for whom He wills and pleases.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Verily, those who believe not in the Hereafter, name the angels with female names.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
While they have no knowledge thereof. They follow but a guess, and verily, guess is no substitute for the truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Therefore withdraw (O Muhammad SAW) from him who turns away from Our Reminder (this Quran) and desires nothing but the life of this world.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is what they could reach of knowledge. Verily, your Lord it is He Who knows best him who goes astray from His Path, and He knows best him who receives guidance.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And to Allah belongs all that is in the heavens and all that is in the earth, that He may requite those who do evil with that which they have done (i.e. punish them in Hell), and reward those who do good, with what is best (i.e. Paradise).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid great sins (see the Quran, Verses: 6:152, 153) and Al-Fawahish (illegal sexual intercourse, etc.) except the small faults, verily, your Lord is of vast forgiveness. He knows you well when He created you from the earth (Adam), and when you were fetuses in your mothers' wombs. So ascribe not purity to yourselves. He knows best him who fears Allah and keep his duty to Him [i.e. those who are Al-Muttaqun (pious - see V. 2:2)].\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Did you (O Muhammad SAW) observe him who turned away (from Islam).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave a little, then stopped (giving)?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Is with him the knowledge of the unseen so that he sees?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or is he not informed with what is in the Pages (Scripture) of Musa (Moses),\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Ibrahim (Abraham) who fulfilled (or conveyed) all that (what Allah ordered him to do or convey),\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no burdened person (with sins) shall bear the burden (sins) of another.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that man can have nothing but what he does (good or bad).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his deeds will be seen,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then he will be recompensed with a full and the best recompense.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that to your Lord (Allah) is the End (Return of everything).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He (Allah) Who makes (whom He wills) laugh, and makes (whom He wills) weep;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He (Allah) Who causes death and gives life;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that He (Allah) creates the pairs, male and female,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From Nutfah (drops of semen male and female discharges) when it is emitted;\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that upon Him (Allah) is another bringing forth (Resurrection);\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He (Allah) Who gives much or a little (or gives wealth and contentment),\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that He (Allah) is the Lord of Sirius (the star which the pagan Arabs used to worship);\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that it is He (Allah) Who destroyed the former 'Ad (people),\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And Thamud (people). He spared none of them.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And the people of Nuh (Noah) aforetime, verily, they were more unjust and more rebellious and transgressing [in disobeying Allah and His Messenger Nuh (Noah)].\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And He destroyed the overthrown cities [of Sodom to which Prophet Lout (Lot) was sent].\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
So there covered them that which did cover (i.e. torment with stones).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Then which of the Graces of your Lord (O man!) will you doubt.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This (Muhammad SAW) is a warner (Messenger) of the (series of) warners (Messengers) of old.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The Day of Resurrection draws near,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None besides Allah can avert it, (or advance it, or delay it).\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do you then wonder at this recital (the Quran)?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And you laugh at it and weep not,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
Wasting your (precious) lifetime in pastime and amusements (singing, etc.).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So fall you down in prostration to Allah, and worship Him (Alone).\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour has drawn near, and the moon has been cleft asunder (the people of Makkah requested Prophet Muhammad SAW to show them a miracle, so he showed them the splitting of the moon).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And if they see a sign, they turn away, and say: ``This is continuous magic."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They belied (the Verses of Allah, this Quran), and followed their own lusts. And every matter will be settled [according to the kind of deeds (for the doer of good deeds, his deeds will take him to Paradise, and similarly evil deeds will take their doers to Hell)].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And indeed there has come to them news (in this Quran) wherein there is (enough warning) to check (them from evil),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Perfect wisdom (this Quran), but (the preaching of) warners benefit them not,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So (O Muhammad SAW) withdraw from them. The Day that the caller will call (them) to a terrible thing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
They will come forth, with humbled eyes from (their) graves as if they were locusts spread abroad,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Hastening towards the caller, the disbelievers will say: ``This is a hard Day."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
The people of Nuh (Noah) denied (their Messenger) before them, they rejected Our slave, and said: ``A madman!" and he was insolently rebuked and threatened.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Then he invoked his Lord (saying): ``I have been overcome, so help (me)!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
So We opened the gates of heaven with water pouring forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And We caused the earth to gush forth with springs. So the waters (of the heaven and the earth) met for a matter predestined.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried him on a (ship) made of planks and nails,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Floating under Our Eyes, a reward for him who had been rejected!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And indeed, We have left this as a sign, then is there any that will remember (or receive admonition)?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
Then how (terrible) was My Torment and My Warnings?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And We have indeed made the Quran easy to understand and remember, then is there any that will remember (or receive admonition)?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
'Ad (people) belied (their Prophet, Hud), then how (terrible) was My Torment and My Warnings?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
Verily, We sent against them a furious wind of harsh voice on a day of evil omen and continuous calamity.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Plucking out men as if they were uprooted stems of date-palms.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
Then, how (terrible) was My Torment and My Warnings?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And We have indeed made the Quran easy to understand and remember, then is there any that will remember (or receive admonition)?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamud (people also) belied the warnings.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
For they said: ``A man! Alone from among us, that we are to follow? Truly, then we should be in error and distress or madness!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
``Is it that the Reminder is sent to him [Prophet Salih (Saleh)] alone from among us? Nay, he is an insolent liar!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
Tomorrow they will come to know, who is the liar, the insolent one!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
Verily, We are sending the she-camel as a test for them. So watch them [O Salih (Saleh)], and be patient!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And inform them that the water is to be shared between (her and) them. Each one's right to drink being established (by turns).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called their comrade and he took (a sword) and killed (her).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
Then, how (terrible) was My Torment and My Warnings?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Verily, We sent against them a single Saihah (torment - awful cry, etc.), and they became like the dry stubble of a fold-builder.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And indeed, We have made the Quran easy to understand and remember, then is there any that will remember (or receive admonition)?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lout (Lot) belied the warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Verily, We sent against them a violent storm of stones (which destroyed them all), except the family of Lout (Lot), whom We saved in last hour of the night,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As a Favour from Us, thus do We reward him who gives thanks (by obeying Us).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And he [Lout (Lot)] indeed had warned them of Our Grasp, but they did doubt the warnings!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And they indeed sought to shame his guest (by asking to commit sodomy with them). So We blinded their eyes, ``Then taste you My Torment and My Warnings."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And verily, an abiding torment seized them early in the morning.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
``Then taste you My Torment and My Warnings."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And indeed, We have made the Quran easy to understand and remember, then is there any that will remember (or receive admonition)?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And indeed, warnings came to the people of Fir'aun (Pharaoh) [through Musa (Moses) and Harun (Aaron)].\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
(They) belied all Our Signs, so We seized them with a Seizure of the All-Mighty, All-Capable to carry out what he Will (Omnipotent).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your disbelievers (O Quraish!) better than these [nations of Nuh (Noah), Lout (Lot), Salih (Saleh), and the people of Fir'aun (Pharaoh), etc., who were destroyed)? Or have you an immunity (against Our Torment) in the Divine Scriptures?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say: ``We are a great multitude, and we shall be victorious?"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Their multitude will be put to flight, and they will show their backs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay, but the Hour is their appointed time (for their full recompense), and the Hour will be more grievous and more bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Verily, the Mujrimun (polytheists, disbelievers, sinners, criminals, etc.) are in error (in this world) and will burn (in the Hell-fire in the Hereafter).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The Day they will be dragged in the Fire on their faces (it will be said to them): ``Taste you the touch of Hell!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Verily, We have created all things with Qadar (Divine Preordainments of all things before their creation, as written in the Book of Decrees Al-Lauh Al-Mahfuz).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our Commandment is but one, as the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And indeed, We have destroyed your likes, then is there any that will remember (or receive admonition)?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And each and everything they have done is noted in (their) Records (of deeds).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And everything, small and big is written (in Al-Lauh Al-Mahfuz already beforehand i.e. before it befalls, or is done by its doer) (See the Quran V. 57:22).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Verily, The Muttaqun (pious), will be in the midst of Gardens and Rivers (Paradise).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In a seat of truth (i.e. Paradise), near the Omnipotent King (Allah, the All-Blessed, the Most High, the Owner of Majesty and Honour).\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Most Beneficent (Allah)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Has taught (you mankind) the Quran (by His Mercy).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created man.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
He taught him eloquent speech.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon run on their fixed courses (exactly) calculated with measured out stages for each (for reckoning, etc.).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the herbs (or stars) and the trees both prostrate.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the heaven He has raised high, and He has set up the Balance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
In order that you may not transgress (due) balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
And observe the weight with equity and do not make the balance deficient.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth He has put for the creatures.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein are fruits, date-palms producing sheathed fruit-stalks (enclosing dates).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And also corn, with (its) leaves and stalk for fodder, and sweet-scented plants.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man (Adam) from sounding clay like the clay of pottery.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And the jinns did He create from a smokeless flame of fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
(He is) the Lord of the two easts (places of sunrise during early summer and early winter) and the Lord of the two wests (places of sunset during early summer and early winter).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He has let loosed the two seas (the salt water and the sweet) meeting together.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Between them is a barrier which none of them can transgress.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
Out of them both come out pearl and coral.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
And His are the ships going and coming in the seas, like mountains.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Whatsoever is on it (the earth) will perish.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
And the Face of your Lord full of Majesty and Honour will abide forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Whosoever is in the heavens and on earth begs of Him (its needs from Him). Every day He has a matter to bring forth (such as giving honour to some, disgrace to some, life to some, death to some, etc.)!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We shall attend to you, O you two classes (jinns and men)!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O assembly of jinns and men! If you have power to pass beyond the zones of the heavens and the earth, then pass (them)! But you will never be able to pass them, except with authority (from Allah)!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
There will be sent against you both, smokeless flames of fire and (molten) brass, and you will not be able to defend yourselves.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
Then when the heaven is rent asunder, and it becomes rosy or red like red-oil, or red hide.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
So on that Day no question will be asked of man or jinn as to his sin, (because they have already been known from their faces either white or black).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The Mujrimun (polytheists, criminals, sinners, etc.) will be known by their marks (black faces), and they will be seized by their forelocks and their feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is Hell which the Mujrimun (polytheists, criminals, sinners, etc.) denied.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They will go between it (Hell) and the boiling hot water!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for him who [the true believer of Islamic Monotheism who performs all the duties ordained by Allah and His Messenger Muhammad SAW, and keeps away (abstain) from all kinds of sin and evil deeds prohibited in Islam and] fears the standing before his Lord, there will be two Gardens (i.e. in Paradise).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
With spreading branches;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In them (both) will be two springs flowing (free)\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In them (both) will be every kind of fruit in pairs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining upon the couches lined with silk brocade, and the fruits of the two Gardens will be near at hand.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Wherein both will be those (maidens) restraining their glances upon their husbands, whom no man or jinn yatmithhunna (has opened their hymens with sexual intercourse) before them.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
(In beauty) they are like rubies and coral.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is there any reward for good other than good?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And besides these two, there are two other Gardens (i.e. in Paradise).\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Dark green (in colour).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In them (both) will be two springs gushing forth water.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them (both) will be fruits, and date- palms and pomegranates.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
Therein (gardens) will be fair (wives) good and beautiful;\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Houris (beautiful, fair females) restrained in pavilions;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Whom no man or jinn yatmithhunna (has opened their hymens with sexual intercourse) before them.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions and rich beautiful mattresses.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Then which of the Blessings of your Lord will you both (jinns and men) deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the Name of your Lord (Allah), the Owner of Majesty and Honour.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Event (i.e. the Day of Resurrection) befalls.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
And there can be no denying of its befalling.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
It will bring low (some); (and others) it will exalt;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth will be shaken with a terrible shake.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains will be powdered to dust.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
So that they will become floating dust particles.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And you (all) will be in three kinds (i.e. separate groups).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
So those on the Right Hand (i.e. those who will be given their Records in their right hands), Who will be those on the Right Hand? (As a respect for them, because they will enter Paradise).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And those on the Left Hand (i.e. those who will be given their Record in their left hands), Who will be those on the Left Hand? (As a disgrace for them, because they will enter Hell).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And those foremost [(in Islamic Faith of Monotheism and in performing righteous deeds) in the life of this world on the very first call for to embrace Islam,] will be foremost (in Paradise).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
These will be those nearest to Allah.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In the Gardens of delight (Paradise).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A multitude of those (foremost) will be from the first generations (who embraced Islam).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few of those (foremost) will be from the later time (generations).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
(They will be) on thrones woven with gold and precious stones,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining thereon, face to face.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
They will be served by immortal boys,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With cups, and jugs, and a glass from the flowing wine,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Wherefrom they will get neither any aching of the head, nor any intoxication.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And fruit; that they may choose.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And the flesh of fowls that they desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And (there will be) Houris (fair females) with wide, lovely eyes (as wives for the pious),\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
Like unto preserved pearls.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
A reward for what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
No Laghw (dirty, false, evil vain talk) will they hear therein, nor any sinful speech (like backbiting, etc.).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
But only the saying of: Salam!, Salam! (greetings with peace)!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And those on the Right Hand, Who will be those on the Right Hand?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
(They will be) among thornless lote-trees,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
Among Talh (banana-trees) with fruits piled one above another,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
In shade long-extended,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
By water flowing constantly,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit in plenty,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Whose season is not limited, and their supply will not be cut off,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And on couches or thrones, raised high.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Verily, We have created them (maidens) of special creation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgins.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Loving (their husbands only), equal in age.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For those on the Right Hand.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A multitude of those (on the Right Hand) will be from the first generation (who embraced Islam).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a multitude of those (on the Right Hand) will be from the later times (generations).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And those on the Left Hand Who will be those on the Left Hand?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
In fierce hot wind and boiling water,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And shadow of black smoke,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
(That shadow) neither cool, nor (even) good,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Verily, before that, they indulged in luxury,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And were persisting in great sin (joining partners in worship along with Allah, committing murders and other crimes, etc.)\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say: ``When we die and become dust and bones, shall we then indeed be resurrected?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
``And also our forefathers?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say (O Muhammad SAW): ``(Yes) verily, those of old, and those of later times.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
``All will surely be gathered together for appointed Meeting of a known Day.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
``Then moreover, verily, you the erring-ones, the deniers (of Resurrection)!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
``You verily will eat of the trees of Zaqqum.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
``Then you will fill your bellies therewith,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
``And drink boiling water on top of it,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
``So you will drink (that) like thirsty camels!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
That will be their entertainment on the Day of Recompense!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you, then why do you believe not?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Then tell Me (about) the human semen that you emit.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Is it you who create it (i.e. make this semen into a perfect human being), or are We the Creator?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed death to you all, and We are not unable,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
To transfigure you and create you in (forms) that you know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And indeed, you have already known the first form of creation (i.e. the creation of Adam), why then do you not remember or take heed?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Tell Me! The seed that you sow in the ground.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you that make it grow, or are We the Grower?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
Were it Our Will, We could crumble it to dry pieces, and you would be regretful (or left in wonderment).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
(Saying): ``We are indeed Mughramun (i.e. ruined or lost the money without any profit, or punished by the loss of all that we spend for cultivation, etc.)! [See Tafsir Al-Qurtubi, Vol. 17, Page 219]\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
``Nay, but we are deprived!"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Tell Me! The water that you drink.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who cause it from the rainclouds to come down, or are We the Causer of it to come down?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We willed, We verily could make it salt (and undrinkable), why then do you not give thanks (to Allah)?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Tell Me! The fire which you kindle,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you who made the tree thereof to grow, or are We the Grower?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a Reminder (for the Hell-fire, in the Hereafter); and an article of use for the travellers (and all the others, in this world).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Then glorify with praises the Name of your Lord, the Most Great.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
So I swear by Mawaqi (setting or the mansions, etc.) of the stars (they traverse).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And verily, that is indeed a great oath, if you but know.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
That (this) is indeed an honourable recital (the Noble Quran).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a Book well-guarded (with Allah in the heaven i.e. Al-Lauh Al-Mahfuz).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
Which (that Book with Allah) none can touch but the purified (i.e. the angels).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
A Revelation (this Quran) from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it such a talk (this Quran) that you (disbelievers) deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And instead (of thanking Allah) for the provision He gives you, on the contrary, you deny Him (by disbelief)!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Then why do you not (intervene) when (the soul of a dying person) reaches the throat?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And you at the moment are looking on,\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
But We (i.e. Our angels who take the soul) are nearer to him than you, but you see not, [Tafsir At-Tabari, Vol. 27, Page 209]\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Then why do you not, if you are exempt from the reckoning and recompense (punishment, etc.)\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Bring back the soul (to its body), if you are truthful?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Then, if he (the dying person) be of the Muqarrabun (those brought near to Allah),\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
(There is for him) rest and provision, and a Garden of delights (Paradise).\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he (the dying person) be of those on the Right Hand,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then there is safety and peace (from the Punishment of Allah) for (you as you are from) those on the Right Hand.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he (the dying person) be of the denying (of the Resurrection), the erring (away from the Right Path of Islamic Monotheism),\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then for him is entertainment with boiling water.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And burning in Hell-fire.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Verily, this! This is an absolute Truth with certainty.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So glorify with praises the Name of your Lord, the Most Great.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Whatsoever is in the heavens and the earth glorifies Allah, and He is the All-Mighty, All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the kingdom of the heavens and the earth, It is He Who gives life and causes death; and He is Able to do all things.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First (nothing is before Him) and the Last (nothing is after Him), the Most High (nothing is above Him) and the Most Near (nothing is nearer than Him). And He is the All-Knower of every thing.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in six Days and then Istawa (rose over) the Throne (in a manner that suits His Majesty). He knows what goes into the earth and what comes forth from it, what descends from the heaven and what ascends thereto. And He is with you (by His Knowledge) wheresoever you may be. And Allah is the All-Seer of what you do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the kingdom of the heavens and the earth. And to Allah return all the matters (for decision).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He merges night into day (i.e. the decrease in the hours of the night is added into the hours of the day), and merges day into night (i.e. the decrease in the hours of the day is added into the hours of the night), and He has full knowledge of whatsoever is in the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His Messenger (Muhammad SAW), and spend of that whereof He has made you trustees. And such of you as believe and spend (in Allah's Way), theirs will be a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
And what is the matter with you that you believe not in Allah! While the Messenger (Muhammad SAW) invites you to believe in your Lord (Allah), and He (Allah) has indeed taken your covenant, if you are real believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He Who sends down manifest Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) to His slave (Muhammad SAW) that He may bring you out from darkness into light. And verily, Allah is to you full of kindness, Most Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what is the matter with you that you spend not in the Cause of Allah? And to Allah belongs the heritage of the heavens and the earth. Not equal among you are those who spent and fought before the conquering (of Makkah) (with those among you who did so later). Such are higher in degree than those who spent and fought afterwards. But to all, Allah has promised the best (reward). And Allah is All-Aware of what you do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will lend to Allah a goodly loan, then (Allah) will increase it manifold to his credit (in repaying), and he will have (besides) a good reward (i.e. Paradise).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On the Day you shall see the believing men and the believing women their light running forward before them and by their right hands. Glad tidings for you this Day! Gardens under which rivers flow (Paradise), to dwell therein forever! Truly, this is the great success!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On the Day when the hypocrites men and women will say to the believers: ``Wait for us! Let us get something from your light!" It will be said: ``Go back to your rear! Then seek a light!" So a wall will be put up between them, with a gate therein. Inside it will be mercy, and outside it will be torment."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
(The hypocrites) will call the believers: ``Were we not with you?" The believers will reply: ``Yes! But you led yourselves into temptations, you looked forward for our destruction; you doubted (in Faith); and you were deceived by false desires, till the Command of Allah came to pass. And the chief deceiver (Satan) deceived you in respect of Allah."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
So this Day no ransom shall be taken from you (hypocrites), nor of those who disbelieved, (in the Oneness of Allah Islamic Monotheism). Your abode is the Fire, that is the proper place for you, and worst indeed is that destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Has not the time come for the hearts of those who believe (in the Oneness of Allah - Islamic Monotheism) to be affected by Allah's Reminder (this Quran), and that which has been revealed of the truth, lest they become as those who received the Scripture [the Taurat (Torah) and the Injeel (Gospel)] before (i.e. Jews and Christians), and the term was prolonged for them and so their hearts were hardened? And many of them were Fasiqun (rebellious, disobedient to Allah).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah gives life to the earth after its death! Indeed We have made clear the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) to you, if you but understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Verily, those who give Sadaqat (i.e. Zakat and alms, etc.), men and women, and lend to Allah a goodly loan, it shall be increased manifold (to their credit), and theirs shall be an honourable good reward (i.e. Paradise).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in (the Oneness of) Allah and His Messengers, they are the Siddiqun (i.e. those followers of the Prophets who were first and foremost to believe in them), and the martyrs with their Lord, they shall have their reward and their light. But those who disbelieve (in the Oneness of Allah - Islamic Monotheism) and deny Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they shall be the dwellers of the blazing Fire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of this world is only play and amusement, pomp and mutual boasting among you, and rivalry in respect of wealth and children, as the likeness of vegetation after rain, thereof the growth is pleasing to the tiller; afterwards it dries up and you see it turning yellow; then it becomes straw. But in the Hereafter (there is) a severe torment (for the disbelievers, evil-doers), and (there is) Forgiveness from Allah and (His) Good Pleasure (for the believers, good-doers), whereas the life of this world is only a deceiving enjoyment.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race one with another in hastening towards Forgiveness from your Lord (Allah), and towards Paradise, the width whereof is as the width of heaven and earth, prepared for those who believe in Allah and His Messengers. That is the Grace of Allah which He bestows on whom He pleases. And Allah is the Owner of Great Bounty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No calamity befalls on the earth or in yourselves but is inscribed in the Book of Decrees (Al-Lauh Al-Mahfuz), before We bring it into existence. Verily, that is easy for Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
In order that you may not be sad over matters that you fail to get, nor rejoice because of that which has been given to you. And Allah likes not prideful boasters.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Those who are misers and enjoin upon people miserliness (Allah is not in need of their charity). And whosoever turns away (from Faith Allah's Monotheism), then Allah is Rich (Free of all wants), Worthy of all praise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Indeed We have sent Our Messengers with clear proofs, and revealed with them the Scripture and the Balance (justice) that mankind may keep up justice. And We brought forth iron wherein is mighty power (in matters of war), as well as many benefits for mankind, that Allah may test who it is that will help Him (His religion), and His Messengers in the unseen. Verily, Allah is All-Strong, All-Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And indeed, We sent Nuh (Noah) and Ibrahim (Abraham), and placed in their offspring Prophethood and Scripture, and among them there is he who is guided, but many of them are Fasiqun (rebellious, disobedient to Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then, We sent after them, Our Messengers, and We sent 'Iesa (Jesus) - son of Maryam (Mary), and gave him the Injeel (Gospel). And We ordained in the hearts of those who followed him, compassion and mercy. But the Monasticism which they invented for themselves, We did not prescribe for them, but (they sought it) only to please Allah therewith, but that they did not observe it with the right observance. So We gave those among them who believed, their (due) reward, but many of them are Fasiqun (rebellious, disobedient to Allah).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O you who believe [in Musa (Moses) (i.e. Jews) and 'Iesa (Jesus) (i.e. Christians)]! Fear Allah, and believe too in His Messenger (Muhammad SAW), He will give you a double portion of His Mercy, and He will give you a light by which you shall walk (straight), and He will forgive you. And Allah is Oft-Forgiving, Most Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
So that the people of the Scripture (Jews and Christians) may know that they have no power whatsoever over the Grace of Allah, and that (His) Grace is (entirely) in His Hand to bestow it on whomsoever He wills. And Allah is the Owner of Great Bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Indeed Allah has heard the statement of her (Khaulah bint Tha'labah) that disputes with you (O Muhammad SAW) concerning her husband (Aus bin As-Samit), and complains to Allah. And Allah hears the argument between you both. Verily, Allah is All-Hearer, All-Seer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those among you who make their wives unlawful (Az-Zihar) to them by saying to them ``You are like my mother's back." They cannot be their mothers. None can be their mothers except those who gave them birth. And verily, they utter an ill word and a lie. And verily, Allah is Oft-Pardoning, Oft-Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
And those who make unlawful to them (their wives) (by Az-Zihar) and wish to free themselves from what they uttered, (the penalty) in that case (is) the freeing of a slave before they touch each other. That is an admonition to you (so that you may not return to such an ill thing). And Allah is All-Aware of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And he who finds not (the money for freeing a slave) must fast two successive months before they both touch each other. And for him who is unable to do so, he should feed sixty of Miskin (poor). That is in order that you may have perfect Faith in Allah and His Messenger. These are the limits set by Allah. And for disbelievers, there is a painful torment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Verily, those who oppose Allah and His Messenger (Muhammad SAW) will be disgraced, as those before them (among the past nation), were disgraced. And We have sent down clear Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.). And for the disbelievers is a disgracing torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day when Allah will resurrect them all together (i.e. the Day of Resurrection) and inform them of what they did. Allah has kept account of it, while they have forgotten it. And Allah is Witness over all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Have you not seen that Allah knows whatsoever is in the heavens and whatsoever is on the earth? There is no Najwa (secret counsel) of three, but He is their fourth (with His Knowledge, while He Himself is over the Throne, over the seventh heaven), nor of five but He is their sixth (with His Knowledge), not of less than that or more, but He is with them (with His Knowledge) wheresoever they may be; and afterwards on the Day of Resurrection, He will inform them of what they did. Verily, Allah is the All-Knower of everything.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you not seen those who were forbidden to hold secret counsels, and afterwards returned to that which they had been forbidden, and conspired together for sin and wrong doing and disobedience to the Messenger (Muhammad SAW). And when they come to you, they greet you with a greeting wherewith Allah greets you not, and say within themselves: ``Why should Allah punish us not for what we say?" Hell will be sufficient for them, they will burn therein, and worst indeed is that destination!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O you who believe! When you hold secret counsel, do it not for sin and wrong-doing, and disobedience towards the Messenger (Muhammad SAW) but do it for Al-Birr (righteousness) and Taqwa (virtues and piety); and fear Allah unto Whom you shall be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Secret counsels (conspiracies) are only from Shaitan (Satan), in order that he may cause grief to the believers. But he cannot harm them in the least, except as Allah permits, and in Allah let the believers put their trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O you who believe! When you are told to make room in the assemblies, (spread out and) make room. Allah will give you (ample) room (from His Mercy). And when you are told to rise up [for prayers, Jihad (holy fighting in Allah's Cause), or for any other good deed], rise up. Allah will exalt in degree those of you who believe, and those who have been granted knowledge. And Allah is Well-Acquainted with what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O you who believe! When you (want to) consult the Messenger (Muhammad SAW) in private, spend something in charity before your private consultation. That will be better and purer for you. But if you find not (the means for it), then verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you afraid of spending in charity before your private consultation (with him)? If then you do it not, and Allah has forgiven you, then (at least) perform As-Salat (Iqamat-as-Salat) and give Zakat and obey Allah (i.e. do all what Allah and His Prophet SAW order you to do). And Allah is All-Aware of what you do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Have you (O Muhammad SAW) not seen those (hypocrites) who take for friends a people upon whom is the Wrath of Allah (i.e. Jews)? They are neither of you (Muslims) nor of them (Jews), and they swear to a lie while they know.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a severe torment. Evil indeed is that which they used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have made their oaths a screen (for their evil actions). Thus they hinder (men) from the Path of Allah, so they shall have a humiliating torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Their children and their wealth will avail them nothing against Allah. They will be (the) dwellers of the Fire, to dwell therein forever.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day when Allah will resurrect them all together (for their account), then they will swear to Him as they swear to you (O Muslims). And they think that they have something (to stand upon). Verily, they are liars!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
Shaitan (Satan) has overtaken them. So he has made them forget the remembrance of Allah. They are the party of Shaitan (Satan). Verily, it is the party of Shaitan (Satan) that will be the losers!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Those who oppose Allah and His Messenger (Muhammad SAW), they will be among the lowest (most humiliated).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has decreed: ``Verily! It is I and My Messengers who shall be the victorious." Verily, Allah is All-Powerful, All-Mighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You (O Muhammad SAW) will not find any people who believe in Allah and the Last Day, making friendship with those who oppose Allah and His Messenger (Muhammad SAW), even though they were their fathers, or their sons, or their brothers, or their kindred (people). For such He has written Faith in their hearts, and strengthened them with Ruh (proofs, light and true guidance) from Himself. And We will admit them to Gardens (Paradise) under which rivers flow, to dwell therein (forever). Allah is pleased with them, and they with Him. They are the Party of Allah. Verily, it is the Party of Allah that will be the successful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. And He is the All-Mighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
He it is Who drove out the disbelievers among the people of the Scripture (i.e. the Jews of the tribe of Bani An-Nadir) from their homes at the first gathering. You did not think that they would get out. And they thought that their fortresses would defend them from Allah! But Allah's (Torment) reached them from a place whereof they expected it not, and He cast terror into their hearts, so that they destroyed their own dwellings with their own hands and the hands of the believers. Then take admonition, O you with eyes (to see).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And had it not been that Allah had decreed exile for them, He would certainly have punished them in this world, and in the Hereafter theirs shall be the torment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they opposed Allah and His Messenger (Muhammad SAW). And whosoever opposes Allah, then verily, Allah is Severe in punishment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
What you (O Muslims) cut down of the palm-trees (of the enemy), or you left them standing on their stems, it was by Leave of Allah, and in order that He might disgrace the Fasiqun (rebellious, disobedient to Allah).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And what Allah gave as booty (Fai') to His Messenger (Muhammad SAW) from them, for which you made no expedition with either cavalry or camelry. But Allah gives power to His Messengers over whomsoever He wills. And Allah is Able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
What Allah gave as booty (Fai') to His Messenger (Muhammad SAW) from the people of the townships, - it is for Allah, His Messenger (Muhammad SAW), the kindred (of Messenger Muhammad SAW), the orphans, Al-Masakin (the poor), and the wayfarer, in order that it may not become a fortune used by the rich among you. And whatsoever the Messenger (Muhammad SAW) gives you, take it, and whatsoever he forbids you, abstain (from it), and fear Allah. Verily, Allah is Severe in punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
(And there is also a share in this booty) for the poor emigrants, who were expelled from their homes and their property, seeking Bounties from Allah and to please Him. And helping Allah (i.e. helping His religion) and His Messenger (Muhammad SAW). Such are indeed the truthful (to what they say);\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And those who, before them, had homes (in Al-Madinah) and had adopted the Faith, love those who emigrate to them, and have no jealousy in their breasts for that which they have been given (from the booty of Bani An-Nadir), and give them (emigrants) preference over themselves, even though they were in need of that. And whosoever is saved from his own covetousness, such are they who will be the successful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came after them say: ``Our Lord! Forgive us and our brethren who have preceded us in Faith, and put not in our hearts any hatred against those who have believed. Our Lord! You are indeed full of kindness, Most Merciful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Have you (O Muhammad SAW) not observed the hypocrites who say to their friends among the people of the Scripture who disbelieve: ``(By Allah) If you are expelled, we (too) indeed will go out with you, and we shall never obey any one against you, and if you are attacked (in fight), we shall indeed help you." But Allah is Witness, that they verily, are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
Surely, if they (the Jews) are expelled, never will they (hypocrites) go out with them, and if they are attacked, they will never help them. And if they do help them, they (hypocrites) will turn their backs, so they will not be victorious.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Verily, you (believers in the Oneness of Allah - Islamic Monotheism) are more awful as a fear in their (Jews of Bani An-Nadir) breasts than Allah. That is because they are a people who comprehend not (the Majesty and Power of Allah).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They fight not against you even together, except in fortified townships, or from behind walls. Their enmity among themselves is very great. You would think they were united, but their hearts are divided, that is because they are a people who understand not.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
They are like their immediate predecessors (the Jews of Bani Qainuqa', who suffered), they tasted the evil result of their conduct, and (in the Hereafter, there is) for them a painful torment;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
(Their allies deceived them) like Shaitan (Satan), when he says to man: ``Disbelieve in Allah." But when (man) disbelieves in Allah, Shaitan (Satan) says: ``I am free of you, I fear Allah, the Lord of the 'Alamin (mankind, jinns and all that exists)!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
So the end of both will be that they will be in the Fire, abiding therein. Such is the recompense of the Zalimun (i.e. polytheists, wrong-doers, disbelievers in Allah and in His Oneness, etc.).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O you who believe! Fear Allah and keep your duty to Him. And let every person look to what he has sent forth for the morrow, and fear Allah. Verily, Allah is All-Aware of what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not like those who forgot Allah (i.e. became disobedient to Allah) and He caused them to forget their ownselves, (let them to forget to do righteous deeds). Those are the Fasiqun (rebellious, disobedient to Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the dwellers of the Fire and the dwellers of the Paradise. It is the dwellers of Paradise that will be successful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Quran on a mountain, you would surely have seen it humbling itself and rending asunder by the fear of Allah. Such are the parables which We put forward to mankind that they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, than Whom there is La ilaha illa Huwa (none has the right to be worshipped but He) the All-Knower of the unseen and the seen (open). He is the Most Beneficent, the Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah than Whom there is La ilaha illa Huwa (none has the right to be worshipped but He) the King, the Holy, the One Free from all defects, the Giver of security, the Watcher over His creatures, the All-Mighty, the Compeller, the Supreme. Glory be to Allah! (High is He) above all that they associate as partners with Him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Inventor of all things, the Bestower of forms. To Him belong the Best Names. All that is in the heavens and the earth glorify Him. And He is the All-Mighty, the All-Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O you who believe! Take not My enemies and your enemies (i.e. disbelievers and polytheists, etc.) as friends, showing affection towards them, while they have disbelieved in what has come to you of the truth (i.e. Islamic Monotheism, this Quran, and Muhammad SAW), and have driven out the Messenger (Muhammad SAW) and yourselves (from your homeland) because you believe in Allah your Lord! If you have come forth to strive in My Cause and to seek My Good Pleasure, (then take not these disbelievers and polytheists, etc., as your friends). You show friendship to them in secret, while I am All-Aware of what you conceal and what you reveal. And whosoever of you (Muslims) does that, then indeed he has gone (far) astray, (away) from the Straight Path.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
Should they gain the upper hand over you, they would behave to you as enemies, and stretch forth their hands and their tongues against you with evil, and they desire that you should disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Neither your relatives nor your children will benefit you on the Day of Resurrection (against Allah). He will judge between you. And Allah is the All-Seer of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
Indeed there has been an excellent example for you in Ibrahim (Abraham) and those with him, when they said to their people: ``Verily, we are free from you and whatever you worship besides Allah, we have rejected you, and there has started between us and you, hostility and hatred for ever, until you believe in Allah Alone," except the saying of Ibrahim (Abraham) to his father: ``Verily, I will ask for forgiveness (from Allah) for you, but I have no power to do anything for you before Allah." Our Lord! In You (Alone) we put our trust, and to You (Alone) we turn in repentance, and to You (Alone) is (our) final Return,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
``Our Lord! Make us not a trial for the disbelievers, and forgive us, Our Lord! Verily, You, only You are the All-Mighty, the All-Wise."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Certainly, there has been in them an excellent example for you to follow, for those who look forward to (the Meeting with) Allah (for the reward from Him) and the Last Day. And whosoever turn away, then verily, Allah is Rich (Free of all wants), Worthy of all Praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
Perhaps Allah will make friendship between you and those whom you hold as enemies. And Allah has power (over all things), and Allah is Oft-Forgiving, Most Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid you to deal justly and kindly with those who fought not against you on account of religion and did not drive you out of your homes. Verily, Allah loves those who deal with equity.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
It is only as regards those who fought against you on account of religion, and have driven you out of your homes, and helped to drive you out, that Allah forbids you to befriend them. And whosoever will befriend them, then such are the Zalimun (wrong-doers those who disobey Allah).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O you who believe! When believing women come to you as emigrants, examine them, Allah knows best as to their Faith, then if you ascertain that they are true believers, send them not back to the disbelievers, they are not lawful (wives) for the disbelievers nor are the disbelievers lawful (husbands) for them. But give the disbelievers that (amount of money) which they have spent [as their Mahr] to them. And there will be no sin on you to marry them if you have paid their Mahr to them. Likewise hold not the disbelieving women as wives, and ask for (the return of) that which you have spent (as Mahr) and let them (the disbelievers, etc.) ask back for that which they have spent. That is the Judgement of Allah. He judges between you. And Allah is All-Knowing, All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives have gone from you to the disbelievers, and you have an accession (by the coming over of a woman from the other side), then pay to those whose wives have gone, the equivalent of what they had spent (on their Mahr). And fear Allah in Whom you believe.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet! When believing women come to you to give you the Bai'a (pledge), that they will not associate anything in worship with Allah, that they will not steal, that they will not commit illegal sexual intercourse, that they will not kill their children, that they will not utter slander, intentionally forging falsehood (i.e. by making illegal children belonging to their husbands), and that they will not disobey you in any Ma'ruf (Islamic Monotheism and all that which Islam ordains) then accept their Bai'a (pledge), and ask Allah to forgive them, Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O you who believe! Take not as friends the people who incurred the Wrath of Allah (i.e. the Jews). Surely, they have been in despair to receive any good in the Hereafter, just as the disbelievers have been in despair about those (buried) in graves (that they will not be resurrected on the Day of Resurrection).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. And He is the All-Mighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O you who believe! Why do you say that which you do not do?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Most hateful it is with Allah that you say that which you do not do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Verily, Allah loves those who fight in His Cause in rows (ranks) as if they were a solid structure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And (remember) when Musa (Moses) said to his people: ``O my people! Why do you hurt me while you know certainly that I am the Messenger of Allah to you? So when they turned away (from the Path of Allah), Allah turned their hearts away (from the Right Path). And Allah guides not the people who are Fasiqun (rebellious, disobedient to Allah).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And (remember) when 'Iesa (Jesus), son of Maryam (Mary), said: ``O Children of Israel! I am the Messenger of Allah unto you confirming the Taurat [(Torah) which came] before me, and giving glad tidings of a Messenger to come after me, whose name shall be Ahmad. But when he (Ahmad i.e. Muhammad SAW) came to them with clear proofs, they said: ``This is plain magic."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who does more wrong than the one who invents a lie against Allah, while he is being invited to Islam? And Allah guides not the people who are Zalimun (polytheists, wrong-doers and disbelievers) folk.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They intend to put out the Light of Allah (i.e. the religion of Islam, this Quran, and Prophet Muhammad SAW) with their mouths. But Allah will complete His Light even though the disbelievers hate (it).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
He it is Who has sent His Messenger (Muhammad SAW) with guidance and the religion of truth (Islamic Monotheism) to make it victorious over all (other) religions even though the Mushrikun (polytheists, pagans, idolaters, and disbelievers in the Oneness of Allah and in His Messenger Muhammed SAW) hate (it).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O You who believe! Shall I guide you to a commerce that will save you from a painful torment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
That you believe in Allah and His Messenger (Muhammad SAW), and that you strive hard and fight in the Cause of Allah with your wealth and your lives, that will be better for you, if you but know!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
(If you do so) He will forgive you your sins, and admit you into Gardens under which rivers flow, and pleasant dwelling in Gardens of 'Adn - Eternity ['Adn (Edn) Paradise], that is indeed the great success.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And also (He will give you) another (blessing) which you love, help from Allah (against your enemies) and a near victory. And give glad tidings (O Muhammad SAW) to the believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O you who believe! Be you helpers (in the Cause) of Allah as said 'Iesa (Jesus), son of Maryam (Mary), to Al-Hawariun (the disciples): ``Who are my helpers (in the Cause) of Allah?" Al-Hawarieen (the disciples) said: ``We are Allah's helpers" (i.e. we will strive in His Cause!). Then a group of the Children of Israel believed and a group disbelieved. So We gave power to those who believed against their enemies, and they became the uppermost.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah, the King (of everything), the Holy, the All-Mighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
He it is Who sent among the unlettered ones a Messenger (Muhammad SAW) from among themselves, reciting to them His Verses, purifying them (from the filth of disbelief and polytheism), and teaching them the Book (this Quran, Islamic laws and Islamic jurisprudence) and Al-Hikmah (As-Sunnah: legal ways, orders, acts of worship, etc. of Prophet Muhammad SAW). And verily, they had been before in mainfest error;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And He has sent him (Prophet Muhammad SAW) also to others among them (Muslims) who have not yet joined them (but they will come). And He (Allah) is the All-Mighty, the All-Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the Grace of Allah, which He bestows on whom He wills. And Allah is the Owner of Mighty Grace.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who were entrusted with the (obligation of the) Taurat (Torah) (i.e. to obey its commandments and to practise its legal laws), but who subsequently failed in those (obligations), is as the likeness of a donkey who carries huge burdens of books (but understands nothing from them). How bad is the example (or the likeness) of people who deny the Ayat (proofs, evidences, verses, signs, revelations, etc.) of Allah. And Allah guides not the people who are Zalimun (polytheists, wrong-doers, disbelievers, etc.).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say (O Muhammad SAW): ``O you Jews! If you pretend that you are friends of Allah, to the exclusion of (all) other mankind, then long for death if you are truthful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will never long for it (death), because of what (deeds) their hands have sent before them! And Allah knows well the Zalimun (polytheists, wrong-doers, disbelievers, etc.).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say (to them): ``Verily, the death from which you flee will surely meet you, then you will be sent back to (Allah), the All-Knower of the unseen and the seen, and He will tell you what you used to do."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O you who believe (Muslims)! When the call is proclaimed for the Salat (prayer) on the day of Friday (Jumu'ah prayer), come to the remembrance of Allah [Jumu'ah religious talk (Khutbah) and Salat (prayer)] and leave off business (and every other thing), that is better for you if you did but know!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then when the (Jumu'ah) Salat (prayer) is finished, you may disperse through the land, and seek the Bounty of Allah (by working, etc.), and remember Allah much, that you may be successful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
And when they see some merchandise or some amusement [beating of Tambur (drum) etc.] they disperse headlong to it, and leave you (Muhammad SAW) standing [while delivering Jumu'ah's religious talk (Khutbah)]. Say ``That which Allah has is better than any amusement or merchandise! And Allah is the Best of providers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to you (O Muhammad SAW), they say: ``We bear witness that you are indeed the Messenger of Allah." Allah knows that you are indeed His Messenger and Allah bears witness that the hypocrites are liars indeed.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have made their oaths a screen (for their hypocrisy). Thus they hinder (men) from the Path of Allah. Verily, evil is what they used to do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, then disbelieved, therefore their hearts are sealed, so they understand not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when you look at them, their bodies please you; and when they speak, you listen to their words. They are as blocks of wood propped up. They think that every cry is against them. They are the enemies, so beware of them. May Allah curse them! How are they denying (or deviating from) the Right Path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them: ``Come, so that the Messenger of Allah may ask forgiveness from Allah for you", they turn aside their heads, and you would see them turning away their faces in pride.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is equal to them whether you (Muhammad SAW) ask forgiveness or ask not forgiveness for them. Verily, Allah guides not the people who are the Fasiqin (rebellious, disobedient to Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They are the ones who say: ``Spend not on those who are with Allah's Messenger, until they desert him." And to Allah belong the treasures of the heavens and the earth, but the hypocrites comprehend not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They (hyprocrites) say: ``If we return to Al-Madinah, indeed the more honourable ('Abdullah bin Ubai bin Salul, the chief of hyprocrites at Al-Madinah) will expel therefrom the meaner (i.e. Allah's Messenger SAW)." But honour, power and glory belong to Allah, His Messenger (Muhammad SAW), and to the believers, but the hypocrites know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O you who believe! Let not your properties or your children divert you from the remembrance of Allah. And whosoever does that, then they are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend (in charity) of that with which We have provided you, before death comes to one of you and he says: ``My Lord! If only You would give me respite for a little while (i.e. return to the worldly life), then I should give Sadaqah (i.e. Zakat) of my wealth, and be among the righteous [i.e. perform Hajj (pilgrimage to Makkah)].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
And Allah grants respite to none when his appointed time (death) comes. And Allah is All-Aware of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. His is the dominion, and to Him belong all the praises and thanks, and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
He it is Who created you, then some of you are disbelievers and some of you are believers. And Allah is All-Seer of what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He has created the heavens and the earth with truth, and He shaped you and made good your shapes, and to Him is the final Return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows what is in the heavens and on earth, and He knows what you conceal and what you reveal. And Allah is the All-Knower of what is in the breasts (of men).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has not the news reached you of those who disbelieved aforetime? And so they tasted the evil result of their disbelief, and theirs will be a painful torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That was because there came to them their Messengers with clear proofs (signs), but they said: ``Shall mere men guide us?" So they disbelieved and turned away (from the truth), and Allah was not in need (of them). And Allah is Rich (Free of all wants), Worthy of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The disbelievers pretend that they will never be resurrected (for the Account). Say (O Muhammad SAW): ``Yes! By my Lord, you will certainly be resurrected, then you will be informed of (and recompensed for) what you did, and that is easy for Allah.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Therefore, believe in Allah and His Messenger (Muhammad SAW), and in the Light (this Quran) which We have sent down. And Allah is All-Aware of what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
(And remember) the Day when He will gather you (all) on the Day of Gathering, that will be the Day of mutual loss and gain (i.e. loss for the disbelievers as they will enter the Hell-fire and gain for the believers as they will enter Paradise). And whosoever believes in Allah and performs righteous good deeds, He will remit from him his sins, and will admit him to Gardens under which rivers flow (Paradise) to dwell therein forever, that will be the great success.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But those who disbelieved (in the Oneness of Allah - Islamic Monotheism) and denied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they will be the dwellers of the Fire, to dwell therein forever. And worst indeed is that destination.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No calamity befalls, but with the Leave [i.e. decision and Qadar (Divine Preordainments)] of Allah, and whosoever believes in Allah, He guides his heart [to the true Faith with certainty, i.e. what has befallen him was already written for him by Allah from the Qadar (Divine Preordainments)], and Allah is the All-Knower of everything.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah, and obey the Messenger (Muhammad SAW), but if you turn away, then the duty of Our Messenger is only to convey (the Message) clearly.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah! La ilaha illa Huwa (none has the right to be worshipped but He), and in Allah (Alone), therefore, let the believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O you who believe! Verily, among your wives and your children there are enemies for you (i.e. may stop you from the obedience of Allah), therefore beware of them! But if you pardon (them) and overlook, and forgive (their faults), then verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are only a trial, whereas Allah! With Him is a great reward (Paradise).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So keep your duty to Allah and fear Him as much as you can; listen and obey; and spend in charity, that is better for yourselves. And whosoever is saved from his own covetousness, then they are the successful ones.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend to Allah a goodly loan (i.e. spend in Allah's Cause) He will double it for you, and will forgive you. And Allah is Most Ready to appreciate and to reward, Most Forbearing,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
All-Knower of the unseen and seen, the All-Mighty, the All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet (SAW)! When you divorce women, divorce them at their 'Iddah (prescribed periods), and count (accurately) their 'Iddah (periods). And fear Allah your Lord (O Muslims), and turn them not out of their (husband's) homes, nor shall they (themselves) leave, except in case they are guilty of some open illegal sexual intercourse. And those are the set limits of Allah. And whosoever transgresses the set limits of Allah, then indeed he has wronged himself. You (the one who divorces his wife) know not, it may be that Allah will afterward bring some new thing to pass (i.e. to return her back to you if that was the first or second divorce).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Then when they are about to fulfil their term appointed, either take them back in a good manner or part with them in a good manner. And take for witness two just persons from among you (Muslims). And establish the witness for Allah. That will be an admonition given to him who believes in Allah and the Last Day. And whosoever fears Allah and keeps his duty to Him, He will make a way for him to get out (from every difficulty).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And He will provide him from (sources) he never could imagine. And whosoever puts his trust in Allah, then He will suffice him. Verily, Allah will accomplish his purpose. Indeed Allah has set a measure for all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
And those of your women as have passed the age of monthly courses, for them the 'Iddah (prescribed period), if you have doubts (about their periods), is three months, and for those who have no courses [(i.e. they are still immature) their 'Iddah (prescribed period) is three months likewise, except in case of death]. And for those who are pregnant (whether they are divorced or their husbands are dead), their 'Iddah (prescribed period) is until they deliver (their burdens), and whosoever fears Allah and keeps his duty to Him, He will make his matter easy for him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the Command of Allah, which He has sent down to you, and whosoever fears Allah and keeps his duty to Him, He will remit his sins from him, and will enlarge his reward.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them (the divorced women) where you dwell, according to your means, and do not treat them in such a harmful way that they be obliged to leave. And if they are pregnant, then spend on them till they deliver. Then if they give suck to the children for you, give them their due payment, and let each of you accept the advice of the other in a just way. But if you make difficulties for one another, then some other woman may give suck for him (the father of the child).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the rich man spend according to his means, and the man whose resources are restricted, let him spend according to what Allah has given him. Allah puts no burden on any person beyond what He has given him. Allah will grant after hardship, ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And many a town (population) revolted against the Command of its Lord and His Messengers, and We called it to a severe account (i.e. torment in this worldly life), and shall punish it with a horrible torment (in Hell, in the Hereafter).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So it tasted the evil result of its disbelief, and the consequence of its disbelief was loss (destruction in this life and an eternal punishment in the Hereafter).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has prepared for them a severe torment. So fear Allah and keep your duty to Him, O men of understanding who have believed! - Allah has indeed sent down to you a Reminder (this Quran).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
(And has also sent to you) a Messenger (Muhammad SAW), who recites to you the Verses of Allah (the Quran) containing clear explanations, that He may take out, those who believe and do righteous good deeds from the darkness (of polytheism and disbelief) to the light (of Monotheism and true Faith). And whosoever believes in Allah and performs righteous good deeds, He will admit him into Gardens under which rivers flow (Paradise), to dwell therein forever. Allah has indeed granted for him an excellent provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is Allah Who has created seven heavens and of the earth the like thereof (i.e. seven). His Command descends between them (heavens and earth), that you may know that Allah has power over all things, and that Allah surrounds (comprehends) all things in (His) Knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet! Why do you ban (for yourself) that which Allah has made lawful to you, seeking to please your wives? And Allah is Oft-Forgiving, Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has already ordained for you (O men), the dissolution of your oaths. And Allah is your Maula (Lord, or Master, or Protector, etc.) and He is the All-Knower, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And (remember) when the Prophet (SAW) disclosed a matter in confidence to one of his wives (Hafsah), so when she told it (to another i.e. 'Aishah), and Allah made it known to him, he informed part thereof and left a part. Then when he told her (Hafsah) thereof, she said: ``Who told you this?" He said: ``The All-Knower, the All-Aware (Allah) has told me".\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you two (wives of the Prophet SAW, namely 'Aishah and Hafsah) turn in repentance to Allah, (it will be better for you), your hearts are indeed so inclined (to oppose what the Prophet SAW likes), but if you help one another against him (Muhammad SAW), then verily, Allah is his Maula (Lord, or Master, or Protector, etc.), and Jibrael (Gabriel), and the righteous among the believers, and furthermore, the angels are his helpers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It may be if he divorced you (all) that his Lord will give him instead of you, wives better than you, Muslims (who submit to Allah), believers, obedient to Allah, turning to Allah in repentance, worshipping Allah sincerely, fasting or emigrants (for Allah's sake), previously married and virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O you who believe! Ward off from yourselves and your families a Fire (Hell) whose fuel is men and stones, over which are (appointed) angels stern (and) severe, who disobey not, (from executing) the Commands they receive from Allah, but do that which they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
(It will be said in the Hereafter) O you who disbelieve (in the Oneness of Allah - Islamic Monotheism)! Make no excuses this Day! You are being requited only for what you used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O you who believe! Turn to Allah with sincere repentance! It may be that your Lord will remit from you your sins, and admit you into Gardens under which rivers flow (Paradise) the Day that Allah will not disgrace the Prophet (Muhammad SAW) and those who believe with him, their Light will run forward before them and with (their Records Books of deeds) in their right hands they will say: ``Our Lord! Keep perfect our Light for us [and do not put it off till we cross over the Sirat (a slippery bridge over the Hell) safely] and grant us forgiveness. Verily, You are Able to do all things."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet (Muhammad SAW)! Strive hard against the disbelievers and the hypocrites, and be severe against them, their abode will be Hell, and worst indeed is that destination.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah sets forth an example for those who disbelieve, the wife of Nuh (Noah) and the wife of Lout (Lot). They were under two of our righteous slaves, but they both betrayed their (husbands by rejecting their doctrine) so they [Nuh (Noah) and Lout (Lot)] benefited them (their respective wives) not, against Allah, and it was said: ``Enter the Fire along with those who enter!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah has set forth an example for those who believe, the wife of Fir'aun (Pharaoh), when she said: ``My Lord! Build for me a home with You in Paradise, and save me from Fir'aun (Pharaoh) and his work, and save me from the people who are Zalimun (polytheists, wrong-doers and disbelievers in Allah).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Maryam (Mary), the daughter of 'Imran who guarded her chastity; and We breathed into (the sleeve of her shirt or her garment) through Our Ruh [i.e. Jibrael (Gabriel)], and she testified to the truth of the Words of her Lord [i.e. believed in the Words of Allah: ``Be!" and he was; that is 'Iesa (Jesus) - son of Maryam (Mary); as a Messenger of Allah], and (also believed in) His Scriptures, and she was of the Qanitin (i.e. obedient to Allah).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed is He in Whose Hand is the dominion, and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
Who has created death and life, that He may test you which of you is best in deed. And He is the All-Mighty, the Oft-Forgiving;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
Who has created the seven heavens one above another, you can see no fault in the creations of the Most Beneficent. Then look again: ``Can you see any rifts?"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then look again and yet again, your sight will return to you in a state of humiliation and worn out.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And indeed We have adorned the nearest heaven with lamps, and We have made such lamps (as) missiles to drive away the Shayatin (devils), and have prepared for them the torment of the blazing Fire.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord (Allah) is the torment of Hell, and worst indeed is that destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are cast therein, they will hear the (terrible) drawing in of its breath as it blazes forth.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
It almost bursts up with fury. Every time a group is cast therein, its keeper will ask: ``Did no warner come to you?"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say: ``Yes indeed; a warner did come to us, but we belied him and said: 'Allah never sent down anything (of revelation), you are only in great error.'"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say: ``Had we but listened or used our intelligence, we would not have been among the dwellers of the blazing Fire!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
Then they will confess their sin. So, away with the dwellers of the blazing Fire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Verily! Those who fear their Lord unseen (i.e. they do not see Him, nor His Punishment in the Hereafter, etc.), theirs will be forgiveness and a great reward (i.e. Paradise).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And whether you keep your talk secret or disclose it, verily, He is the All-Knower of what is in the breasts (of men).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Should not He Who has created know? And He is the Most Kind and Courteous (to His slaves) All-Aware (of everything).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
He it is, Who has made the earth subservient to you (i.e. easy for you to walk, to live and to do agriculture on it, etc.), so walk in the path thereof and eat of His provision, and to Him will be the Resurrection.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He, Who is over the heaven (Allah), will not cause the earth to sink with you, then behold it shakes (as in an earthquake)?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or do you feel secure that He, Who is over the heaven (Allah), will not send against you a violent whirlwind? Then you shall know how (terrible) has been My Warning?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And indeed those before them belied (the Messengers of Allah), then how terrible was My denial (punishment)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Do they not see the birds above them, spreading out their wings and folding them in? None upholds them except the Most Beneficent (Allah). Verily, He is the All-Seer of everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Who is he besides the Most Beneficent that can be an army to you to help you? The disbelievers are in nothing but delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Who is he that can provide for you if He should withhold His provision? Nay, but they continue to be in pride, and (they) flee (from the truth).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is he who walks without seeing on his face, more rightly guided, or he who (sees and) walks on a Straight Way (i.e. Islamic Monotheism).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say it is He Who has created you, and endowed you with hearing (ears), seeing (eyes), and hearts. Little thanks you give.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: ``It is He Who has created you from the earth, and to Him shall you be gathered (in the Hereafter)."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They say: ``When will this promise (i.e. the Day of Resurrection) come to pass? if you are telling the truth."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say (O Muhammad SAW): ``The knowledge (of its exact time) is with Allah only, and I am only a plain warner."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they will see it (the torment on the Day of Resurrection) approaching, the faces of those who disbelieve will be different (black, sad, and in grieve), and it will be said (to them): ``This is (the promise) which you were calling for!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say (O Muhammad SAW): ``Tell me! If Allah destroys me, and those with me, or He bestows His Mercy on us, - who can save the disbelievers from a painful torment?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: ``He is the Most Beneficent (Allah), in Him we believe, and in Him we put our trust. So you will come to know who is it that is in manifest error."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say (O Muhammad SAW): ``Tell me! If (all) your water were to be sunk away, who then can supply you with flowing (spring) water?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. [These letters (Nun, etc.) are one of the miracles of the Quran, and none but Allah (Alone) knows their meanings]. By the pen and what the (angels) write (in the Records of men).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
You (O Muhammad SAW) are not, by the Grace of your Lord, a madman.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And verily, for you (O Muhammad SAW) will be an endless reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And verily, you (O Muhammad SAW) are on an exalted standard of character.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
You will see, and they will see,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is afflicted with madness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Verily, your Lord knows better, who (among men) has gone astray from His Path, and He knows better those who are guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
So (O Muhammad SAW) obey not the deniers [(of Islamic Monotheism those who belie the Verses of Allah), the Oneness of Allah, and the Messenger of Allah (Muhammad SAW), etc.]\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They wish that you should compromise (in religion out of courtesy) with them, so they (too) would compromise with you.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And obey not everyone who swears much, and is considered worthless,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
A slanderer, going about with calumnies,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
Hinderer of the good, transgressor, sinful,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Cruel, after all that base-born (of illegitimate birth),\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
(He was so) because he had wealth and children.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our Verses (of the Quran) are recited to him, he says: ``Tales of the men of old!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We shall brand him over the nose!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Verily, We have tried them as We tried the people of the garden, when they swore to pluck the fruits of the (garden) in the morning,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
Without saying: Insha' Allah (If Allah will).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then there passed by on the (garden) something (fire) from your Lord at night and burnt it while they were asleep.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
So the (garden) became black by the morning, like a pitch dark night (in complete ruins).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
Then they called out one to another as soon as the morning broke,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
Saying: ``Go to your tilth in the morning, if you would pluck the fruits."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they departed, conversing in secret low tones (saying),\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
No Miskin (poor man) shall enter upon you into it today.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went in the morning with strong intention, thinking that they have power (to prevent the poor taking anything of the fruits therefrom).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw the (garden), they said: ``Verily, we have gone astray,"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
(Then they said): ``Nay! Indeed we are deprived of (the fruits)!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The best among them said: ``Did I not tell you: why do you not say: Insha' Allah (If Allah will)."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said: ``Glory to Our Lord! Verily, we have been Zalimun (wrong-doers, etc.)."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they turned, one against another, in blaming.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: ``Woe to us! Verily, we were Taghun (transgressors and disobedient, etc.)\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
We hope that our Lord will give us in exchange a better (garden) than this. Truly, we turn to our Lord (wishing for good that He may forgive our sins, and reward us in the Hereafter)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the punishment (in this life), but truly, the punishment of the Hereafter is greater, if they but knew.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Verily, for the Muttaqun (pious and righteous persons - see V. 2:2) are Gardens of delight (Paradise) with their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We then treat the (submitting) Muslims like the Mujrimun (criminals, polytheists and disbelievers, etc.)?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you? How judge you?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or have you a Book through which you learn.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That you shall have all that you choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or you have oaths from Us, reaching to the Day of Resurrection that yours will be what you judge.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, which of them will stand surety for that!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or have they ``partners"? Then let them bring their ``partners" if they are truthful!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
(Remember) the Day when the Shin shall be laid bare (i.e. the Day of Resurrection) and they shall be called to prostrate (to Allah), but they (hypocrites) shall not be able to do so,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes will be cast down, ignominy will cover them; they used to be called to prostrate (offer prayers), while they were healthy and good (in the life of the world, but they did not).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Then leave Me Alone with such as belie this Quran. We shall punish them gradually from directions they perceive not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I will grant them a respite. Verily, My Plan is strong.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or is it that you (O Muhammad SAW) ask them a wage, so that they are heavily burdened with debt?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or that the Ghaib (unseen here in this Verse it means Al-Lauh Al-Mahfuz) is in their hands, so that they can write it down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So wait with patience for the Decision of your Lord, and be not like the Companion of the Fish, when he cried out (to Us) while he was in deep sorrow. (See the Quran, Verse 21:87).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had not a Grace from his Lord reached him, he would indeed have been (left in the stomach of the fish, but We forgave him), so he was cast off on the naked shore, while he was to be blamed.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord chose him and made him of the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And verily, those who disbelieve would almost make you slip with their eyes through hatredness when they hear the Reminder (the Quran), and they say: ``Verily, he (Muhammad SAW) is a madman!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is nothing else than a Reminder to all the 'Alamin (mankind, jinns and all that exists).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Reality (i.e. the Day of Resurrection)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Reality?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what will make you know what the Reality is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamud and 'Ad people denied the Qari'ah [the striking Hour (of Judgement)]!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamud, they were destroyed by the awful cry!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for 'Ad, they were destroyed by a furious violent wind;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
Which Allah imposed on them for seven nights and eight days in succession, so that you could see men lying overthrown (destroyed), as if they were hollow trunks of date-palms!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Do you see any remnants of them?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Fir'aun (Pharaoh), and those before him, and the cities overthrown [the towns of the people of [Lout (Lot)] committed sin,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And they disobeyed their Lord's Messenger, so He punished them with a strong punishment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Verily! When the water rose beyond its limits [Nuh's (Noah) Flood], We carried you (mankind) in the floating [ship that was constructed by Nuh (Noah)].\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it a remembrance for you, and the keen ear (person) may (hear and) understand it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
Then when the Trumpet will be blown with one blowing (the first one),\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains shall be removed from their places, and crushed with a single crushing,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
Then on that Day shall the (Great) Event befall,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will split asunder, for that Day it (the heaven will be frail (weak), and torn up,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be on its sides, and eight angels will, that Day, bear the Throne of your Lord above them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
That Day shall you be brought to Judgement, not a secret of you will be hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then as for him who will be given his Record in his right hand will say: ``Take, read my Record!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
``Surely, I did believe that I shall meet my Account!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
So he shall be in a life, well-pleasing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a lofty Paradise,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
The fruits in bunches whereof will be low and near at hand.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
Eat and drink at ease for that which you have sent on before you in days past!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for him who will be given his Record in his left hand, will say: ``I wish that I had not been given my Record!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
``And that I had never known, how my Account is?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
``I wish, would that it had been my end (death)!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
``My wealth has not availed me,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
``My power and arguments (to defend myself) have gone from me!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(It will be said): ``Seize him and fetter him,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
Then throw him in the blazing Fire.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
``Then fasten him with a chain whereof the length is seventy cubits!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Verily, He used not to believe in Allah, the Most Great,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
And urged not on the feeding of Al-Miskin (the poor),\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
So no friend has he here this Day,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
Nor any food except filth from the washing of wounds,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
None will eat except the Khati'un (sinners, disbelievers, polytheists, etc.).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
So I swear by whatsoever you see,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And by whatsoever you see not,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
That this is verily the word of an honoured Messenger [i.e. Jibrael (Gabriel) or Muhammad SAW which he has brought from Allah].\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not the word of a poet, little is that you believe!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the word of a soothsayer (or a foreteller), little is that you remember!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
This is the Revelation sent down from the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if he (Muhammad SAW) had forged a false saying concerning Us (Allah),\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We surely should have seized him by his right hand (or with power and might),\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
And then certainly should have cut off his life artery (Aorta),\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And none of you could withhold Us from (punishing) him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And verily, this Quran is a Reminder for the Muttaqun (pious - see V. 2:2).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And verily, We know that there are some among you that belie (this Quran). [Tafsir At-Tabari, Vol. 29, Page 68]\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And indeed it (this Quran) will be an anguish for the disbelievers (on the Day of Resurrection).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And Verily, it (this Quran) is an absolute truth with certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So glorify the Name of your Lord, the Most Great.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner asked concerning a torment about to befall\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
Upon the disbelievers, which none can avert,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From Allah, the Lord of the ways of ascent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
The angels and the Ruh [Jibrael (Gabriel)] ascend to Him in a Day the measure whereof is fifty thousand years,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So be patient (O Muhammad SAW), with a good patience.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Verily! They see it (the torment) afar off,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
But We see it (quite) near.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
The Day that the sky will be like the boiling filth of oil, (or molten copper or silver or lead, etc.).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the mountains will be like flakes of wool,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no friend will ask of a friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
Though they shall be made to see one another [(i.e. on the Day of Resurrection), there will be none but see his father, children and relatives, but he will neither speak to them nor will ask them for any help)], - the Mujrim, (criminal, sinner, disbeliever, etc.) would desire to ransom himself from the punishment of that Day by his children.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his wife and his brother,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his kindred who sheltered him,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all that are in the earth, so that it might save him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! Verily, it will be the Fire of Hell!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
Taking away (burning completely) the head skin!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
Calling: ``[O Kafir (O disbeliever in Allah, His angels, His Book, His Messengers, Day of Resurrection and in Al-Qadar (Divine Preordainments), O Mushrik (O polytheist, disbeliever in the Oneness of Allah)] (all) such as turn their backs and turn away their faces (from Faith) [picking and swallowing them up from that great gathering of mankind (on the Day of Resurrection) just as a bird picks up a food-grain from the earth with its beak and swallows it up] [Tafsir Al-Qurtubi, Vol. 18, Page 289]\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And collect (wealth) and hide it (from spending it in the Cause of Allah).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Verily, man (disbeliever) was created very impatient;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Irritable (discontented) when evil touches him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And niggardly when good touches him;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Except those devoted to Salat (prayers)\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who remain constant in their Salat (prayers);\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose wealth there is a known right,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the beggar who asks, and for the unlucky who has lost his property and wealth, (and his means of living has been straitened);\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who believe in the Day of Recompense,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who fear the torment of their Lord,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Verily! The torment of their Lord is that before which none can feel secure,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who guard their chastity (i.e. private parts from illegal sexual acts).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except with their wives and the (women slaves and captives) whom their right hands possess, for (then) they are not to be blamed,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whosoever seeks beyond that, then it is those who are trespassers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who keep their trusts and covenants;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand firm in their testimonies;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who guard their Salat (prayers) well.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Such shall dwell in the Gardens (i.e. Paradise) honoured.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
So what is the matter with those who disbelieve that they hasten to listen from you (O Muhammad SAW), in order to belie you and to mock at you, and at Allah's Book (this Quran).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
(Sitting) in groups on the right and on the left (of you, O Muhammad SAW)?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does every man of them hope to enter the Paradise of delight?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
No, that is not like that! Verily, We have created them out of that which they know!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
So I swear by the Lord of all [the three hundred and sixty (360)] points of sunrise and sunset in the east and the west that surely We are Able\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them by (others) better than them; and We are not to be outrun.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them to plunge in vain talk and play about, until they meet their Day which they are promised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day when they will come out of the graves quickly as racing to a goal,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
With their eyes lowered in fear and humility, ignominy covering them (all over)! That is the Day which they were promised!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Verily, We sent Nuh (Noah) to his people (Saying): ``Warn your people before there comes to them a painful torment."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: ``O my people! Verily, I am a plain warner to you,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
``That you should worship Allah (Alone), be dutiful to Him, and obey me,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
``He (Allah) will forgive you of your sins and respite you to an appointed term. Verily, the term of Allah when it comes, cannot be delayed, if you but knew."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: ``O my Lord! Verily, I have called my people night and day (i.e. secretly and openly to accept the doctrine of Islamic Monotheism).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
``But all my calling added nothing but to (their) flight (from the truth).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
``And verily! Every time I called unto them that You might forgive them, they thrust their fingers into their ears, covered themselves up with their garments, and persisted (in their refusal), and magnified themselves in pride.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
``Then verily, I called to them openly (aloud);\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
``Then verily, I proclaimed to them in public, and I have appealed to them in private,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
``I said (to them): 'Ask forgiveness from your Lord; Verily, He is Oft-Forgiving;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
'He will send rain to you in abundance;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
'And give you increase in wealth and children, and bestow on you gardens and bestow on you rivers."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is the matter with you, [that you fear not Allah (His punishment), and] you hope not for reward (from Allah or you believe not in His Oneness).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
While He has created you in (different) stages [i.e. first Nutfah, then 'Alaqah and then Mudghah, see (VV. 23:13, 14) the Quran].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
See you not how Allah has created the seven heavens one above another,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And has made the moon a light therein, and made the sun a lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah has brought you forth from the (dust of) earth. [Tafsir At-Tabari, Vol. 29, Page 97].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
Afterwards He will return you into it (the earth), and bring you forth (again on the Day of Resurrection)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And Allah has made for you the earth wide spread (an expanse).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That you may go about therein in broad roads.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Nuh (Noah) said: ``My Lord! They have disobeyed me, and followed one whose wealth and children give him no increase but only loss.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
``And they have plotted a mighty plot.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
``And they have said: 'You shall not leave your gods, nor shall you leave Wadd, nor Suwa', nor Yaghuth, nor Ya'uq, nor Nasr (names of the idols);\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
``And indeed they have led many astray. And (O Allah): 'Grant no increase to the Zalimun (polytheists, wrong-doers, and disbelievers, etc.) save error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned, then were made to enter the Fire, and they found none to help them instead of Allah.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Nuh (Noah) said: ``My Lord! Leave not one of the disbelievers on the earth!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
``If You leave them, they will mislead Your slaves, and they will beget none but wicked disbelievers."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
``My Lord! Forgive me, and my parents, and him who enters my home as a believer, and all the believing men and women. And to the Zalimun (polytheists, wrong-doers, and disbelievers, etc.) grant You no increase but destruction!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say (O Muhammad SAW): ``It has been revealed to me that a group (from three to ten in number) of jinns listened (to this Quran). They said: 'Verily! We have heard a wonderful Recital (this Quran)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
'It guides to the Right Path, and we have believed therein, and we shall never join (in worship) anything with our Lord (Allah).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
'And exalted be the Majesty of our Lord, He has taken neither a wife, nor a son (or offspring or children).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
'And that the foolish among us [i.e. Iblis (Satan) or the polytheists amongst the jinns] used to utter against Allah that which was wrong and not right.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
'And verily, we thought that men and jinns would not utter a lie against Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
'And verily, there were men among mankind who took shelter with the masculine among the jinns, but they (jinns) increased them (mankind) in sin and disbelief.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
'And they thought as you thought, that Allah will not send any Messenger (to mankind or jinns).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
'And we have sought to reach the heaven; but found it filled with stern guards and flaming fires.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
'And verily, we used to sit there in stations, to (steal) a hearing, but any who listens now will find a flaming fire watching him in ambush.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
'And we know not whether evil is intended for those on earth, or whether their Lord intends for them a Right Path.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
'There are among us some that are righteous, and some the contrary; we are groups each having a different way (religious sect, etc.).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
'And we think that we cannot escape (from the punishment of) Allah in the earth, nor can we escape (from the punishment) by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
'And indeed when we heard the Guidance (this Quran), we believed therein (Islamic Monotheism), and whosoever believes in his Lord shall have no fear, either of a decrease in the reward of his good deeds or an increase in punishment for his sins.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
'And of us some are Muslims (who have submitted to Allah, after listening to this Quran), and of us some are Al-Qasitun (disbelievers those who have deviated from the Right Path)'. And whosoever has embraced Islam (i.e. has become a Muslim by submitting to Allah), then such have sought the Right Path."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
And as for the Qasitun (disbelievers who deviated from the Right Path), they shall be firewood for Hell,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
If they (non-Muslims) had believed in Allah, and went on the Right Way (i.e. Islam) We should surely have bestowed on them water (rain) in abundance.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
That We might try them thereby. And whosoever turns away from the Reminder of his Lord (i.e. this Quran, and practice not its laws and orders), He will cause him to enter in a severe torment (i.e. Hell).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
And the mosques are for Allah (Alone), so invoke not anyone along with Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
(It has been revealed to me that) When the slave of Allah (Muhammad SAW) stood up invoking (his Lord Allah) in prayer to Him they (the jinns) just made round him a dense crowd as if sticking one over the other (in order to listen to the Prophet's recitation).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say (O Muhammad SAW): ``I invoke only my Lord (Allah Alone), and I associate none as partners along with Him."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: ``It is not in my power to cause you harm, or to bring you to the Right Path."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say (O Muhammad SAW): ``None can protect me from Allah's punishment (if I were to disobey Him), nor should I find refuge except in Him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
``(Mine is) but conveyance (of the truth) from Allah and His Messages (of Islamic Monotheism), and whosoever disobeys Allah and His Messenger, then verily, for him is the Fire of Hell, he shall dwell therein forever."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Till, when they see that which they are promised, then they will know who it is that is weaker concerning helpers and less important concerning numbers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say (O Muhammad SAW): ``I know not whether (the punishment) which you are promised is near or whether my Lord will appoint for it a distant term.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
``(He Alone) the All-Knower of the Gha'ib (unseen), and He reveals to none His Gha'ib (unseen)."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Except to a Messenger (from mankind) whom He has chosen (He informs him of unseen as much as He likes), and then He makes a band of watching guards (angels) to march before him and behind him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
[He (Allah) protects them (the Messengers)], till He sees that they (the Messengers) have conveyed the Messages of their Lord (Allah). And He (Allah) surrounds all that which is with them, and He (Allah) keeps count of all things (i.e. He knows the exact number of everything).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you wrapped in garments (i.e. Prophet Muhammad SAW)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stand (to pray) all night, except a little.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
Half of it, or a little less than that,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or a little more; and recite the Quran (aloud) in a slow, (pleasant tone and) style.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Verily, We shall send down to you a weighty Word (i.e. obligations, legal laws, etc.).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Verily, the rising by night (for Tahajjud prayer) is very hard and most potent and good for governing (the soul), and most suitable for (understanding) the Word (of Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Verily, there is for you by day prolonged occupation with ordinary duties,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember the Name of your Lord and devote yourself to Him with a complete devotion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
(He Alone is) the Lord of the east and the west, La ilaha illa Huwa (none has the right to be worshipped but He). So take Him Alone as Wakil (Disposer of your affairs).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And be patient (O Muhammad SAW) with what they say, and keep away from them in a good way.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave Me Alone to deal with the beliers (those who deny My Verses, etc.), and those who are in possession of good things of life. And give them respite for a little while.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Verily, with Us are fetters (to bind them), and a raging Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And a food that chokes, and a painful torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the Day when the earth and the mountains will be in violent shake, and the mountains will be a heap of sand poured out and flowing down.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Verily, We have sent to you (O men) a Messenger (Muhammad SAW) to be a witness over you, as We did send a Messenger [Musa (Moses)] to Fir'aun (Pharaoh).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Fir'aun (Pharaoh) disobeyed the Messenger [Musa (Moses)], so We seized him with a severe punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
Then how can you avoid the punishment, if you disbelieve, on a Day that will make the children grey-headed (i.e. the Day of Resurrection)?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
Whereon the heaven will be cleft asunder? His Promise is certainly to be accomplished.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Verily, this is an admonition, therefore whosoever will, let him take a Path to His Lord!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Verily, your Lord knows that you do stand (to pray at night) a little less than two-thirds of the night, or half the night, or a third of the night, and so do a party of those with you, And Allah measures the night and the day. He knows that you are unable to pray the whole night, so He has turned to you (in mercy). So, recite you of the Quran as much as may be easy for you. He knows that there will be some among you sick, others travelling through the land, seeking of Allah's Bounty; yet others fighting in Allah's Cause. So recite as much of the Quran as may be easy (for you), and perform As-Salat (Iqamat-as-Salat) and give Zakat, and lend to Allah a goodly loan, and whatever good you send before you for yourselves, (i.e. Nawafil non-obligatory acts of worship: prayers, charity, fasting, Hajj and 'Umrah, etc.), you will certainly find it with Allah, better and greater in reward. And seek Forgiveness of Allah. Verily, Allah is Oft-Forgiving, Most-Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you (Muhammad SAW) enveloped (in garments)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and warn!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And your Lord (Allah) magnify!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And your garments purify!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And keep away from Ar-Rujz (the idols)!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And give not a thing in order to have more (or consider not your deeds of Allah's obedience as a favour to Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
And be patient for the sake of your Lord (i.e. perform your duty to Allah)!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
Then, when the Trumpet is sounded (i.e. its second blowing);\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
Truly, that Day will be a Hard Day.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
Far from easy for the disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me Alone (to deal) with whom I created Alone (without any means, i.e. Al-Walid bin Al-Mughirah Al-Makhzumi)!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And then granted him resources in abundance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And children to be by his side!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And made life smooth and comfortable for him!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
After all that he desires that I should give more;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Nay! Verily, he has been stubborn and opposing Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I shall oblige him to (climb a slippery mountain in the Hell-fire called As-Sa'ud, or to) face a severe torment!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Verily, he thought and plotted;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
So let him be cursed! How he plotted!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
And once more let him be cursed, how he plotted!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he thought;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then he frowned and he looked in a bad tempered way;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned back and was proud;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
Then he said: ``This is nothing but magic from that of old;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
``This is nothing but the word of a human being!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will cast him into Hell-fire\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what will make you know exactly what Hell-fire is?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It spares not (any sinner), nor does it leave (anything unburnt)!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
Burning the skins!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are nineteen (angels as guardians and keepers of Hell).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
And We have set none but angels as guardians of the Fire, and We have fixed their number (19) only as a trial for the disbelievers, in order that the people of the Scripture (Jews and Christians) may arrive at a certainty [that this Quran is the truth as it agrees with their Books i.e. their number (19) is written in the Taurat (Torah) and the Injeel (Gospel)] and the believers may increase in Faith (as this Quran is the truth) and that no doubts may be left for the people of the Scripture and the believers, and that those in whose hearts is a disease (of hypocrisy) and the disbelievers may say: ``What Allah intends by this (curious) example?" Thus Allah leads astray whom He wills and guides whom He wills. And none can know the hosts of your Lord but He. And this (Hell) is nothing else than a (warning) reminder to mankind.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay, and by the moon,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And by the night when it withdraws,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And by the dawn when it brightens,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Verily, it (Hell, or their denial of the Prophet Muhammad SAW, or the Day of Resurrection) is but one of the greatest calamities.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
A warning to mankind,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
To any of you that chooses to go forward (by working righteous deeds), or to remain behind (by commiting sins),\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every person is a pledge for what he has earned,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except those on the Right, (i.e. the pious true believers of Islamic Monotheism);\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens (Paradise) they will ask one another,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
About Al-Mujrimun (polytheists, criminals, disbelievers, etc.), (And they will say to them):\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
``What has caused you to enter Hell?"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say: ``We were not of those who used to offer their Salat (prayers)\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
``Nor we used to feed Al-Miskin (the poor);\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
``And we used to talk falsehood (all that which Allah hated) with vain talkers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
``And we used to belie the Day of Recompense\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
``Until there came to us (the death) that is certain."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
So no intercession of intercessors will be of any use to them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Then what is wrong with them (i.e. the disbelievers) that they turn away from (receiving) admonition?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As if they were frightened (wild) donkeys.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a hunter, or a lion, or a beast of prey.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Nay, everyone of them desires that he should be given pages spread out (coming from Allah with a writing that Islam is the right religion, and Muhammad SAW has come with the truth from Allah the Lord of the heavens and earth, etc.).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
Nay! But they fear not the Hereafter (from Allah's punishment).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nay, verily, this (Quran) is an admonition,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So whosoever will (let him read it), and receive admonition (from it)!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they will not receive admonition unless Allah wills; He (Allah) is the One, deserving that mankind should be afraid of, and should be dutiful to Him, and should not take any Ilah (God) along with Him, and He is the One Who forgives (sins).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I swear by the Day of Resurrection;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And I swear by the self-reproaching person (a believer).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man (a disbeliever) think that We shall not assemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes, We are Able to put together in perfect order the tips of his fingers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
Nay! (Man denies Resurrection and Reckoning. So) he desires to continue committing sins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks: ``When will be this Day of Resurrection?"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
So, when the sight shall be dazed,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon will be eclipsed,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and moon will be joined together (by going one into the other or folded up or deprived of their light, etc.)\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that Day man will say: ``Where (is the refuge) to flee?"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No! There is no refuge!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Unto your Lord (Alone) will be the place of rest that Day.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that Day man will be informed of what he sent forward (of his evil or good deeds), and what he left behind (of his good or evil traditions).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Nay! Man will be a witness against himself [as his body parts (skin, hands, legs, etc.) will speak about his deeds].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Though he may put forth his excuses (to cover his evil deeds).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not your tongue concerning (the Quran, O Muhammad SAW) to make haste therewith.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
It is for Us to collect it and to give you (O Muhammad SAW) the ability to recite it (the Quran),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
And when We have recited it to you [O Muhammad SAW through Jibrael (Gabriel)], then follow you its (the Quran's) recital.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then it is for Us (Allah) to make it clear to you,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Not [as you think, that you (mankind) will not be resurrected and recompensed for your deeds], but (you men) love the present life of this world,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And leave (neglect) the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Some faces that Day shall be Nadirah (shining and radiant).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking at their Lord (Allah);\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And some faces, that Day, will be Basirah (dark, gloomy, frowning, and sad),\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Thinking that some calamity was about to fall on them;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Nay, when (the soul) reaches to the collar bone (i.e. up to the throat in its exit),\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And it will be said: ``Who can cure him and save him from death?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he (the dying person) will conclude that it was (the time) of departing (death);\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And leg will be joined with another leg (shrouded)\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
The drive will be, on that Day, to your Lord (Allah)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
So he (the disbeliever) neither believed (in this Quran, in the Message of Muhammad SAW) nor prayed!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But on the contrary, he belied (this Quran and the Message of Muhammad SAW) and turned away!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then he walked in full pride to his family admiring himself!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe to you [O man (disbeliever)]! And then (again) woe to you!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again, woe to you [O man (disbeliever)]! And then (again) woe to you!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left Suda [neglected without being punished or rewarded for the obligatory duties enjoined by his Lord (Allah) on him]?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a Nutfah (mixed male and female discharge of semen) poured forth?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he became an 'Alaqa (a clot); then (Allah) shaped and fashioned (him) in due proportion.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made him in two sexes, male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is not He (Allah Who does that), Able to give life to the dead? (Yes! He is Able to do all things).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there not been over man a period of time, when he was nothing to be mentioned?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Verily, We have created man from Nutfah drops of mixed semen (discharge of man and woman), in order to try him, so We made him hearer, seer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Verily, We showed him the way, whether he be grateful or ungrateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Verily, We have prepared for the disbelievers iron chains, iron collars, and a blazing Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Verily, the Abrar (pious, who fear Allah and avoid evil), shall drink a cup (of wine) mixed with water from a spring in Paradise called Kafur.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A spring wherefrom the slaves of Allah will drink, causing it to gush forth abundantly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They (are those who) fulfill (their) vows, and they fear a Day whose evil will be wide-spreading.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they give food, inspite of their love for it (or for the love of Him), to Miskin (poor), the orphan, and the captive,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(Saying): ``We feed you seeking Allah's Countenance only. We wish for no reward, nor thanks from you.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
``Verily, We fear from our Lord a Day, hard and distressful, that will make the faces look horrible (from extreme dislikeness to it)."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So Allah saved them from the evil of that Day, and gave them Nadratan (a light of beauty) and joy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And their recompense shall be Paradise, and silken garments, because they were patient.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining therein on raised thrones, they will see there neither the excessive heat of the sun, nor the excessive bitter cold, (as in Paradise there is no sun and no moon).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And the shade thereof is close upon them, and the bunches of fruit thereof will hang low within their reach.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
And amongst them will be passed round vessels of silver and cups of crystal,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Crystal-clear, made of silver. They will determine the measure thereof according to their wishes.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And they will be given to drink there a cup (of wine) mixed with Zanjabil (ginger, etc.),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
A spring there, called Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
And round about them will (serve) boys of everlasting youth. If you see them, you would think them scattered pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when you look there (in Paradise), you will see a delight (that cannot be imagined), and a great dominion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Their garments will be of fine green silk, and gold embroidery. They will be adorned with bracelets of silver, and their Lord will give them a pure drink.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
(And it will be said to them): ``Verily, this is a reward for you, and your endeavour has been accepted."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Verily! It is We Who have sent down the Quran to you (O Muhammad SAW) by stages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
Therefore be patient (O Muhammad SAW) and submit to the Command of your Lord (Allah, by doing your duty to Him and by conveying His Message to mankind), and obey neither a sinner nor a disbeliever among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And remember the Name of your Lord every morning and afternoon [i.e. offering of the Morning (Fajr), Zuhr, and 'Asr prayers].\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And during night, prostrate yourself to Him (i.e. the offering of Maghrib and 'Isha' prayers), and glorify Him a long night through (i.e. Tahajjud prayer).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Verily! These (disbelievers) love the present life of this world, and put behind them a heavy Day (that will be hard).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
It is We Who created them, and We have made them of strong built. And when We will, We can replace them with others like them with a complete replacement.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Verily! This (Verses of the Quran) is an admonition, so whosoever wills, let him take a Path to his Lord (Allah).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
But you cannot will, unless Allah wills. Verily, Allah is Ever All-Knowing, All-Wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He will admit to His Mercy whom He will and as for the Zalimun, (polytheists, wrong-doers, etc.) He has prepared a painful torment.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the winds (or angels or the Messengers of Allah) sent forth one after another.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
And by the winds that blow violently,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
And by the winds that scatter clouds and rain;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
And by the Verses (of the Quran) that separate the right from the wrong.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
And by the angels that bring the revelations to the Messengers,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
To cut off all excuses or to warn;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Surely, what you are promised must come to pass.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
Then when the stars lose their lights;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when the heaven is cleft asunder;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are blown away;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the Messengers are gathered to their time appointed;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what Day are these signs postponed?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of sorting out (the men of Paradise from the men destined for Hell).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what will explain to you what is the Day of sorting out?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the ancients?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
So shall We make later generations to follow them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus do We deal with the Mujrimun (polytheists, disbelievers, sinners, criminals, etc.)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from a worthless water (semen, etc.)?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
Then We placed it in a place of safety (womb),\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known period (determined by gestation)?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
So We did measure, and We are the Best to measure (the things).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth a receptacle?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
For the living and the dead.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And have placed therein firm, and tall mountains; and have given you to drink sweet water?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
(It will be said to the disbelievers): ``Depart you to that which you used to deny!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
``Depart you to a shadow (of Hell-fire smoke ascending) in three columns,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
``Neither shading, nor of any use against the fierce flame of the Fire."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Verily! It (Hell) throws sparks (huge) as Al-Qasr [a fort or a Qasr (huge log of wood)],\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
As if they were Jimalatun Sufr (yellow camels or bundles of ropes)."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
That will be a Day when they shall not speak (during some part of it),\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
And they will not be permitted to put forth any excuse.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
That will be a Day of Decision! We have brought you and the men of old together!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
So if you have a plot, use it against Me (Allah)!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Verily, the Muttaqun (pious - see V. 2:2) shall be amidst shades and springs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits, such as they desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
``Eat and drink comfortably for that which you used to do.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Verily, thus We reward the Muhsinun (good-doers).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
(O you disbelievers)! Eat and enjoy yourselves (in this worldly life) for a little while. Verily, you are the Mujrimun (polytheists, disbelievers, sinners, criminals, etc.).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them: ``Bow down yourself (in prayer)!" They bow not down (offer not their prayers).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
Then in what statement after this (the Quran) will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen What are they asking (one another)?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the great news, (i.e. Islamic Monotheism, the Quran, which Prophet Muhammad (Peace be upon him) brought and the Day of Resurrection, etc.),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
About which they are in disagreement.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Nay, they will come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Nay, again, they will come to know!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth as a bed,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as pegs?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We have created you in pairs (male and female, tall and short, good and bad, etc.).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And have made your sleep as a thing for rest.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And have made the night as a covering (through its darkness),\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And have made the day for livelihood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We have built above you seven strong (heavens),\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And have made (therein) a shinning lamp (sun).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And have sent down from the rainy clouds abundant water.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
That We may produce therewith corn and vegetations,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens of thick growth.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Verily, the Day of Decision is a fixed time,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The Day when the Trumpet will be blown, and you shall come forth in crowds (groups);\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven shall be opened, and it will become as gates,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains shall be moved away from their places and they will be as if they were a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Truly, Hell is a place of ambush,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
A dwelling place for the Taghun (those who transgress the boundry limits set by Allah like polytheists, disbelievers in the Oneness of Allah, hyprocrites, sinners, criminals, etc.),\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will abide therein for ages,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
Nothing cool shall they taste therein, nor any drink.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Except boiling water, and dirty wound discharges.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
An exact recompense (according to their evil crimes).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For verily, they used not to look for a reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
But they belied Our Ayat (proofs, evidences, verses, lessons, signs, revelations, and that which Our Prophet (Peace be upon him) brought) completely.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And all things We have recorded in a Book.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
So taste you (the results of your evil actions); no increase shall We give you, except in torment.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Verily, for the Muttaqun, there will be a success (Paradise);\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens and grapeyards;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And young full-breasted (mature) maidens of equal age;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a full cup (of wine).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
No Laghw (dirty, false, evil talk) shall they hear therein, nor lying;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
A reward from your Lord, an ample calculated gift (according to the best of their good deeds).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
(From) the Lord of the heavens and the earth, and whatsoever is in between them, the Most Beneficent, none can dare to speak with Him (on the Day of Resurrection except after His Leave).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The Day that Ar-Ruh [Jibrael (Gabriel) or another angel] and the angels will stand forth in rows, none shall speak except him whom the Most Beneficent (Allah) allows, and he will speak what is right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is without doubt the True Day, so, whosoever wills, let him seek a place with (or a way to) His Lord (by obeying Him in this worldly life)!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Verily, We have warned you of a near torment, the Day when man will see that (the deeds) which his hands have sent forth, and the disbeliever will say: ``Woe to me! Would that I were dust!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those (angels) who pull out (the souls of the disbelievers and the wicked) with great violence;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
By those (angels) who gently take out (the souls of the believers);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And by those that swim along (i.e. angels or planets in their orbits, etc.).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And by those that press forward as in a race (i.e. the angels or stars or the horses, etc.).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And by those angels who arrange to do the Commands of their Lord, (so verily, you disbelievers will be called to account).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the Day (when the first blowing of the Trumpet is blown), the earth and the mountains will shake violently (and everybody will die),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
The second blowing of the Trumpet follows it (and everybody will be raised up),\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
(Some) hearts that Day will shake with fear and anxiety.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Their eyes cast down.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say: ``Shall we indeed be returned to (our) former state of life?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
``Even after we are crumbled bones?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: ``It would in that case, be a return with loss!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But only, it will be a single Zajrah [shout (i.e., the second blowing of the Trumpet)]. (See Verse 37:19).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
When, behold, they find themselves over the earth alive after their death,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has there come to you the story of Musa (Moses)?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called him in the sacred valley of Tuwa,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
Go to Fir'aun (Pharaoh), verily, he has transgressed all bounds (in crimes, sins, polytheism, disbelief, etc.).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say to him: ``Would you purify yourself (from the sin of disbelief by becoming a believer)",\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
And that I guide you to your Lord, so you should fear Him?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
Then [Musa (Moses)] showed him the great sign (miracles).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But [Fir'aun (Pharaoh)] belied and disobeyed;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then he turned his back, striving hard (against Allah).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
Then he gathered his people and cried aloud,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
Saying: ``I am your lord, most high",\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So Allah, seized him with punishment for his last [i.e. his saying: ``I am your lord, most high") (see Verse 79:24)] and first [(i.e. his saying, ``O chiefs! I know not that you have a god other than I" (see Verse 28:38)] transgression.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Verily, in this is an instructive admonition for whosoever fears Allah.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are you more difficult to create, or is the heaven that He constructed?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised its height, and He has equally ordered it,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
Its night He covers with darkness, and its forenoon He brings out (with light).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And after that He spread the earth;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And brought forth therefrom its water and its pasture;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains He has fixed firmly;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
(To be) a provision and benefit for you and your cattle.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when there comes the greatest catastrophe (i.e. the Day of Recompense, etc.),\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The Day when man shall remember what he strove for,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And Hell-fire shall be made apparent in full view for (every) one who sees,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
Then, for him who Tagha (transgressed all bounds, in disbelief, oppression and evil deeds of disobedience to Allah).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And preferred the life of this world (by following his evil desires and lusts),\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Verily, his abode will be Hell-fire;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for him who feared standing before his Lord, and restrained himself from impure evil desires, and lusts.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Verily, Paradise will be his abode.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask you (O Muhammad (Peace be upon him)) about the Hour, - when will be its appointed time?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
You have no knowledge to say anything about it,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
To your Lord belongs (the knowledge of) the term thereof?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You (O Muhammad (Peace be upon him)) are only a warner for those who fear it,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
The Day they see it, (it will be) as if they had not tarried (in this world) except an afternoon or a morning.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen (The Prophet (Peace be upon him)) frowned and turned away,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because there came to him the blind man (i.e. 'Abdullah bin Umm-Maktum, who came to the Prophet (Peace be upon him) while he was preaching to one or some of the Quraish chiefs).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
But what could tell you that per chance he might become pure (from sins)?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or that he might receive admonition, and that the admonition might profit him?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for him who thinks himself self-sufficient,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
To him you attend;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
What does it matter to you if he will not become pure (from disbelief, you are only a Messenger, your duty is to convey the Message of Allah).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as to him who came to you running.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And is afraid (of Allah and His Punishment),\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
Of him you are neglectful and divert your attention to another,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
Nay, (do not do like this), indeed it (these Verses of this Quran) are an admonition,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So whoever wills, let him pay attention to it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
(It is) in Records held (greatly) in honour (Al-Lauh Al-Mahfuz).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted (in dignity), purified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
In the hands of scribes (angels).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Honourable and obedient.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Be cursed (the disbelieving) man! How ungrateful he is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what thing did He create him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From Nutfah (male and female semen drops) He created him, and then set him in due proportion;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then He makes the Path easy for him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He causes him to die, and puts him in his grave;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then, when it is His Will, He will resurrect him (again).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Nay, but (man) has not done what He commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Then let man look at his food,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
That We pour forth water in abundance,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
And We split the earth in clefts,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And We cause therein the grain to grow,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and clover plants (i.e. green fodder for the cattle),\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olives and date-palms,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And gardens, dense with many trees,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and Abba (herbage, etc.),\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
(To be) a provision and benefit for you and your cattle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
Then, when there comes As-Sakhkhah (the Day of Resurrection's second blowing of Trumpet),\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
That Day shall a man flee from his brother,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And from his mother and his father,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And from his wife and his children.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Everyman, that Day, will have enough to make him careless of others.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces that Day, will be bright (true believers of Islamic Monotheism).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing at good news (of Paradise).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And other faces, that Day, will be dust-stained;\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Darkness will cover them,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Such will be the Kafarah (disbelievers in Allah, in His Oneness, and in His Messenger Muhammad (Peace be upon him), etc.), the Fajarah (wicked evil doers).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun Kuwwirat (wound round and lost its light and is overthrown).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars shall fall;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the mountains shall made to pass away;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when the pregnant she-camels shall be neglected;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when the wild beasts shall be gathered together;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas shall become as blazing Fire or shall overflow;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when the souls shall be joined with their bodies;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the female (infant) buried alive (as the pagan Arabs used to do) shall be questioned.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what sin she was killed?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the written pages of deeds (good and bad) of every person shall be laid open;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the heaven shall be stripped off and taken away from its place;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when Hell-fire shall be kindled to fierce ablaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when Paradise shall be brought near,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
(Then) every person will know what he has brought (of good and evil).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
So verily, I swear by the planets that recede (i.e. disappear during the day and appear during the night).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
And by the planets that move swiftly and hide themselves,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by the night as it departs;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by the dawn as it brightens;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
Verily, this is the Word (this Quran brought by) a most honourable messenger [Jibrael (Gabriel), from Allah to the Prophet Muhammad (Peace be upon him)].\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Owner of power, and high rank with (Allah) the Lord of the Throne,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
Obeyed (by the angels), trustworthy there (in the heavens).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And (O people) your companion (Muhammad (Peace be upon him)) is not a madman;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
And indeed he (Muhammad (Peace be upon him)) saw him [Jibrael (Gabriel)] in the clear horizon (towards the east).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And he (Muhammad (Peace be upon him)) withholds not a knowledge of the unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And it (the Quran) is not the word of the outcast Shaitan (Satan).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Then where are you going?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
Verily, this (the Quran) is no less than a Reminder to (all) the 'Alamin (mankind and jinns).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
To whomsoever among you who wills to walk straight,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And you will not, unless (it be) that Allah wills, the Lord of the 'Alamin (mankind, jinns and all that exists).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven is cleft asunder.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
And when the stars have fallen and scattered;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
And when the seas are burst forth (got dried up);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the graves are turned upside down (and they bring out their contents)\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
(Then) a person will know what he has sent forward and (what he has) left behind (of good or bad deeds).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What has made you careless concerning your Lord, the Most Generous?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created you, fashioned you perfectly, and gave you due proportion;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever form He willed, He put you together.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Nay! But you deny the Recompense (reward for good deeds and punishment for evil deeds).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
But verily, over you (are appointed angels in charge of mankind) to watch you.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Kiraman (honourable) Katibin writing down (your deeds).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know all that you do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Verily, the Abrar (pious and righteous) will be in delight (Paradise);\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And verily, the Fujjar (the wicked, disbelievers, sinners and evil-doers) will be in the blazing Fire (Hell),\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
In which they will enter, and taste its burning flame on the Day of Recompense,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And they (Al-Fujjar) will not be absent therefrom (i.e. will not go out from the Hell).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what will make you know what the Day of Recompense is?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what will make you know what the Day of Recompense is?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
(It will be) the Day when no person shall have power (to do) anything for another, and the Decision, that Day, will be (wholly) with Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to Al-Mutaffifin [those who give less in measure and weight (decrease the rights of others)],\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who, when they have to receive by measure from men, demand full measure,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
And when they have to give by measure or weight to men, give less than due.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Think they not that they will be resurrected (for reckoning),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
On a Great Day,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The Day when (all) mankind will stand before the Lord of the 'Alamin (mankind, jinns and all that exists)?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Nay! Truly, the Record (writing of the deeds) of the Fujjar (disbelievers, sinners, evil-doers and wicked) is (preserved) in Sijjin.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what will make you know what Sijjin is?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A Register inscribed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe, that Day, to those who deny [(Allah, His Angels, His Books, His Messengers, the Day of Resurrection, and Al-Qadar (Divine Preordainments)].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who deny the Day of Recompense.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none can deny it except every transgressor beyond bounds, (in disbelief, oppression and disobedience of Allah, the sinner!)\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our Verses (of the Quran) are recited to him he says: ``Tales of the ancients!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
Nay! But on their hearts is the Ran (covering of sins and evil deeds) which they used to earn.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Nay! Surely, they (evil-doers) will be veiled from seeing their Lord that Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then, verily they will indeed enter and taste the burning flame of Hell.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then, it will be said to them: ``This is what you used to deny!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
Nay! Verily, the Record (writing of the deeds) of Al-Abrar (the pious who fear Allah and avoid evil), is (preserved) in 'Illiyyun.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what will make you know what 'Illiyyun is?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A Register inscribed.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
To which bear witness those nearest (to Allah, i.e. the angels).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Verily, Al-Abrar (the pious who fear Allah and avoid evil) will be in delight (Paradise).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On thrones, looking (at all things).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You will recognise in their faces the brightness of delight.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given to drink pure sealed wine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
The last thereof (that wine) will be the smell of musk, and for this let (all) those strive who want to strive (i.e. hasten earnestly to the obedience of Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
It (that wine) will be mixed with Tasnim.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring whereof drink those nearest to Allah.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Verily! (During the worldly life) those who committed crimes used to laugh at those who believed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And whenever they passed by them, used to wink one to another (in mockery);\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their own people, they would return jesting;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And when they saw them, they said: ``Verily! These have indeed gone astray!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
But they (disbelievers, sinners) had not been sent as watchers over them (the believers).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But this Day (the Day of Resurrection) those who believe will laugh at the disbelievers\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On (high) thrones, looking (at all things).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Are not the disbelievers paid (fully) for what they used to do?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the heaven is split asunder,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And listens and obeys its Lord, and it must do so;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is stretched forth,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And has cast out all that was in it and became empty,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And listens and obeys its Lord, and it must do so;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man! Verily, you are returning towards your Lord with your deeds and actions (good or bad), a sure returning, so you will meet (i.e. the results of your deeds which you did).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then, as for him who will be given his Record in his right hand,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
He surely will receive an easy reckoning,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And will return to his family in joy!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But whosoever is given his Record behind his back,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He will invoke (his) destruction,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And shall enter a blazing Fire, and made to taste its burning.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Verily, he was among his people in joy!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
Verily, he thought that he would never come back (to Us)!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Yes! Verily, his Lord has been ever beholding him!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
So I swear by the afterglow of sunset;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And by the night and whatever it gathers in its darkness;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And by the moon when it is at the full,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
You shall certainly travel from stage to stage (in this life and in the Hereafter).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What is the matter with them, that they believe not?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Quran is recited to them, they fall not prostrate,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Nay, (on the contrary), those who disbelieve, belie (Prophet Muhammad (Peace be upon him) and whatever he brought, i.e. this Quran and Islamic Monotheism, etc.).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
And Allah knows best what they gather (of good and bad deeds),\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So announce to them a painful torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Save those who believe and do righteous good deeds, for them is a reward that will never come to an end (i.e. Paradise).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven, holding the big stars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by the Promised Day (i.e. the Day of Resurrection);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by the witnessing day (i.e. Friday), and by the witnessed day [i.e. the day of 'Arafat (Hajj) the ninth of Dhul-Hijjah];\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Cursed were the people of the ditch (the story of the Boy and the King).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
Fire supplied (abundantly) with fuel,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they sat by it (fire),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And they witnessed what they were doing against the believers (i.e. burning them).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
They had nothing against them, except that they believed in Allah, the All-Mighty, Worthy of all Praise!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
Who, to Whom belongs the dominion of the heavens and the earth! And Allah is Witness over everything.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Verily, those who put into trial the believing men and believing women (by torturing them and burning them), and then do not turn in repentance, (to Allah), will have the torment of Hell, and they will have the punishment of the burning Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Verily, those who believe and do righteous good deeds, for them will be Gardens under which rivers flow (Paradise). That is the great success.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Verily, (O Muhammad (Peace be upon him)) the Grip (Punishment) of your Lord is severe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Verily, He it is Who begins (punishment) and repeats (punishment in the Hereafter) (or originates the creation of everything, and then repeats it on the Day of Resurrection).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is Oft-Forgiving, full of love (towards the pious who are real true believers of Islamic Monotheism),\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Owner of the throne, the Glorious\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
He does what He intends (or wills).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has the story reached you of the hosts,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of Fir'aun (Pharaoh) and Thamud?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
Nay! The disbelievers (persisted) in denying (Prophet Muhammad (Peace be upon him) and his Message of Islamic Monotheism).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
And Allah encompasses them from behind! (i.e. all their deeds are within His Knowledge, and He will requite them for their deeds).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay! This is a Glorious Quran,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
(Inscribed) in Al-Lauh Al-Mahfuz (The Preserved Tablet)!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the heaven, and At-Tariq (the night-comer, i.e. the bright star);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what will make you to know what At-Tariq (night-comer) is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
(It is) the star of piercing brightness;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no human being but has a protector over him (or her) (i.e. angels incharge of each human being guarding him, writing his good and bad deeds, etc.)\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man see from what he is created!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He is created from a water gushing forth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
Proceeding from between the back-bone and the ribs,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Verily, (Allah) is Able to bring him back (to life)!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
The Day when all the secrets (deeds, prayers, fasting, etc.) will be examined (as to their truth).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
Then will (man) have no power, nor any helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the sky (having rain clouds) which gives rain, again and again.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And the earth which splits (with the growth of trees and plants),\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Verily! This (the Quran) is the Word that separates (the truth from falsehood, and commands strict legal laws for mankind to cut the roots of evil).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
And it is not a thing for amusement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Verily, they are but plotting a plot (against you O Muhammad (Peace be upon him)).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I (too) am planning a plan.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So give a respite to the disbelievers. Deal you gently with them for a while.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Glorify the Name of your Lord, the Most High,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who has created (everything), and then proportioned it;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
And Who has measured (preordainments for each and everything even to be blessed or wretched); then guided (i.e. showed mankind the right as well as wrong paths, and guided the animals to pasture);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
And Who brings out the pasturage,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
And then makes it dark stubble.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make you to recite (the Quran), so you (O Muhammad (Peace be upon him)) shall not forget (it),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except what Allah, may will, He knows what is apparent and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We shall make easy for you (O Muhammad (Peace be upon him)) the easy way (i.e. the doing of righteous deeds).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore remind (men) in case the reminder profits (them).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
The reminder will be received by him who fears (Allah),\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But it will be avoided by the wretched,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
Who will enter the great Fire and made to taste its burning,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Wherein he will neither die (to be in rest) nor live (a good living).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Indeed whosoever purifies himself (by avoiding polytheism and accepting Islamic Monotheism) shall achieve success,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And remembers (glorifies) the Name of his Lord (worships none but Allah), and prays (five compulsory prayers and Nawafil additional prayers).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
Nay, you prefer the life of this world;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Although the Hereafter is better and more lasting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Verily! This is in the former Scriptures,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The Scriptures of Ibrahim (Abraham) and Musa (Moses).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has there come to you the narration of the overwhelming (i.e. the Day of Resurrection);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Some faces, that Day, will be humiliated (in the Hell-fire, i.e. the faces of all disbelievers, Jews and Christians, etc.).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Labouring (hard in the worldly life by worshipping others besides Allah), weary (in the Hereafter with humility and disgrace).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
They will enter in the hot blazing Fire,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
They will be given to drink from a boiling spring,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
No food will there be for them but a poisonous thorny plant,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which will neither nourish nor avail against hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
(Other) faces, that Day, will be joyful,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Glad with their endeavour (for their good deeds which they did in this world, along with the true Faith of Islamic Monotheism).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a lofty Paradise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
Where they shall neither hear harmful speech nor falsehood,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Therein will be a running spring,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Therein will be thrones raised high,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And cups set at hand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions set in rows,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And rich carpets (all) spread out.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Do they not look at the camels, how they are created?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the heaven, how it is raised?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the mountains, how they are rooted and fixed firm?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the earth, how it is spread out?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
So remind them (O Muhammad (Peace be upon him)), you are only a one who reminds.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You are not a dictator over them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
Save the one who turns away and disbelieves\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Then Allah will punish him with the greatest punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Verily, to Us will be their return;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then verily, for Us will be their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
By the ten nights (i.e. the first ten days of the month of Dhul-Hijjah).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And by the even and the odd (of all the creations of Allah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And by the night when it departs.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
There is indeed in them (the above oaths) sufficient proofs for men of understanding (and that, they should avoid all kinds of sins and disbeliefs, etc.)!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Did you (O Muhammad (Peace be upon him)) not see (thought) how your Lord dealt with 'Ad (people)?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
Who were very tall like lofty pillars,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which were not created in the land?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And (with) Thamud (people), who cut (hewed) out rocks in the valley (to make dwellings)?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And (with) Fir'aun (Pharaoh), who had pegs (who used to torture men by binding them to pegs)?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Who did transgress beyond bounds in the lands (in the disobedience of Allah).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And made therein much mischief.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
So your Lord poured on them different kinds of severe torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Verily, your Lord is Ever Watchful (over them).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, when his Lord tries him by giving him honour and gifts, then he says (puffed up): ``My Lord has honoured me."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He tries him, by straitening his means of life, he says: ``My Lord has humiliated me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
Nay! But you treat not the orphans with kindness and generosity (i.e. you neither treat them well, nor give them their exact right of inheritance)!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And urge not on the feeding of AlMiskin (the poor)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And you devour inheritance all with greed,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And you love wealth with much love!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
Nay! When the earth is ground to powder,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And your Lord comes with the angels in rows,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And Hell will be brought near that Day. On that Day will man remember, but how will that remembrance (then) avail him?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: ``Alas! Would that I had sent forth (good deeds) for (this) my life!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
So on that Day, none will punish as He will punish.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And none will bind as He will bind.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
(It will be said to the pious): ``O (you) the one in (complete) rest and satisfaction!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
``Come back to your Lord, Well-pleased (yourself) and well-pleasing unto Him!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
``Enter you, then, among My honoured slaves,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
``And enter you My Paradise!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I swear by this city (Makkah);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And you are free (from sin, to punish the enemies of Islam on the Day of the conquest) in this city (Makkah).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by the begetter (i.e. Adam) and that which he begot (i.e. his progeny);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
Verily, We have created man in toil.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Thinks he that none can overcome him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says (boastfully): ``I have wasted wealth in abundance!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Thinks he that none sees him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not made for him a pair of eyes?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and a pair of lips?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And shown him the two ways (good and evil)?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he has made no effort to pass on the path that is steep.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what will make you know the path that is steep?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
(It is) Freeing a neck (slave, etc.)\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or giving food in a day of hunger (famine),\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
To an orphan near of kin.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or to a Miskin (poor) afflicted with misery.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
Then he became one of those who believed, and recommended one another to perseverance and patience, and (also) recommended one another to pity and compassion.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
They are those on the Right Hand (the dwellers of Paradise),\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But those who disbelieved in Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they are those on the Left Hand (the dwellers of Hell).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
The Fire will be shut over them (i.e. they will be enveloped by the Fire without any opening or window or outlet.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen And by the sun and its brightness;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
And by the moon as it follows it (the sun);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
And by the day as it shows up (the sun's) brightness;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
And by the night as it conceals it (the sun);\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
And by the heaven and Him Who built it;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
And by the earth and Him Who spread it,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
And by Nafs (Adam or a person or a soul, etc.), and Him Who perfected him in proportion;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
Then He showed him what is wrong for him and what is right for him;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Indeed he succeeds who purifies his ownself (i.e. obeys and performs all that Allah ordered, by following the true Faith of Islamic Monotheism and by doing righteous good deeds).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And indeed he fails who corrupts his ownself (i.e. disobeys what Allah has ordered by rejecting the true Faith of Islamic Monotheism or by following polytheism, etc. or by doing every kind of evil wicked deeds).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamud (people) denied (their Prophet) through their transgression (by rejecting the true Faith of Islamic Monotheism, and by following polytheism, and by committing every kind of sin).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When the most wicked man among them went forth (to kill the she-camel).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
But the Messenger of Allah [Salih (Saleh)] said to them: ``Be cautious! Fear the evil end. That is the she-camel of Allah! (Do not harm it) and bar it not from having its drink!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
Then they denied him and they killed it. So their Lord destroyed them because of their sin, and made them equal in destruction (i.e. all grades of people, rich and poor, strong and weak, etc.)!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He (Allah) feared not the consequences thereof.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night as it envelops;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
And by the day as it appears in brightness;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And by Him Who created male and female;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Certainly, your efforts and deeds are diverse (different in aims and purposes);\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who gives (in charity) and keeps his duty to Allah and fears Him,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And believes in Al-Husna.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We will make smooth for him the path of ease (goodness).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But he who is greedy miser and thinks himself self-sufficient.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And gives the lie to Al-Husna (see Verse No: 6 footnote);\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We will make smooth for him the path for evil;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
And what will his wealth benefit him when he goes down (in destruction).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Truly! Ours it is (to give) guidance,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And truly, unto Us (belong) the last (Hereafter) and the first (this world).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Therefore I have warned you of a Fire blazing fiercely (Hell);\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None shall enter it save the most wretched,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
Who denies and turns away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
And Al-Muttaqun (the pious and righteous - see V. 2:2) will be far removed from it (Hell).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
He who spends his wealth for increase in self-purification,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And have in his mind no favour from anyone for which a reward is expected in return,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
Except only the desire to seek the Countenance of his Lord, the Most High;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
He surely will be pleased (when he will enter Paradise).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the forenoon (after sun-rise);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And by the night when it is still (or darkens);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Your Lord (O Muhammad (Peace be upon him)) has neither forsaken you nor hated you.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And indeed the Hereafter is better for you than the present (life of this world).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And verily, your Lord will give you (all i.e. good) so that you shall be well-pleased.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you (O Muhammad (Peace be upon him)) an orphan and gave you a refuge?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And He found you unaware (of the Quran, its legal laws, and Prophethood, etc.) and guided you?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And He found you poor, and made you rich (selfsufficient with selfcontentment, etc.)?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore, treat not the orphan with oppression,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
And repulse not the beggar;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
And proclaim the Grace of your Lord (i.e. the Prophethood and all other Graces).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not opened your breast for you (O Muhammad (Peace be upon him))?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And removed from you your burden,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which weighed down your back?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And raised high your fame?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
So verily, with the hardship, there is relief,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Verily, with the hardship, there is relief (i.e. there is one hardship with two reliefs, so one hardship cannot overcome two reliefs).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when you have finished (from your occupation), then stand up for Allah's worship (i.e. stand up for prayer).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And to your Lord (Alone) turn (all your intentions and hopes and) your invocations.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig, and the olive,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
By Mount Sinai,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And by this city of security (Makkah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
Verily, We created man of the best stature (mould),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then We reduced him to the lowest of the low,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Save those who believe (in Islamic Monotheism) and do righteous deeds, then they shall have a reward without end (Paradise).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
Then what (or who) causes you (O disbelievers) to deny the Recompense (i.e. Day of Resurrection)?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the Best of judges?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read! In the Name of your Lord, Who has created (all that exists),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Has created man from a clot (a piece of thick coagulated blood).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read! And your Lord is the Most Generous,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who has taught (the writing) by the pen [the first person to write was Prophet Idrees (Enoch)].\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Has taught man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Nay! Verily, man does transgress all bounds (in disbelief and evil deed, etc.).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
Because he considers himself self-sufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Surely! Unto your Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Have you (O Muhammad (Peace be upon him)) seen him (i.e. Abu Jahl) who prevents,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A slave (Muhammad (Peace be upon him)) when he prays?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Tell me, if he (Muhammad (Peace be upon him)) is on the guidance (of Allah)?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or enjoins piety?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Tell me if he (the disbeliever, Abu Jahl) denies (the truth, i.e. this Quran), and turns away?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Knows he not that Allah does see (what he does)?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Nay! If he (Abu Jahl) ceases not, We will catch him by the forelock,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A lying, sinful forelock!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then, let him call upon his council (of helpers),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call the guards of Hell (to deal with him)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
Nay! (O Muhammad (Peace be upon him))! Do not obey him (Abu Jahl). Fall prostrate and draw near to Allah!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Verily! We have sent it (this Quran) down in the night of Al-Qadr (Decree)\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what will make you know what the night of Al-Qadr (Decree) is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The night of Al-Qadr (Decree) is better than a thousand months (i.e. worshipping Allah in that night is better than worshipping Him a thousand months, (i.e. 83 years and 4 months).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
Therein descend the angels and the Ruh [Jibrael (Gabriel)] by Allah's Permission with all Decrees,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace! (All that night, there is Peace and Goodness from Allah to His believing slaves) until the appearance of dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieve from among the people of the Scripture (Jews and Christians) and among Al-Mushrikun, were not going to leave (their disbelief) until there came to them clear evidence.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A Messenger (Muhammad (Peace be upon him)) from Allah, reciting (the Quran) purified pages [purified from Al-Batil (falsehood, etc.)].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Containing correct and straight laws from Allah.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
And the people of the Scripture (Jews and Christians) differed not until after there came to them clear evidence. (i.e. Prophet Muhammad (Peace be upon him) and whatever was revealed to him).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they were commanded not, but that they should worship Allah, and worship none but Him Alone (abstaining from ascribing partners to Him), and perform As-Salat (Iqamat-as-Salat) and give Zakat: and that is the right religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Verily, those who disbelieve (in the religion of Islam, the Quran and Prophet Muhammad (Peace be upon him)) from among the people of the Scripture (Jews and Christians) and Al-Mushrikun will abide in the Fire of Hell. They are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Verily, those who believe [in the Oneness of Allah, and in His Messenger Muhammad (Peace be upon him)) including all obligations ordered by Islam] and do righteous good deeds, they are the best of creatures.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward with their Lord is 'Adn (Eden) Paradise (Gardens of Eternity), underneath which rivers flow, they will abide therein forever, Allah Well-Pleased with them, and they with Him. That is for him who fears his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken with its (final) earthquake.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And when the earth throws out its burdens,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man will say: ``What is the matter with it?"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
That Day it will declare its information (about all what happened over it of good or evil).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because your Lord has inspired it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
That Day mankind will proceed in scattered groups that they may be shown their deeds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
So whosoever does good equal to the weight of an atom (or a small ant), shall see it.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whosoever does evil equal to the weight of an atom (or a small ant), shall see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the (steeds) that run, with panting (breath),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
Striking sparks of fire (by their hooves),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And scouring to the raid at dawn\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
And raise the dust in clouds the while,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
Penetrating forthwith as one into the midst (of the foe);\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Verily! Man (disbeliever) is ungrateful to his Lord;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And to that fact he bears witness (by his deeds);\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And verily, he is violent in the love of wealth.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Knows he not that when the contents of the graves are brought out and poured forth (all mankind is resurrected).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And that which is in the breasts (of men) shall be made known.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Verily, that Day (i.e. the Day of Resurrection) their Lord will be Well-Acquainted with them (as to their deeds), (and will reward them for their deeds).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen Al-Qari'ah (the striking Hour i.e. the Day of Resurrection),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the striking (Hour)?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what will make you know what the striking (Hour) is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
It is a Day whereon mankind will be like moths scattered about,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will be like carded wool,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then as for him whose balance (of good deeds) will be heavy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He will live a pleasant life (in Paradise).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But as for him whose balance (of good deeds) will be light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
He will have his home in Hawiyah (pit, i.e. Hell).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what will make you know what it is?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
(It is) a hot blazing Fire!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The mutual rivalry for piling up of worldly things diverts you,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until you visit the graves (i.e. till you die).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Nay! You shall come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again, Nay! You shall come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Nay! If you knew with a sure knowledge (the end result of piling up, you would not have occupied yourselves in worldly things)\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
Verily, You shall see the blazing Fire (Hell)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
And again, you shall see it with certainty of sight!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that Day, you shall be asked about the delight (you indulged in, in this world)!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By Al-'Asr (the time).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Verily! Man is in loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except those who believe (in Islamic Monotheism) and do righteous good deeds, and recommend one another to the truth (i.e. order one another to perform all kinds of good deeds (Al-Ma'ruf) which Allah has ordained, and abstain from all kinds of sins and evil deeds (Al-Munkar) which Allah has forbidden), and recommend one another to patience (for the sufferings, harms, and injuries which one may encounter in Allah's Cause during preaching His religion of Islamic Monotheism or Jihad, etc.).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every slanderer and backbiter.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who has gathered wealth and counted it,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He thinks that his wealth will make him last forever!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
Nay! Verily, he will be thrown into the crushing Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what will make you know what the crushing Fire is?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
The fire of Allah, kindled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which leaps up over the hearts,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Verily, it shall be closed in on them,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In pillars stretched forth (i.e. they will be punished in the Fire with pillars, etc.).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you (O Muhammad (Peace be upon him)) not seen how your Lord dealt with the Owners of the Elephant? [The elephant army which came from Yemen under the command of Abrahah Al-Ashram intending to destroy the Ka'bah at Makkah].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their plot go astray?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And sent against them birds, in flocks,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Striking them with stones of Sijjil.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
And made them like an empty field of stalks (of which the corn has been eaten up by cattle).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen (It is a great Grace and Protection from Allah), for the taming of the Quraish,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
(And with all those Allah's Grace and Protections for their taming, We cause) the (Quraish) caravans to set forth safe in winter (to the south), and in summer (to the north without any fear),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
So let them worship (Allah) the Lord of this House (the Ka'bah in Makkah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
(He) Who has fed them against hunger, and has made them safe from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Have you seen him who denies the Recompense?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
That is he who repulses the orphan (harshly),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And urges not the feeding of AlMiskin (the poor),\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So woe unto those performers of Salat (prayers) (hypocrites),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Who delay their Salat (prayer) from their stated fixed times,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who do good deeds only to be seen (of men),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And refuse Al-Ma'un (small kindnesses e.g. salt, sugar, water, etc.).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Verily, We have granted you (O Muhammad (Peace be upon him)) Al-Kauthar (a river in Paradise);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
Therefore turn in prayer to your Lord and sacrifice (to Him only).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
For he who makes you angry (O Muhammad (Peace be upon him)), - he will be cut off (from every good thing in this world and in the Hereafter).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say (O Muhammad (Peace be upon him) to these Mushrikun and Kafirun): ``O Al-Kafirun (disbelievers in Allah, in His Oneness, in His Angels, in His Books, in His Messengers, in the Day of Resurrection, and in Al-Qadar, etc.)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
``I worship not that which you worship,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
``Nor will you worship that which I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
``And I shall not worship that which you are worshipping.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
``Nor will you worship that which I worship.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
``To you be your religion, and to me my religion (Islamic Monotheism)."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When comes the Help of Allah (to you, O Muhammad (Peace be upon him) against your enemies) and the conquest (of Makkah),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And you see that the people enter Allah's religion (Islam) in crowds,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
So glorify the Praises of your Lord, and ask for His Forgiveness. Verily, He is the One Who accepts the repentance and forgives.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the two hands of Abu Lahab (an uncle of the Prophet), and perish he!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth and his children (etc.) will not benefit him!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will be burnt in a Fire of blazing flames!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife too, who carries wood (thorns of Sadan which she used to put on the way of the Prophet (Peace be upon him), or use to slander him).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
In her neck is a twisted rope of Masad (palm fibre).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say (O Muhammad (Peace be upon him)): ``He is Allah, (the) One.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
``Allah-us-Samad (The Self-Sufficient Master, Whom all creatures need, He neither eats nor drinks).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
``He begets not, nor was He begotten;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
``And there is none co-equal or comparable unto Him."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: ``I seek refuge with (Allah) the Lord of the daybreak,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
``From the evil of what He has created;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
``And from the evil of the darkening (night) as it comes with its darkness; (or the moon as it sets or goes away).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
``And from the evil of the witchcrafts when they blow in the knots,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
``And from the evil of the envier when he envies."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: ``I seek refuge with (Allah) the Lord of mankind,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
``The King of mankind,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
``The Ilah (God) of mankind,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
``From the evil of the whisperer (devil who whispers evil in the hearts of men) who withdraws (from his whispering in one's heart after one remembers Allah),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
``Who whispers in the breasts of mankind,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
``Of jinns and men."\qt@no{6}}%
%% End of file `qurantext-env.translation.def'
