\qt@newcmd\qurantrans@en@i{%
In the name of Allah, the Compassionate, the Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
All praise unto Allah, the Lord of all the worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
The Compassionate, the Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
Sovereign of the Day of Requital.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
Thee alone do we worship and of Thee alone do we seek help,\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us Thou unto the path straight\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The path of those whom Thou hast favoured. Not of those on whom is indignation brought down, nor of the astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif. Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This Book whereof there is no doubt, is a guidance unto the God-fearing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the Unseen, and establish prayer, and out of that wherewith We have provided them expend.\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in that which hath been sent down unto thee and that which hath been sent down before thee and of the Hereafter they are convinced.\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
These are on guidance from their Lord, and these they are the blissful ones.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
Verily those who have disbelieved, it is equal to them whether thou warnest them or warnest them not; they will not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah hath set a seal upon their hearts and upon their hearing, and over their sights is a covering; and unto them shall be a torment mighty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And of mankind are some who say: we believe in Allah and in the Last Day: whereas they are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They would deceive Allah and those who believe, whereas they deceive not save themselves, and they perceive not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease, so Allah hath increased unto them that disease; and unto them shall be a torment afflictive, for they have been lying.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it said unto them: act not corruptly on the earth, they say: we are but reconcilers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Lo! verily it is they who are the corrupters, and yet they perceive not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it said unto them: believe even as mankind have believed, they say: shall we believe even as the fools have believed? Lo! verily it is they who are the fools; and yet they know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they meet those who have believed, they say: We believe. And when they are alone with their Satans, they say: verily we are with you, we were but mocking.\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah mocketh back at them, and letteth them in their exorbitance wander bewildered.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are they who purchased error for guidance, but their traffic profited not, nor have they ever become guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their likeness is as the likeness of him who kindleth a fire, then when it hath lit up that which is around him, Allah taketh away their light and leaveth them in darknesses where they see not\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb, blind; wherefore they will not return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
like unto a rain--laden cloud from heaven, wherein are darknesses and thunder and lightening. They so put their fingers in their ears because of the thunder-claps, guarding against death, and Allah is Encompasser of the infidels.\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning well-nigh snatcheth away their sight; whensoever it flasheth on them, they walk therein, and when it becometh dark unto them, they stand still. And had Allah willed He would of a surety have taken away their hearing and their sights; verily Allah is over everything potent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O Mankind worship your Lord who hath created you and those before you, haply ye may become God-fearing-\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
Who hath made the earth for you a carpet and the heaven a structure, and sent down from heaven water, and brought forth therewith fruits as a Provision for you; wherefore set not up compeers unto Allah while ye know.\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if ye be in doubt concerning that which We have revealed unto Our bondsman, then bring a chapter like thereunto, and call your witnesses as against Allah, if ye say sooth.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if ye do it not, --and by no means ye shall, --then dread the Fire, the fuel whereof is men and stones, gotten ready for the infidels.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And bear thou the glad tidings unto those who believe and do righteous works that verily for them shall be Gardens whereunder rivers flow. So oft as they shall be provided with a fruit therefrom they will say: this is that wherewith we were provided afore; and they shall be vouchsafed that which is consimilar; and for them shall be therein spouses purified, and therein they shall be abiders.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Verily Allah is not ashamed to propound a similitude, be it of a gnat or of aught above it. Then as to those who believe, they know that it is the truth from their Lord. And to those who disbelieve, they say what intendeth God by similitude? He sendeth many astray thereby, and He guideth many thereby, and He sendeth not astray thereby any except the transgressors,\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Who break the covenant of Allah after the ratification thereof, and sunder that which Allah hath commanded should be joined, and act corruptly on the earth. These! they are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How will ye disbelieve in Allah whereas ye were lifeless and he quickened you; thereafter He will cause you to die, thereafter He will give you life, thereafter unto Him ye shall be returned!\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He it is who created for you all that is on the earth, thereafter He turned to the heaven, and formed them seven heavens. And He is of everything the Knower.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And recall what time thine Lord said unto the angels: verily I am going to place a vicegerent On the earth. They said: wilt Thou place therein one who will act corruptly therein and shed blood While we hallow Thine praise and glorify Thee! Allah said: verily I know that which ye know not.\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam the names, all of them; thereafter He set them before the angles, and said declare unto Me the names of those if ye say sooth.\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said: hallowed be Thou no knowledge is our save that which Thou hast taught us, verily Thou! Thou art the Knower, Wise.\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
Allah said: O Adam! declare thou unto them the names of those objects. Then when he had declared unto them the names of those, He said: said I not unto you, verily I know the hidden in the heavens and the earth, and know that which ye disclose and that which ye are wont to conceal!\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And recall what time We said unto the angels: prostrate yourselves before Adam, they prostrated themselves; but not Iblis he refused and was stiff - necked and became of the infidels.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said: Adam! dwell thou and thine spouse in the Garden, and eat ye twain plenteously thereof as ye list, but approach not yonder tree, lest yet twain become of the wrong-doers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
Then the Satan caused the twain to slip on account thereof, and drave them forth from that which the twain were in. And We said: get ye down, one of you an enemy unto anot her, and for you on the earth shall be a resting-place and enjoyment for a season.\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam learnt from his Lord certain Words, and He relented toward him, verily He! He is the Relentant, the Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said: get ye all down from hence, and if there cometh unto you a guidance from Me, then whosoever shall follow Mine guidance, -- no fear shall come on them, nor shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
And those who disbelieve and belie Our signs, --they, shall be fellows of the Fire; therein they shall be abiders.\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
Children of Israel! remember My favour wherewith favoured you, and fulfil My covenant, and shall fulfil your covenant, and Me alone shall ye dread.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in that which I have sent down confirming that which is with you, and be not the first to disbelieve therein, and barter not My revelations for a small price, and Me alone shall ye fear.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And confound not the truth with falsehood, nor hide the truth while ye know.\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And establish prayer, and give the poor-rate, and bow down with those who bow down.\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Command ye mankind to piety and forget yourselves, the while ye read the Book! Understand then ye not!\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help in patience and prayer and verily it is, hard except prayer unto the meek.\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
Who know that verily they are going to meet their Lord, and that verily unto Him they are going to return,\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel: remember My favour wherewith I favoured you, and that verily I preferred you over the world.\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And fear a Day whereon not in aught shall a soul satisfy for a soul, nor shall intercession be accepted thereof, shall compensation be received therefor, nor shall they be succoured.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And recall what time We delivered you from the house of Fir'awn imposing upon you evil torment, slaughtering your sons and letting your women live; and therein was a trial, from your Lord, Mighty.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And recall what time We separated the sea for you and delivered you and drowned Fir'awn's house while ye looked on.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And recall what time We treated with Musa forty nights, then ye betook the calf after him, and ye were wrong-doers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then We pardoned you thereafter, that haply ye may return thanks.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And recall what time We vouchsafed unto Musa the Book and the distinction that haply ye may be guided.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And recall what time Musa said unto his people: my people! verily ye have wronged your souls by your taking the calf, wherefore repent unto your Maker, and slay yourselves: that were best for you with your Maker. Then He relented toward you; verily He! He is the Relentant, the Merciful\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And recall what time ye said: O Musa! we will not believe in thee until we see God openly; then a thunderbolt took hold of you while ye looked on.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you after your death that haply ye may return thanks.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We overshadowed you with Clouds and We sent down unto you the Manna and the quails, saying: eat of the clean things, wherewith We have provided you. And they wronged Us not, but themselves they were wont to wrong.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And recall what time We said: enter this town and eat plenteously therefrom as ye list, and enter the gate prostrating yourselves and say: forgiveness; We shall forgive you your trespasses, and anon We shall increase unto the well-doers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
Then those who did wrong changed the Word that had been told them for anot her; so We sent down upon those who did wrong a scourge from heaven, for they were wont to transgress.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And recall what time Musa prayed for drink for his people. We said: smite With thy staff the stone. Then there gushed forth thereout twelve springs; every people already knew their drinking-place; eat and drink of the provision of Allah, and commit not evil on the earth as corrupters.\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And recall what time ye said: O Musa! we shall by no means bear patiently with one food, wherefore supplicate for us unto thy Lord that He bring forth for us of that which the earth groweth, of its vegetables, and its cucumbers, and its Wheat, and its lentils, and its onions. He Said: would ye take in exchange that which is mean for that which is better! Get ye down into a City, as verily therein is for you that which ye ask for. And stuck upon them were abjection and poverty. And they drew on themselves indignation from Allah. This, because they were ever disbelieving in the signs of Allah and slaying the prophets without justice. This, because they disobeyed and were ever trespassing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Verily those who believe, and those who are Judaised, and the Nazarenes, and the Sabians, - whosoever, believeth in Allah and the Last Day and worketh righteously, these! unto them shall be their hire with their Lord, no feal shall come on them nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And recall what time We took your bond, and raised over you the Tur saying: hold fast to that which We have vouchsafed unto you, and remember that which is therein, that haply ye may become God-fearing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then ye turned away there after; so had not the grace of Allah been unto you and His mercy, ye had surely become of the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And assuredly ye know of those of you who trespassed in the matter of the Sabbath, wherefore We said unto them: be ye apes despised.\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
And We made it a deterrent unto those of their day and those after them, and an exhortation unto the God-fearing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And recall what time Musa said unto his people: verily Allah commandeth you that ye slaughter a cow. They said: makest thou a jest of us? He said take refuge with Allah that I should be of the ignorant.\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said: supplicate for us unto thy Lord that He make manifest unto us whatever she should be. He said: verily He saith, she should be a cow neither old nor young, but middle-aged betwixt that; do then as ye are commanded.\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said: supplicate for us unto thy Lord that He make manifest unto us whatever her colour should be. He said: verily He saith, she should be a yellow cow the colour whereof is deepest, delighting the beholders.\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said supplicate for us unto thy Lord that He make manifest unto us whatever she should be, for verily the cow hath become dubious unto us and verily we, if God will, shall beguided.\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He said: verily He saith, verify she should be a cow unyoked, not broken to till the ground or to water the field, whole, and without blemish in her. They said: now hast thou brought the truth. Then they slaughtered her, and they were wellnigh not doing it.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And recall what time ye slew a person, then quarrelled among yourselves respecting it, and Allah was to bring out that which ye were hiding.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
Wherefore We said: smite him with part of her. Thus will Allah quicken the dead and He sheweth you His signs that haply ye may under stand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then your hearts hardened thereafter, so they are as stones or stronger in hardness: and verily of stones there are some from which gush forth rivers, and verily there are of them some that cleave asunder and water issueth therefrom, and verily there are of them some that fall down in awe of Allah: and Allah is not neglectful of that which ye work.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Covet ye then that they would believe for you whereas surely a Party of them hath been hearing the Word of Allah and then reverting it after they have understood it, While they know.\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they meet those who believe they say: we believe; and when some of them are alone with some others they say speak ye unto them of that which God hath opened unto you so that they may argue therewith against you before your Lord? understand then ye not?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Know they not that Allah knoweth that which they hide and that which they make known?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And of them are unlettered ones who know not the Book but vain desires; and they do but conjecture.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Woe then unto those who write out the Book with their hands and say thereafter: this is from God, that they may barter it for a small price. Woe then unto them for that which thei hands had written; and woe unto them for that which they earn therwith.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say: Fire shall touch us not save for a few numbered days. Say thou: have ye taken a covenant with Allah, so that Allah shall not fail His covenant? or fabricate ye against Allah that which ye know not\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
O Yea! whosoever earnoth vice and his sin hath encompassed him, those shall be the fellows of the Fire, as abiders therein.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those who believe and do righteous works, --those shall be the fellows of the Garden, as abiders therein.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And recall what time We took a bond with the Children of Israel saying: worship not any god save Allah, and unto parents show kindness, and also unto the kindred and the orphans and the poor, and speak kindly unto mankind, and establish prayer and give the poor rate. Then ye turned away, save a few of you, and ye are backsliders.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And recall what time We took a bond with you: saying: ye shall not shed your blood, nor drive one anot her from your homes; then ye ratified it and ye Were witnesses\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
Thereafter it is ye the very ones who slay each other and drive a party of you from their homes, and back up against them with guilt and iniquity; and if they come unto you as captives, ye ransom them, whereas forbidden unto you was their driving away itself. Believe ye then in part of the Book and disbelieve in part? What, then, is to be the meed of those of you who do that, save humiliation in the life of the world? And on the Day of Judgement they shall be brought back to the severest torment, and Allah is not neglectful of that which ye work.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
These are they who have purchased the life of the world for the Hereafter; wherefore the torment shall not be lightened for them, nor shall they be succoured.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And assuredly We vouchsafed unto Musa the Book and We followed him up by the apostles after him, and unto 'lsa, son of Maryam, We vouchsafed evidences and aided him with the Holy Spirit. Then so often as there came unto you an apostle with that which your souls desired not, ye waxed stiff necked; and some ye belied and some ye slew?\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they say: our hearts are uncircumcised. Nay! Allah hath cursed them because of their infidelity: little wherefore it is they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there came unto them a Book from before Allah confirming that which was with them, --and afore they were entreating God for victory over these who disbelieved, -then when there came unto them that which they recognised. they disbelieved therein wherefore Allah's curse be on the infidels!\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
Vile is that for which they have bartered their souls, that they should disbelieve that which Allah hath sent down, out of envy that Allah should reveal, out of His grace, unto whosoever of His bond men He listeth. Wherefore they have drawn upon themselves wrath upon wrath, and unto the infidel shall be a torment ignominious.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it said unto them believe in that which Allah hath sent down now, they say: we believe in that which hath been sent down unto Us. And they disbelieve in that which is besides that while it is the truth, confirming that which is with them. Say thou: wherefore then slew ye Allah's prophets afore, a if ye have been believers?\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And assuredly Musa came unto you with evidence, then ye betook the calf after him, and ye were wrong-doers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And recall what time We took your bond and raised over you the Tur, saying: hold fast to that which We have vouchsafed unto you and hearken. They said: we hear and we disobey. And into their hearts the calf was made to sink because of their infidelity. Say thou: vile is that which your belief commandeth you, if ye are believers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say thou: if for you alone is the abode of the Hereafter with Allah to the exclusion of mankind, then wish for death if ye say sooth.\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
And they will by no means ever wish for it, because of that which their hands have sent on before; and Allah is the Knower of the wrong-doers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
And surely thou wilt find them the greediest of men after life, even greedier than those who associate. Each one of them would fain life for a thousand years, and this will not save him from the torment, even if he hath lived so long. And Allah is the Beholder of that which they work.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say thou: whosoever is an enemy unto Jibril, ----then verily he it is Who hath brought down this Revelation, by Allah's command, to thine heart, confirming that which went before, and a guidance and glad tidings unto the believers.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Whosoever is an enemy unto Allah and His angels and His apostles and Jibril and Mikail, then verily Allah is an enemy unto the infidels.\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
And assuredly We have sent down Unto thee evident signs, and none shall disbelieve therein save the transgressors.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it that whenever they enter into a covenant some party among them cast it aside? Aye! most of them even believe not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And whenever there came unto them an apostle from Allah confessing to that which was with them, a Party among those who were vouchsafed the Book, cast Allah's Book behind their backs as though they knew not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
And they follow that which the Satans recited in the reign of Sulaiman; and Sulaiman blasphemed not, but the Satans blasphemed.; teaching people magic; and they follow that also which was sent down unto the two angels in Babil, Harut, and Marut. Unto none the twain taught it until they had said: We are but a temptation, so blaspheme not; but they learned from the twain that wherewith they might separate man from his wife; and they could harm none thereby save by Allah's will. And they have learnt that which harmeth them, and profiteth them not; and assuredly they know that whosoever purchaseth it, his is no portion in the Hereafter. And surely vile is the price for which they have bartered themselves, if they but knew!\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
And had they believed and feared, surely better had been the reward from before Allah, if they but knew!\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O O Ye who believe! say not: Ra'ina, but say: Unzurna, and hearken; and unto the infidel shall be a torment afflictive.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Fain would they who disbelieve, be they of the people of the Book or of the associators, that naught of good should be sent down unto you from Your Lord; whereas Allah singleth out for His mercy whomsoever He will and Allah is the Lord of mighty grace.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
Whatsoever verse We abrogate or cause to be forgotten We bring a better one or the like thereof; knowest thou not that Allah is over everything Potent?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Knowest thou not that verily Allah! His is the dominion of the heavens and the earth? and for you beside Allah is no protector or helper.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Seek ye to question your apostle, even as Musa was questioned afore. And whosoever changeth belief for infidelity, he hath of a surety strayed from the even way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Fain would Many of the People of the Book turn you back infidels after ye have believed, out of envy from their, after the truth hath become manifest unto them so Pardon them, and pass over, until Allah sendeth His command. Verily Allah is over everything Potent.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And establish prayer and give the poor-rate. and whatsoever of good ye send forth for your souls ye shall find with Allah; verily Allah is the Beholder of that which ye work.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say: none shall enter the Garden except he be a Jew or a Nazarene. Such are their vain desires! Say thou: forthwith your proof if ye say\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Aye! whosoever submitteth himself unto Allah and he is a well-doer-his hire is with his Lord; no fear shall come on them nor shall they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
And the Jews say: the Nazarenes are not grounded on aught: and the Nazarenes say: the Jews are not grounded on aught While they recite the same Book. Even so say those who know not, the like of their saying. Allah will judge between them on the Day of Resurrection regarding that wherein they have been differing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who is more unjust than he who preventeth the mosques of Allah, that His name be mentioned therein, and striveth after their ruin? These! it was not for them to enter therein except in fear. Unto them shall be humiliation in this World, and unto them in the Hereafter a torment mighty.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
And unto Allah belongeth the east and the west; so withersoever you turn there is the countenance of Allah: verily Allah is pervading, Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they Say: God hath betaken unto Him a son! Hallowed be He: Aye unto Him belongeth whatsoever is in the heavens and the earth: ', all are unto Him devout\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
The Originator of the heavens and the earth; and whensoever He decreeth an affair, He only saith unto it: be; and it becometh.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
And those who know not, say: Wherefore speakest not God unto us? or cometh not unto us a sign? Thus aid those before them the like of their saying: consimilar are their hearts. We have already manifested the signs unto the people who would be convinced.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Verily We have sent thee with the truth, as a bearer of glad tidings and a warner, and thou shalt not be questioned of the fellows of the Flame.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
And the Jews will never be pleased with thee, nor the Nazarenes, except thou follow their faith. Say thou: verily the guidance of Allah, --that is the guidance. And of a surety wert thou to follow their desires after that which hath come unto thee of the knowledge, there will be for thee against Allah neither protector nor helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those unto whom We have vouchsafed the Book and they recite it as it ought to be recited - they shall believe therein and whosoever disbelieveth therein, those then! they shall be the losers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Isra'il! remember My favour wherewith favoured you, and that I preferred you over the world.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear a Day whereon not in aught shall a soul satisfy for a soul, nor shall compensation be accepted therefor, nor shall intercession profit it, nor shall they be succoured.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And recall what time his Lord Proved Ibrahim with certain words then he performed them. He said: verily I am going to make thee a leader unto mankind. Ibrahim said: and also of my progeny? Allah said: My covenant shall not reach the wrong-doers.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And recall what time We appointed the House a resort unto man kind and a place of security and said: take the station of Ibrahim for a place of prayer. And We covenanted with Ibrahim and Ismai'l, saying: purify ye twain My Houses for those who shall circumambulate it and those who shall stay, and those who shall bow down and prostrate themselves.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And recall what time Ibrahim said: my Lord! make this city a place of security, and provide the People thereof with fruits, - such of them as will believe in Allah and the last Day. Allah said: and whosoever will disbelieve, him also shall give enjoyment for a while; thereafter I shall drive him to the torment of the Fire, - an ill abode!\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And recall what time Ibrahim was raising the foundation of the House and also Ismai'l, praying: our Lord! accept of us; verily Thou! Thou art the Hearer, the Knower!\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Our Lord! make us twain submissive unto Thee, and of our progeny community submissive unto Thee, and show us our rites, and relent toward us! verily Thou! Thou art the Relentant, the Merciful!\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Our Lord! raise up unto them an apostle from among them, who shall recite unto them Thy revelations, and shall teach them the Book and wisdom, and shall cleanse them. Verily Thou! Thou art the Mighty, the Wise.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who shall be averse from the faith of Ibrahim, save one who befooleth his soul! And assuredly We chose him in this World, and verily he in the Hereafter shall be of the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
Recall what time his Lord said unto him: submit, he said: I submit to the Lord of the Worlds.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And Ibrahim enjoined his sons the same and did Ya'qub also, saying: O my sons! verily Allah hath chosen for you the religion, so die not except ye be Muslims.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Were ye witnesses when death presented itself to Ya'qub, what time he said unto his sons: what will ye worship after me! They said: we shall worship the God the God of thy fathers, Ibrahim and Ismai'l and Ishaq, and unto Him we are submissive.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That are a community who have passed away, unto them shall be that which they earned and unto you that which ye earn, and ye shall be questioned not of that which they were wont to Work.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say: become Jews or Nazarenes, and ye shall be guided. Say thou: Aye! we follow the faith of Ibrahim, the upright, and he was not of the associators.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say: we believe in Allah and that which hath been sent down unto us and that which was sent down unto Ibrahim and Ismai'l and Ishaq and Ya'qub and the tribes, and that which was vouchsafed unto Musa and lsa, and that which was vouchsafed unto the prophets from their Lord; we differentiate not between any of them, and unto Him are submissive.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
So if they believe in the like of that which ye believe in, surely they are guided; but if they turn away, then they are but in Cleavage. So Allah will suffice thee against them and He is the Hearer, the Knower.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
Ours is the dye of Allah! and who is better at dyeing than Allah! And we are His worshippers.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say thou: contend ye with us regarding Allah, whereas He is our Lord even as He is Your Lord And unto us our works, and unto you your works, and we are His devotees.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or say ye that Ibrahim and Ismai'l and Ishaq and Ya'qub, and the tribes were Jews or Nazarenes? Say thou: are ye the more knowing or is Allah? And who is more unjust than he who hideth a testimony that is with him from Allah? And Allah is not neglectful of that which ye Work.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That are a community who have passed away; unto them shall be that which they earned, and unto you that which ye earn; and ye shall be questioned not of that which they were wont to Work.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
Anon will the foolish among mankind say: what hath turned them away from their Qiblah whereon they had been? Say thou: unto Allah belongeth the east and the west he guideth whomsoever He listeth unto a straight path.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
And in this wise We have made you a community justly balanced, that ye may be witness against the man kind and that the apostle may be in regard to you a witness. And We appointed not the Qiblah which thou hast had save in order that We might know him who followeth the apostle from him who turnoth back upon his heels. And of a surety the change is grievous save unto those whom Allah hath guided. And Allah is not one to let your faith go wasted; verily Allah is unto mankind Tender, Merciful.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
Oft We have seen the turning of thy face to the heaven, wherefore We shall assuredly cause thee to turn towards the Qiblah which shall please thee. Turn then thy face toward the Sacred Mosque; and turn ye, wheresoever ye be, your faces toward it. And verily those who are vouchsafed the Book know this to be the truth and from their Lord. Allah is not neglectful of that which they Work.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
And shouldst thou bring unto those who are vouchsafed the Book every sign, they would not follow thy Qiblah, neither art thou to be a follower of their Qiblah; nor doth one part of them follow the Qiblah of the other. And shouldst thou follow their desires, after that which hath come unto thee of the knowledge, then verily thou wilt become one of the wrong-doers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those unto whom We have vouchsafed the Book recognise him even as they recognise their children; and verily a party of them hide the truth while they know.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
The truth is from thy Lord; be then thou not of the doubters.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
For every one is a direction witherward he turnoth; so strive to be foremost in virtues. Wheresoever ye may be, Allah will bring you together. Verily Allah is over everything Potent.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
And from whencesoever thou goest forth, turn thy face toward the Sacred Mosque, and verily it is the very truth from thy Lord; and Allah is not neglectful of that which ye work.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
And from whencesoever thou goest forth, turn thy face toward the Sacred Mosque, and wheresoever ye be, turn your face toward it, lest there should be with people an argument against you, except those of them who do wrong so fear them not, but fear Me; so that I may accomplish My favour upon you, and that ye may remain guided-\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Even as We have sent amidst you an apostle from amongst you, who rehearseth unto you Our revelations and purifieth you, and teacheth you the Book and wisdom, and teacheth you that which ye were not wont to know.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
Remember Me wherefore, and I shall remember you: and unto Me give thanks, and be notingrate unto Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O O Ye who believe! seek help in patience and prayer; verily Allah is with the patient.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And say not of those who are slain in the way of Allah: dead. Nay, they are living, but ye perceive not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
And We will surely prove you with aught of fear and hunger and diminution in riches and lives and fruits; and bear thou the glad tidings unto the patient;\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who, when there afflicteth them an affliction, say: verily we are Allah's, and verily unto Him we are returners.\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
These! on them shall be benedictions from their Lord and His mercy, and these! they are the rightly guided.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Verily Safa and Marwa are of the landmarks of Allah; so whosoever maketh a pilgrimage to the House, or performeth the Umra, in him there is no fault if he walketh in-between the twain. And whosoever voluntarily doth good, then verily Allah is Appreciative, Knowing.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Verily those who hide that which We have sent down of evidence and the guidance, after We have expounded its Unto mankind in the Book, these! - curseth them Allah, and shall curse them the cursers\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Save those that repent and amend, and make manifest the truth I these it is toward whom I relent. And I am the Relenting, the Merciful!\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Verily those who disbelieve, and die while they are infidels, these it is on whom shall be the curse of Allah and the angels and mankind all.\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They shall be abiders therein, the torment shall not be lightened on them, nor shall they be respited.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
And the God of you all is one God; there is no God but he, the Compassionate, the Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Verily in the creation of the heavens and the earth, and the alternation of night and day, and the ships that course upon the sea laden with that which profiteth mankind, and that which Allah sendeth down of water from the heaven and quickenoth the earth thereby after the death thereof; and scattereth therein of all kinds of moving creatures, and in the veering of the winds and the cloud subjected for service betwixt heaven and earth. are signs unto a people who understand.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
And of mankind are some that set up compeers; unto Allah they love them as with the love due to Allah. And those who believe are strongest in love of Allah. Would that those who do wrong saw, when they saw the torment, that verily power belonged wholly unto Allah, and that Allah was severe in requital -\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
When those who were followed shall quit themselves of those who followed, and they all shall behold the torment, and sundered between them shall be the Cords.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And those who had followed shall say would that for us were a return, then would we quit ourselves of them as they have quitted themselves of us. In this wise Allah will show them their works as vain regrets; and they shall not be coming forth from the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
Mankind! eat of whatsoever is, the earth, lawful, and clean and follow not the footsteps of Satan; verily he is an enemy unto you manifest.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He only commandeth you to evil and indecency, and that ye should say against Allah that which ye know not\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it said unto them: follow that which Allah hath sent down, they say: nay, we shall follow that way whereon we found our fathers - even though their fathers understood not aught, nor were they guided aright?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
And the likeness of those who disbelieve is as the likeness of one who shouteth unto that which heareth naught except a call and a cry; deaf, dumb; blind, wherefore they understand not.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O O Ye who believe! eat of the clean things wherewith We have provided you, and return thanks unto Allah, if Him indeed ye are wont to worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He hath only forbidden unto you the carcass and blood and the flesh of swine, and that over which is invoked the name of other than Allah. But whosoever is driven by necessity, neither alusting nor transgressing, for him is no sin; verily Allah is Forgiving, Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Verily those who hide that which Allah hath sent down in the Book and Purchase therewith a small gain, these are they who eat in their bellies naught but Fire. Allah will not speak unto them on the Day of Resurrection, nor purify them; and unto them shall be a torment afflictive.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
These are they who have purchased error for guidance, and torment for forgiveness, How enduring must they be of the Fire!\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
This shall be because Allah hath verily sent down the Book with truth: and verily those who differ respecting the Book. are surely in cleavage wide.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
Virtue is not in this that ye turn your faces toward the east and west, but virtue is of him who believeth in Allah and the Last Day and the angels and the Book and the prophets: and giveth of his substance, for love of Him unto kindred and orphans and the needy and the wayfarer and the beggars and for redeeming necks, and establisheth prayer and giveth the poor-rate and is of the performers of their covenant when they have covenanted; and is of the patient in adversity and affliction and in time or violence these are they who are proven true, and these they are God-fearing.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O O Ye who believe! prescribed unto you is retaliation for the slain; the free for the free, and a bondsman for a bondsman, and a woman for a woman; yet unto whomsoever is pardoned aught by his brother, then a serving with lenity and payments with kindness. That is an alleviation from your Lord and a mercy so whosoever shall transgress thereafter, for him there shall be a torment afflictive.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And for you in retaliation is life men of insight! that haply ye may fear God.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
Prescribed unto you, when death is nigh unto one of you, if he leaveth any property, is the making of a bequest for parents and kindred equitably - a duty on the God-fearing.\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then whosoever altereth it after he hath heard it, the sin thereof shall be only on those who shall alter it: verily Allah is Hearing, Knowing.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
How beit whosoever apprehendeth from the testator a mistake or a sin and thereupon he maketh up the matter between them, on him there shall be no sin; verily Allah is Forgiving, Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O ye who believe! prescribed unto you is fasting even as it was prescribed unto those before you, that haply ye may fear God.\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
Days numbered and few; then whosoever among you is sick or journeying, for him the like number of other days. And for those who can keep it with hardship the ransom is the feeding of a and whosoever voluntarily poor man doth good, it will be better for him; and that ye fast Will be better for you, if ye only knew.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadhan: therein was sent down the Qur'an: is a guidance unto mankind, and with evidences: one of the Books of guidance and the distinction. So whosoever of you witnesseth the month, he shall fast it, and whosoever sick or journeying, for him the like number of other days. Allah intendeth for you ease, and intendeth not for you hardship; so ye shall fulfil the number and shall magnify Allah for His having guided you, and haply ye may give thanks.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My bondsmen ask thee regarding Me, then verily I am Nigh; I answer the call of the caller when he calleth unto Me,; so let them answer Me and believe in Me, haply they may be rightly directed.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
Allowed unto you, on the night of fasts, is consorting with your women. they are a garment unto you, and ye are a garment unto them. Allah knoweth that ye have been defrauding yourselves, so He hath relented toward you and pardoned you. Wherefore now copulate with them, and seek that which Allah hath prescribed for you, and eat and drink, Until the white thread becometh manifest unto you from the black thread of the dawn; thereafter complete the fast till night fall. And copulate not with them While ye are retreating in the mosques. These are the bounds of Allah, wherefore approach them not. Thus Allah expoundeth all His signs unto mankind that haply they may fear Him.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And devour not your riches among yourselves in vanity, nor convey them unto the judges that ye may devour thereby a portion of other people's riches sinfully while ye know.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask thee of new moons. Say thou: they are time-marks to mankind and for pilgrimage. And it is not piety that ye enter your houses by the backs thereof, but Piety is of him who feareth God; so enter the houses by the doors thereof, and fear Allah that haply ye may thrive.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the way of Allah those who fight you, and transgress not; verily Allah loveth not the transgressors\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And slay them wheresoever ye come upon them, and drive them out whence they drove you out; and temptation is more grievous than slaughter. And fight them not near the Sacred Mosque until they fight you therein, but if they get ready to fight you there, then slay them. That is the meed of the infidels.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
Then if they desist, then verily Allah is Forgiving, Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until there be no more temptation, and their obedience be wholly unto Allah. So if they desist, then there is to be no violence save against the wrong-doers.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
A sacred month is for a sacred month; these sacrednesses are in retaliation. Whosoever then offereth violence unto you, Offer violence unto him the like of his violence unto you, and fear Allah, and know that Allah is with the God-fearing.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And expend in the way of Allah, and cast not yourselves with your hands into perdition, and do well. verily Allah loveth the well- doers,\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And fulfil the pilgrimage and 'Umra for Allah. And if ye be besieged, offer whatsoever offering be easy, and shave not Your heads, until the offering reacheth its destination. Then whosoever of you sick or hath hurt in his head, for him is a ransom by fasting or alms or a rite. Then when ye are secure, whosoever combinoth 'Umra with the pilgrimage, for him is whatsoever offering be easy. And whosoever cannot afford then for him is a fast of three days during the pilgrimage and of seven when ye return these are ten days complete. That is for him whose family dwell not near the Sacred Mosque. And fear Allah, and know that verily Allah is severe in chastising.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The season of Pilgrimage is the months known; wherefore whosoever ordaineth unto himself the pilgrimage therein, there is no lewdness nor wickedness nor wrangling during the pilgrimage, and whatsoever of good ye do, Allah shall know it. And take provision for the journey, for verily the best provision is abstainment; and fear Me, O men of understanding!\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
No fault it is in you if ye seek grace from your Lord. Then when ye hurry from Arafat, remember Allah near the sacred monument. Remember Him as He hath guided you, and ye were afore of the erring.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then hurry from the place whence the other people have hurried, and ask forgiveness of Allah, verily Allah is Forgiving, Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when ye have completed Your rites, remember Allah even as ye remember your fathers or with a stronger remembrance. Of mankind there are some who say: our Lord vouchsafe unto us in, the world. And for such there shall be no portion in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And of mankind are some who say: our Lord! vouchsafe unto us good in the world and good in the Hereafter, and save us from the torment of the Fire.\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
These! for them will be a share for that which they have earned. and Allah is swift at reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember Allah on the days numbered. Then whosoever hastenoth in two days on him is no sin, and whosoever delayeth, On him is no sin: this for him: who feareth. So fear Allah, and know that verily unto Him shall ye be gathered.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And of mankind is he whose discourse for the purpose of this world thou admirest, and he taketh Allah to witness as to that which is in his heart, whereas he is the most contentious of the adversaries.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he turnoth away, he speedeth through the land that He may act corruptly therein and destroy the tilth and the stock. And Allah approveth not corruptness.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it said unto him: fear Allah, arrogance taketh him to sin. Enough for him is Hell: surely an ill resort!\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And of mankind is he who selleth his life even, seeking the pleasure of Allah; and Allah is Tender unto His bond men\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O Ye who believe! enter into Islam wholly, and follow not the foot steps of the Satan, verily he is unto you an enemy manifest.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
Wherefore if ye slip after that which hath come unto you of the evidence then - know that Allah is Mighty, Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Await they only that Allah shall come unto them in the shadows of the Clouds, and also the angels, and the affair is decreed! And unto Allah are all affairs returned.\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask thou the Children of Isra'il, how many a manifest sign We brought unto them. And whosoever altereth the favour of Allah after it hath come unto him, then verily Allah is severe in Chastising.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Fair-seeming is made the life of the world unto those who disbelieve, and they scoff at those who believe, whereas those who fear God shall be above them on the Day of Resurrection. And Allah provideth whomsoever He listeth without reckoning.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind was one community; thereafter Allah raised prophets as bearers of glad tidings and warners, as He sent down the Book With truth that He may judge between mankind in that wherein they disputed. And none differed therein save those unto whom it was vouchsafed after the evidences had come to them, out of spite among themselves; then Allah guided those who believed unto the truth of that regarding which they differed, by His leave. Allah guideth whomsoever He listeth unto a path straight.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Deem ye that ye will enter the Garden while ye hath not come upon you the like of that which came upon those who have passed away before you There touched them adversity and distress, and shaken were they, until the apostle and those who believed with him said; when cometh the succour of Allah! Lo! verily Allah's succour is nigh.\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask thee regarding whatsoever they shall expend. Say thou: whatsoever ye expend of wealth, let it be for the parents and kindred and orphans and the needy and the wayfarer and whatever good ye do, verily Allah is the Knower thereof.\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Prescribed unto you is fighting, albeit it is abhorrent unto you. Belike ye abhor at thing whereas it is good for you, and belike ye desire a thing whereas it Is bad for you. And Allah knowcth and ye know not.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask thee of the sacred month, of fighting therein. Say thou; fighting therein is grievous; and hindering people from the way of Allah and unbelief in Him and in the sanctity of the Sacred Mosque and driving out its dwellers therefrom are more grievous with Allah, and such temptation is far more grievous than that slaughter. And they will not cease fighting you so that they might make you apostatize from your religion, if they can. And whosoever of you apostatizeth from his faith and dieth an Infidel, then these it is whose works shall be of none effect in this world and the Hereafter, and they shall be the fellows of the Fire; therein they shall be abiders.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Verily those who have believed and those who have emigrated and have striven hard in the way of Allah, all these shall hope for the mercy of Allah, and Allah is Forgiving, Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask thee of wine, and gambling. Say thou: in both is a great sin, and some benefits for men, but the sin of them is for greater than their benefit. And they ask thee, how much they should expend. Say thou: the redundant portion. In this wise Allah expoundeth unto you His commandments that haply ye may ponder.\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
On this Wor1d and the Here after. And they ask thee of orphans. Say thou: to set right affairs for them were best. If ye mix with them, then they are your brethren. Allah knoweth the foul-dealer from the fair-dealer. And had Allah so willed, He could have harassed you; verily Allah is Mighty, Wise.\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
And wed not infidel women until they believe; of a surety a believing bondwoman is better than an infidel Woman, albeit she please you. And wed not your women to infidel men until they believe; of a surety a believing bondman is better than an infidel, albeit the please you. These Call you unto the Fire, and Allah calleth you unto the Garden and unto forgiveness, by His leave; and He expoundeth His commandments unto mankind that haply they may be admonished.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
And they ask thee of menstruation. Say thou: it is a pollution, so keep away from women during menstruation, and go not in unto them until they have purified themselves. Then when they have thoroughly purified themselves, go in unto them as Allah hath commanded you. Verily Allah loveth the penitents, and loveth the purifiers of themselves.\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your women are tilth Unto you, so go in unto your tilth as ye list, and provide beforehand for your souls. And fear Allah, and know that ye are going to meet Him; and give thou glad tidings Unto the believers.\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And make not Allah a butt of your oaths that ye shall not act piously nor fear Allah nor set things right between and Allah is Hearing, Knowing.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not take you to task for the vain in Your oaths, but he shall take you to task for that which your hearts have earned, and He is the Forgiving, the Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
For those who swear off from their wives is a awaiting of four months; then if they go back, verily Allah is Forgiving, Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they resolve on divorcement, then verily Allah is Hearing, Knowing.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
And the divorced women shall keep themselves in waiting for three courses nor is it allowed unto them that they should hide that which Allah hath created in their wombs, if they believe in Allah and the Last Day. And their husbands are more entitled to their restorations during the same, if they desire rectification. Unto women is due likes that which is due from women reputably. And for men is a degree over them. And Allah is Mighty, Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorcement is twice: thereafter either retaining her reputably, or letting her off kindly. And it is not allowed unto you to take away aught ye have given them, except the twain fear that they may not observe the bonds of Allah. If yes fear that the twain may not observe the bonds of Allah, then no blame is on the twain for that where with she ransometh herself. These are the bonds of Allah, wherefore trespass them not; and whosoever trespasseth the bonds of Allah, then verily these! they are the wrong-doers.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
If he divorceth her, then she is not allowed unto him thereafter until she wed a husband other than he; then if he divorceth her, no blame is on the twain in that they return unto each other, if they imagine they will oh serve the bonds of Allah. And these are the bonds of Allah; He expoundeth them unto a people who know.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when ye have divorced your women, and they have attained their period, then either retain them reputably or let them off kindly; and retain them not to their hurt that ye may trespass; and whosoever doth this assuredly wrongeth his soul. And hold not Allah's commandments in mockery and remember Allah's favour upon you, and that he hath sent down unto you the Book and the wisdom wherewith He exhorted you; and fear Allah, and know that verily Allah is of everything the Knower\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when ye have divorced women and they have attained their period; straiten them not so that they wed not their husbands when they have agreed between themselves reputably; hereby is exhorted he among you who believeth in Allah and the Last Day: this is cleanest for you and purest. Allah knoweth and ye know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
And mothers shall suckle their children two whole years: this is for him who intendeth that he shall complete the suckling; and on him to whom the child is born, is their provision and clothing reputably; not a soul is tasked except according to its capacity. Neither shall a mother be hurt because of her child, nor shall he to whom the child is born because of his Child; and on the heir shall devolve the like thereof. Then if the twain desire weaning by agreement between them and mutual counsel, on the twain is no blame. And if ye desire to give your children out for suckling, On you is no blame when ye hand over that which ye had agreed to give her reputably. And fear Allah, and know that of that which ye work Allah is the Beholder.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
And as for those of you who die and leave wives behind, they Shall keep them selves in waiting for four months and ten days. Then when they have attained their period, no blame there is on you for that which they do with them selves reputably. And of that which ye work Allah is aware.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
And no blame is on you in that ye speak indirectly of your troth unto the said women or conceal it in, your souls! Allah knoweth that ye will anon make mention of these women: but make no promises unto them in secret, except ye speak a reputable saying. And even resolve not on wedding-knot until the prescribed term hath attained its end; and know that Allah knoweth that which is in your souls, wherefore beware of Him, and know that Allah is Forgiving, Forbearing\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
No blame is on you if ye divorce women while yet ye have not touched them nor settled unto them a settlement. Benefit them on the affluent is due according to his means, and on the straitened is due according to his means. a reputable present, and duty on the well-doers.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if ye divorce them ere ye have touched them but have settled unto them a settlement, then due from you is half of that which ye have settled unless the wives forego, or he in whose hand is the wedding-knot foregoeth, and that ye should forego is nigher unto piety. And forget not grace amongst yourself; verily of that which ye work Allah is the Beholder.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard the prayers, and the middle prayer, and stand up to Allah truly devout.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if ye fear, then pray on foot or riding; then when ye are secure, remember Allah in the way He hath taught you which ye ever knew not.\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those of you who die and leave wives behind, they shall make a bequest unto their wives a year's maintenance without their having to go out, then if they go out, then no blame is on you for that which they, do with themselves reputably, and Allah is Mighty, Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And for the divorced women shall be a reputable present: and duty on the God-fearing.\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
In this wise Allah expoundeth unto you His commandments, haply ye may reflect.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Bethinkest thou not of those Who Went forth from their habitations, and they were in their thousands, to escape death Then Allah said unto them: die and thereafter quickened them. Verily Allah is Gracious unto men; albeit most men give not thanks.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
And fight in the way of Allah and know that verily Allah is Hearing, Knowing.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will lend unto Allah a goodly loan, so that he will multiply it unto him manifold And Allah scanteth and amplifieth, and unto Him ye shall be returned.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Bethinkest thou not of the chiefs of the Children of Isra'il, after Musa? They said unto a Prophet of theirs: raise for us a king that we may fight in the way of God. He said: may it not be that if fighting were prescribed unto you, ye would not fight! They said: and wherefore shall we not fight in the way of God, whereas we have been driven forth from our habitations and children. Then when fighting was prescribed unto them, they turned away, save a few of them: and Allah is the Knower of the wrong-doers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
And their prophet said unto them: verily Allah hath raised unto you Talut as a king. They said: how can there be the dominion for him over us, whereas we are more worthy of the dominion than he nor hath he been vouchsafed an amplitude of wealth! He said: verily Allah hath chosen him over you and hath increased him amply in knowledge and physique, and Allah vouchsafeth His dominion unto whomsoever He listeth; and Allah is Bountiful, Knowing.\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their prophet said unto them: verily the sign of his dominion is that there shall come unto you the ark wherein is tranquillity from your Lord and the relic of that which the household of Musa and the household of Harun had left, the angels bearing it; verily, herein is a sign for you if ye are believers.\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
Then when Talut sallied forth with the hosts, he said, verily God will prove you with a river: then whosoever drinketh thereof shall be none of mine, and whosoever tasteth it not, verily shall be mine, excepting him who ladeth a lading with his hand. But they drank thereof, save a few of them. Then when he had crossed it, he, and those who believe with him, they said: We have no strength to-day against Jalut and his hosts. But those who imagined that they were going to meet Allah Said how oft hath a small party prevailed against a large party by God's leave! And Allah is with the patiently persevering.\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they arrayed themselves against Jalut and his hosts, they said: our Lord pour forth on us patience, and set firm our feet, and make us triumph over the infidel people.\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
Then they vanquished them by the leave of Allah, and Da'ud slew Jalut, and Allah vouchsafed him dominion, and Wisdom and taught him of that which He Willed. And, it not for Allah's repelling people, some of them by means of others, the earth surely were corrupted; but Allah is Gracious unto the Worlds.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the revelations of Allah We rehearse them unto thee with truth, and verily thou art of the sentones.\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
These apostles: We have preferred some of them above some others: of them are some unto whom Allah spake, and some He raised many degrees. And We vouchsafed unto Isa, son of Maryam, the evidences, and We aided him with the holy spirit; and had Allah so willed those who came after them had not fought among themselves after the evidences had come unto them but they differed; then of them some believed and of them some disbelieved. And had Allah so willed, they had not fought among themselves, but Allah doth whatsoever He intendeth.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O O Ye who believe: expend of that which We have provided you ere the Day cometh wherein there will be neither bargain nor friendship nor intercession. And the infidels - they are the wrong-doers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah! There is no God but he, the Living, the Sustainer Slumber taketh hold of Him not, nor sleep. His is whatsoever is in the heavens and whatsoever is on the earth. Who is he that shall intercede With Him except with His leave! He knoweth that which was before them and that which shall he after them, and they encompass not aught of His knowledge save that which He willeth. His throne comprehendeth the heavens and the earth, and the guarding of the twain wearieth Him not. And He is the High, the Supreme.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
No constraint is there in the religion; surely rectitude hath become manifestly distinguished from the error. Whosoever then disbelieveth in the devil and believeth in Allah, hath of a surety rain hold of the firm cable whereof there is no giving way. And Allah is Hearing, Knowing.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Patron of those who believe; He bringeth them forth from darknesses into the light; And, for those who disbelieve, the devils are their patrons; they bring them forth from the light into darknesses. These are the fellows of Fire, therein shall be abiders.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Bethinkest thou not of one who contended with Ibrahim concerning his Lord, because Allah had vouchsafed unto him dominion! When Ibrahim said: my Lord is He Who giveth life and causeth death, he said: give life and cause death. Ibrahim said: verily Allah bringeth the sun from the east, then bring it thou from the west. Thereupon he Who disbelieved Was dumb-founded, And Allah guideth not a wrong-doing people.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or, the like unto him who passed by a town, and it lay overturned on its roofs. He said: how shall Allah quicken this after the death thereof Thereupon Allah made him dead for a hundred years, and thereafter raised him and said: how long hast thou tarried He said: I have tarried any day, or part of any day. Allah said: nay! thou hast tarried a hundred years: look at thy food and thy drink, they have not rotten, and look at thine ass; and this We have done in order that We may make of thee a sign unto men; and look thou at the bones, how we shall make them stand up and clothe them with flesh. Then when it became manifest Allah unto him he said: I know that verily everything Potent.\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And recall what time Ibrahim Said: my Lord! shew me how Thou wiltquicken the dead. He said: belie Vest thou not! He said: O Yea but that my heart may rest at ease. He said: take then thou four of the birds, and incline them towards thee, and then put a part thereof on each hill, and thereafter call them; they will come unto thee speeding. And know thou that verily Allah is Mighty, Wise.\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The likeness of those who expend their substance in the way of Allah is as the likeness of a grain that groweth seven ears and in each ear one hundred grains: and Allah multiplieth unto whomsoever He listeth. Allah is Bounteous, Knowing.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who expend their riches in the way of Allah and thereafter follow not that which they have expended with the laying of an obligation or with hurt, for them shall be their hire with their Lord; and no fear shall come on them, nor shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
A reputable word and forgiveness are better than an alms which hurt followeth; and Allah is Self-Sufficient, Forbearing.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O O Ye who believe! make not your alms void by laying an obligation and by hurt, like unto him who expendeth his substance to be seen of men, and believeth not in Allah and the Last Day. The likeness of him is as the likeness of a smooth stone whereon is dust; a heavy rain falleth upon it, and leaveth it bare. They shall not have power over aught of that which they have earned and Allah shall not guide the disbelieving people.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the likeness of those who expend their riches seeking the pleasure of Allah and for the strengthening of their souls is as the likeness of a garden on a height. A heavy rain falleth upon it, and it yieldeth its fruits two-fold and if no heavy rain falleth upon it, then a gentle rain and Allah is of that which ye work Beholder.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Fain would any of you that there be for him a garden of date-palms and grape-vines whereunder rivers flow end with every fruit therein for him, and that old age should befall him while he hath a progeny of weaklings, and that a whirlwind wherein is fire should then smite it, so that it is all consumed! In this wise Allah expoundeth unto you the signs that haply ye may ponder.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O O Ye who believe expend out of the good things which! ye have earned and out of that which We have brought forth for you from the earth, and seek not the vile thereof to expend, where as ye yourselves would not accept such except ye connived thereat. And know that Allah Self-Sufficient, Praiseworthy.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Satan promiseth You poverty and commandeth you to niggardliness, whereas Allah promiseth you forgiveness from Himself and abundance; and Allah is Bounteous, Knowing.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He vouchsafeth wisdom unto whomsoever He will, and whosoever is vouchsafed wisdom is of a surety vouchsafed abundant good, and none receiveth admonition Save men of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever expense ye expend or whatever VOW ye vow, verily Allah knoweth it: and for the wrong doers there will be no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If ye disclose the alms, even so it is well, and if ye hide them and give them unto the poor, it will be better for you and He will expiate some of your misdeeds Allah is of that which ye work Aware.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Not on thee is their guidance, but Allah guideth whomsoever He listeth. And whatsoever ye expend of good it is for your own souls, and ye expend not save to seek Allah's countenance and whatsoever ye expend of good shall be repaid to you, and ye shall not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
Alms are for the poor who are restricted in the way of Allah, disabled from going about in the land. The (unknowing taketh them for the affluent because of their modesty thou I wouldst recognise them by their appearance: they ask not of men with importunity. And whatsoever ye shall expend of good, verily Allah is thereof Knower\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who expend their riches by night and by day, in secret and openly, theirs shall be their hire with their Lord; no fear shall come on them, nor shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who devour Usury Shall not be able to stand except standeth one whom the Satan hath confounded with his touch. That shall be because they say: bargaining is but as usury whereas Allah hath allowed bargaining and hath forbidden usury. Wherefore Unto whomsoever an exhortation cometh from his Lord, and he desisteth, his is that which is past, and his affair is with Allah. And whosoever returnoth --such shall be the fellows of the Fire, therein they shall be abiders.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah obliterateth usury, and increaseth the alms. And Allah loveth not any ingrate sinner.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Verily those who believe and work righteous works and establish prayer and give the Poor-rate, theirs shall be their hire with their Lord: no fear shall come on them nor shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O O Ye who believe: fear Allah and leave that which remainoth of usury if ye are believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
But if ye will do it not, then be apprised of war from Allah and His apostle. And if ye repent, then yours shall be your capital sums; ye shall neither wrong nor be wronged.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if one be in difficulties, then let there be and deferment until easiness. But if ye forego, it were better for you if ye knew.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And fear the Day whereon ye shall be brought back unto Allah, then shall each sour be repaid, in full that which he hath earned, and they shall not be wronged.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O ye who believe! when ye deal, one with anot her, in lending for a term named, write it down, and let a scribe write it down justly between you, and let not the scribe refuse to write according as Allah hath taught him. Let him write them, and let him who oweth dictate, and let him fear Allah, his Lord, and diminish not aught thereof. But if he who oweth be witless or infirm or unable himself to dictate, then let his guardian dictate justly. And call to witness two witnesses of your men, but if both be not men, then a man and two women of those ye agree upon as witnesses, so that if one of the twain err, the one thereof shall remind the other: and let not the witnesses refuse When they are called on And be not Weary of writing it down, be it small or big, with the term thereof. This is the most equitable in the sight of Allah and the most confirmatory of testimony and nearest that ye may not doubt, except when it be a ready merchandise that ye circulate between you, for then there Shall be no blame on you if ye write it not down. And call witnesses when ye bargain With one anot her; and let not the scribe eome to harm nor the witness; and if ye do, verily it will be wickedness in you. Fear Allah; and Allah teacheth you Knower; and Allah is of everything Knower.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if ye be on a journey and ye find not a scribe, then let there be a pledge taken; then, if one of you entrusteth the other, let the one is trusted discharge his trust, and let him fear Allah, his Lord. And hide not testimony whosoever hideth and it, his heart verily is Knower. Allah is of that which ye work\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
Allah's is whatsoever is in the heavens and Whatsoever is in the earth, and whether ye disclose that which is in your soul or conceal it, Allah will reckon with you therefor, then He will forgive whomsoever He will, and torment whomsoever He will, And Allah is over everything Potent.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The apostle believeth in that which is sent down Unto him from his Lord, and so do the believers. Each one believeth in Allah and His angels and His Books and His apostles, saying: we differentiate not between any of His apostles. And they say: we hearken and obey; Thy forgiveness, Our Lord! and Unto Thee is the return!\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah tasketh not a soul except according to its capacity. For it shall be the good it earnoth, and against it the evil it earnoth. Our Lord! reckon with not if we forget or er. Our Lord! ray not on us a burthen like unto that which Thou laidest on those before us, Our Lord! impose not on US that for which we have not strength. And Pardon us; forgive US; and have mercy on us; Thou art our Patron: so make US triumph over the disbelieving people!\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif, Lam, Mim,\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah There is no god but He, the Living, the Sustainer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He hath revealed unto thee the Book with truth confirming that which went before it; and He sent down the Taurat and Injil.\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Aforetime, for a guidance unto the people, and sent down the criterion. Verily those who disbelieve in the signs of Allah Unto them shall be torment severe. And Allah is Mighty, Lord of Retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Verily Allah aught is concealed from Him in the earth or in the\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
He it is Who fashionoth You in the Wombs as He will: there is no god but He, the Mighty, the Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
He it is who hath sent down unto thee the Book, wherein some verses are firmly constructed they are the mother of the Book: and others consimilar. But those in whose hearts is and deviation follow that which is consimilar therein, seeking discord and seeking to misinterpret the same whereas none knoweth the interpretation thereof a save Allah. And the firmly- grounded in knowledge Say: we believe therein, the whole is from our Lord. And none receiveth admonition save men of understanding.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
Our Lord Suffer not our hearts to deviate after that Thou hast guided US, and bestow from Thine presence mercy. Verily Thou! Thou art the Bestower!\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord! verily Thou art the Assembler of mankind for a Day whereof there is no doubt. Verily Allah faileth not the tryst.\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
Verily those who disbelieve-neither their riches nor their offspring shall avail them aught with Allah. and these! they shall be the fuel of the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
After the wont of the people of Fir'awn and those before them. They belied Our signs, wherefore Allah laid hold of them for their sins. And Allah is Severe in chastising.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say thou unto those who disbelieve: anon shall ye be overcome, and gathered unto Hell--an evil couch!\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
Of a surety there hath been unto you a sign, the two hosts that met, one host fighting in the way of Allah, and the other disbelieving, beholding themselves, with their own eyes, twice as many as they. And Allah aideth with His succour whomsoever He will. Verily herein is a lesson for men of insight.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Fair-seeming is made unto men the love of pleasurable things from women and children and talents heaped-up of gold and silver and horses branded up and cattle and tilth. All that is the enjoyment of the life of the World, and Allah! with Him is the best resort.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say thou! Shall I declare unto you that which is better than these For those who fear Allah are Gardens with their Lord, there under rivers flow, wherein they shall be abiders, and spouses purified, and pleasure from Allah. And Allah is Beholder of His bondsmen\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say our Lord! verify we! we have believed, wherefore forgive us our sins, and protect us from the torment of the Fire.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
The patient ones and the truthful ones and the devout ones and the expanders and the praying ones at early dawn for forgiveness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah beareth witness - and also the angles and those endued with knowledge that there is no god but He, the Maintainer of equity: there is no god but He, the Mighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Verily the religion with Allah is Islam and those Who Were vouchsafed the Book differed Not save after the knowledge had come unto them, out of spite among themselves. And whosoever disbelieveth in the revelations of Allah, then verily Allah swift at reckoning.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
Wherefore if they contend with thee, say thou: have surrendered myself unto Allah and he who followeth me. And say thou unto those who have been vouchsafed the Book and unto the illiterates; do you (also) accept Islam? Then if they accept Islam, they are of a surety guided; and if they turn away, then upon thee is only the preaching, and Allah is Beholder of His bondsmen.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Verily those who disbelieve in the revelations of Allah and slay the prophets without justice and slay those among men who command equity thou unto them a torment afflictive.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
These are they whose works have Come to naught in the world and the Hereafter, nor have they helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Hast thou not observed those vouchsafed a portion of the Book called to the Book of Allah that it may judge between them? Then a party of them turn away and they are backsliders\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
That is because they say, the Fire shall touch us not save for a few days numbered. And there had deluded them in their religion that which they have been fabricating.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How shall it be then, when we shall gather them on the Day whereof there is no doubt, and every soul shall be repaid in full that which it hath earned, and they shall not be wronged.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say thou: O Allah! sovereign of the dominion: Thou givest dominion unto whomsoever Thou wilt, and Thou takest away dominion from whomsoever Thou wilt; Thou honourest whomsoever Thou wilt, and Thou abasest whomsoever Thou wilt; and in Thine hand is good. And verily Thou art over every thing Potent.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
Thou plungest night into day and Thou plungest day into night, and Thou bringest forth the living from the lifeless, and Thou bringest forth the lifeless from the living; and Thou providest for whomsoever Thou wilt without reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers take unto themselves the infidels as friends, beside the believers: and whosoever doth that, then he is not in respect of Allah in aught, unless indeed ye fear from them a danger. And Allah maketh ye beware of Himself; and unto Allah is the last wending.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say thou: Whether ye conceal that which is in your breasts or disclose it, Allah knoweth it, and He knoweth that which is in the heavens and in the earth; and Allah is over everything Potent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
The Day whereon each soul shall find presented whatsoever it hath worked of good and whatsoever it hath worked of evil, it would fain that there were betwixt it and that Day a wide space. And Allah maketh you beware of Himself: Allah is Tender unto His bondsmen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say thou: if ye, are wont to love Allah, then follow me, and Allah shall rove you and forgive you your sins; and Allah is Forgiving, Merciful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say thou: obey Allah and the apostle if thereafter they turn away. then verily Allah loveth not the infidels.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Verily did Allah choose Adam and Nuh and the house of lbrahim and the house of 'lmran out of the worlds\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Progeny, one of the other, and Allah is Hearing, Knowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
Recall what time the wife of 'lmran said my Lord verily have vowed unto Thee that which is in my belly to be dedicated; accept Thou then of me. Verily Thou! Thou art the Hearer, the Knower.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
Then when she brought her forth, she said: my Lord verily have brought forth a female - and Allah knew best that which she had brought forth, - and the male is not as the female, and verily have named her Maryam, and verily seek refuge for her and her progeny with Thee from the Satan the accursed.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Then her Lord accepted her with goodly acceptance and made her grow up with a goodly growth, and He made Zakariyya take care of her. So oft as Zakariyya entered the apartment to see her, he found provision by her. He said: O Maryam! whence hast thou this! She said this is from before Allah. Verily Allah provideth for whomsoever He will without reckoning.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Forthwith Zakariyya prayed unto his Lord my Lord bestow on me from Thine presence a goodly offspring; verily Thou! Thou art the Hearer of prayer.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
Then the angels called unto him even while he stood Praying in the apartment: verily Allah announceth unto thee Yahya confessing to a word from Allah, and a leader, and a chaste and a prophet of the righteous one.\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: my Lord! in what wise shall there be unto me a youth whereas age hath overtaken me and my wife is barren. Allah said: even so: Allah doeth whatsoever He listeth.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: my Lord! appoint unto me a sign. Allah said: thy sign is that thou shalt not speak unto mankind for three days save by beckoning; and remember thy Lord much and hallow Him in the evening and morning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And recall what time the angels said: O Maryam! verily Allah chose thee and purified thee and chose thee above the women of the worlds.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
Maryam! be devout unto thy Lord, prostrate thyself, and bow down with them that bow down.\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is of the tidings of things hidden which We reveal unto thee and thou wast not with them when they cast their reeds as to which of them should take care of Maryam, nor wast thou with them when they disputed.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
Recall what time the angels said: Maryam! verily Allah announceth unto thee a word from Him: his name Shall be the Masih, Isa, son of Maryam, illustrious in the world and the Hereafter and one of those brought nigh.\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
And he shall speak unto mankind from the cradle and in maturity; and be one of the righteous.\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: my Lord! in what wise shall there be unto me a son whereas no human being hath touched me. Allah said: even so. Allah createth whatsoever He will, When He hath decreed a thing, He only saith to it: Be, and it becometh;\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He shall teach him the Book and wisdom and the Taurat and the Injil:\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
And an apostle Unto the children of Israi'l with this message: verily have come unto you with a sign from your Lord, verily I form for you out of clay as though the likeness of a bird and then I breathe thereunto, and a bird it becometh by Allah's command. And heal the blind from birth and the leprous and quicken the dead by Allah's command. And I declare unto you that which ye have eaten and that which ye have stored in your houses. Verily herein is a sign for you if ye are believers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
And I come confessing to the Taurat that was before me, and to allow unto you some of that which was forbidden unto you. So And I have come unto you with a sign from your Lord wherefore fear Allah and obey me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Verily Allah is my Lord; and your Lord, wherefore worship Him; this is the straight path.\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
Then when 'Isa perceived in them infidelity, he said: who will be my helpers unto Allah! The disciples said; we are helpers of Allah; we believe in Allah and bear thou witness that verily we are Muslims.\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Our Lord! we believe in that which Thou hast sent down, and, follow the apostle; write us up wherefore with the witnesses.\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And they plotted, and Allah plotted, and Allah is the Best of plotters.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
Recall what time Allah said: O 'Isa! verily I shall make thee die, and am lifting thee to myself and am purifying thee from those who disbelieve, and shall place those who follow thee above those who disbelieve until the Day of Resurrection; thereafter unto Me shall be the return of you all, then I shall judge between you of that wherein ye were wont to differ.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
Then as for those who disbelieved I shall torment them with a severe torment in the world and the Hereafter, nor shall have they any helpers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
And as for those who believed and worked righteous works, He shall repay them their hires in full, and Allah loveth not the wrong-doers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This which we recite unto thee is of the signs and of the wise admonition.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Verily the likeness of 'lsa with Allah is as the likeness of Adam: him He created out of dust, thereafter He said unto him: Be, and lo! he becometh.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
This is the truth from thy Lord, wherefore be thou not of those who dubitate.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
Wherefore those who contend with thee therein after that which hath come unto thee of the knowledge - say thou: come! let us call our sons and your sons, and our women and your women, and ourselves and yourselves, then let us humbly pray, and invoke the curse of Allah upon the liars.\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
Verily this! it is the true recital; and God there is none save Allah, and verily Allah! He is the Mighty, the Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
But if they turn away, then Allah is Knower of the corrupters.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say thou: O people of the Book! come to a word common between us and between you; that we shall worship none save Allah's and that we shall not associate aught with Him, and that none of you shall take others as Lords beside Allah. Then if they turn away, say: bear witness that verily we are Muslims.\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O people of the Book! wherefore contend ye concerning Ibrahim, whereas the Taurat and the Injil were not sent down save after him! Will ye not then under stand?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Ah! ye are those who fell to contending respecting that whereof ye had some knowledge, wherefore then should ye contend respecting that whereof ye have no knowledge! And Allah knoweth, and ye know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Ibrahim was not a Jew, nor a Nazarene, but he was an upright Muslim, nor was he of the associators.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Verily the nearest of mankind to Ibrahim, surely those who followed him, and this prophet, and those who believe; and Allah is the Patron of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
Pain would a party of the people of the Book lead you astray, and none they lead astray save themselves, and they perceive not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O people of the Book! wherefore disbelieve ye in the revelations of Allah whereas ye bear witness?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O people of the Book! wherefore confound ye the truth with falsehood, and hide the truths While ye know?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a Party of the people of the Book say: believe in that which hath been sent down unto those who have believed, at the break of day, and disbelieve at the close thereof, haply they may turn away;\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And believe not save one who followeth your religion. Say thou: verily the guidance of Allah - that is the guidance. Envy ye that any one should be vouchsafed the like of that which was vouchsafed unto you or fear ye that those others may overcome you in Contention before your Lord! Say thou: verily the grace is in the hand of Allah He vouchsafeth it unto whomsoever He will; and Allah is Bounteous, Knowing.\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He singleth out for His mercy Whomsoever He will; And Allah is the Owner of mighty Grace.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
And of the people of the Book is he whom if thou trustest with a talent, he will restore it unto thee, and among them is he whom if thou trustest with a dinar, he will not restore it unto thee except thou art ever standing over him that is because they say there is in the matter of the illiterates no call on us. And they forge a lie against Allah while they know.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Aye whosoever keepeth his covenant and feareth Allah--then verily Allah loveth the God-fearing.\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Verily those who barter Allah's covenant and their oaths at a Small price- no portion is theirs in the Hereafter; nor shall Allah speak unto them or look at them on the Day of Resurrection, nor shall He cleanse them, and theirs shall be a torment afflictive.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And verily among them, are a party who pervert the Book with their tongues, that ye might deem it of the Book whereas it is not of the Book. And they say it is from God; whereas it is not from Allah, and they forge a lie against Allah while they know.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not Possible for a human being unto whom Allah hath vouchsafed the Book and Wisdom and prophethood that he should thereafter say unto men: be ye worshippers of me, beside Allah; but be ye faithful servants of the Lord, seeing that ye are wont to teach the Books and seeing that ye are wont to exercise yourselves therein.\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
And he would not command you that ye should take the angels and the prophets for lords. Would he command you to infidelity after ye are become Muslims?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And recall what time Allah took a bond from the prophets saying whatever I vouchsafed unto you of Book and Wisdom, end, thereafter there cometh unto you an apostle confessing to that which is with you, ye shall surely believe in him and succour him. He said: assent ye, and take ye My burthen thereunto They said: we assent. He said: then bear Witness, and I, with you among the witnesses.\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Wherefore whosoever shall turn away thereafter -those then! they are the transgressors.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Seek they then other than the religion of Allah Whereas unto Him hath submitted whosoever is in the heavens and the earth willingly or unwillingly, and unto Him shall they all be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say thou: we believe in Allah and in that which is sent down unto us, and that which was sent down unto Ibrahim and Isma'il and Is-haq and Ya'qub and the tribes, and that which was vouchsafed unto Musa and 'Isa and other prophets from their Lord: we differentiate not between any of them, and unto Him we are submistive.\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whosoever will seek a religion other than Islam, it shall not be accepted of Him, and he shall be of the losers in the Hereafter.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who disbelieved after their belief and after they bore witness that the apostle was true and after evidences had come unto them! And Allah guideth not a wrong-doing people.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
These! their meed is that on them shall be the curse of Allah and of angles and of mankind, all;\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
Abiders therein, their torment shall not be lightened nor shall they be respited.\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Save such shall repent thereafter and amend; verily Allah is Forgiving, Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Verily those who disbelieve after they have believed and thereafter wax in infidelity, their- repentance shall by no means be accepted. These! they are the straying ones.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Verily those who disbelieve and die while they are infidels, not an earthful of gold shall be accepted from any such, were he to offer it as a ransom. These! theirs shall be a torment afflictive, nor shall they have any helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
O Ye shall not attain unto virtue until ye expend of that which ye love; and whatsoever ye expend, verily Allah Is thereof Knower.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
Every foods was allowable unto the Children of Isra'il, save that which Isra'il had forbidden unto himself, ere the Taurat was revealed. Say thou: bring ye then the Taurat and recite it, if ye say sooth.\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Then whosoever fabricateth after this, lie against Allah - these! they are the wrong-doers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say thou: Allah hath spoken the truth; follow therefore the faith of Ibrahim the upright; and he was not of the associators.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Verily the first House set apart unto mankind was that at Bakka, blest, and a guidance unto the worlds.\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
Therein are signs manifest, the station of Ibrahim. And whosoever entereth it shall be secure. And incumbent on mankind is pilgrimage to the House for that good-will of Allah: on him who is able to find a way thereunto. And whosoever disbelieveth, then verily Allah is Independent of the worlds.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say thou: O People of the Book! wherefore disbelieve ye in the revelations of Allah, whereas Allah is witness of that which ye work!\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say thou: O people of the Book! wherefore turn ye aside from the way of Allah those who believe, seeking for it crookedness, while ye are witnesses! And Allah is not neglectful of that which ye work.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O Ye who believe! were ye to obey any party amongst those that have been vouchsafed the Book, they would, after your having believed, render you Infidels.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
How can you disbelieve while unto you are recited the revelations of Allah, and in your midst is His apostle! And whosoever holdeth fast to Allah, he is of a surety guided unto a straight path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O Ye who believe! fear Allah with fear due to Him, and die not except ye be Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold ye fast, all of you, to the cord of Allah, so and separate not. And remember Allah's favour unto you in that ye were enemies and He joined your hearts together, so ye became by His favour brethren; and ye were on the brink of an abyss of the Fire and He rescued you therefrom. In this wise Allah expoundeth unto you His revelations that haply ye may remain guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And let there be of you a community calling others to good and commanding that which is reputable and prohibiting that which is disreputable. And these they are the blissful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And be not like unto those who separated and differed among themselves after there had come unto them evidences. These! for them shall be a torment mighty.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On a day whereon faces become whitened and faces become blackened. Then as for those whose faces shall have become blackened: disbelieved ye after your profession of belief! taste the torment for that ye have been disbelieving.\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
And as for those whose faces shall have become whitened-- they shall be in Allah's mercy; therein they shall be abiders.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are revelations of Allah; We rehearse them unto thee with truth, and Allah intendeth not wrong unto the worlds.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
Allah's is whatsoever is in the heavens and in the earth; and unto Allah shall be committed all affairs.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
O Ye are the best community sent forth unto mankind; ye command that which is reputable and ye prevent that which is disreputable. and ye believe in Allah If the people of the Book believe, surely it were better for them. Of them are believers, and most of them are transgressors.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They shall not be able to harm you save with small hurt, and if they fight you, they shall turn upon you their backs; then they shall be succoured not.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
Stuck upon them is abjection wheresoever they may be come upon, except in a compact with Allah and a compact with men; and they drew upon themselves indignation from Allah; and stuck upon them is poverty. That is because they have been disbelieving in the signs of Allah, and slaying the prophets without justice. That is because they disobeyed and have been trespassing.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
Not are they all alike. Of the people of the Book there are a community steadfast, reciting the revelations of Allah in the hours of night while they prostrate themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
And they believe in Allah and the Last Day and command that which is reputable and prohibit that which is disreputable, and vie with each other to virtues. And these are of the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatsoever they do of virtue shall not be denied. And Allah is Knower of the God-fearing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Verily those who disbelieve, neither their riches nor their progeny shall avail them aught against Allah. And these are the fellows of the Fire; thereinto they shall be abiders.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The likeness of that which they expend in this life of the world is as the likeness of a wind wherein is intense cold, it befalleth the tilth of a people who have wronged themselves, and destroyeth it. Allah wronged them not, but themselves they wrong.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O Ye who believe! take not for an intimate anyone besides yourselves; they shall not be remiss in doing you mischief. Fain would they that which distresseth you. Surely their malice hath shewn itself by their mouths, and that which their breasts conceal is greater still. Surely We have expounded unto you the signs, if ye will but reflect.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Lo! it is you who love them whereas they love you not, and you believe in the Book, all of it. When they meet you, they say: we believe. And when they are alone, they bite their fingertips at you in rage. Say thou: die in your rage. Verily Allah is Knower of that which is in the breasts.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If there happenoth unto you any good it grieveth them, and if there happenoth unto you an ill, they rejoice thereat. And if ye remain persevering and God-fearing their guile shall not harm you at all. Verily Allah is of that which they work Encompasser.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And recall what time thou settedst forth from thy household early to settle believers in positions for the fight. And Allah is Hearing, Knowing.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
Recall what time two sections of you bethought that they should flag whereas Allah was the Patron of the twain. In Allah, then, let the believers trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
And assuredly Allah had succoured you at Badr While ye were humble. Wherefore fear Allah that haply ye may return thanks.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
And Recall what time thou saidst to the believers: sufficieth it not unto that your lord should reinforce you with three thousand angels sent down.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
O Yea! if ye but remain persevering and God-fearing, and they should come upon you in this rush of theirs, your Lord shall reinforce you with five thousand angels marked.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
And this Allah made not except as a joyful enunciation unto you, and that thereby your hearts might be set at rest--and no succour is there but from before Allah, the Mighty, the Wise.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He may cut: off a portion of those who disbelieve, or abase them so that they may go back disappointed.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
Not with thee is aught of the affair: He shall either relent toward them or torment them, for verily they are wrong-doers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
Allah's is whatsoever is in the heavens and whatsoever is in the earth. He forgiveth whomsoever He listeth, and tormenteth whomsoever He listeth. And Allah is Forgiving, Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O Ye who believe! devour not multiplied manifold; and fear usury, Allah, haply ye may fare well.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And beware of the Fire gotten ready for the infidels.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the apostle, haply ye may be shewn mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And vie with each other in hastening to obtain forgiveness from your Lord and toward the Garden whereof the width equalleth the heavens and the earth, gotten ready for the God- fearing\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who expend in weal and woe, and the repressors of rage and the pardoners of men; and Allah loveth the doers of good.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those, who, when they have done an ill-deed or wronged themselves, remember Allah and ask forgiveness of their sins - and who forgiveth sins save Allah! Is --and persist not in that which they have done, while they know.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
Those! their meed is forgiveness from their Lord and Gardens whereunder rivers flow; they shall be abiders therein. Excellent is the hire of the workers!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Dispensations have gone forth before you go about then on the earth, and behold what wise hath been the end of the beliers!\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This in exposition unto mankind and a guidance and an admonition unto the God-fearing.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
And faint not, nor grieve; ye shall overcome, if ye are believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If there hath befallen you a sore, a sore like thereunto hath already befallen that people. These are the haps that We change about among man kind, that Allah may know those who believe and may take martyrs from among you and Allah loveth not the wrong doers.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And that Allah may purge those who believe and destroy the infidels.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Or, deem ye that ye shall enter the Garden while yet Allah hath not known those of you who have striven hard nor yet known the steadfast!\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
And assuredly ye were wont to long for death ere ye had met it. Now ye are beholding it even while ye are looking on.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
And Muhammad is naught but an apostle; apostles have surely passed away before him. Will ye then, if he dieth or be slain, turn round on your heels! And whosoever turnoth round on his heels, hurteth not Allah at all. And anon shall Allah recompense the grateful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
It is not Possible for any person to die except by Allah's command at a term recorded. And whosoever desireth the reward of the world, We vouchsafe unto him thereof. and whosoever desireth the reward of the Hereafter, We vouchsafe unto him thereof. And anon will we recompense the grateful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And many a prophet hath fought With a number of godly men beside him. They fainted not for aught that befell them in the way of Allah, nor they weakened, nor they humbled themselves; and Allah loveth the steadfast.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
And their speech was naught but that they said: our Lord! forgive us our sins and our extravagance in our affairs, and make our foothold firm, and make us triumph over the disbelieving people.\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
Wherefore Allah vouchsafed unto them the reward of the World, and the excellent reward of the Hereafter. And Allah loveth the well-doer.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O O Ye who believe! if ye obey those who disbelieve, they will send you back on your heels, and ye will turn back losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
But: Allah is your Friend, and He is the Best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
Anon shall We cast a terror into the hearts of those who disbelieve, for they have associated with Allah that for which Allah hath sent down no warranty, and their resort is the Fire: vile is the abode of the wrong-doers!\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
And Allah had assuredly made good His promise unto you when ye were extirpating them by His leave, until when ye flagged and ye disagreed about the command and ye disobeyed after He had shewn you that for which ye longed. Of you some desired the World and of you some desired the Hereafter, wherefore He turned you away from them that he might prove; and of a surety He hath pardoned you And Allah is Gracious unto the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
And recall what time ye were running off and would not look back on any one, albeit the apostle In your rear was calling unto you. Wherefore He caused sorrow to overtake you for sorrow. that ye might not grieve for that which ye might lose nor for that which might befall you. And Allah is Aware of that which ye Work.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then, after sorrow, He sent down unto you a security-- slumber coming over a section of you; While anot her section, concerned about themselves, bethought of Allah unjustly: the thought of paganism. They said: have we aught at all of the affair? Say thou: the affair is wholly Allah's. They hide within themselves that which they disclose not unto thee, saying: had we aught of the affair, we would not have been slain here. Say thou: had ye stayed in your houses, even then those decreed to be slain would surely have gone forth to their places of slaughter; and this happened in order that he might prove that which was in your breasts, and purge that which was in your hearts; and Allah is Knower of that which is in the breasts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
As for those of you who turned back on the day the two hosts met, it was the Satan who made them slip because of something they had earned; and of a surety Allah hath pardoned them. Verily, Allah is Forgiving, Forbearing.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O O Ye who believe! be not like unto those who disbelieve and say of their brethren when they journey in the land or go to religious war: had they been with, they had not died nor had they been slain; this is in order that Allah may cause an anguish in their hearts. And it is Allah who maketh alive and causeth to die, and Allah is of that which ye work Beholder.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
Verily if ye be slain in the way of Allah or die, forgiveness from Allah and mercy are surely better than that which they amass.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
And whether ye die or be slain, assuredly unto Allah shall ye be gathered.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
It was then of the mercy of Allah that thou hast been gentle with them; and wert thou rough, hardhearted, they had surely dispersed from around thee. So pardon them thou, and ask thou forgiveness for them and take thou counsel with them in the affair, and when thou hast resolved, put thy trust in Allah. Verily Allah loveth the trustful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah succoureth you, there is none that can overcome you; if He abandon you, who is there that can succour you after Him? And in Allah let the believers trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not the part of a prophet to hide anything away: whosoever hideth anything away, he shall bring forth on the Day of Resurrection that which he had hidden away; then shall each one be repaid in full that which he hath earned, and they shall not be wronged.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is then one who followeth the pleasure of Allah like unto him who hath settled under the displeasure of Allah? His resort is Hell, and ill is that destination\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
Of diverse degrees shall be they with Allah, and Allah is Beholder of that which they work.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Assuredly Allah hath conferred a benefit on the believers when He raised up unto them an apostle from amongst themselves, he rehearseth unto them His revelations and purifieth them and teacheth them the Book and wisdom, and afore they were in an error manifest.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
Is its that when a reverse hath befallen you, albeit ye had inflicted twice as much, ye say: whence is this? Say thou: it is but from yourselves verily Allah is over everything potent.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
And that which befell you on the day whereon the two hosts met was by Allah's leave, and that he might know the believers.\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that he might know those who played the hypocrite. And it was said unto them: come ye, fight in the way of Allah or defend. They said: if we knew it was to be a fair fight We would surely have followed you. Nearer were they on that day to infidelity than to belief. They say with their mouths that which is not in their hearts and Allah knoweth best that which they conceal.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
They say of their brethren, while they themselves staid: had they obeyed us they had not been slain. Say thou: then repel death from yourselves if ye say sooth.\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
And reckon not thou those slain in the way of Allah to be dead. Nay, they are alive, and with their Lord, and provided for.\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
Exulting in that which Allah hath vouchsafed them of His grace. And they rejoice in those who have not yet joined them from behind them, in the thought that unto them no fear shall come, nor shall they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice at the favour of Allah and His grace, and that verily Allah wasteth not the hire of the believers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who answered to the call of Allah and the apostle after the wound that befell them --for those who did well among them and feared God shall be a mighty hire-\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those unto whom when certain men said: verily the people have mustered strong against you, so be afraid of them, it only increased them in belief, and they said: sufficient unto us is Allah, and an excellent Trustee is He!\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
They then returned with a favour from Allah and His grace: no evil touched them: and they followed Allah's pleasure and Allah is Owner of mighty grace.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is only that the Satan frighteth you of his friends, wherefore fear them not, but fear Me, if ye are believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And let not those grieve thee who hasten toward infidelity; verily they shall not harm Allah at all. Allah desireth not to provide for them a portion in the Hereafter; and theirs shall be a torment mighty.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Verily those who have purchased infidelity for belief shall not hurt Allah at all, and theirs shall be a torment afflictive.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not those who disbelieve deem that We respite them for their good: We respite them only that they may increase in sin; and theirs shall be a torment ignominious.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah is not one to leave the believers in the state wherein ye are until He hath discriminated the impure from the pure. And Allah is not one to acquaint you with the Unseen, but Allah chooseth him whomsoever He willeth, of His apostles. Believe wherefore in Allah and His apostles; and if ye believe and fear, yours shall be a mighty hire.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who stint with that which Allah hath vouchsafed them in His grace deem that this is good for them: nay! it is bad for them; anon shall that wherewith they stint be hung round their necks on the Day of Judgement. And Allah's is the heritage of the heavens and the earth; and Allah is of that which ye work Aware.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Assuredly Allah hath heard the saying of those who say: verily Allah is poor and we are rich. Surely We shall write down that which they have said and their slaying of the prophets with- out justice, and We shall say taste the torment of the burning.\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
That is for that which your hands have sent on afore, for verily Allah is not a wronger of His bondmen.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
There are those who say. verily God hath covenanted with us that we should believe not in an apostle until he bring unto us a sacrifice which a fire shall devour. Say thou: surety there came unto you apostles before me with evidences and with that which ye speak of, wherefore then did ye slay them, if ye say sooth?\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
If then they belie thee, even so were belied apostles before thee who came with evidences and scriptures, and the luminous Book.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul Shall taste of death and only on the Day of Resurrection ye will be repaid your hire in full. Then whosoever shall be removed far away from the Fire and made to enter into the Garden, he indeed hath achieved the goal; and the life of the world is naught but an illusory enjoyment.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
O Ye shall surely be proven in your riches and in your lives; and will surely bear much hurt from those who were vouchsafed the Book before you and from those who associate gods, and if ye endure and fear, then verily that is of the commandments determined.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And recall what time Allah took a bond from those who were vouchsafed the Book: ye shall surely expound it to the people and ye shall hide it not; whereafter they cast it behind their backs, and bartered it for a small price. Vile is that wherewith they have bartered.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Bethink not thou that those who exult in that which they have brought and love to De praised for that which they have not done, - bethink not thou that they shall be in security from the torment! And theirs shall be a torment afflictive.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
Allah's is the dominion of the heavens and the earth. and Allah is over everything Potent.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Verily in the creation of the heavens and the earth and in the alter nation of the night and the day are signs Unto the men of understanding.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Who remember- Allah Standing and sitting and lying on their sides, and reflect on the creation of the heavens and the earth: our Lord Thou createdest not all this in vain. Hallowed be Thou! Save us, Thou, from the torment of the Fire!\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord verily whomsoever Thou makest to enter into the Fire, him Thou hast surely humiliated and for the wrong-doers there shall be no helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord verily we heard a caller calling to belief: believe in your Lord, wherefore we have come to believe. Our Lord forgive us our sins, and expiate from us our misdeeds, and let us die along with the pious.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
Our Lord! vouchsafe unto us that which Thou hast promised us by Thine apostles, and humiliate us not on the Day of Resurrection. Verily Thou failest not the tryst.\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
Then their Lord hearkened unto them saying: I let not the work of a worker amongst you to waste, man or woman, one of you from the other. So those who emigrated and were driven forth from their homes and persecuted in My cause, and who fought and were slain, surely I shall expiate from them their misdeeds and surely I shall make them enter Gardens whereunder rivers flow; a reward from before Allah! And Allah! with Him is the excellent reward.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let not beguile thee the moving to and fro about of those who disbelieve, in the cities\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
A brief enjoyment, and then Hell shall be their abode; ill is the resort!\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But as to those who fear their Lord, theirs shall be Gardens whereunder rivers flow; they shall be abiders therein: an entertainment from before their Lord; and that which is with Allah it still better for the pious.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And verily of the people of the Book there are some who believe in Allah and in that which hath been sent down unto you and that which hath been sent down unto them, humbling themselves before Allah, and barter not the revelations of Allah for a small price, these they shall have their hire with Allah. Verily Allah swift in reckoning.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O Ye who believe! persevere, and excel in perseverance and be ever ready, and fear Allah that haply ye may thrive.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O ye mankind! fear your Lord; Who created you of a single soul and He created the reef the spouse thereof, and of the twain He spread abroad men manifold and women. And fear Allah by Whom ye importune one anot her, and the wombs. Verily Allah is ever over you a Watcher.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give unto the orphans their substance, and substitute not the bad for the good; and devour not their substance by adding it to your substance; verily that is a great crime.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if ye apprehend that ye may not deal justly with the orphan girls, then marry such as please you, of other Women, by twos and threes or fours, but if ye apprehend that ye shall not act justly, then marry one only, or that which your right hand own that Will be more fit, that ye may swerve not. their\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give unto women dowries as a gift, and if of themselves they give up aught thereof unto you, then eat it in pleasure and profit.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
And give not unto the weak-witted the substance which Allah made a stay for you, but feed them there out, Sand clothe them, and say unto them a reputable saying.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And examine the orphans until they attain the age of wedlock, then if ye perceive in them and discretion, hand over unto them their substance, and consume it not extravagantly or hastily for fear that they may grow. And whosoever is rich, let him abstain, and whosoever is needy let him take thereof reputably. And when ye hand over their substance unto them, call in witnesses in their presence, and sufficeth Allah as a Reckoner.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
Unto males shall be a portion of that which their parents and others near of kin may leave; and unto females shall be a portion of that which their parents and other near of kin may leave, whether it be small or large, a portion allotted.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
And when those of kin are Present at the division and the orphans and the needy, provide for them thereout, and say unto them a reputable saying.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let them beware who, should they leave behind them a weakly progeny, would be afraid on their account; let them, wherefore, fear Allah, and says a proper saying.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Verily those who devour the substance of the orphans wrongously, only devour the fire into their bellies, and anon they shall roast in the Blaze.\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah enjoineth you in the matter of your children; the male will have as much as the portion of two females, but if they be females more than two, then they will have two-thirds of that which he hath left, and if only one, she will have a half; and as far as his parents, each of the twain shall have a sixth of that which he hath left if he have a child, but if he hath no child and his parents be his heirs, then his mother shall have a third; but if he have brothers, then his mother shall have a sixth: all after paying a bequest he may have bequeathed or a debt. Your fathers and your sons - ye know not which of them is higher unto you in benefit: an ordinance this from Allah, verily Allah is Knowing, Wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
And ye will have half of that which your wives may leave, if they have no Child, but if they have a child then ye shall have one- fourth of that which they may leave, after paying a bequest they may have bequeathed or a debt. And they shall have one-fourth of that which ye may leaves if ye have no child; but if ye have a child then they will have one-eighth of that which ye may leave, after paying a bequest ye may have bequeathed or a debt. And if a man or a woman who leaveth the heritage hath no direct heirs but hath a brother or a sister, each of the twain will have a sixth; and if more than one, then they will have equal shares in one third after paying a bequest they may have bequeathed or a debt without prejudice: an ordinance this from Allah; and Allah Is Knowing, Forbearing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the statutes of Allah, and whosoever obeyeth Allah and His apostle, him He shall cause to enter the Gardens whereunder rivers flow, as abiders therein; and that is an achievement mighty.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
And whosoever disobeyeth Allah and His apostle, and transgresseth His statutes, him He shall cause to enter the Fire, as an abider therein; and unto him shall be a torment ignominous.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
As for those of your women who may commit whoredom, call against them four witnesses from among them if they testify, confine you them to their houses till death complete their turn of life, or Allah appoint for them some other way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And as for those twain of you who commit it, hurt them both; then, if they repent and amend, turn away from them; verily Allah is Relenting, Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
With Allah is the repentance of those alone who do an evil foolishly and thereafter repent speedily, surely it is they unto whom Allah shall relent. And Allah is Knowing, Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
And repentance is not for those who go on working evil until when death presenteth itself unto one of them, and he saith: verily now I repent; nor for those who die while they are infidel. These! for them We have gotten ready a torment afflictive.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O Ye who believe! it is not allowed unto you that ye may heir the women forcibly; nor shut them up that ye may take away from them part of that which ye had given them, except when they be guilty of manifest enormity. And live with them reputably if ye detest them, belike ye detest a thing and yet Allah hath placed therein abundant good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
And if ye intend to replace a wife by anot her, and ye have given the one of them a talent, take not back aught therefrom. Would ye take it back by slander and manifest sin.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how can ye take it back when one of you hath gone in unto the other, and they have obtained from you a rigid bond!\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And wed not of women those whom your fathers had wedded, except that which hath already passed. Verily it hath been an indecency and an abomination and an evil way:\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden unto you are your mothers and your daughters and your sisters and your father's sisters and your mother's sisters, and your brother's daughters and your sister's daughters. and your foster mothers and your foster sisters, and the mothers of your wives and your step-daughters, that are your wards, born of your wives unto whom ye have gone in, but if ye have not gone in unto them, no sin shall be on you, and the wives of your sons that are from your own loins, and, also that ye should have two sisters together, except that which hath already passed; verily Allah is ever Forgiving, Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
And also forbidden are the wedded among women, save those whom your right hands own Allah's rescript for you. And allowed unto you is whatsoever is beyond that, so that ye may seek them with your substances as properly wedded men, not as fornicators. Then whomsoever of them ye have enjoyed, give them their dowers stipulated. And there will be no blame on you in regard to aught on which ye mutually agree after the stipulation; verily Allah is Knowing, Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whosoever of you has not ampleness of means that he may wed free believing women, let him wed such of the believing bondswomen as the right hands of you people own. And Allah noweth well your belief, ye are one from the other. O Ye may wed them then, with the leave of their owners, and give them their dowers reputably as properly wedded women, not as fornicateresses, nor as those taking to themselves secret paramours. And when they have been wedded, if they commit an indecency, on them the punishment shall be a moiety of that for free wedded women. This is for him among you, who dreameth perdition; and that ye should abstain is better for you, and Allah is Forgiving, Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah intendeth to expound unto you and to guide you into the dispensations of those before you and relent toward you. And Allah is Knowing, Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
And Allah intendeth to relent toward you, and those that follow lusts intend that ye shall incline a mighty inclining.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah intendeth that he shall lighten unto you, and man hath been created weak.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O Ye who believe! devour not your substance among yourselves unlawfully, but let it be a trading among you by mutual agreement. And slay not yourselves, verily Allah is unto you ever Merciful.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whosoever doth that in transgression- and wrong, presently We shall roast him in Fire; and with Allah that is ever easy.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If ye shun the grievous sins from which ye are prohibited, We shall expiate from you your misdeeds, and make you enter a noble Entrance.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And long not for that wherewith Allah hath preferred one of you above anot her Unto men shall be the portion of that which they earn, and unto women shall be the portion of that which they earn. And ask Allah for some of His grace, verily Allah is of everything Knower.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And unto each We have appointed inheritors of that which the parents or the near of kin leave behind, and unto those with whom ye have made your pledges give their portion. Verily Allah is ever of everything a Witness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are overseers over women, by reason of that wherewith Allah hath made one of them excel over anot her, and by reason of that which they expend of their substance. Wherefore righteous women are obedient, and are watchers in husbands absence by the aid and protection of Allah. And those wives whose refractoriness ye fear, exhort them, and avoid them in beds, and beat them; but if they obey you, seek not a way against them; verily Allah is ever Lofty, Grand.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
And if ye fear a divergence between the twain, set up an arbiter from his household and an arbiter from her household; then if the twain desire rectification Allah shall bring harmony between the twain; verily Allah is ever Knowing, Aware.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
And worship Allah and associate not aught with Him; and unto parents show kindness, and also unto kindred and orphans and the needy and the near neighbour and the distant neighbour and the companion by your side and the wayfarer and those whom your right hands own Verily Allah loveth not one who is vainglorious, boaster-\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Those who are niggardly and command mankind to niggardliness and hide that which Allah hath vouchsafed unto them of His grace; and We, have gotten ready for the infidels a torment ignominous;\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And those who expend of their substance for show of men, and believe not in Allah nor in the Last Day; and whosoever hath for him Satan as a companion, a vile companion hath he!\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what would befall them were they to believe in Allah and the Last Day and expend out of that wherewith Allah hath provided them? And of them Allah is ever the Knower.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Verily Allah wrongeth not any one a grain's weight, and if there is a virtue He shall multiply it and give from His presence a mighty hire.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How will it be then, when We shall bring, out of each community, a witness, and We shall bring thee against these as a witness?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
That Day those who had disbelieved and disobeyed the apostle would fain that the earth would be levelled over them, and from Allah they will not be able to hide any discourse.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O Ye who believe! approach not prayer while ye are intoxicated until ye know that which ye say, nor yet while ye are polluted, save when ye be way faring, until ye have washed your selves. And if ye be ailing or on a journey, or one of you cometh from the privy have touched women, or ye and ye find not water, then betake your selves to clean earth and wipe your faces and your hands therewith; verily Allah is ever Pardoning, Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Observest thou not those unto whom was vouchsafed a portion of the book purchasing error, and desiring that ye would err as regards the way!\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
And Allah is Knower of your enemies. Sufficieth Allah as a Friend and sufficieth Allah as a Helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Of those who are Judaised, are they who pervert Words from their meanings and say: We hear and we disobey, and: hear thou without being made to hear, and RA'INA, twisting their tongues and scoffing at the faith! And had they said: we hear and obey, and: hear thou, and: UNZURNA, it had surely been better for them and more upright. But Allah hath cursed them for their infidelity, wherefore they shall not believe, save a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O Ye who are vouchsafed the Book believe in that which We have sent down confirming that which is with you, ere We alter countenances and turn them into their hinder parts, or We might curse them even as We cursed the fellows of the Sabt; and Allah's command is ever fulfilled.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Verily Allah shall not Forgive that aught be associated with Him, and He will forgive all else unto whomsoever He listeth. And whosoever associateth aught with Allah, he hath of a surety fabricated a mighty sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Hast thou not observed those who hold themselves purified Nay! Allah purifieth whomsoever He will, and they shall not be wronged a whit.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Behold how they fabricate a lie against Allah! and sufficeth that as a manifest sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Hast thou not observed those unto whom is vouchsafed a portion of the Book testifying to idols and devils, and saying of those who have disbelieved: these are better guided as regards the way than the believers?\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
These are they whom Allah hath cursed; and whomsoever Allah curseth, for him thou shalt not find a helper.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Is theirs a portion of the dominion? In that case, they would not give the people a speck.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or envy they the people on account of that which Allah hath vouchsafed unto them out of His grace! so, surely We vouchsafed unto the house of Ibrahim the Book and the wisdom and We vouchsafed unto them a mighty dominion.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
Then of them were some who believed therein, and of them were some who turned aside therefrom, and Hell -will suffice as a Flame.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Verily those who disbelieve in Our revelations, presently We shall roast them into Fire. So oft as their skins are cooked We shall change them for other skins, so that they may keep on tasting the torment verily Allah is ever Mighty, Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
And those who believe and work righteous works, anon We shall cause them to enter the Gardens whereunder rivers flow as abiders therein for ever. For them shall be spouses purified, and We shall cause them to enter a sheltering shade.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Verily Allah commandeth you that ye shall render dues unto the owners thereof, and that, when ye judge between men, judge with justice. Verily excel lent is that wherewith Allah exhorteth you verily Allah is ever Hearing, Beholding.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O Ye who believe! obey Allah and obey the apostle and owners of authority from amongst you. then if dispute in aught refer it Unto ye Allah and the apostle if ye indeed believe in Allah and the Last Day. That is the best and fairest interpretation.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Hast thou not observed those who assert that they believe in that which hath been sent down unto thee and that which hath been sent down before thee desiring to go to the devil for judgement, whereas they have been commanded to disbelieve in him; and Satan desireth to lead them far astray.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it said unto them come unto that which Allah hath sent down and unto the apostle, thou wilt see the hypocrites hang back far from thee.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How then, when some ill befalleth them because of that which their hands have sent forth and then they come to thee swearing by Allah: we meant naught save kindness and concord.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
These are they of whom Allah knoweth whatsoever is in their hearts: wherefore turn thou from them and exhort them, and say unto them for their souls, effectual saying.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
And not an apostle We have sent but to be obeyed by Allah's command. And if they, when they had wronged their souls, had come unto thee and begged forgiveness of Allah, and the apostle had begged forgiveness for them they would surely have found Allah Relentant, Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
Aye! by thy Lord, they shall not believe until they have made thee judge of that which is disputed among them, and then find no vexation in their hearts with that which thou hast decreed, and they submit with full submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
And had We prescribed unto them: slay yourselves or go forth from your dwellings, they had not done it, save a few of them. And did they do that which they are exhorted to do, it would be for them better and more strengthening.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And then We would surely have vouchsafed unto them from Our presence a mighty hire.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And We would surely have guided them on the right path.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
And whosoever obeyeth Allah and the apostle, then those shall be with them whom Allah hath blessed --from among the prophets, the saints, the martyrs, and the righteous. Excellent are these as a company!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is the grace from Allah, and sufficeth Allah as Knower!\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O Ye who believe! take your precaution then sally forth in detachment or sally forth all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
And verily there Is among you he who laggeth behind, and if an ill befalleth you, he saith: surely Allah hath bestowed favour on me in that I was not Present with them.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
And if there betideth you grace from Allah, then, as though there had been no tenderness between you and him, he saith: would that I had been with them! then I would have achieved a mighty achievement.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let them wherefore fight in the way of Allah those who have purchased the life of this world for the Hereafter: And whosoever fighteth in the way of Allah, and is then slain or overcometh, We shall vouchsafe unto him a mighty hire.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And what aileth you that ye fight not in the way of Allah and for the oppressed among men and women and Children who say: our Lord! take US forth from this town whereof the people are Wrong-doing, and appoint us from before Thee a patron, and appoint us from before Thee a helper!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
These who believe fight in the way of Allah and those who disbelieve fight in the way of the devil. Fight then against the friends of Satan; verily the craft of Satan is ever feeble.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Hast thou not observed those unto whom it was said;. withhold your hands, and establish prayer and give the poor-rate; but when thereafter fighting was prescribed unto them, lo! there is a party of them dreading men as with the dread of Allah, or with greater dread; and they say: our Lord! why hast Thou prescribed unto us fighting! Wouldst that Thou hadst let us tarry a term nearby! Say thou: the enjoyment of the world is little, and the Hereafter is better for him who feareth God; and ye shall not be wronged a whit.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wheresoever ye may be, death shall overtake you, even though ye be in fortresses plastered. And if there betideth them some good, they say: this is from God. And if there betideth them some ill, they say: this is because of thee. Say thou: everything is from Allah. What aileth then this people, that well-nigh they understand not any speech\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatsoever of good betideth thee is from Allah, and whatsoever of ill betideth thee is because of thy self. And We have sent thee unto the mankind as an apostle; and sufficieth Allah as a Witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whosoever obeyeth the apostle hath indeed obeyed Allah, and whosoever turnoth away -We have not sent thee over them as a keeper.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
And they say: Obedience. Then when they so forth from before thee, a part of them plan together by night other than they had said: and Allah writeth down that which they plan by night. Wherefore turn thou from them and trust in Allah and sufficeth Allah as a Trustee.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Ponder then they not on the Qur'an? Were it from other than Allah they would surely find therein many a contradiction.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
And when there cometh unto them aught of security aught of alarm, they bruit it; abroad: whereas had they referred it to the apostle and those in authority among them, then those of them who can think it out would have known it. And had there not been Allah's grace upon you and His mercy, ye would surely have followed Satan, save a few.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Fight thou therefore in the way of Allah thou are not tasked except for thy own soul, and persuade the believers; belike Allah will withhold the violence of those who disbelieve. And Allah is stronger in violence and Stronger in chastising.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whosoever intercedeth with a goodly intercession, his shall be a portion therefrom, and whosoever intercedeth with an ill intercession his shall be a responsibility thereof; and Allah is of everything the Controller.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
And when ye are greeted with a greeting, then greet back with one better than that or return that; verily Allah is of everything the Reckoner.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! there is no god but he. Surely He shall gather you together on the Day of Resurrecticn, whereof there is no doubt; and who is more truthful than Allah in discourse?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What aileth you then, that ye are two parties regarding the hypocrites? whereas Allah hath reverted them because of that which they have earned. Would ye lead aright those whom Allah hath sent astray? And whomsoever Allah sendeth astray, for him thou shalt not find a way.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
Fain would they that ye disbelieved even as they have disbelieved, so that ye may be all alike. Wherefore take not friends from among them until they migrate for the sake of Allah; and if they turn away, then lay hold of them and slay them, wheresoever ye find them, and take not from among them a friend or a helper.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Excepting those who join a people between whom and you there is a bond or who come to you with their breasts straitened that they should fight you or fight their own people. And had Allah so willed, He would have surely set them upon you. If then they withdraw from you, and fight not against you and offer you peace, then Allah openoth not for you against them a way.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
Surely ye will find others desiring, that they may be secure from you and may be secure from their people; and yet so oft as they are brought back into the temptation, they revert thereto. Wherefore if they withdraw not from you, nor offer you peace, nor restrain their hands, lay hold of them and slay them wheresoever ye find them. These: against them We have given you a clear warranty.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to slay a believer except by a mischance; and whosoever slayeth a believer by mischance on him is the setting free of a believing bondman and blood-wit to be delivered to his family except that they forego. Then if he be of a people hostile unto you and is himself a believer, then the setting free of a believing bondman; and if he be of a people between man whom and you is a bond, then the bloodwit to be delivered to his family and the setting free of a believing bondman. Then whosoever findeth not the wherewithal, on him is the fasting for two months in succession: a penance from Allah. And Allah is ever Knowing, Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And whosoever slayeth a believer intentionally, His meed is Hell, as an abider therein; and Allah shall be wroth with him and shall curse him, and shall get ready for him a torment terrible.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O Ye who believe! when ye march forth in the way of Allah, make things clear and say not unto one who giveth you a salutation: thou art none of a believer, seeking the perishable goods of the life of the world; for with Allah are spoils abundant. Even Thus were ye aforetime, then Allah favoured you. So make things clear; verily Allah is of that which ye work ever Aware.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are the holders back among the believers, save those who are disabled, and the strivers in the way of Allah with their- riches and their lives. Allah hath preferred in rank the strivers with their riches and their lives above the holders-back, and unto all Allah hath promised good. And Allah hath preferred the strivers above the holdersback with a mighty hire.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Ranks from Him and forgiveness and mercy; and Allah is ever Forgiving, Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
Verily unto those whom the angels carry off in death, while they are yet oppressors of their souls, they will say: what were ye in? They will say: Weakened were we in the land. They Will say: was not Allah's land wide so that ye could migrate thereto. These: their resort is hell an evil retreat! -\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Excepting the weak ones among men, women and children, unable to find a stratagem and not guided to a way.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
These: belike Allah will pardon them, and Allah is ever Pardoning, Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
And whosoever migrateth in the way of Allah, shall find in the earth plentiful refuge and ampleness; and whosoever goes forth from his house as a fugitive unto Allah and His apostle, and death then overtaketh him his hire hath surely devolved upon Allah, and Allah is ever Forgiving, Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when ye are journeying in the earth there shall be no fault in you that ye shorten the prayer if ye fear that those who disbelieve shall molest you, verily the infidels are ever unto you an avowed enemy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
And when thou art amidst them and hast set up the prayer for them, then let a party of them stand with thee and let them retain their arms; then when they have prostrated themselves, let them go behind you, and let anot her party who have not yet prayed, come and pray with thee; and let them also take their caution and their arms. Pain would those who disbelieve that ye neglected your arms and your baggage, so that they might swoop down upon you at one swoop. And there shall be no fault in you, if there be an injury to you from rain or ye are ailing, that ye lay down your arms and yet take your caution. Verily Allah hath gotten ready for the infidels a torment ignominious.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
Then when ye have finished the prayer, remember Allah, standing and sitting and lying on Your sides. Then when ye are secure, establish the prayer verily the prayer is prescribed unto the believers at definite times.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And slacken not in seeking the enemy people if ye are suffering, then they suffer even as ye suffer, and you hope from Allah that which they hope not; and Allah is ever Knowing, Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Verily We! We have sent down the Book unto thee With truth that thou mightest judge between people by that which Allah hath shewn thee; and be not thou On behalf of the deceivers a pleader.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And beg thou forgiveness of verily Allah is ever Forgiving.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And contend thou not for those who defraud their souls verily Allah loveth not one who is a defrauder, sinner.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They feel ashamed of men and feel not ashamed of Allah, whereas He is Present with them when by night they plan together of discourse which pleaseth Him not; and Allah is of that which they work ever an Encompasser.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Lo! it is ye who have contended for them in the life of the world; then who will contend for them with Allah on the Day of Resurrection, or who shall be their champion?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
And whosoever worketh an ill or wrongeth his own soul, and thereafter beggeth forgiveness of Allah shall find Allah Forgiving, Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And whosoever earnoth a sin, only against his own soul he earnoth it; and Allah is ever Knowing, Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whosoever earnoth a vice or a sin, and thereafter casteth it on an innocent, he hath surely borne a calumny and a manifest sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
Were not the grace of Allah on thee and His mercy, a party of them had surely resolved to mislead thee; whereas they mislead not but themselves, and they shall not hurt thee in aught. And Allah hath sent down unto thee the Book and wisdom, and hath taught thee that which thou knowest not; and the grace of Allah on thee is ever mighty.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
No good is there in much of their whispers except in his who commandeth charity or kindness or reconciliation among mankind; and whosoever doeth this seeking the good-will of Allah, We shall presently give him a mighty hire.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whosoever opposeth the apostle after the truth hath become manifest unto him, and followeth other way than that of the believers, We shall let him follow that to which he hath turned, and shall roast him in Hell - an evil retreat!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Verily Allah shall not forgive that aught be associated with Him, and He will forgive all else unto whomsoever He liketh; and whosoever associateth ought with Allah, hath surely strayed away a far straying.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They invoke beside Him but females, and they invoke not but a Satan rebellious.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Allah hath accursed him. And he said: surely shall take of Thine bondmen a portion allotted.\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
And surely I will lead them and will fill them with vain desires, and I will command them so that they will slit the ears of the cattle, and I will command them so that they will alter the creation of Allah. And whosoever taketh Satan for a patron, instead of Allah, shall surely suffer a manifest loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
The Satan maketh them promises and filleth them with vain desires. and Satan promiseth them not but delusion.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
These: their resort shall be Hell, and they shall not find therefrom an escape.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
And those who believe and work righteous works, anon We shall make them enter Gardens whereunder the rivers flow, as abiders therein for ever: promise of Allah, true. And who is more truthful than Allah in speech?\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
Not by your vain desires nor by the vain desires of the people of the Book; whosoever worketh an evil, shall be requited therewith, and he will not find beside Allah a patron nor a helper.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whosoever worketh of righteous works, male or female, and is a believer, these shall enter the Garden and shall not be wronged a speck.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who can be better in religion than he who submitteth his countenance unto Allah, and sincere, and followeth the faith of Ibrahim, the upright And Allah took Ibrahim for a friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
And Allah's is whatsoever is in the heavens and whatsoever is in the earth; and of everything Allah is ever an Encompasser.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
And they ask thy decree concerning women. Say thou: Allah decreeth unto you concerning them and so do the revelations that have been rehearsed unto you in the Book concerning the orphan women unto whom yes give not that which is prescribed for them and yet desire that ye shall wed them, and concerning the oppressed children, and concerning this, that ye shall deal with the orphans in equity, and whatsoever of good ye de, then verily thereof Allah is ever Aware.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
And if a woman feareth from her husband refractoriness or estrangement, it shall be no blame on the twain if they effect between them a reconciliation; and reconciliation is better. And souls are engrained with greed. And if ye act kindly and fear Him, then verily Allah is ever of that which ye work Aware.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
And ye are not able to deal evenly between the wives, even though ye long to do so, but incline not an extreme inclining so that ye may leave her as one ahanging. And if ye effect a reconciliation and fear Allah, then Allah is ever Forgiving, Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
And if the twain must sunder, Allah shall render the twain independent out of His bounty, and Allah is ever Bountiful, Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
Allah's is whatsoever is in the heavens and whatsoever is in the earth. And assuredly We enjoined those who were vouchsafed the Book before you and yourselves: fear Allah, and if ye disbelieve then Allah's is whatsoever is in the heavens and whatsoever is in the earth; and Allah is ever Self-Sufficient, Praiseworthy.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And Allah's is whatsoever is in the heavens and whatsoever is in the earth, and sufficeth Allah as a Champion.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He will, He will take you away, O mankind! and bring forward others; and over that Allah is ever Potent.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whosoever seeketh the reward of this world, with Allah is the reward of this world and of the Hereafter; and Allah is ever Hearing, Beholding.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O Ye who believe! be ye maintainers of justice, bearers of testimony for Allah's sake, though it be against yourselves or your parents or kindred. Be he rich or poor, Allah is nigher unto either wherefore follow not the passion, lest ye deviate. If ye incline or turn away, then verily of that which ye work Allah is ever Aware.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O Ye who believe believe in Allah's and His apostle and the Book He hath sent down unto His apostle and the Book He sent down aforetime; and whosoever disbelieveth in Allah and His angels and His Books and His Apostles and the Last Day, hath surely strayed away a far straying.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Verily those who believed and then disbelieved, and then believed and then, disbelieved, and thereafter waxed in infidelity ye Allah shall not forgive them nor guide them on the way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Announce thou to the hypocrites that theirs shall be a torment afflictive.\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take infidels for, friends, instead of the believers. Seek thy honour with them verily then honour is Allah's altogether.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
And it hath been revealed to you in the Book that when ye hear Allah's revelations being disbelieved in and mocked at, sit not down with them until they plunge in a discourse other than that; for, then, ye would surely become like unto them. Verily Allah is about to gather hypocrites and infidels in Hell together.\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who wait about you. If then there be victory for you from Allah, they say: were we not with you? And if there is a portion for the infidels, they say: gained we not mastery over you, and kept we not you back from the believers! Allah shall Judge betwixt you On the Day of Judgement, and Allah shall not make for the infidels against the believers a way.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Verily the hypocrites would beguile Allah, whereas it is He who beguileth them,; and when they stand up to prayer, they stand up languidly, making a show to the people, and they remember not Allah but little.\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
Wave ring between this and that; neither for this nor for that and whomsoever Allah sendeth astray, for him thou wilt never find a way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O Ye who believe! take not infidels for friends, instead of believers. Would ye give Allah against you a manifest warranty!\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Verily the hypocrites shall be in the lowest abyss of the Fire; and thou wilt not find for them a helper.\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except those who shall yet repent and amend and hold fast by repent Allah and make their religion exclusive for Allah. These then shall be with the believers, and presently Allah shall give the believers a mighty hire.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What will Allah do with your torment, if ye return thanks and believe? And Allah is ever Appreciative, Knowing.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah approveth not the publishment of evil speech, unless by one who hath been wronged; and Allah is ever Hearing, Knowing.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
Whether ye disclose a good or conceal it, or pardon an evil, then verily Allah is ever Pardoning potent.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Verily those who disbelieve in Allah and His apostles, and would differentiate between Allah, and His apostles, and say: some we believe in and others we deny; and they would take a way in between this and that.\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
These: they are the infidels in very truth, and We have gotten ready for the infidels a torment ignominious.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in Allah and His apostles and differentiate not between any of them, anon We shall give them their hire; and Allah is ever Forgiving, Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The people of the Book ask thee to bring down a Book to them from the heaven. But surely they asked Musa a thing greater than that; they said: shew us God manifestly; whencefore the thunderbolt overtook them for their wrong-doing. Then they took a calf after there had come unto them the evidences. Even so We pardoned that, and We gave Musa a manifest authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We raised the Mount over them for their bond. And We said unto them: enter the portal prostrating yourselves. And We said unto them: transgress not in the matter of the Sabbath and We took from them a firm bond.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
Accursed are they then for their breach of the bond and their rejecting the commandments of Allah and their slaying the prophets without justification, and their saying: our hearts are uncircumcised. Aye! Allah hath set a seal upon them for their infidelity, wherefore they believe not but a little.\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And for their blasphemy and for their speaking against Maryam a mighty calumny.\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And for their saying: verily We have slain the Messiah 'Isa son of Maryam, an apostle of Allah, whereas they slew him not, nor they crucified him but it was made dubious unto them. And verily those who differ therein are in doubt thereof, they have no knowledge thereof; they but follow an opinion; and surely they slew him not.\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
But Allah raised him unto Himself; and Allah is ever Mighty, Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
And there is none among the people of the Book but shall surely believe in him before his death, and on the Day of Judgement he shall be a witness against them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
Wherefore because of the wrongdoing on the part of those who are Judaised We forbade unto them the clean things that had been allowed unto them, and also because of their keeping away many from Allah's way;\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And also because of their taking usury whereas they were prohibited therefrom, and also because of their devouring the riches of men unlawfully. And for the infidels among them We have gotten ready a torment afflictive.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But of them those well-grounded in the Knowledge and the believers believe in that which hath been sent down unto thee and that which hath been sent down before thee, and the establishers of prayer and the givers of the poor-rate and the believers in Allah and the Last Day- those: unto them anon We shall give a mighty hire.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
Verily We have revealed unto thee even as We revealed unto Nuh and the prophets after him, and as We revealed unto Ibrahim and Isma'il and Is-haq and Ya'qub and the tribes, and 'Isa and Ayyub and Yunus and Harun and Sulaiman, and unto Daud We vouchsafed a Scripture.\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
And We Revealed unto apostles of some of whom We have narrated unto thee aforetime and of others of whom We have not narrated unto thee; and unto Musa Allah spake directly.\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
We sent all these apostles as bearers of glad tidings and warners in order that there be no plea for mankind against Allah, after the apostle; and Allah is ever Mighty Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
How be it Allah beareth witness by that which He hath sent down unto thee He sent it down with His own knowledge and the angels also bear witness; and sufficieth Allah as a Witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Verily those who disbelieve and keep others from the way of Allah, have surely strayed far away.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Verily those who have disbelieved and done wrong, Allah is not one to forgive them nor to guide them to any way.\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the way to Hell, as abiders therein for ever, and this unto Allah is ever easy.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O ye mankind! assuredly there hath come unto you the Prophet with the truth from your Lord wherefore believe that it may be well for you. And if ye disbelieve, then verily Allah's is whatsoever is in the heavens and the earth; and Allah is ever Knowing, Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O ye people of the Book; exceed not the bounds in Your religion, and say not of Allah save that which is the truth. The Messiah 'Isa, son of Maryam, is but an apostle of Allah and His word --He cast it upon Maryam-- and a spirit from Him. Believe wherefore in Allah and His apostles, and say not: three. Desist, that it may be well for you. Allah is but the One God: hallowed be He that there should be unto Him a son! His is whatsoever is in the heavens and the earth, and sufficeth Allah as a Trustee.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah disdaineth not that he should be a bondman of Allah, nor do the angels brought near. And whosoever disdaineth serving Him and stiff-necked, anon He shall gather them all unto Him.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
Then as to those who have believed and worked righteous works, He shall give unto them their hire in full and shall give unto them an increase out of His grace. And as to those who disdained and were stiff-necked, He shall torment them with a torment afflictive. And they shall not find for themselves, against Allah, a protecting friend or a helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O ye mankind! there surely hath come unto you a proof from your Lord, and We have sent down unto you a manifest light.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
Then as to those who believe in Allah and hold fast by Him, anon He shall make them enter into a mercy from Himself and grace and shall lead them unto Himself by a path straight.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask thee for pronouncement. Say thou: Allah pronounceth thus in the matter of one without father or child: if a person perisheth and hath no child, but hath a sister, hers shall be the half of that which he hath left: and he shall be her heir if she hath no child, if there be two sisters, then theirs shall be two-third of that which he hath left; and if there be both brothers and sisters, then male shall have as much as the portion of two females. Allah expoundeth unto you, lest ye err; and Allah is of everything Knower.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O ye who believe! fulfil the compacts. Allowed unto you is the beast of the flock except that which is rehearsed unto you, not allowing the chase while ye are in a state of sanctity. Verily Allah ordaineth whatsoever He will.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O ye who believe! profane not the landmarks of Allah nor any sacred month nor the offering nor the victims with the garlands nor those repairing to the Sacred House seeking the grace of their Lord and His goodwill. And when ye have put off the state of sanctity, ye may chase. And let not the hatred against a people, because they kept you from the Sacred Mosque, incite you to trespass. Assist each other to virtue and piety, and assist not each other to sin and transgression, Fear Allah: verily Allah is Severe in chastising.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden unto you are the deadmeat, and blood, and the flesh of the swine, and that over which is invoked the name of other than Allah, and the strangled, and the felled, and the tumbled, and the gored, and that which wild animals have devoured, unless ye have cleansed, and that which hath been slaughtered on the altars, and that ye seek a division by means of the divining arrows: all that is an abomination. To- day those who disbelieve have despaired of your religion; wherefore fear them not, and fear Me. To-day I have perfected for you your religion, and have completed My favour upon you, and am well-pleased with Islam as your religion. Then whosoever is driven to extreme hunger not inclining to sin, verily then Allah is Forgiving, Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask thee as to whatever is allowed unto them. Say thou: allowed unto you are all clean foods, and as to the animals of prey which ye have taught even as Allah hath taught you, eat of that which they have caught for you, and mention the name of Allah over it; and fear Allah, verily Allah is swift in reckoning.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
To-day are allowed unto you all clean foods, and the meat of those vouchsafed the Book is allowable for you, and your meat is allowable for them as also are the wedded believing women and the wedded women of those vouchsafed the Book before you, when ye have given them their dowers, taking them in wedlock, neither fornicating, nor taking them is secret paramours. And who soever rejecteth the faith, his work will surely come to naught, and in the Hereafter he shall be of the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O ye who believe! when ye stand up for the prayer wash your faces and your hands unto the elbows, and wipe your heads, and wash your feet unto the ankles. And if ye be polluted, then purify yourselves And if ye be ailing or on a journey or one of you cometh from the privy or ye have touched women, and ye find not water, then betake yourselves to clean earth and wipe your faces and hands therewith. Allah intendeth not to lay upon you a hardship, but intendeth to purify you and to complete His favour upon you, that haply ye may return thanks.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember Allah's favour on you and His bond wherewith He bound you firmly when ye said: we hearken and we obey. And fear Allah: verily Allah is Knower of that which is in the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O ye who believe! be maintainers of your pact with Allah and witnesses in equity, and let not the hatred of a people incite you not to act fairly; act fairly; that is highest unto piety. And fear Allah; verily Allah is Aware of that which ye work.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah hath promised those who believe and work righteous works that for them shall be forgiveness; and a mighty hire.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
And those who disbelieve and belie Our signs, they shall be the fellows of the Flaming Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O ye who believe! remember Allah's favour on you when a people determined to stretch forth their hands against you, but he withheld their hands from you, And fear Allah, and in Allah let the believers trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
And assuredly Allah took a bond from the Children of Isra'il, and We raised from amongst them twelve wardens. And Allah said: verily I am with you, if ye establish prayer and give the poor-rate and believe in My apostles and support them and lend unto Allah a goodly loan, I shall surely expiate for you your misdeeds and surely shall make you enter the Gardens whereunder rivers flow; then whosoever of you shall disbelieve thereafter, he hath surely strayed from the level way.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
Wherefore for their breach of their bond We accursed them and We made their hearts hard. They pervert the words from the meanings thereof and have abandoned a good portion of that wherewith they were admonished. And thou wilt not cease to light upon defrauding on their part, save a few of them; yet pardon thou them and overlook them, verily Allah loveth the well-doers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And of them who say: verily we are Nazarenes, We took a bond from them, but they have abandoned a good portion of that wherewith they were admonished. Wherefore We have occasioned enmity and hatred amongst them till the Day of Judgement, and presently Allah shall declare unto them that which they have been performing.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O ye people of the Book! surely there hath come Our apostle unto you expounding unto you much in the Book that ye were wont to hide, and much he passeth over. Of a surety, there hath come unto you from Allah a light and a Book luminous.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
Therewith Allah guideth those who follow His goodwill unto the ways of safety, and bringeth them forth out of darkness into the light by His leave, and guideth them onto the right path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
Assuredly they have disbelieved who say. verily God! He is the Masih, son of Maryam. Say thou; who can avail in aught against Allah, if He intended to destroy Masih, son of Maryam, and his mother and thou on the earth altogether? And Allah's is the dominion of the heavens and the earth and that which is in between the twain. He createth whatsoever He will, and Allah is over everything Potent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
And the Jews and the Nazarenes say: we are the children of God and His loved ones. Say thou: wherefore then doth He torment you for your sins? Aye! ye are but men, part of those whom He hath created. He forgiveth whomsoever He will and tormenteth whomsoever He will. And Allah's is the dominion of the heavens and the earth and that which is in- between the twain, and unto Him in the return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O people of the Book! surely there hath come unto you Our apostle, after a cessation of the apostles, expounding unto you, lest ye may say: there came not unto us a bearer of glad tidings nor a warner. So now there surely hath come unto you a bearer of glad tidings and a warner; and Allah is over everything Potent.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And recall what time Musa said unto his people: O my people! remember the favour of Allah on you when he made amongst you prophets and made princes, and vouchsafed unto you that which he vouchsafed not to anyone in the world.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
O my people! enter the holy land which Allah hath prescribed for you and turn not back to your rearward for then ye become losers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said: O Musa! verily therein are a people high handed, and verily we shall never enter it until they go forth therefrom; so if they go forth thence, we shall verily enter in.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Thereupon spake two men of those who feared and whom Allah had favoured; enter ye the gate against them, then as ye enter it ye are the over - and put your trust in Allah, if ye are indeed believers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: O Musa! verily we shall never enter it so long as they remain therein; go thou and thy Lord, and fight ye twain, we shall remain here sitting.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
Said he: my Lord control not but myself and my brother, so decide Thou between us and this transgressing people.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
Said He: verily then it is forbidden unto them for forty years, while they shall wander about in the earth, so mourn not thou over this transgressing people.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And rehearse thou unto them with truth the tale of the two sons of Adam, when the twain offered an offering, and it was accepted from one of them, and was not accepted from the other; he said: surely I will slay thee. Said the other: Allah accepteth only from the God- fearing.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
If thou stretchest forth thine hand against me to slay me, I shall not be stretching forth my hand against thee to slay thee, verily I fear Allah, the Lord of the worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
Verily would that thou bear my sin and thine own sin, and then thou become of the fellows of the Fire; that is the meed of the wrong-doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
Then his soul made the slaying of his brother agreeable to him, so he slew him, and he became of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a raven scratching in the earth to show him in what wise he might cover the corpse of his brother. He said: woe unto me was incapable of being like unto this raven so that I might cover the corpse of my brother! And he became of the remorseful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Because of that We Prescribed unto the Children of Isra'il: whosoever slayeth a person, except for a person, or for corruption in the land, it shall be as through he had slain all mankind, and whosoever bringeth life to one it shall be as though he had brought life to all mankind. And assuredly there came unto them Our apostles with evidences, yet even thereafter many of them are acting on the earth extravagantly.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The meed of those who wage war against Allah and His apostle and go about in the land corrupting is only that they shall be slain or crucified or their hands and feet be cut off on the opposite sides, or be banished from the land. Such shall be their humiliation in the world, and theirs shall be in the Hereafter a mighty torment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Save those who repent ere ye have them in your power; for know that Allah is Forgiving, Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O ye who believe! fear Allah and seek approach unto Him and strive hard in His way, that haply ye may fare well.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
Verily those who have disbelieved, if they had all that is in the earth and with it as much again whereby to ransom themselves from the torment on the Day of Judgement, it shall not be accepted of them, and theirs shall be a torment afflictive.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will desire to come forth from the Fire, but they shall not be able to come forth therefrom, and theirs shall be a torment lasting.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
As for the man-thief and the woman-thief, cut off their hands as a meed for that which they have earned; an exemplary punishment from Allah. And Allah is Mighty, Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
Then whosoever repenteth after his wrong-doing and amendeth, verily Allah shall relent toward him. Verily Allah is Forgiving, Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Knowest thou not that Allah! - verily His is the dominion of the heavens and the earth; He chastiseth whomsoever He will and forgiveth whomsoever He will; and Allah is over everything Potent.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O apostle! let not those grieve thee that hasten after infidelity from among these who say with their mouths: we believe, yet their hearts believe not, and from among those who are Judaised: listeners to falsehoods, listeners to anot her people who come not unto thee; they pervert the words after they have been set in their places, saying: if that which is given you be this accept it, but if that is not given you, beware. And whosesoever temptation Allah Willeth, thou shalt not avail him against Allah in aught. These are they whose hearts Allah would not cleanse; theirs is humiliation in this world and theirs shall be in the Hereafter a mighty torment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
Listeners are they to falsehood, devourers of the forbidden. Wherefore if they come to thee, either judge between them or turn away from them. And if thou turnest away from them, they shall not be able to hurt thee in aught; and if thou judgest, judge between them with equity, verily Allah loveth the equitable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
And how shall they ask thee for judgement, whereas with them is the Taurat wherein is Allah's judgement? And they turn away thereafter? And those are no believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Verily We sent down the Taurat wherein was a guidance and a light. By it the prophets who submitted themselves judged those who were judaised, and so did the divines and the priests by that wherewith they were entrusted of the Book of Allah and they had become witnesses thereof. Wherefore fear not the mankind but fear Me, and barter not My revelations for a small price, And whosoever judgeth not by that which Allah hath sent down - those then they are the infidels.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We prescribed unto them therein: a life for a life, and an eye for an eye, and a nose for a nose, and an ear for an ear, and a tooth for a tooth, and wounds in reprisal, then whosoever forgoeth it, then it shall be for him an expiation. And whosoever judgeth not by that which Allah hath sent down - those then! they are the wrong-doers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And in their footsteps We caused 'Isa, son of Maryam, to follow, confessing to that which had preceded him, the Taurat, and We vouchsafed unto him the Injil wherein was a guidance and a light, confirming that which had preceded it, the Taurat, and a guidance and an admonition unto the God-fearing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
And let the people of the Injil judge by that which Allah hath sent down therein; and whosoever judgeth not by that which Allah hath sent down, then those! - they are the transgressors.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We have sent down the Book unto thee with truth; and confirming that which hath preceded it of the Book, and a guardian thereof. Wherefrom judge thou between them by that which Allah hath sent down, and follow thou not away from that which hath their desires come to thee of the truth. Unto each of you We appointed law and a way. And had Allah listed, He would have made you all a single community, but He willed not in order that he may prove you by that which He hath vouchsafed unto you. Hasten wherefore to the virtues; unto Allah is the return of you all; then He shall declare unto you concerning that wherein ye have been disputing.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And judge thou between them by that which Allah hath sent down, and follow thou not their desires, and beware thou of them lest they tempt thee away from any part of that which Allah hath sent down unto thee. Then if they turn away, then know thou that Allah only intendeth to afflict them for some of their sins. And verily many of the mankind are transgressors.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Seek they then the judgement of Paganism? And who is better than Allah in judgement unto a people who are convinced?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O ye who believe! take not the Jews and the Nazarenes as friends: friends they are to each other: and whosoever of you befriendeth them, verily he is of them; verily Allah guideth not a wrong-doing people.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
Wherefore thou seest those in whose hearts is a disease hasten toward them saying: we fear lest there may befall us a reverse. But belike Allah may bring a victory or some affair from Himself; then they shall find themselves, for which they hide in their souls, remorseful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And those who believe will say: are those they who swear by Allah say their solemn oaths that they were verily with you? Their works came to naught, and they found themselves losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O ye who believe! whosoever of you apostateth from his religion, then presently Allah shall bring a people whom He shall love and who shall love Him, gentle toward the believers, stern toward the infidels, striving hard in the way of Allah, and fearing not the reproof of any reprover. This is the grace of Allah; He bestoweth it on whomsoever He will. And Allah is Bountiful, Knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your friend is but Allah and His apostle and those who have believed- those who establish the prayer and give the poor-rate while they bow down.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whosoever befriendeth Allah and His apostle and those who have believed, then verily the party of Allah! - they are the overcomers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O ye who believe! take not as friends those who make a mockery and fun of your religion from among those who have been vouchsafed the Book before you and other infidels. And fear Allah if ye are believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when ye call for the prayer they make a mockery and fun thereof. This because they are a people who understand not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say thou: O people of the Book! what is it that ye persecute us for save that we believe in Allah and in that which hath been sent down unto us and that which hath been sent down aforetime? and most of you are transgressors.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say thou: shall I declare unto you something worse as a way with Allah than that? Whomsoever Allah hath accursed and is angered with, and of whom some He hath made apes and swine and slaves of the devil - those are worst in abode and furthest astray from the level way.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
And when they come to you they say: we believe; whereas surely with infidelity they entered and surely with it they went forth. And Allah is Knower of that which they have been concealing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And thou shalt see many of them hastening toward sin and transgression and their devouring of the forbidden. Vile indeed is that which they have been doing!\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Wherefore is it that the divines and priests forbid them not of their speaking of sin and their devouring of the forbidden? Vile indeed is that which they have been performing!\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
And the Jews say: the hand of God is fettered. Fettered be their own hands, and cursed be they for that which they have said! Aye! His both hands are wide open. He expendeth howsoever He listeth. And surely that which hath been sent down to thee from thy Lord increaseth many of them in exorbitance and infidelity. And We have cast among them enmity and spite till the Day of Judgement: so oft as they kindle the fire of War Allah extinguisheth it, and they strive after corruption in the land, and Allah approveth not the corrupters.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
And had the people of the Book believed and feared, We would surely have expiated from them their misdeeds and would surely have made them enter the Garden of Delight.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
And had they established the Taurat and the Injil and that which hath now been sent down unto them from their Lord, they would have devoured from above them and from beneath them. Among them is a community right-doing; but many of them - vile is that which they work!\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Apostle! preach thou all that hath been sent down unto thee from thy Lord; and if thou do it not, thou wilt not have preached His message. Allah shall protect thee from mankind; verily Allah shall not guide a disbelieving people.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say thou: people of the Book! ye rest not on aught until ye establish the Taurat and the Injil and that which hath now been sent down unto you from your Lord. And that which hath been sent down unto thee will surely increase many of them in exorbitance and infidelity; so mourn thou not over and disbelieving people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Verily those who believe, and those who are Judaised, and the Sabians and the Nazarenes - whosoever believeth in Allah and the Last Day and worketh righteously, no fear shall come on them, nor shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
Assuredly We took a bond from the Children of Isra'il and We sent unto them apostles. Whenever there came unto them an apostle with that which their souls desired not, a party of them they belied and a party they slew.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
And they imagined that there would be no trial; so they blinded and deafened themselves. Thereafter Allah relented toward them, then they again blinded and deafened themselves. And Allah is Beholder of that which they Work.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
Assuredly they have disbelieved who say: verily God: He is the Masih, son of Maryam, whereas the Masih had said: Children of Isra'il! worship Allah, mine Lord and your Lord; verily whosoever associateth aught with Allah, Allah shall surely forbid the Garden unto him, and his resort is the Fire; and for the wrong-doers there shall be no helpers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
Assuredly they disbelieve who say: God is the third of the three; whereas there is no god except the One God. And if they desist not from that which they say, there shall surely befall those of them who have disbelieved a torment afflictive.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Wherefore turn they not toward Allah and ask His forgiveness? And Allah is Forgiving, Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Masih, son of Maryam, was naught but an apostle; surely there passed away apostles before him and his mother was a saintly woman; both of them were wont to eat food. Behold! how We expound unto them the evidences! Then behold! whither they are deviating!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say thou: worship ye, beside Allah, that which availeth you not for hurt nor for profit! whereas Allah! He is the Hearer, the Knower.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say thou: O people of the Book! exceed not the just bounds in your religion except with truth, and follow not the vain desires of a people who have strayed aforetime and have led many astray and have strayed from the level way.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Cursed were those who disbelieved from among the Children of Isra'il by the tongue of Daud and 'Isa, son of Maryam. That is because they disobeyed and were ever transgressing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They were wont not to desist from the evil they committed; vile is that which they have been doing!\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
Thou wilt see many of them befriending those who disbelieve; vile surely is that which their souls have sent forth for them, so that Allah became incensed against them; and in torment they shall be abiders.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
And had they believed in Allah and the prophet and that which is sent down unto him, they would not have taken them for friends, but many of them are transgressors.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Surely thou wilt find the Jews and those who associate the bitterest of mankind in enmity toward those who believe. And surely thou wilt find the highest in affection to those who believe those who say: we are Nazarenes. That is, because among them are divines and monks and because they are not stiff-necked.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they hear that which hath been sent down unto the apostle, then thou beholdest their eyes overflow, with tears because of the truth they have recognised. They say: Our Lord! we believe, so write us down with the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
And what aileth us that we should not believe in Allah and that which hath come unto us of the truth; and we long that our Lord will enter us with the righteous people.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
Wherefore Allah will reward them, for that which they said, with Gardens whereunder rivers flow as abiders therein: such is the recompense of the well-doers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
And those who disbelieved and belied Our signs, they shall be the fellows of the Flaming Fire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O ye who believe! forbid not the clean things of that which Allah hath allowed unto you, and trespass not verily Allah approveth not the trespassers.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And eat of that wherewith Allah hath provided you as lawful and clean; and fear Allah in whom ye are believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah shall not take you to task for the vain in your oaths; but he shall take you to task for that which your oaths make binding. The expiation thereof is the feeding of ten of the needy with the middle sort of that wherewith ye feed your households, or the clothing of them or the freeing of a neck; but whosoever cannot find, far him is a fasting of three days. That is the expiation of your oaths when ye have sworn and bear in mind your oaths. Thus doth Allah expound unto you His commandments, that haply ye may return thanks.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O ye who believe! wine and gambling and stone altars and divining arrows are only an abomination, a handiwork of Satan, shun it wherefore, that haply ye may fare well.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan only seeketh to breed animosity and spites among you by means of wine and gambling and would keep you from the remembrance of Allah and from prayer; will ye not then desist?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey Allah and obey the apostle, and beware; but if ye turn away, then know that upon Our apostle resteth only the plain preaching.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
No sin is on those who believe and work righteous works for that which they have eaten when they have abstained, and believed and work righteous works, and shall again abstain and believe, and shall again abstain and do well; and Allah loveth the well-doers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O ye who believe! Allah shall surely prove you with aught of the chases which your hands and your lances may reach, in order that Allah may know whosoever feareth Him unseen; so whosoever shall trespass thereafter, for him is a torment afflictive.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O ye who believe! slay not chase while ye are in a state of sanctity; and whosoever of you slayeth it wittingly, his compensation is the like of that which he hath slain, in domestic flocks, which two equitable persons among you shall judge: an offering brought to the Ka'ba; or as an expiation the feeding of the needy, or the equivalent thereof in fasts, that he may taste the grievousness of his deed. Allah hath pardoned that which is past, but whosoever returnoth, Allah shall take retribution from him; verily Allah is Mighty, Lord of Retribution\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Allowed unto you is the game of the sea and the eating thereof: a provision for you and for the caravan; and forbidden unto you is the game of the land while ye are in the state of sanctity. And fear Allah unto whom ye shall be gathered.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah hath made the Ka'ba, the Sacred House, a maintenance for mankind and likewise the Sacred month, and so also the offering and the victims with garlands. That is in order that ye may know that Allah knoweth whatsoever is in the heavens and whatsoever is in the earth, and that of everything Allah is Knower.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is severe in chastising and that Allah is Forgiving, Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
Naught resteth there on the apostle except the preaching, and Allah knoweth that which ye disclose and that which ye hide.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say thou: equal are not the foul and the pure, even though the abundance of the foul may astonish thee; wherefore fear Allah, ye men of understanding! that haply ye may fare well.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O ye who believe! ask not about things which if disclosed to you, may annoy you; and if ye ask about them while the Qur'an is being revealed, they may be disclosed to you. Allah hath pardoned that; and Allah is Forgiving, Forbearing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
Surely people have asked questions before you, and were then found disbelievers therein.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah hath not appointed aught of the bahira or the sa'iba or the wasila or the ham, those who disbelieve have fabricated a lie against Allah, and most of them reflect not.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said unto them: come to that which Allah hath sent down and to the apostle, they say: enough for us is that whereon we found our fathers. What! even though their fathers knew not aught nor were guided.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O ye who believe! on you resteth the case of yourselves; it can hurt you not as to whosoever strayeth so long as ye keep yourselves guided. Unto Allah is the return of you all; then He shall declare unto you that which ye were wont to work.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O ye who believe! the testimony amongst you, when death presenteth itself to you, at the making of a bequest shall be that of two equitable persons from amongst you, or two others from amongst those not of you, if ye be journeying in the earth and the affliction of death afflicteth you. O Ye shall detain the twain after the prayer, if ye be in doubt, and they shall swear by Allah affirming: we shall not barter it for a price, even though he be a kinsman, and we shall not hide the testimony of Allah, for then verily we shall be of the sinners.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
If then it be lit upon that the twain had been guilty of a sin, then two othershall take their place from among those who were sinned against, the two nearest of kin, and they shall swear by Allah affirming: our testimony is worthier of credit than their testimony and we have not trespassed, for then verily we shall be of the wrong-doers.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That shall make it more likely that they shall produce the testimony according to the fact thereof or they shall fear that other oaths would be admitted after their oaths. And fear Allah and hearken; and Allah guideth not a transgressing people.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
Beware of the Day whereon Allah shall assemble the apostles and say unto them: how were you answered? Then they will say: no knowledge have we; verily Thou! Thou art the Great Knower of the things hidden.\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
And call to mind what time Allah will say: 'Isa, son of Maryam, remember My favour unto thee and unto thine mother when I aided thee with the holy spirit so that thou spakest unto mankind in the cradle and in maturity, and when taught thee the Book and wisdom and the Taurah and the Injil, and when thou formedst out of clay as though the likeness of a bird by My command, and thou breathedest thereinto and it became a bird by My command, and thou healedest the blind from birth and the leprous by My command; and when thou causedest the dead to come forth by My command; and when I restrained the Children of Isra'il from thee when thou didst come to them with evidences, and those of them who disbelieved said: this is but magic manifest.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And recall what time I revealed to the disciples: believe in Me and My Apostle, they said: we have believed and bear thou witness that verily we are Muslims.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
Recall what time the disciples said: O 'Isa, son of Maryam! is thine Lord able to send down unto us some food from the heaven? He said: fear Allah, if ye are indeed believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said: we mean that we may eat thereof and we may set our hearts at rest and we be assured that thou hast spoken the truth unto us, and we should be of the witnesses thereof.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
'Isa, son of Maryam, said: O Allah, our Lord send down unto us some food from the heaven, that it may become unto us an occasion of joy, unto the first of us and the last of us, and a sign from Thee. And provide us Thou; and Thou art the Best of providers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: verily I am going to send it down to you, but whosoever of you disbelieveth thereafter, verily shall torment him with a torment wherewith I shall not torment any other of the worlds.\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And call to mind what time Allah will say: O 'Isa, son of Maryam! was it thou who said to the people: take me and my mother as two god beside Allah! 'Isa will say: hallowed be Thou! it was not for me to say that to which had no right; had I said it, Thou would have surely known it; Thou knowest that which is in my mind and know not that which is in Thy mind. Verily Thou! Thou art the Great Knower of the things hidden.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I spake not unto them aught save that for which Thou badest me: worship Allah, mine Lord and your Lord. I was a witness over them so long as abode amongst them: then when Thou tookest up Thou hast been the Watcher. And over everything Thou art a Witness.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
Shouldst Thou torment them, then verily they are Thine creatures; and shouldst Thou forgive them, then verily Thou! Thow art the Mighty, the Wise.\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say: this is a Day whereon their truthfulness will benefit the truthful. Theirs are Gardens whereunder rivers flow; they shall be abiders therein for ever, well-pleased is Allah with them and well-pleased are they with Him: that is an achievement supreme.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
Allah's is the dominion of the heavens and the earth and whatsoever Is therein, and over everything He is Potent.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen All praise unto Allah, who created the heavens and the earth and made the darknesses and the light, yet those who disbelieve equalise others with their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is who created you of clay and then decreed a term - and a term determined is with Him - yet ye waver.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
He is Allah in the heavens and the earth; He knoweth your secret and your publishment, and He knoweth that which ye earn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
And not a sign cometh unto them of the signs of their Lord but that therefore they have been backsliders.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
Surely they have belied the truth when it came unto them; so presently there cometh unto them the tidings of that whereat they have been mocking.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Observe they not how many a generation before them We have destroyed whom We had established on the earth as We have not established you, and upon whom We had sent the rains of heaven pouring and under whom We had made the rivers flow; yet We destroyed them for their sins and We produced after them a generation of others.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
And had We sent down unto thee a Book written upon parchment so that they could have touched it with their hands, those who disbelieve would have said: this is naught but magic manifest.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they say: wherefore hath not an angel been sent down unto him? Were We to send down an angel, the affair would have been decreed and they would not be respited.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And had We made him an angel, We would still have made him a man, and We would have confounded for them that which they are confounding.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And assuredly mocked were the apostles before thee, wherefore that whereat they scoffed beset these who had been mocking.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say thou: go about in the earth and then see what wise hath been the end of the beliers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say thou: whose is whatsoever is in the heavens and the earth? Say thou: Allah's. He hath prescribed mercy for Himself. Surely He shall gather you together on the Day of Judgement whereof there is no doubt. Those who have lost themselves shall not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
His is whatsoever dwelleth in the night and the day; and He is the Hearer, the Knower.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say thou: Shall I take for a patron any other than Allah, the Maker of the heavens and the earth! And He feedeth, and is not fed. Say thou: I am commanded that I be the first who submitteth himself, and that: be thou not of the associaters.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say thou: verily fear, if disobey my Lord, the torment of a Mighty Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
From whomsoever it is averted on that Day, upon him indeed He has had mercy; that is a supreme achievement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
If Allah touch thee with hurt there is no reverser thereof but he, and if he touch thee with good, then He is over everything Potent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is the Supreme above His creatures; and He is the Wise, the Aware.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say thou: what thing is the greatest in testimony? Say thou: Allah is Witness between me and you, and this Qur'an hath been revealed unto me that I may thereby warn you and whomsoever it may reach. Would ye indeed testify that there is anot her god together with Allah? Say thou: I testify not. Say thou: verily He is the One God, and I am quit of that which ye associate.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those whom We have vouchsafed the Book recognise him even as they recognise their own children. Yet those who have lost themselves will not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who is a greater wrong-doer than he who fabricateth a lie against Allah or belieth His signs? Verily the wrong-doers shall not fare well.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And let them beware the Day whereon We shall gather them all together; then We shall say unto those who associated: where are your associate-gods whom ye have been asserting?\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then they will have no excuse but to say: by God our Lord, we have not been associaters.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Behold! how they lied against themselves! and then failed them that which they had been fabricating.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And of them are some who hearken unto thee and We have set over their hearts veils lest they understand it, and in their ears heaviness, and though they see any sign they will not believe therein: in as much as when they come to thee, they dispute with thee. Then who disbelieve say: this is naught but the fables of the ancients.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they prohibit others therefrom, and they withdraw therefrom, and they destroy not but their own souls while they perceive not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
And couldst thou see what time they shall be held over the Fire, and then they will say: would that we were sent back and now we shall not belie the signs of our Lord and we shall be of the believers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Yea! manifest hath become unto them that which they were erst wont to hide. And were they sent back they would surely return to that which was prohibited to them, and verily they are perfect liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they say: there is naught but our life of the world, nor are we to be raised.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
And couldst thou see what time they shall be held before their Lord? He will say: is this not real? They will say: aye! by our Lord! He will say: taste then the torment for ye have been disbelieving.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Lost surely are those who belie their meeting with Allah, until when the Hour cometh on them on a sudden, and they will say: woe betide us, that we neglected it! - the while they will be bearing their burthens on their backs. Lo! vile is that which they shall bear.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
And naught is the life of world but a play and a sport, and surely the abode of the Hereafter is better for those who fear. Reflect then ye not?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know indeed that verily that which they say grieveth thee, but it is not thee they belie; it is the signs of Allah the wrong- doers gainsay.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
And apostles have assuredly been belied before thee, but they patiently bare that wherefore they were belied, and they were hurt, until Our succour came to them. And none can change the words of Allah; and assuredly there hath come unto thee some tidings of the sent ones.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
And if their backsliding is hard unto thee, then seek out, if thou canst, an opening into the earth or a ladder to the heaven that thou mayst bring unto them a sign. And had Allah willed, He would have assembled them unto the guidance; wherefore be not thou of the ignorant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Only those respond who hearken. And as to the dead, Allah will raise them, and thereafter unto Him they shall be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they say: wherefore is not a sign sent down upon him from his Lord? Say thou: verily Allah is able to send down a sign, howbeit most of them know not.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
And there is not an animal on the earth nor a fowl that flieth with its two wings but are communities like unto you. And We have not been remiss in respect of aught in the Book: then unto their Lord they shall be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
And those who belie our signs are deaf and dumb, in darkness. Whomsoever Allah willeth He sendeth astray, and whomsoever He willeth He putteth on the right path.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say thou: look ye now, were Allah's torment to come upon you, or the Hour come upon you, would ye then cry unto other than Allah, if ye are truthful?\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
Aye! unto Him alone ye would cry, and He would remove that where for ye cried unto Him, if He will, and ye would forget that which ye associate.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
And assuredly We sent apostles unto communities before thee; then We laid hold of them with adversity and distress, that haply they may humble themselves.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
Wherefore then did they not, when the affliction from us came upon them, humble themselves? But their hearts became hardened, and the Satan made fair-seeming unto them that which they were wont to do.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
Then when they forgot that whereof they were reminded We opened upon them the doors of everything, until when they boasted of that which they were given, We laid hold of them on a sudden, and lo! they were dumbfounded.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
Then the people who committed wrong were cut off completely. And all praise is unto Allah, the Lord of the worlds.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say thou: look ye were Allah to take away your hearing and your sight and seal up your hearts, what god, other than Allah, shall bring them unto you? Behold! how variously We propound the signs, yet they turn aside.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say thou look ye now, were Allah's torment to come upon you on a sudden or openly, would there be destroyed any but the wrong- doers?\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
And We send not the sent ones except as bearers of glad tidings and warners. Then whosoever believeth and amendeth, on such shell come no fear nor they shall grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
And those who belie Our signs-torment shall touch them for they have been transgressing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say thou: I say not unto you, that with me are the treasures of Allah, nor I know the Unseen, nor say unto you that I am an angel; I but follow that which hath been revealed unto me. Say thou: are the blind and the seeing equal? Will ye not then consider?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn thou therewith those who fear that they shall be gathered unto their Lord, when there shall be for them no patron nor intercessor beside Him; haply they may become God-fearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And drive not away those who call upon their Lord morning and evening, seeking His countenance. Not on thee is aught of their reckoning, nor on them aught of thine reckoning, so that thou mayest drive them away and thus become of the wrong-doers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
And Thus We have tried some of them by means of others, that they might say: are those they whom God hath favoured amongst us? Is not Allah the Best Knower of the thankful?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those who believe in Our signs come unto them, say thou: peace be on you; your Lord hath prescribed mercy for Himself; so that whosoever of you doeth an evil through Ignorance, then repenteth thereafter and amendeth, then verily He is Forgiving, Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
And Thus We expound revelations so that the way of the culprits may be shown up.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say thou: verily I am forbidden to worship those whom ye call upon beside Allah. Say thou: I shall not follow your vain desires, for then I shall be gone astray, and shall not remain of the guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say thou: verily stand upon an evidence from my Lord, and ye belie it; not with me is that which ye fain would hasten on. The judgement is not but of Allah. He counteth the truth, and He is the Best of deciders.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say thou: if that which ye fain would hasten on be with me, the affair would have been decided between me and you; and Allah is the Best Knower of you the wrong-doers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And with Him are the keys of the unseen; none knoweth them but he. And He knoweth whatsoever is in the land and the sea. Not a leaf falleth but he knoweth it, nor a seed-grain groweth in the darkness of the earth, nor aught of fresh or dry but is in a Book luminous.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
And He it is who taketh your souls by night, and knoweth that which ye earn by day. Then He raiseth you therein, that there may be fulfilled the term allotted. Thereafter unto Him shall be your return; and then He shall declare unto you that which ye have been working.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
And He is the supreme over His creatures, and He sendeth guardians over you until when death cometh unto one of you Our messengers take his soul, and they fail not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they all shall be taken back unto Allah, their true Master. Lo! His shall be the judgement. And he is the Most Swift of reckoners.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say thou: who delivereth you from the darknesses of the land and the sea, when ye cry unto Him in humility and in secrecy: if He delivered us from this, we shall surely be of the thankful?\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say thou: Allah delivereth you therefrom and from every pain, yet ye thereafter associate.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say thou: He is Able to stir up torment on you from above you or from beneath your feet or to confound you by factions and make you taste the violence of one anot her. Behold! how variously We propound the signs that haply they may understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
And thy people belie it, while it is certain to befall. Say thou: I am not over you a trustee.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every announcement is a set time; and presently ye shall know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And when thou seest those who plunge in Our revelations keep away from them until they plunge in a discourse other than that; and if the Satan causeth thee to forget, then sit not thou, after the recollection, with the wrong-doing people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
And naught on their account shall be on those who fear but admonition that haply they also may become God-fearing.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
And let those alone who have taken their religion as a play and a sport and whom the life of the world hath beguiled. And admonish thou them therewith lest a soul be given up to perdition for that which it hath earned, when for him there shall be no friend or intercessor beside Allah, and when if he offer every equivalent it shall not be accepted of him. Those are they who are given up to perdition for that which they have earned. For them shall be drink of boiling water and a torment afflictive, for they were wont to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say thou: shall we call upon, beside Allah, that which can neither profit us nor hurt us, and shall we turn on our heels after Allah hath guided us, like unto one whom the Satans have be guiled to wander bewildered in the land, his: fellows calling him unto the right path: come unto us? Say thou: verily the guidance of Allah, that is the Guidance, and we are commanded to submit ourselves to the Lord of the worlds.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
And that: establish prayer and fear Him; and it is He unto whom ye shall be gathered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
And it is He who hath created the heavens and the earth in truth. And the Day when He saith: be, it shall become. His saying is the Reality. And His will be the dominion the Day the Trumpet will be blown. Knower of the Unseen and the seen, is the Wise, the Aware.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And recall what time Ibrahim said unto his father Azar: takest thou idols for gods! Verily I see thee and thy people in error manifest.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
And in this wise We showed unto Ibrahim the governance of the heavens and the earth, and that he might become of the convinced.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
Then when the night darkened on him, he beheld a star. He said: this is mine Lord. Then when it set, he said. I love not the setting ones.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
Then when he beheld the moon uprise, he said: this is mine Lord. Then when it set, he said: were it not that my Lord kept me guiding, surely I must have been of the erring people.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
Then when he beheld the sun uprise, he said: this is mine Lord; this is the greatest. Then when it set, he said: O my people! verily I am quit of that which ye associate.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Verily I have set my countenance towards Him who hath created the heavens and the earth, upright, and am not of the associaters.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
And his people contended with him. He said; contend ye with me concerning Allah when He hath surely guided me? I fear not that which ye associate with Him save aught that mine Lord may will. My Lord comprehendeth everything in His Knowledge. Will ye not then be admonished?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And how should I fear that which ye have associated, while ye fear not to have associated with Allah that for which He hath sent down unto you no warranty? Which, then, of the two parties, is more worthy of security, if ye but knew?\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
It is those who believe and confound not their belief with wrong doing. These! theirs is the security and they are the guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
And this was Our argument which We vouchsafed unto Ibrahim against his people. We raise in degrees whomsoever We list; verily thy Lord is Wise, Knowing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon him Is-haq and Ya'qub: each one We guided. And Nuh We had guided afore, and of his progeny Da-ud and Sulaiman and Ayyub and Yusuf and Musa and Harun. And thus We recompense the well-doers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And also Zakariyya and Yahya and Isa and llyas: each one was of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Ismai'l and Alyas'a and Yunus and Lut: each one of them We preferred above the worlds.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And also some of their fathers and their progeny and their brethren: We chose them and guided them onto the right path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
This is the guidance of Allah whereby He guideth whomsoever of His bondmen He listeth. And if they had associated, to naught would have come all that they were wont to work.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are they unto whom We vouchsafed the Book and judgement and prophethood. Wherefore if those disbelieve therein, We have surely entrusted its unto a people who are not disbelievers therein.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those are they whom Allah had guided, so follow thou their guidance, Say thou: no hire I ask therefor; it is but an admonition unto the worlds.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
And they estimated not Allah with an estimation due unto Him when they said: on no human being hath God sent down aught. Say thou: who sent down the Books wherewith Musa came, a light and a guidance unto mankind, which ye have made into separate parchments. Some of it ye disclose and much thereof ye conceal. And ye were taught that which ye knew not: neither ye nor your fathers. Say thou: Allah, and let them alone, sporting in their vain discourse.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a Book We have sent down, blest, and confirming that which hath been before it. And it is sent that thou mayest warn thereby the mother of towns and those around it. And those who believe in the Hereafter believe in it, and they guard their prayer.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
And who is a greater wrong-doer than one who fabricateth a lie against Allah, or saith: a Revelation hath came to me, whereas no Revelation hath come to him in aught, and one who saith: I shall send down the like of that which God hath sent down? Would that thou souldst see what time the wrong-doers are in the pangs of death while the angels are stretching forth their hands saying: yield up your souls; to-day ye will be awarded a torment of ignomity for that which ye have been saying of Allah other than the truth, and against His signs ye were wont to be stiff-necked.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
And now ye are come unto us singly even as We had created you for the first time, and ye have left behind your backs that which We had granted unto you, and We see not along with you your intercessors who ye fancied were Our associates in respect of you as ye asserted. Now are the ties betwixt you severed and strayed from you is that which ye were wont to assert.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Verily Allah is the Cleaver of the seed-grain and the date- stone. He bringeth forth the living from the lifeless, and He is the Bringer-forth of the lifeless from the living. Such is Allah: whither away then are ye deviating?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
The Cleaver of the dawn; and He hath appointed the night as a rest, and appointed the sun and the moon according to a reckoning that is the disposition of the Mighty, the Knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
And it is He who hath appointed for you the stars that ye may be guided thereby in the darknesses of the land and the sea. Surely We have expounded the signs unto a people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
And it is He who hath produced you from one person, and thenceforth provided for you an abode and a depository. Surely We have expounded the signs unto a people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
And it is He who hath sent down rain from heaven and We have thereby brought forth growth of every kind, and thereout We have brought forth green stalks from which We bring forth close-growing seed- grain. And from the date-stone: from the spathe thereof come forth clusters of dates lowhanging; and gardens of grapes, and the olive, and the pomegranate, like unto one anot her and unlike. Look at the fruit thereof when it fruiteth and the reforming thereof. Verily therein are signs unto a people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
And they have set up the genii as associates unto Allah, whereas He hath created them and they impute unto Him falsely without knowledge, sons and daughters. Hallowed be He, far above that which they ascribe!\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
Originator of the heavens and the earth! How should He have a son when there is for Him no spouse? And He hath created everything and He is Knower of everything.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord, There is no god but He, the Creator of everything: so worship Him. And He is unto everything a Trustee.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
Sights comprehend Him not, and He comprehendeth all sights. And He is the Subtle, the Aware.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Surely there hath come unto you enlightenment from your Lord. Whosoever then shall see shall do so for his own soul, and whosoever blindeth himself shall do so to his own hurt. And say thou I am not over you a guardian.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
And Thus We variously propound the revelation, and this is in order that they may say: thou hast studied, and that We may expound it to a people who know.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow thou that which hath been revealed unto thee from thy Lord: no god is there but He; and turn thou away from the associaters.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
And had Allah willed, they had not associated. And We have not made thee a guardian over them nor art thou unto them a trustee.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Revile not those whom they invoke besides Allah, lest they may spitefully revile Allah without knowledge. Thus fair-seeming unto every community We have made their work. Then unto their Lord is their return, and then He will declare unto them that which they were wont to work.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swear by God with thee their solemn oaths that if there came unto them a sign they would surely believe therein. Say thou: signs are but with Allah; and what will make ye perceive that even if it came they will not believe?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We shall turn aside their hearts and their eyesights, even as they believed not therein for the first time and We shall let them wander in their exorbitance perplexed.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
And even thou We had sent down angels unto them, and the dead had spoken to them, and We had gathered together about them everything face to face, they were not such as could believe, unless Allah had so willed, but most of them speak ignorantly.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
And in this wises have we appointed unto every prophet an enemy-- Satans of men and of genii inspiring to each other gilded speech as a delusion. And had thy Lord willed, they could not have done so; wherefore let thou alone if them and that which they fabricate.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
And it is in order that the; hearts of those who believe not in the Hereafter might incline thereto, and that they might be pleased therewith, and that they might do that whereof they are the doers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
Say thou: shall I then seek as judge other than Allah, when it is He who hath sent down toward you the Book detailed? And those whom We vouchsafed the book know that it hath been revealed by thy Lord in truth; so be thou not of the doubters.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
And perfected is the word of thy Lord in veracity and in justice. And none can change His words. And He is the Hearer, the Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
And if thou obeyedest most of those on the earth, they would lead thee astray from the way of Allah; they follow not but their fancy, and they only conjecture.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Verily thy Lord; He knoweth best whosoever strayeth from His path and He knoweth best the guided ones.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
Wherefore eat of that whereon the name of Allah hath been pronounced, if ye are believers in His revelations.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
And what aileth you that ye should not eat that whereon the name of Allah hath been pronounced while He hath surely detailed unto you that which He hath forbidden you, unless ye are driven thereto? Verily many lead others astray by their desires without knowledge. Verily thy Lord! He knoweth best the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
And leave the outside of sin and the inside thereof; verily those who earn sin, anon will they be requited for that which they were wont to do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
And eat not of that whereon the name of Allah hath not been pronounced; for verily that is a departure. Verily the Satans are ever inspiring their friends that they may wrangle with you; and were ye to obey them, verily ye shall become associaters indeed.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead, and We quickened him and appointed for him a light whereby he walketh among mankind, like unto him whose similitude is that he is in darknesses forth from which he cannot come? Even so is made fair-seeming to the infidels that which they are wont to do.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And even so we set up in every town the great ones as its sinners, that they may plot therein. And they plot not but against themselves, and they perceive not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And whensoever there cometh unto them a sign, they say: we shall not believe until we are vouchsafed the like of that which is vouchsafed unto the apostles of Allah. Allah knoweth best wheresoever to place His apostleship. Anon shall befall those who have sinned vileness before Allah and severe chastisement for that which they were wont to plot.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
So whomsoever Allah willeth that he shall guide, He expoundeth his breast for Islam; and whomsoever He willeth that he shall send astray, He maketh his breast strait, narrow, as if he were mounting up into the sky, thus Allah layeth the abomination on those who believe not.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
And this is the path of thine Lord, straight. We have surely detailed the revelations unto a people who would be admonished.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them is an abode of peace with their Lord; and He shall be their patron for that which they have been doing.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
On the Day whereon He will gather them all together: O ye race of genii! surely much ye have gotten out of mankind. And their friends among mankind will say: our Lord! much use some of us made of others, and now we have reached the appointed term which Thou appointedest for us. He will say: the Fire shall be your habitation, therein ye shall be as abiders, save as Allah may will. Verily thy Lord is Wise, Knowing.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
And thus We shall keep some of the wrong-doers close to others for that which they were wont to earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
O ye race of genii and mankind came there not apostles unto you from amongst you recounting unto you My signs and warning you of your meeting of this Day? They will say: we bear witness against ourselves. The life of the world hath deluded them, and they shall bear witness against themselves that verily they had been infidels.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
This is because thy Lord is not one to destroy a town for its wrong-doing while its people are unaware.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
For all there will be degrees in accordance with that which they did, and thy Lord is not unaware of that which they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
And thine Lord is Self-sufficient, the Owner of mercy. If He will, He can take you away, and make those succeed you, after you, whomsoever He will, even as He raised you from the seed of anot her people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Verily that which ye are promised is sure to arrive, and ye cannot escape.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say thou. O my people! go on acting in your way, verily I am going to act in my way, presently ye shall know whose will be the happy end of the abode; and verily the wrong-doers will not fare well.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And they'll appoint for Allah, of the tilth and cattle He hath produced, a portion, they say according to their fancy: this is for Allah, and: this for our associate-gods. Then, that which is for their associate-gods reacheth not Allah, while that which is for Allah reacheth their associate-gods; vile is the way they judge!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And even so their associate-gods have made fair seeming unto many of the associaters the slaying of their offspring, so that they may cause them to perish and that they may confound unto them their religion. And had Allah so willed, they would not have done it. Wherefore let thou alone them and that which they fabricate.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they say according to their fancy: such cattle and tilth are taboo none shall eat thereof save whom we allow, and there are cattle whose backs are forbidden, and cattle over which they pronounce not the name of Allah: a fabrication against Him Anon He shall requite them for that which they were wont to fabricate.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say: whatsoever is in the bellies of such cattle is for our males alone and is forbidden unto our wives, and if it be born dead, then they all are partakers thereof. Anon He shall requite them for their attribution verily He is Wise, Knowing.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Surely lost are they who slay their offspring foolishly and without knowledge, and have forbidden that which Allah had provided for them: a fabrication against Allah: surely they have strayed and have not become guided ones.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
And it is He who hath produced gardens, trellised and untrellised, and the date-palm and the corn of varied produce, and the olives and the pomegranates alike and unlike. Eat of the fruit thereof when it fruiteth, and give the due thereof on the day of its harvesting; and waste not; verily He approveth not the wasters.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle He hath created beasts of burden and small ones. Eat of that which Allah hath provided for you; and follow not the foot-steps of the Satan; verily he is unto you a manifest foe.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
He hath created eight pairs of the sheep a twain, and of the goats a twain. Say thou: is it the two males He hath forbidden or the two females, or that which the wombs of the two females contain? Declare unto me with knowledge, if ye are truth-tellers.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And of the camels He hath created a twain and of the oxen a twain. Say thou: is it the two males He hath forbidden or the two females, or that which the wombs of the two females contain? Were ye present when Allah enjoined this on you? Who then doth greater wrong than he who fabricateth a lie against Allah that he may lead people astray; verily Allah shall not guide a wrong-doing people.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say thou: I find not in that which hath been revealed unto me aught forbidden unto an eater that eateth thereof, except it be carcass, or blood poured forth, or flesh of swine, for that verily is foul, or an abomination over which is invoked the name of other than that of Allah. Then whosoever is driven thereto, neither lusting nor transgressing, verily thy Lord is Forgiving, Merciful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And unto those who are Judaised We forbade every animal with cloven hoof; and of the bullock and the goats We forbade unto them the fat thereof, save that which is borne on their backs or entrails or that which sticketh to the bone. Thus We requited them for their rebellion, and verily We are the Truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
So if they belie thee, say thou: Your Lord is Owner of extensive mercy, and His wrath shall not be turned aside from the guilty people,\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Anon will those who associate had God willed, we would not say: have associated, nor our fathers; neither could we have forbidden aught. Even so belied those before them, until they tasted Our wrath. Say thou: is there with you any authority, that ye may bring unto us? ye but follow your fancy, and only conjecture.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say thou: with Allah resteth the argument evident. Wherefore, had He so willed, He would have guided you all.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say thou: here with your witnesses, those who will testify that Allah hath forbidden all this. Then even if they testify, testify thou not with them. And follow thou not the desires of those who belie Our signs and those who believe not in the Hereafter while they equalise others with their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say thou: come, I shall recite that which your Lord hath forbidden unto you: associate not aught with Him, and shew kindness unto the parents, and slay not your offspring for fear of want - We it is who shall provide for you and them -and approach not indecencies, whatsoever is open thereof and whatsoever is concealed, and slay not anyone whom Allah hath forbidden except for justification. Thus He enjoineth you that haply ye may reflect.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And approach not the substance of an orphan save with that which is best until he attaineth his age of strength, and fill up the measure and balance with equity- We burthen not a soul except according to its capacity and when ye speak, be fair, even though it be against a kinsman; and the covenant of Allah fulfil. Thus He enjoineth you that haply ye may be admonished.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
And that: verily this is my path, straight; follow it then, and follow not other ways; that will deviate you from His way. Thus He enjoineth you, that haply ye may fear God.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then unto Musa We vouchsafed the Book perfect for him who would do well and detailing every thing and a guidance and a mercy, that haply in the meeting of their Lord they would believe.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this is a Book We have sent down, blest, follow it then and fear God, haply ye may be shewn mercy.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest ye should say: the Book was only sent down to the two sects before us, and we in sooth were unaware of their readings.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest ye should say. if only the Book had been sent down to us, we should surely have been better guided than they. So now surely there hath come unto you an evidence from Your Lord and a guidance and a mercy. Who then doth greater wrong than he who belieth the signs of Allah and shunneth them? Anon We will requite those who shun Our signs with an evil torment in as much as they were wont to shun them.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
They await indeed that the angel should come unto them, or that thy Lord should come or that certain of the signs of thy Lord should come. On the Day whereon certain of the signs of thy Lord will come, belief will not profit any person who had not believed theretofore or had not earned any good by his belief. Say thou: so wait ye verily we also are waiting.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Verily those who have split their religion and become sects, thou art not amongst them in aught: their affair is only with Allah. Then He will declare unto them that which they were wont to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whosoever will come with a virtue for him shall be then like thereof, and whosoever will come with a vice shall not be requited save with the like thereof; and they shall not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say thou as for me, my Lord hath guided me unto a straight path, a right religion, the faith of Ibrahim, the upright, and he was not of the associaters.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say thou: verily my prayer and my rites and my living and my dying are all for Allah, Lord of the worlds.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
No associate hath He. And to this I am bidden, and I am the first of the Muslims.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say thou: shall seek a Lord other than Allah, while He is the Lord of everything? And no person earneth aught save against himself, and no bearer of burden shall bear anot her's burden. Thereafter Unto your Lord shall be your return, and He will declare unto you that wherein ye have been disputing.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
And He it is Who hath made you successors in the earth, and hath raised some of you over others in degrees, that he might prove you by that which He hath vouchsafed unto you. Verily thy Lord is swift in chastising, and verily He is Forgiving, Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif-Lam-Mim-Suad,\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
This is a Book sent down toward thee: so let there be no straitness in thy breast therefor: that thou mayest warn thereby! and this is an admonition unto the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow that which is sent down toward you from your Lord, and follow not any patrons beside Him; yet little ye are admonished.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
And how many a township We have destroyed, upon them Our violence came at night or while they were taking their midday rest.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
Then naught was their cry a when Our violence came upon them save that they said: verily we have been the wrong-doers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then We will surely question those to whom were the messengers sent, and We will surely question the sent ones.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then surely We will recount unto them with knowledge, and We have not been absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
And the weighing on that Day is certain, then whosesoever balances will be heavy, those! they shall fare well.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And whosesoever balances will be light - those are they who have lost themselves in respect of Our signs.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And assuredly We established you in the earth and appointed for you livelihoods therein; yet little thanks ye return.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And assuredly We created you, thereafter We fashioned you, and thereafter We said to the angels: prostrate yourselves before Adam; then they fell prostrate; not so Iblis: he was not of those who fell prostrate.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
Allah said: what prevented thee, that thou shouldst not prostrate thyself, when I bade thee? He said. I am better than he; me Thou createdest me from fire, and him Thou createdest from clay.\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
Allah said: then get thee down from hence; not for thee is it to be stiff-necked herein. So go thou forth; verily thou art of the abject ones.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
He said: respite me till the Day they shall be raised up.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
Allah said: verily thou art of the respited.\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
He said: because Thou hast seduced me, I will beset for them Thy straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then surely I will come upon them from before them and from behind them and from their right and from their left, and Thou shalt not find the most of them thankful.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
Allah said: go thou forth from hence, scorned, driven away. Whosoever of them followeth thee, I will of a surety fill Hell with you all.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
And: O Adam: dwell thou and thy spouse in the Garden and eat ye twain thereof Whence ye will, and approach not yonder tree lest ye twain become of the wrong-doers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then the Satan whispered unto the twain in order that he might discover unto the twain that which lay hidden from the twain of their shame, and said: your Lord forbade you not vender tree but lest ye twain should become angels or become of the abiders.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he sware unto them both: verily I am unto you of your good counsellors.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
Thus with guile he caused the twain to fall. Then when the twain had tasted of the tree, their shame was discovered to them, and the twain began to cover themselves with leaves from the Garden; and their Lord called out unto the twain: forbade I not ye twain yonder tree, and said I not unto you, verily the Satan is unto you twain a manifest enemy?\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
The twain said. our Lord! we have wronged our souls, and if Thou forgivest us not and hath not mercy on us, we shall of a surety be of the losers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
Allah said: get ye down, one of you an enemy unto anot her; and for you on the earth there shall be a habitation and provision for a season.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
Allah said: therein ye shall live and therein ye shall die, and therefrom ye shall be brought forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Children of Adam! verily We have sent down unto you a garment covering your shame and as an adornment; and the garment of piety --that is the best. That is of the signss of Allah, that haply they may be admonished.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Children of Adam! let not the Satan tempt you even as he drave forth your parents from the Garden, divesting the twain of their garment that he might discover unto the twain their shame. Verily he beholdeth you, he and his tribe, in such wise that ye behold them not. Verily We have made the Satans patrons of those only who believe not.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit an indecency, they say: we found our fathers thereon, and God hath enjoined it on us. Say thou. verily Allah enjoineth not an indecency; say ye falsely of Allah that which ye know not?\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say thou; my Lord hath enjoined equity, and that ye shall set your faces aright at every prostration, and call on Him, making religion pure for Him. Even as He began you; ye shall be brought back.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A part He hath guided, and upon a part the straying hath been justified. Verily they have taken the Satans as patrons instead of Allah and they imagine that they are guided ones.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! take your adornment at every worship: and eat and drink, and waste not; verily He approveth not the wasters.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say thou: who hath forbidden the adornment which Allah hath produced for His servants and the clean things of food? Say thou: these on the Day of Judgement, shall be for those alone who in the life of this world have believed. Thus We expound the signs unto a people who know.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say thou: my Lord hath only forbidden indecencies the open thereof and the hidden thereof, and sin, and high-handedness without justice, and ye associate aught with Allah, for which He hath sent down no warranty, and that ye speak falsely of Allah that which ye know not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And for every community there is an appointed term; then when its term shall arrive, not an hour will they stay behind or go in advance.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Children of Adam! if there come unto you apostles from amongst you recounting My signs unto you, then whosoever shall fear God and amend, on them no fear shall come nor they shall grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
And those who shall belie Our signs and shall be stiff- necked against them--they shall be fellows of the Fire; therein they shall be abiders.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who doth greater wrong than he who fabricateth a lie against Allah or belieth His sign? These: their full portion from the Book shall reach them until when Our messengers come unto them causing them to die, and say: where is that which ye were wont to call upon beside Allah? They will say: they have strayed from us. And they shall testify against themselves that they have been infidels.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
Allah will say. enter the Fire among the communities who have passed away before you, of genii and mankind. So oft as a community will enter it, it shall curse its sister, until, when all shall have arrived one after anot her therein, the last of them shall say of the first of them: our Lord! these led us astray; so mete out unto them and double torment of the Fire, He will say: to each, double; but ye know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
And the first of them will say unto the last of them: ye have then no preference over us; taste then the torment for that which ye were wont to earn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Verily those who belie Our signs and are stiff-necked against them, for them will not be opened the portals of heaven, nor shall they enter the Garden until a camel passeth through the eye of a needle. And Thus We requite the guilty ones.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Their shall be a bed in Hell, and over them coverings; and Thus We requite the wrong-doers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
And those who believed and worked righteous works-We burthen not a soul except according to its capacity, they shall be fellows of the Garden; therein they shell be abiders.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We shall extract whatsoever of rancour there may be in their breasts, rivers flowing beneath them, and they will say all praise unto Allah who hath guided us onto this; we were not such as to find guidance were it not that Allah had guided us; assuredly the aspotles of our Lord came with truth. And they shall be cried unto: this is the Garden, it ye inherit for that which ye have been working.\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the fellows of the Garden shall cry unto the fellows of the Fire: surely we have found true that which our Lord had promised us; have ye found true that which your Lord had promised you? They shall say: Yea! Then a Crier in-between them shall cry: the curse of Allah be upon the wrong-doers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
Those who turned away from the way of Allah and would seek to render it crooked and in the Herafter they were disbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And betwixt the twain there will be a veil, and, on the heights will be men recognising them all by their mark, and they will cry unto the fellows of the Garden; peace be unto you! They will not have entered it yet, while they shall be longing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes Will be turned toward the fellows of the Fire, they will say: our Lord! place us not with these wrong-doing people.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the fellows of the heights will cry unto the men whom they would recognise by their mark, and say: your multitude availed you naught nor that over which ye were wont to be stiff-necked.\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
Are these the ones of whom ye sware that Allah would not reach them with His mercy? Unto them it hath been said enter the Garden; on you shall come no fear nor shall ye grieve.\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
And the fellows of the Fire will cry unto the fellows of the Garden: pour out on us water or aught wherewith Allah hath provided you. They will say verily Allah hath forbidden it unto infidels.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
Who took their religion as a sport and a play and whom the life of the world beguiled. So today We will forget them even as they forget the meeting of this their Day and as they were ever gainsaying Our signs.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
And assuredly We have brought unto them a book which We have detailed according to knowledge a guidance and, mercy unto a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
They await only its fulfilment. The Day whereon the fulfilment thereof arriveth, those who were negligent thereof afore shall say: surely the apostles of our Lord brought the truths; are there for us any intercessors that they might intercede for us? or could we be sent back that we may work otherwise than we were wont to work? Surely they have lost themselves, and there hath strayed from them that which they were wont to fabricate.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Verily your Lord is Allah who created the heavens and the earth in six days, then established Himself on the Throne, making the night cover the day, seeking it swiftly, and created the sun and the moon and the stars subjected to service by His command. Lo! His is the creation and the command. Blessed is Allah, the Lord of the worlds.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Call on Your Lord in humility and in secrecy; verily He approveth not the trespassers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
And act not corruptly in the earth after the good ordering thereof, and call on Him fearing and longing; verily the mercy of Allah is nigh unto the well-doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He who sendeth forth the heralding winds before His mercy, until when they have carried a heavy-laden cloud We drive it unto a dead land and send down rain thereby and bring forth thereby all kinds of fruits. In this wise We will raise the dead; haply ye may be admonished.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
And a good land: its herbage cometh forth by the command of its Lord; and that which is vile, it cometh forth only scantily. In this wise We vary the signs for a people who return thanks.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
Assuredly We sent Nuh unto his people, and he said: O my people! worship Allah; no god ye have but He; verily I fear for you the torment of a mighty day.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The chiefs of his people said: verily we see thee in error manifest.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
He said: O my people! not with me is the error, but I am an apostle from the Lord of the worlds.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
I preach unto you the messages of my Lord and I councel you good, and I know from Allah which ye know not.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
Marvel ye that an admonition from your Lord should come unto you upon a man from amongst yourselves, in order that the may warn you and that ye may fear, and that haply ye may be shewn mercy?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
Then they belied him; there upon We delivered him and those with him in the ark, and drowned those who belied Our signs; verily they were a people blind.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And unto 'Ad We sent their brothers Hud. He said: O my people! worship Allah, no god ye have but He; Fear ye not?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The chiefs of those who disbelived among his people said: verily we see thee in folly, and verily we deem thee to be of the liars.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said: O my people! not with me is folly, but I am an apostle from the Lord of the worlds.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
I preach unto you the messages of my Lord, and I am unto you a counseller faithful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
Marvel ye that an admonition from your Lord should come unto you upon a Man from amongst you in order that he may warn you? Remember what time He made you successors after the people, of Nuh, and increased you amply in stature Remember the benefits of Allah, that haply ye may fare well.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: art thou come unto us that we should worship God alone and leave that which our fathers were wont to worship? Bring thou then upon us that wherewith thou threatenest us if thou sayest sooth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
He said: surely there have befallen you wrath and indignation from your Lord. Dispute ye with me over names ye have named, ye and your fathers, for which Allah hath sent down no warranty? Wait then; I also will be with you of those who wait.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
Then We delivered him and those with him by a mercy from Us, and We utterly cut off those who belied Our signs, and would not be believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And unto Thamud We sent their brother, Salih He said: my people! worship Allah, no god ye have but He; surely there hath come unto you an evidence from your Lord. Yonder is the she-camel of Allah: a sign unto you; so leave her alone, pasturing on Allah's earth, and touch her not with evil, lest there seize you a torment afflictive.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And remember what time He made you successors after 'Ad and inherited you in earth; ye take for yourselves palaces in the plains whereof and ye hew out the mountains as houses. Remember ye wherefore the benefits of Allah and commit not evil on the earth as corrupters.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The chiefs of those who were stiff-necked amongst His people said unto those who were counted weak -unto such of them as believed: know ye that Salih is a sent one of his Lord? They said: verily we are believers in that wherewith he hath been sent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were stiff-necked said: verily we are disbelievers in that which ye believe.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
Then they hamstrung the she camel and disdained the commandment of their Lord, and said: Salih! bring upon us that wherewith thou hast threatened us if thou art in sooth of the sent ones.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
Whereupon an earthquake seized them, so that they lay prone in their dwellings.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
Then he turned from them, and said: O my people! assuredly delivered unto you the messages of my Lord, and counselled you good, but ye approve not the good counsellors.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And We sent Lut, when he said unto his people: commit ye an indecency wherewith none hath preceded you in the worlds?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
Verily ye go in lustfully unto men instead of women! Aye! ye are a people extravagant.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And naught was the answer of his people save that they said: drive themforth from your city, verily they are a people who would be pure!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
Then We delivered him and his household, save his wife: she was among the lingerers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained upon them a rain. So behold! what like was the end of the sinners.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And unto Madyan We sent their brother Shu'aib. He said: O my people! worship Allah, no god ye have buthe; surely there hath come unto you an evidence from your Lord. So give full measure and weight, and defraud not people of their things, and act not corruptly on the earth after the ordering thereof; thatis best for you if ye be believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
And beset not every highway menacing and turning aside from the path of Allah those who believe in Him, and seeking to make it crooked. And remember when ye were small, and He thereafter multiplied you; and behold what like was the end of the corrupters.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
And if there be a party of you who believeth in that wherewith I am sent and a party who believeth not, then have patience until Allah judgeth between us, and He is the Best of judges.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The chiefs of those who were stiff-necked amongst his people said: surely we shall drive you forth, Shu'aib! and those who have believed with thee from our city, or else ye shall return unto our faith. He said: what! even though we be averse!\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
We must have been fabricating a lie against Allah if we returned to your faith after Allah hath delivered us therefrom. And it is not for us to return thereunto except that Allah our Lord so willed; everything our Lord comprehendeth in His knowledge; in Allah we place our trust. O our Lord! decide Thou between us and our people with truth, Thou art the Best of the deciders.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
And the chiefs of those who disbelieved amongst his people said: should ye follow Shu'aib, lo! verily ye will be the losers.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
Whereupon an earthquake laid hold of them: so that they lay prone in their dwelling.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who belied Shu'aib became as though they had never dwelt therein; those who belied Shu'aib, it is they who became the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
Then he turned from them, and said: my people! assuredly I delivered unto you the messages of my Lord, and counselled you good; how then should I lament over an unbelieving people?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And We sent not a prophet to any township but We laid hold of the people thereof with tribulation and distress that haply they may humble themselves.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Thereafter We substituted ease in place of adversity until they abounded and said: even Thus tribulation and prosperity touched our fathers. Then We laid hold of them of a sudden, while they perceived not.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
And had the people of those townships believed and feared, We would of a surety have opened up to them blessings from the heavens and the earth; but they belied, wherefore We laid hold of them for that which they had been earning.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Are the people of the townships then secure that Our wrath would not come upon them at night while they are slumbering?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or, are the people of the township secure that Our wrath would not come upon them by daylight while they are disporting themselves?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Are then they secure against the contrivance of Allah? And none feeleth secure against the contrivance of Allah except the people who are losers.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Guideth it not those who inherit the land after the people thereof, that, had We willed, We would have afflicted them for their sins? And We have put a seal upon their hearts, so that they hearken not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Those townships! We recount unto thee some tidings thereof. Assuredly there came unto them their apostles with evidences, but they were not such as to believe that which they had erst belied. Thus doth Allah put a seal upon the hearts of the infidels.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
And We found no covenant in most of them; and most of them We found ungodly.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then We sent, after them, Musa with Our signs unto Fir'awn and his chiefs, but they wronged them. Behold that wise was the end of the corrupters!\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Musa said: O Fir'awn! I am an apostle from the Lord of the worlds;\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
Incumbent it is upon me that I speak naught respecting Allah save the truth; surely I have brought you an evidence from your Lord; wherefore let then go with me the Children of Isra'il.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
He said: if thou hast brought a sign, forth with it then, if thou art of the truth-tellers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
Thereupon he cast down his rod, when, lo it was a serpent manifest.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew forth his hand, when lo: it was white unto the beholders.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The chiefs of the people of Fir'awn said: verily this is a magician knowing.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
He would drive you forth from your land; so what is it that ye enjoin?\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said: put him and his bro ther off, and send unto the cities callers.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
That they may bring to thee every magician knowing.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the magicians came unto Fir'awn. They said: surely there is for us a reward if we are the overcomers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said: yea! and verily ye shall be of those brought nigh.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: O Musa! either thou cast down, or we shall be the ones to cast down.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said: cast ye. Then when they cast clown, they enchanted the eyes of the people, and terrified them and brought mighty magic to bear.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And we revealed unto Musa: cast down thy rod. And lo! it Was swallowing up that which they had feigned.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus the truth prevailed, and that which they had brought vanished.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
Thus they were overcome and made to look abiect.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the magicians flung themselves prostrate.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said: we believe in the Lord of the worlds.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
The Lord of Musa and Harun.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Fir'awn said:? believed ye in him ere I have given you leave? Verily this is a plot ye have plotted in the city that ye may drive forth the people thereof So presently ye shall know.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
Surely I will cut off your hands and feet on the opposite sides and thereafter I will crucify you all.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said: verily unto our Lord we are turning.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
And what is it for which thou takest vengeance on us save that we have believed in the signs of our Lord when they came unto us? Our Lord! pour out upon us perseverance and cause us to die as Muslims.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
And the chiefs of the people of Fir'awn said: wilt thou leave alone Musa and his people to act corruptly in the land and to leave alone thee and thy gods! He said: soon we shall slay their sons and let live their women, and we are masters over them.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Musa said unto his people: seek help in Allah and persevere; verily the earth is Allah's; He maketh whomsoever He willeth of His bondmen inherit it, and the happy end is of the God-fearing.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said: oppressed we have been ere thou camest unto us and since thou hast come unto us. He said: belike your Lord will destroy your enemy and establish yougs in their stead in the land, thathe may see what wise ye act.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And assuredly We laid hold of the people of Fir'awn with lean years and lack of fruits, that haply they might dread.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
So whenever good-hap came unto them, they would say: ours is this. And if a mishap afflicted them, they would lay it to the evil augury of Musa and these with him. Behold! their evil augury was only with Allah, but most of them knew not.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said: whatsoever thou mayest bring unto us of the nature of a sign wherewith to enchant us, in thee we are not going to be believers\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
Thereafter We sent upon them the flood, and the locusts, and the lice, and the frogs, and the blood: signs detailed; yet they remained stiff-necked and they, were a people sinful.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And whensoever a plague fell on them, they said: O Musa! supplicate thy Lord for us, by that which He hath covenanted with thee; surely if thou remove the plague from us we will surely believe in thee, and we will send away with thee the Children of Israi'l.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
Then whensoever We removed the plague from them, till a term which they were to reach, lo! they were breaking faith.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
Wherefore We took vengeance on them and drowned them in the sea, for they belied Our signs and were neglectful of them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We caused the people who had been oppressed to inherit the eastern parts of the land, and the western parts thereof, which We had blest. And fulfilled was the good word of thy Lord unto the Children of Isra'il' for they were long-suffering, and We destroyed that which Fir'awn and his people had builded and that which they had raised.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We led the Children of Isra'il across the sea. Then they came upon a people cleaving to the idols they had. T'hev said: Musa! make for us a god even as they have gods. He said: verily ye are a people given to ignorance.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
Verily these! destroyed is that wherein they are engaged and vain is that which they have been doing.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said: shall I seek for you a god other than Allah, whereas He hath preferred you above the worlds?\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And recall what time We delivered you from the house of Fir'awn perpetrating on you terrible torment, slaying your sons and letting your women live, and therein was a trial from your Lord, tremendous.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We treated with Musa thirty nights, and We completed them with ten; so the appointment of his Lord was completed by forty nights. And Musa said unto his brother Harun: act thou in my place among my people, and rectify, and follow not the way of the corrupters.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Musa came at Our appointment, and his Lord spake unto him, he said my Lord! shew Thyself unto me, that I may look at Thee! He said: thou canst not see Me: but look at the yonder mount; if it stands in its place, then thou wilt see Me. Then when his Lord unveiled His glory unto the mount, it turned it to dust, and Musa tell down thunderstruck. Then when he recovered, he said: hallowed be Thou! I turn unto Thee repentant, and I am the first of the believers,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
He said: O Musa! verily I have chosen thee above mankind by My messages and by My speaking; so hold fast thou that which I have given thee, and be of the thankful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him in the tablets of everything an exhortation, and and a detail of everything. So hold thou fast with firmness, and bid thy people follow the best thereof anonl will shew you the dwelling of the ungodly people.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn away from My signs those who are big with pride on the earth, without justice, and although they may see every sign, they will not believe therein; and if they see the path of rectitude they will not take it as their path, and if they see the path of error they will take it for their path. This is because they belied Our signs, and they were ever negligent thereof.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
And those who belie Our signs and the meeting of the Hereafter- vain shall be their Work. They shall be requited not save for that which they wrought.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And ehe people of Musa, after him, took of their trinkets a calf: a body with a low. Saw they not that it spake nor unto them nor could guide them to a way? They took it, and became wrong-doers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they repented and saw that they had strayed, they said: if our Lord have not mercy on us and forgive us not, we shall surely be of the losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Musa returned unto his people indignant and sorrowing, he said: ill is that which ye have acted as my successors, after me Anticipated ye the command of you Lord! And he cast down the tablets and took hold of the head of his brother dragging him unto himself. Aaron said: son of my mother! the people held me weak and well- nigh slew me, so cause not the enemies rejoice over me, and place me not with the wrong-doing people\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
Musa said: O Lord! forgive me and my brother, and cause us twain to enter into Thy mercy, and Thou art the Most Merciful of the merciful.\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Verily those who took the calf, anon will overtake them indignation from their Lord and abasement in the life of the World. Thus We require the fabricators.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
And those who committed evils, and repented thereafter and believed --verily thy Lord is thereafter Forgiving, Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the indignation of Musa was appeased, he took up the tablets, and in the inscription thereon were guidance and mercy unto these who dread their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Musa singled out of his people seventy men for Our appointment, then when the earthquake laid hold of them he said. O my Lord! hadst Thou willed, Thou wouldst have destroyed them afore and me also. wilt Thou destroy Us for that which the foolish ones amongst us have done! lt is only thy trial, whereby thou sendest astray whomsoever Thou wilt and keepest guided whomsoever Thou wilt. Thou art our patron. So forgive us Thou and have mercy on us; and thou art the Best of the forgivers.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
And ordain for us good in the world and in the Hereafter; verily we have been guided unto Thee. Allah said: as to My chastisement, therewith afflict whomsoever I Will and as to My mercy, it comprehendeth everything. Wherefore I shall ordain it for those who fear an give poor- rate and those who believe in Our signs.\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the apostle, the unlettered prophet. Whom they find written down with them in the Taurat and the Injil; he biddeth them to the seemly and prohibiteth unto them the unseemly, alloweth unto them things clean and forbiddeth unto them things unclean and relieveth them of their burthen and the shackles which have been upon them. Those who believe in him and side with him and succour him and follow the light which hath been sent down with him; those: they shall fare well.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say thou: O mankind! verily I am the apostle of Allah unto you all- of Him whose is the dominion of the heavens and the earth. No god is there but he; He giveth life and causeth to die. Believe then in Allah and His prophet, the unlettered prcphet, who believeth in Allah and His words, and follow him that haply ye may be guided.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And of the people of Musa there is a community guiding others by the truth and judging thereby.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We cut them up into twelve tribes as communities. And We revealed unto Musa, when his people asked him for drink: Smite the rock with thy rod. Then gushed forth therefrcm twelve springs: every people already knew their drinking-places. And We shaded them with thick clouds, and We sent down upon them the manna and the quails, saying: eat of the clean things wherewith We have provided you. And they wronged not Us, but themselves they were wont to wrong.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And recall what time it was said unto them: dwell in yonder town and eat plentifully therefrom an ye list, and say: fergiveness, and enter the gate bowing; and We will forgive you your trespasses: anon We will increase unto the well-doers.\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
Then those of them who did wrong changed the word that had been told them for anot her, whereupon We sent upon them a scourge from the heaven for they were wont to transgress.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask thou them concerning the town that was close on the sea, when they transgressed in the matter of the sabt, when their fish came unto them openly on their sabt day, while they came not on the day whereon they kept not We proved them for the sabt. Thus they were wont to transgress.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And recall what time a community of them said Why exhort ye a people whom Allah is going to destroy or chastise with a severe chastisenent They said: to justify us before your Lord, and that haply they may fear.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
Then when they forgot that wherewith they had been exhorted, We delivered those who restrained from evil, and We laid hold of those who did wrong with a distressing torment for they were wont to transgress.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
So when they exceeded the bounds of that which they were prohibited We said unto them: be ye apes despised.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And recall what time thy Lord proclaimed that he would surely raise upon them, till the Day of Resurrection, someone perpetrating upon them worst oppression. Verily thy Lord is swift in chastising, and verily He is Forgiving, Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We cut them up into communities on the earth; some of them righteous, and some of them otherwise; and We proved them wifh good and evil that haply they may return.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
Then there succeeded them a posterity; they inherited the Book taking this near world's gear and saying surety it will be forgiven, And if there cometh unto them anot her gear like thereunto they shall take it. Hath there not lain upon them the bond of the Book that they shall not say of God aught but the truth? And they have read that which is therein. And the abode of the Hereafter is better for those who fear. Understand then ye not?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And those who hold fast by the Book and establish prayer-- verily We shall not waste the hire of the rectifiers.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And recall what time We shook the mountain over them as though it were a canopy, and they imagined that it was going to fall on them; and We said: hold with firmness that which We have vouchsafed you, and remember that which is therein, that haply ye may fear.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And recall what time thy Lord took from the children of Adam their posterity from their backs, and made them testify as to them selves saying: am I not your lord? They said: Yea! we testify. That was lest ye should say on the Day of Resurrection verily of this we have been unaware.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or lest ye should say: it Was only our fathers who associated afore, and we have been a posterity after them; wilt Thou then destroy us for that which the followers of falsehood did?\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
And Thus We detail the revelations, that haply they may return.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite thou unto them the story of him Unto whom We vouchsafed Our signs, but he sloughed them off, wherefore the Satan followed him, and he became of the perverted.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed We would surely have lifted him thereby, but he clung to the earth and followed his desire, wherefore his case became like unto the case of a dog, who, if thou attackest him, lolleth out his tongue and if thou leavest him alone, lolleth out his tongue. Such is the likeness of the people who belie Our sign; so recount thou the narratives, that haply they may refelect.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Vile is the likeness of the people who belie Our signs, and their own souls they are wont to wrong.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomsoever Allah guideth, he is the rightly guided: and whomsoever He sendeth astray - those! they are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And assuredly We have created for Hell many of the genii and mankind; they have hearts wherewith they understand not, and they have eyes wherewith they see not, and they have ears wherewith they hearken not; they are like unto cattle; nay, they are further astray; those! they are the negligent ones.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
Allah's are the excellent names; so call on Him thereby; and leave alone those who profane His names. Anon will they be requitcd for that which they were wont to work.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And of those whom We have created there is a community guiding others with truth and acting justly according thereto.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
And those who belie Our signs, step by step We lead them on in a way they know not.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I give them rein: verily My contrivance is firm.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Reflect they not that in their companions there is no madness! he is naught but a manifest warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Look they not at the governance of the heaven and the earth and whatsoever Allah hath created of aught, and at the fact that their term may have drawn nigh? In what discourse then will they, thereafter, believe!\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whomsoever Allah sendeth astray, no guide is then for him, and He letteth them wander perplexed in their exorbitance.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask thee concerning the Hour, when will its coming be? Say thou: knowledge thereof is with my Lord only: none shall disclose it at its time buthe; heavy it is in the heavens and the earth; it shall not come upon you except on a sudden. They ask thee as though thou wert familiar therewith. Say thou: knowledge thereof is with Allah only; but most of men know not.\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say thou: I possess no power over benefit or hurt to myself save as Allah willeth; and had I knowledge of the unseen I would have amassed ample good, and evil would not have touched me. I am naught but a warner and a bringer of tidings unto a people who believe.\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
He it is who created you from a single soul, and He created therefrom his spouse that he might find repose in her. Then when he covereth her she beareth a light burthen and fareth about there with; then when she groweth heavy the twain call upon Allah their Lord: if Thou vouchsafest us a goodly Child, we shall surely be of the thankful.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He vouchsafeth the twain a goodly child they set up unto Him associates in respect of that which He hath vouchsafed to them. Exalted be Allah far from that which they associate!\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Associate they those who cannot create aught and are created?\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
And who cannot succour them, nor can succour themselves.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if ye call them toward guidance they follow you not: it is the same to you whether ye call them or are silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Verily those whom ye call upon beside Allah are creatures like unto you; so call on them, and let them answer you if ye say sooth.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet wherewith they wend? Have they hands wherewith they grip? Have they eyes wherewith they see? Have they ears wherewith they hearken? Say thou: call upon your associate gods, and then plot against me and respite me not.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
Verily my protector is Allah who hath revealed the Book, and He protecteth the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
And those whom ye call upon be side Him cannot succour you nor them selves they can succour.\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if ye Call them towards guidance they will not hear and thou wilt behold them looking at thee, but they see not.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Use thou indulgence and enjoin seemliness and turn away from the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if there prompt thee a prompting from the Satan, see refugee with Allah; verily He is Hearing, Knowing.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Verily those who fear God when an instigation from the Satan toucheth them, they call to mind land lo! they are enlightened.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
And their brethren drag them on toward error, so they stop not short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And whenever thou bringest not unto them, as a sign, they say: wherefore hast not thou selected it? Say thou: I only follow that which hath been revealed unto me by my Lord. This is an enlightenment from your Lord and a guidance and a mercy unto a people who believe.\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
So when the Qur'an is recited, listen thereto and keep silence, haply ye may be shewn mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember thou thy Lord within thyself with humility and fear, without loudness in word, in the morning and evenings; and be thou not of the negligent.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Verily those who are with thy Lord are not stiff-necked against His woorship, and they hallow, and unto Him they prostrate themselves.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask thee concerning the spoils of war. Say thou: the spoils of war are Allah's and the apostle's. So fear Allah, and set right the matter among you, and obey Allah and His apostle if ye are believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
The believers are only those whose hearts thrill with fear when Allah is mentioned, and when His revelations are rehearsed unto them, they increase their faith and who trust in their Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Who establish prayer and who expend of that wherewith We have provided them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
Those: it is they who are the true believers. For them are degrees with their Lord and forgiveness and a provision honourable.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
This is like what time thy Lord had caused thee to go forthfrom thy house for a right cause, while a party among the believers were averse.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with thee respecting the right cause after it had become manifest, as though they were led forth unto death while they looked on.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And recall what time Allah was promising you one of the two parties that it should be yours, and ye would fain to have that the one without; Whilst Allah besought arms were yours to justify the truth by His words and to cut off the root of the infidels.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
In order that he might justify the truth and falsify the false even though the guilty ones were averse.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
And recall what time ye implored our Lord and He answered you: verily I am about to succour you with a thousand of angels rank in rank.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
And Allah made not this save as a glad tidings, and that your hearts might thereby be set at rest; and succour cometh not but from Allah. Verily Allah is Mighty, Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
Recall what time He caused slumber to cover you as a security from Himself, and He sent down rain upon you from heaven that he might cleanse you thereby and take away from you the pollution of the Satan, and that he might gird up your hearts and make your feet firm thereby.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
And recall what time thy Lord inspired the angels: verily I am with you, so keep firm those who have believed; will cast horror into the hearts of those who have disbelieved, so smite them above the neck and smite of them every fingertip.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This, because they have resisted Allah and His apostle; and whosoever resisteth Allah and His apostle, then verily Allah severe in retribution.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
This! taste it then, and know that for the infidels is the torment of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O Ye who believe! whenever ye those who disbelieve matching meet slowly turn to them not your backs.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
And whosoever turneth his back to them on such a day, unless it be swerving to a fight or wriggling round to anot her company, hath surely drawn upon himself indignation from Allah, and his resort is Hell--an evil destination!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
Wherefore ye slew them not, but Allah slew them, and thou thrtwest not, When thou threWest, but Allah threw, in order that he might prove the believers with a goodly proving from Him. Verily Allah is Hearing, Knowing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
Thus! And know that Allah weakenoth the contrivance of infidels.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
If ye besought a judgement then surely a judgement hath come unto you. And if ye desist it Will be better for you; and if ye return. We will return; and your host shall avail you not, although numerous it be; and know that verily Allah is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O Ye who believe! obey Allah and His apostle and turn not away therefrom while ye hearken.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And be not like unto those who say: we hear, whereas they hearken not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Verily the vilest of beasts with Allah are the deaf and dumb who understand not.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
And had Allah known in them any good He would surely have made them hearken; and even if He made them hear, they would surely turn away as backsliders.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O Ye who believe! answer Allah and the apostle when he calleth you to that which quickeneth you, and know that verily Allah interposeth between a man and his heart, and that verily unto Him ye all shall be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear the trial that shall not afflict those alone who among you do Wrong; and know that verily Allah severe in chastising.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember what time ye were few and downtrodden in the land fearing that the people would snatch you away; then He gave you refuge and strengthened you with His succour, and provided you with good things that haply ye might return thanks.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O Ye who believe! defraud not Allah and the apostle, nor defraud your trusts while ye know.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your riches and your children are but a temptation, and that verily Allah: with Him is a mighty hire.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O Ye who believe! if ye fear Allah He will make for you a distinction and will expiate for you your misdeeds, and forgive you; and Allah is Owner of Mighty Grace.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And recall what time those who disbelieved were plotting against thee to confine thee or to slay thee or to drive thee forth: they were plotting and Allah was plotting, and Allah is the Best of plotters.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our revelations are rehearsed unto them, they say: we have heard; we could if we willed, surely say something the like thereof; naught is this but fables of the ancients.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And recall what time they said: O God! if this indeed be the truth from before Thee, then rain down stones upon us from heaven or bring on us a torment afflictive.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
And Allah is not one to chastise them whilst thou art in their midst, nor was Allah going to chastise them while they were asking forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
And what aileth them that Allah should not chastise them when they are hindering people from the Sacred Mosque, whereas they are not even the keepers thereof - its keepers are none but the God-fearing-- but most of them know not.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
And naught was their prayer at the House but whistling and hand-clapping. Taste then the torment for ye were to disbelieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Verily those who disbelieve are expending their riches in order to hinder People from the way of Allah; so they will go on expending them; thereafter they shall become an anguish unto them; then they shall be overcome. And those who disbelieve shall be gathered for Hell.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
In order that Allah may distinguish the vile from the good; and the vile He shall place one upon anot her, and shall pile it all together, and shall place it into Hell. Those! it is they who are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say thou unto those who have disbelieved: if they desist, that which is past shall be forgiven them, and if they return, then already gone forth is the dispensation of the ancients.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight against them until there be no temptations and their obedience be wholly unto Allah. So if they desist, thens verily Allah is the Beholder of that which they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, then know that Allah is your Patron: excellent Patron! and excellent helper!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatsoever ye obtain of spoils then verily unto Allah belongeth a fifth thereof and unto the apostle and unto his kindreds and the orphans and the needy and the wayfarer if ye indeed have believed in Allah and that which We sent down on our bondmans on the day of distinction, the day whereon the two hosts met. And Allah is over everything Potent.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
And recall what time ye were on the hither side and they were on the yonder side and the caravan below you. And if ye had mutually appointed ye would surely have failed the appointment. But the action wao brought about in order that Allah may decree an affair already enacted, so that he who was to perish, should perish after an evidence and he who was to remain alive may remain alive after an evidence. And verily Allah is Hearing, Knowing.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
And recall what time Allah shewed them few unto thee in thy dream. And had He shewn them numerous unto thee, surely ye would have flagged and surely ye would have disputed over the affair but Allah saved you. Verily He is the Knower of that which is in the breasts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
And recall what time He shewed them few in your eyes when ye met and lessened you in their eyes in order that Allah might decree an affair already enacted; and unto Allah are all affairs returned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O Ye who believe! when ye meet a party, stand firm and remember Allah much, that haply ye may fare well.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His apostle, and dispute not, lest ye flag and your predominance depart, and be patient. Verily Allah is with the patient\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And be not like unto those who came forth from their homes vaunting and to be seen of men and hindering others from the way of Allah; and Allah is the Ecompasser of that which they work.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And recall what time the Satan made their works fair- seeming unto them and said: there is none of mankind to overcome you to- day, and verily I am your neighbour. Then when the two parties faced each other, he turned on his heels, and said: verily I am quit of you, verily I behold that which ye behold not; verily I fear Allah: and Allah severe in retribution.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
And recall what time the hypocrites and these in whose hearts was a disease said: their religion hath be gulfed those. And whosoever relieth on Allah then verily Allah is Mighty, Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
And couldst thou behold when the angels take away the life of those who disbelive striking their faces and their backs: taste the torment of burning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
This, because of that which your hands have sent forth, and verily Allah is never unjust unto His creatures.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
Like are they unto the wont of the house of Fir'awn and those before them. They disbelieved in the signs of Allah, wherefore Allah laid hold of them for their sins. Verily Allah is strong, Severe in retribution.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
This, because Allah is not one to change His favour wherewith He hath favoured a people until they have changed that which is in themselves; and verily Allah is Hearing, Knowing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Like are they Unto the wont of the house of Fir'awn and those before them. They belied the signs of their Lord; wherefore We destroyed them for their sins, and drowned the house of fir'awn; and all of them were wrong-doers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Verily the vilest of moving creatures with Allah are those who disbelieve-wherefore they shall not believe-\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
They with whom thou covenantedest, then they break their covenant every time, and they fear not.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
Wherefore if thou over-takest them in war, disperse thou through them those behind them, that haply they may be admonished.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
And shouldst thou fear treachery from any people cast back then unto them their covenant to be equal. Verily Allah approveth not the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
Let not those who disbelieve deem that they have escaped, verily they cannot frustrate.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
And get ready against them whatsoever ye can of force and wellfed horses whereby ye may overawe the enemy of Allah and your enemy and others besides them whom ye know not Allah knoweth them. And whatsoever ye expend in the way of Allah shall be repaid to you in full; and ye shall not be wronged.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
And if they incline unto peace, then thou mayest incline thereunto, and rely thou on Allah; verily He is the Hearer, the Knower.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they seek to deceive thee, then verily Allah is sufficient unto thee. He it is who aided thee with His succour and with the believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And He united their hearts. Hadst thou expended all that is on the earth thou couldst not have united their hearts, but Allah united them; verily He is Mighty, Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
0 Prophet! sufficient unto thou is Allah and those who follow thee of believers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
0 Prophet! urge the believers unto fighting. If there be twenty of you persevering, they will overcome two hundred, and if there be of you a hundred, they will overcome a thousand of those who disbelieve, for they are a people who understand not.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now Allah hath lightened your burden, and He knoweth that verily there is in you a weakness. So if there be a hundred of you persevering, they will overcome two hundred, and if there be a thousand of you they will overcome two thousand, by the command of Allah and Allah is with the persevering.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It behoveth not a prophet that he should have captives until he hath greatly slaughtered in the land. Ye seek the gear of the world, while Allah seeketh the Hereafter; and Allah is Mighty, Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Were it not that a writ had already gone forth from Allah, there would surely have touched you a mighty torment for that which ye took\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
Eat ye then of that which ye have obtained of spoi1, lawful and clean, fear Allah; verily Allah is Forgiving, Merciful\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! say Unto the captives who are in your hands: if Allah knoweth any good in Your hearts He will give you better than that which hath been taken away from you, and shall forgive you; and Allah is Forgiving, Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
And if they seek defrauding thee, then they have defrauded Allah before, yet he gave thee power over them; and Allah is Knowing, Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Verily those who believed and emigrated and strave hard in the way of Allah with their riches and lives'and those who sheltered and succoured: those shall be heirs unto one anot her. And those who believed but emigrated not, ye have naught of inheritance to do with them, unless they emigrate. And should they seek succour from you in the matter of religion, then incumbent on you is the succour, except against a people between whom and you there is a compact. And Allah is the Beholder of that which ye work.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieve: they shall be heirs unto one anot her. if ye do this not, a sedition there will be in the land and a great corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
And those who believe and have emigrated and striven hard in the way of Allah, those who sheltered and succoured --these! they are the believers in very truth; for them shall be forgiviness and honourable provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed after wards and emigrated and strave hard along with you: these also are of you; and the kindred by blood are nearer unto one anot her in Allah's decree; verily Allah is of everything the Knower.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen Quittance is this from Allah and His aposle unto the associators with whom ye had covenanted.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
Go about, then, in the land for four months. And know that verily ye cannot escape Allah, and that verily Allah is the humiliator of the infidels.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And a proclamation is this from Allah and His apostle unto the mankind on the day of the greater pilgrimage that Allah is quit of the associators, and so is His apostle. Wherefore if ye repent, it shall be better for you, but if ye turn away, then know that ye cannot escape Allah. And announce thou unto those who disbelieve a torment afflictive.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Except those of the associators with whom ye covenanted and they have not failed you in aught, nor have they backed up anyone against you; so fulfil unto them their covenant till their full period. Verily Allah loveth the Godfearing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
When, therefore, the sacred months have slipped away, slay the associators's wheresoever ye find them and capture them and beset them and lie in wait for them at every ambush. Then, should they repent and establish prayer and give the poor-rate, leave their way free. Verily Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And should one of the associators seek protection of thee grant him protection, that he may hear the word of Allah, then let him reach his place of security. That is because they are a people who know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be for the associators covenant with Allah. and His apostle save for those with whom ye covenanted near the Sacred Mosque? Act straight with them so long as they act straight with you. Verily Allah loveth the God-fearing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How indeed! whereas if they get the better of you they respect not regarding you either kinship or agreement. They please you with their mouth, the while their hearts refuse; and most of them are Ungodly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have bartered the revelations of Allah for a small price, so they keep back from His path. Verily vile is that which they have been working.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
They respect not either kinship or agreement in a believer: those! they are the transgressors!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
If they repent and establish prayer and give the poor- rate, then they are your brethren-in-faith. And we detail the revelations unto a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
And if they violate their oaths after their covenant and revile your religion, fight those leaders of infidelity-verily no oaths will hold in their case that haply they may desist.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will ye not fight a people who have violate their oaths and resolved the expulsion of the apostle and who began against you for the first time? Fear ye them? Allah is more worthy that ye should fear Him, if ye are believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them. Allah will torment them at your hands, and humiliate them and give you victory over them and heal the breasts of the believing people.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And He will take away the rage of their hearts. And Allah will relent toward whomsoever He liketh; and Allah is Knowing, Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Deem ye that ye would be left alone while yet Allah hath not known those of you who have striven hard and have not taken an ally besides Allah and His apostle and the believers? And Allah is Aware of that which ye work.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the associators that they shall tend Allah's mosques, while giving evidence of infidelity against themselves. Those! vain shall be their works, and in the Fire they shall be abiders.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
They only shall tend Allah's mosques who believe in Allah and the Last Day and establish prayer and give the poor rate and fear none save Allah. Belike those will be of the guided ones.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Make ye the giving of drinks unto the pilgrims and the tendance of the Sacred Mosque like unto the conduct of one who believeth in Allah and the Last Day and striveth hard in the way of Allah! Equal they are not with Allah, and Allah guideth not the wrong-doing people.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who have believed and emigrated and have striven hard in the way of Allah with their riches and their lives are for higher in degree with Allah. Those! they are the achievers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord giveth them glad tidings of a mercy from Him and of goodwill and of the Gardens wherein theirs will be a delight lasting:\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
As abiders therein for evermore. Verily Allah: with Him is a hire mighty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O Ye who believe! take not your fathers and your brothers for friends if they love infidelity above faith. Whosoever of you then befriendeth them then those! they are the wrong-doers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say thou: if you fathers and your sons and your brothers and your wives and your family and the riches ye have acquired and the traffic wherein ye fear a slackening and the dwellings which please you are dearer unto you than Allah and His apostle and striving in His cause, then wait until Allah bringeth about His decree, and Allah guideth not the ungodly people.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Assuredly Allah hath succoured you on many fields and on the day of Hunain, When your number elated you; then it availed you naught, and the earth, wide as it is, straitened unto you; then ye turned away in retreat.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Thereafter Allah sent down His calm upon His apostle and upon the believers, and He sent down hosts ye saw not and tormented those who would disbelieve: such is the meed of the infidels.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then Allah will, thereafter, relent toward whomsoever He liketh, and Allah is Forgiving, Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O Ye who believe! the associators are simply filthy; so let them not approach the Sacred Mosque after this their year; and if ye fear poverty, Allah shall presently enrich you out of His grace, if He will. Verily Allah is grace. Knowing, Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight against those who believe not in Allah nor in the Last Day and hold not that forbidden which Allah and His apostle have forbidden and observe not the true religion, of those who have been vouchsafed the Book, until they pay the tribute out of hand and they are subdued.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
And the Jews say: Uzair is a child of God; and the Nazarenes say: the Masih is a child of God. That is their saying with their mouth, resembling the saying of those who disbelieved aforetime. May Allah confound them'. whither are they turning away!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken their priests and their monks for their Lords besides God, and also the Masih son of Maryam; whereas they Were commanded not but to worship the One God: no god is there but he. Hallowed be He from that which they associate'.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They seek to extinguish the light of Allah with their mouths; and Allah refuseth to do otherwise than perfect His light, although the infidels may detest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
He it is who hath sent His apostle with the guidance and the true religion that he may make it prevail over all religions, although the associators may detest.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O Ye who believe! verily many of the priests and the monks devour the substances of men in falsehood and hinder People from the way of Allah. And those who treasure up gold and silver and expend them not in the way of Allah -announce thou unto them a torment afflictive.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On a Day whereon they Shall be heated in Hell-Fire, and therewith shall be branded their foreheads and their sides and their backs: this is that which ye treasured up for yourselves, so taste now that which ye have been treasuring up.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Verily the number of months with Allah is twelve months ordained in the writ of Allah on the day whereon He created the heavens and the earth; of these four sacred: that is the right religion. Wherefore wrong not yourselves in respect thereof. And fight the associators, all of them even as they fight all of you; and knew that Allah is with the God-fearing\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The postponement is but an addition unto infidelity, whereby the infidels are led astray, allowing it one year and forbidding it anot her year, that they may make up the number which Allah hath sanctified; and then they allow that which Allah hath forbidden. Made fair-seeming unto them is the vileness of their works; and Allah guideth not an infidel people.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O Ye who believe! what aileth you that when it is said unto you: march forth in the way of Allah, ye are weighed down earthward? Are ye pleased with the life of the world rather than the Hereafter? whereas the enjoyment of the life of the world by the side of the Hereafter is but little.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If ye march not forth, He will torment you with a torment afflictive, and will substitute for you a people-other than you; and Him ye cannot hurt in aught; and Allah is over everything Potent.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If ye succour him not, then surely Allah hath succoured him when these who disbelieved drave him: the second of the two When the twain were in a cave, and when he Said unto his companion. grieve not, verily Allah is with Us. Then Allah sent down His calm upon him and aided him with hosts whom ye saw not, and made the word of those who disbelieved nethermost, and the word of Allah! that is the upper most. And Allah is Mighty, wise,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
March forth light and heavy and strive hard with your riches and your lives in the way of Allah; that is the best for you, if ye have knowledge.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Were there a gear nigh and a journey moderate, they would have surely followed thee, but the distance seemed far unto them. And anon they will be swearing by Allah: if only we could we would surely have come forth with you. They destroy their own souls: and Allah knoweth that verily they are liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
Allah pardon thee! why didst thou give them leave before it was manifest unto thee as to whosoever told the truth and thou hadst known the liars.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day would not ask thy leave to be excused from striving hard with their riches and their lives; and Allah is Knower of the God-fearing.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
It is only those who believe not in Allah and the Last Day and whose hearts doubt who ask thy leave, so in their doubt they are tossed to and fro.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And had they intended the going forth, they would have made some preparation therefor; But Allah was averse to their wending, wherefore He withheld them, and the word was passed: stay of home with the stay-at-homes.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gene forth with you, they would have added unto you naught save unsoundness, and they would surely have hurried about in Your midst seeking sedition unto you; and amongst you there are listeners to them; and Allah is Knower of the wrong-doers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Assuredly they besought sedition afore and turned the affairs upside down for thee until the truth arrived and the decree of Allah prevailed, averse though they were.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And of them there is he who saith: give me leave, and tempt me not. Lo! into temptation they are already fallen, and verily the Hell is the encompasser of the infidels.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalleth thee, it annoyeth them, and if an affliction befalleth thee, they say; surely we took good hold of our affair before. And they turn away while they are exulting.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say thou: naught shall ever befall us save that which Allah hath ordained for us; He is our patron, and on Allah let the believers rely.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say thou await ye for us ought save one of the two excellences; while for you we wait that Allah shall afflict you with a torment from Himself or at our hands. Await then, we also are with you awaiting.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say thou: expend willingly or unwillingly, it will not be accepted of you; verily ye are ever a people ungodly.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And naught preventeth their expendings being accepted except that they have disbelieved in Allah and His apostle, and they perform not prayer except as sluggards and expend not except as those averse.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
Let not wherefore their riches and their children amaze thee. Allah intendeth only to torment them therewith in the life of the world and that their souls pass away while they are infidels.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
And they swear by Allah that they are surely of you, whereas they are not of you; but they are a people who dread.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
Could they find a place of refuge or caverns or a retreating hole, they would turn round thereto rushing headlong.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And of them are some who traduce thee in respect of alms. Then if they are given thereof they are pleased and if they are not given thereof, lo! they are enraged.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
Would that they were pleased with that which Allah and His apostle had given them, and were to say: sufficient unto us is Allah, anon Allah will give us out of His grace and so will His apostle, verily unto Allah we lean.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The compulsory alms are only for the poor and the needy and the agents employed therein and those whose hearts are to be conciliated and those in bondage and debtors and for expenditure in the way of Allah and for the wayfarer: an ordinance from Allah: and Allah is Knowing, Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And of them are some who vex the prophet and say: he is all ears Say thou: he is all ears unto good for you, believing in Allah and giving credence to the believers and a mercy unto those of you who believe. And those who vex the apostle of Allah, unto them shall be a torment afflictive.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear unto you by Allah that ye be pleased, whereas wortheir are Allah and His apostle that they should please Him, if they be believers indeed.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Know they not that whosoever shall oppose Allah and His apostle, verily for him shall be Hell-Fire wherein he shell be an abider? That is a mighty humiliation.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites apprehend lest a Surah should be revealed unto them declaring unto them that which is in their hearts. Say thou: mock on! verily Allah is about to bring out that which ye apprehend.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
Shouldst thou question them, they will surely say:: we were only plunging about and playing. Say thou: was it Allah and His signs and His apostle that ye have been mocking?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuse. Of a surety ye are disbelieving after declaring your faith. If, party of you We shall Opardon, anot her party We shall torment for they have remained sinners.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocritical men and the hypocritical women are all of a piece; they command that which is disreputable and restrain from that which is reputable, and they tighten their hands. They neglected Allah, so He had neglected them. Verily the hypocrites! they are the ungodly ones.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah hath promised the hypocritical men and hypocritical women and unto the open infidels Hell-Fire, wherein they shall be abiders: sufficient is that unto them. And Allah shall accurse them, and theirs shall be a torment lasting.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
Like ye are unto those before you: mightier were they than you in prowess and more abundant in riches and children. They enjoyed their portion awhile, so enjoy your portion awhile even as those before you enjoyed their portion awhile, and ye plunged about even as they plunged about. Those! their works have come to naught in the world and the Hereafter, and those! they are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Have not come to them the tidings of those before them: the people of Nuh and 'Ad and Thamud and the people of Ibrahim and the dwellers of Madyan and of the overturned cities! There came unto them their apostles with evidences. Wherefore Allah was not one to wrong them, but themselves they were wont to wrong.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
And the believing men and believing women are friends one unto anot her: they command that which is reputable and restrain from that which is disreputable, and establish prayer and give the poor-rate and obey Allah and His apostle. Those! Allah will surely show mercy to them; verily Allah is Mighty, Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah hath promised the believing men and believing women Gardens whereunder rivers flow, wherein they shall be abiders, and goodly dwellings in the Everlasting Gardens --and goodwill from Allah is the greatest ofall--that! it is the achievement supreme.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! strive hard against the infidels and the hypocrites; and be severe unto them. And their resort is Hell--a hapless destination.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said it not, but assuredly they said the word of infidelity and disbelieved after their Profession of Islam and they resolved that to which they could not attain. And they avenged not except for this that Allah and His apostle had enriched them out of His grace. If then they repent, it will be better for them, and if they turn away, Allah will torment them with an afflictive torment in the world and the Hereafter, and theirs shall be on the earth no friend nor helper.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And of them are some who covenanted With saying: if He giveth of His grace, we will surely give alms and we will surely become of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Then when He gave them out of His grace, they became niggardly therewith and turned away as backsliders.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He chastised them with setting hypocrisy in their hearts until the Day they shall meet Him, because they kept back from Allah that which they had promised Him, and because they were wont to lie.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Knew they not that Allah knoweth their secret and their Whisper, and that Allah is the Knower of Things Hidden!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
These are they who traduce those who give alms cheerfully, from among the believers, and those who find not anything to give but their hard earnings: at them they scoff. Allah shall scoff back at them. and theirs shall be a torment afflictive.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Ask thou forgiveness for them or ask thou not forgiveness for them: if thou askest forgiveness for them seventy times, Allah will forgive them not. This, because they disbelieved in Allah and His apostle, and Allah guideth not an ungodly people.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left rejoiced at their staying behind the apostle of Allah, and they detested to strive hard with their riches and their lives in the way of Allah, and they said: march not forth in the heat. - Say thou: hotter still is the Hell-Fire. Would that they understood!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Little then let them laugh, and much they shall weep: the meed of that which they have been earning.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If, then, Allah bring thee back to a party of them, and they ask leave of thee for going forth, say thou: never ye shall go forth with me, nor ever fight an enemy with me; verily ye were pleased with sitting at home the first time, wherefore sit now with those who stay behind.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And pray thou not ever over any of them that may die nor stand thou over his grave. Verily they have disbelieved in Allah and His apostle and died while they were ungodly.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And let nor their riches and their children amaze thee. Allah intendeth only to torment them therewith in the world, and that their souls may pass away while they are infidels.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And whenever any Surah is sent down commanding: believe in Allah and strive hard in the company of His apostle, the opulent among them ask leave of thee, and say: leave us; we shall be with those who stay.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
Pleased are they that they should be with the women sitters-at-home, and their hearts are sealed up, so they understand not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the apostle and those who believed in his company strave hard with their riches and their lives. These are they for whom are goods, and these: they are the blissful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
For them Allah hath gotten ready Gardens whereunder rivers flow, wherein they shall be as abiders. That is the supreme achievement.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And there came the apologists from among dwellers of the desert men praying that leave may be given them and those Who had lied unto Allah and His apostle sat at home. An afflictive torment shall afflict those of them who disbelieve.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
Not on the feeble and the ailing nor on those who find not the where withal to expend there is any blame, when they wish well to Allah and His apostle. No way is there against the well-doers; and Allah is Forgiving, Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor on those who, when they came unto thee that thou mightest mount them and thou saidst: I find not any animal to mount you on, turned back while their eyes overflowed with tears for grief that they could not find ought to expend.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The way is only against those who ask leave of thee while they are rich. They are pleased that they should be with the women sitters-at-home. Allah hath sealed up their hearts, so they know not.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will excuse themselves unto you when ye return to them. Say thou: excuse not yourselves, we shall by no means believe you: Allah hath already declared unto us some tidings of you, and Allah will behold your work and so will His apostle; and thereafter ye will be brought back unto Him who knoweth the hidden and the manifest, who will then declare unto you that which ye have been working.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will indeed swear unto you by Allah when ye return to them that ye may avert from them. So avert from them: verily they are an abomination, and their resort is Hell--a recompense for that which they have been earning.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear unto you in order that ye may be well- pleased with them. Then if ye are well-pleased with them, verily Allah will not be well-pleased with an ungodly people.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The dwellers of the desert are the hardest in infidelity and hypocrisy and likeliest not to know the ordinances of that which Allah hath sent down unto His apostle. And Allah is Knowing, Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And of the dwellers of the desert is one who taketh that which he expen deth as a fine, and waiteth for evil turns of fortune for you. Upon them shall be the evil turn of fortune. And Allah is Hearing, Knowing.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And of the dwellers of the desert is one who believeth in Allah and the Last Day, and taketh that which he expendeth as approaches unto Allah and the blessings of His apostle. Lo! verily these are an approach for them; anon Allah will enter them into His mercy. Verily Allah is Forgiving, Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the Muhajirs and Ansar, the leaders and the first ones and those who followed them in well-doing, --well-pleased is Allah with them, and well pleased are they with Him, and He hath gotten ready for them Gardens where under the rivers flow, as abiders therein forever. That is the achievement supreme.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And of the dwellers of the desert around you some are hypocrites, and so are some of the people of Madinah; they have become inured to hypocrisy thou knowest them not, We know them. We will torment them twice, and thereafter they shall be brought back to a torment terrible.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And others have confessed their faults; they have mixed up a righteous work with anot her vicious. Bellike Allah will relent toward them; verily Allah is Forgiving, Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take thou alms out of their riches; thereby thou wilt cleanse them and purify them; and pray thou for them. Verily thy prayer is a repose for them; and Allah is Hearing, Knowing.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Know they not that it is Allah who accepteth the repentance of His bondmen and taketh the alms, and that it is Allah who is the Relenting, the Merciful!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say thou: work on! Allah beholdeth your work and so do His apostle and the believers, and anon ye will be brought back to the Knower of the hidden and the manifest; He will then declare unto you that which ye have been working.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And others are awaiting the decree of Allah, whether He shall torment them or whether He will relent toward them; and Allah is Knowing, Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And as for those who have set up a mosque for hurting and blaspheming and the causing of division among the believers and as a lurking-place for one who hath warred against Allah and His apostle aforetime, and surely; they will swear: we intended only good, whereas Allah testifieth that they are liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Thou Shalt never stand therein. Surely a mosque founded from the first day on piety is wortheir that thou shouldst stand therein. In it are men who love to cleanse themselves: and Allah approveth the clean.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is he, then, who hath founded his building upon piety towards Allah and His good-will better, or he who hath founded his building on the brink of a crumbling bank, so that it crumbleth with him into the Hell-fire! And Allah guideth not the wrong-doing people.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
And their building which they have builded will not cease to be a cause of doubt in their hearts unless it be that their hearts are cut asunder; and Allah is Knowing, Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Verily Allah hath bought of the believers their lives and their riches for the price that theirs shall be the Garden: they fight in the way of Allah and slay and are slain: a promise due thereon in the Taurat, in the Injil - and the Qur'an-and who is more faithful unto his covenant than Allah? Rejoice wherefore in your bargain which ye have made. And that it is the mighty achievement.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
They are those who repent, who worship who praise, who fast constantly, woo bow down, who prostrate themselves, who command the reputable and restrain from the disreputable and who keep the ordinances of Allah; and bear thou glad tidings to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet and those who believe to ask for the forgiveness of the associators, although they be of kin after it hath become manifest unto them that they are the fellows of the Flaming Fire.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And Ibrahim's asking for the forgiveness of his father was only in pursuance of a promise which he had made unto him. Then, when it became manifest unto him that he was an enemy of Allah, he declared himself quit of him. Verily Ibrahim was long-suffering, forbearing.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
Allah is not one to leed a people astray after He hath guided them until He hath made manifest unto them that which they should guard against. Verily Allah is of everything the Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Verily Allah! His is the dominion of the heavens and the earth. He giveth life and He causeth to die; and for you there is, besides Allah, no protector or helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Assuredly Allah hath relented toward the Prophet and the Muhajirs and the Ansar who followed him in the hour of distress after the hearts of a part of them had well-nigh swerved aside when He relented toward them. Verily He is unto them Tender, Merciful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And also He relented toward the three who were left behind until when the earth, vast as it is, became straitened unto them and their own lives became straitened unto them and they imagined that there was no refuge from Allah except unto Him. Thereafter He relented toward them, so that they might repent. Verily Allah! He is the Relenting, the Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O Ye who believe! fear Allah, and be with the truthful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It was not for the people of Madina and those around them of the desert dwellers that they should lay behind the apostle of Allah, nor that they should prefer themselves before him. That is because there afflicteth them not thirst or fatigue or hunger in the way of Allah or they tread a place trodden on enraging the infidels, nor they attain an attainment from the enemy, but a good deed is thereby written down unto them. Verily Allah wasteth not the hire of the well-doers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
And they expend not an expending, small or great, or transverse a vale, but it is written down unto them, so that Allah may recompense them with the best for that which they have been working.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And it is not for the believers to march forth all together. So why should not a band from each party of them march forth so that they may gain understanding in religion and that when they come back unto them, haply they might warn their people when they come back unto them, haply they may beware!\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O Ye who believe! fight the infidels who are near unto you, and surely let them find in you sternness, and know that Allah is with the God-fearing,\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever a Surah s sent down, there are some of them who say which of You hath this increased in faith! As for those who believe, it hath increased them in faith, and they rejoice.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
And as for those in whose hearts is a disease, unto them it hath increased pollution to their pollution, and they die while they are infidels.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Behold they not that they are tried every year once or twice? Yet they repent not, nor are they admonished.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a Surah is sent down they look on at each other as though saying: observeth you anyone? Thereafter they turn to go; Allah hath turned their hearts, for verily they are people who understand not.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Assuredly there hath come unto you an apostle from amongst yourselves: heavy upon him is that which harasseth you, solicitous for you, and with the believers tender and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
If, then, they turn away, say thou: sufficing unto me is Allah, there is no god but he, on Him I rely and He is the Lord of Mighty Throne.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif-Lam-Ra. These are the verses of the Wise Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
It is a matter of wonderment to the mankind that we should reveal unto a man among them saying: warn thou the man kind, and bear those who have believed the glad tidings that theirs shall be a sure footing. with their Lord! The infidels say: verily this in a sorcerer manifest.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Verily your Lord is Allah who hath created the heavens and the earth in six days, then established Himself on the Throne disposing the affair; no in tercessor is there, except after His leave. That is Allah, your Lord; so worship Him. Would ye then not be admonished!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
Unto Him is the return of you all--the promise of Allah is truth. Verily He beginneth the creation, then He shall repeat it, that he may recompense those who believed and did righteous works with equity. And those who disbelieved -- for them shall be draught of boiling water and a torment afflictive for they were wont to disbelieve.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
He it is who hath made the sun a glow and the moon a light, and hath determined mansions for her that ye may know the number of the years and the reckoning Allah hath not created all this except with a purpose; He detaileth these signs unto those who know.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Verily in the alteration of he night and the day and in that which Allah hath created in the heavens and the earth are surely signs unto a people who fear.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Verily those who hope not for meeting with us, and, well- pleased with the life of the world, and are satisfied therewith, and those who are neglectful of our signs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
These! their abode shall be the Fire, for that which they have been earning.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Verily those who believe and do righteous works, their Lord will guide them because of their faith. Beneath them will flow rivers in Gardens of Delight.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their cry therein will be: hallowed be Thou! O Allah! and their greeting therein: peace! And the end of their Cry Will be: all praise unto Allah, the Lord of the worlds\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
And were Allah to hasten the ill unto mankind as their desire for hastening the good, their term would surely have been decreed unto them. So we let alone those who hope not for the meeting with Us, wandering in their exorbitance perplexed.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And when harm toucheth man, he calleth us on his side, or sitting or standing; then when We have removed his harm from him, he passeth on as though he had never called Us to a harm that touched him. In this wise is made fairseeming unto the extravagant that which they have been working.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
And assuredly We have destroyed the generations before you when they did wrong, while their apostles came unto them with the evidences, and they were not such as to believe. In this wise We requite the sinning people.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We appointed you as successors in the land after them, that We might see how ye would work.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And whenever Our manifest revelations are rehearsed unto them, those who hope not for the meeting with Us, say: bring us a Qur'an other than this, or change it. Say thou: it lieth not with me to change it of my own accord; I only follow that which is Revealed unto me; verily I fear, if I disobey my Lord, the torment of the Mighty Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say thou: had Allah so willed. Would not have rehearsed it unto you, nor would He have acquainted you therewith. Of a surety I have tarried among you a lifetime before it. Would ye not then reflect?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who then is a greater wrong doer than he who fabricateth a lie against Allah or belieth His revelations? Verily He will not let the culprits fare well.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship, beside Allah, that which harmeth them not, nor profiteth them, and they say: these are our intercessors with God: Say thou: apprise ye Allah of that which He knoweth not in the heavens nor in the earth? Hallowed be He and Exalted far above that which ye associate!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
And mankind were not but a single ccmmunity then they differed. And had not a word from thy Lord gone forth, it would have been decreed between them in respect of that wherein they differ.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say: wherefore is not a sign sent down unto him from his Lord! Say thou: the Hidden belongeth unto Allah alone; so wait, verily I am with you among those who wait.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We let mankind taste of mercy after an adversity hath touched them, forthwith they have a plot with regard to his signs. Say thou: Allah is swifter in plotting. Verily Our mesengers write down that which ye plot.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is who enableth you to travel by land and sea until when ye are in ships and they run away with them with a goodly wind and they rejoice thereat, there cometh upon them a tempestuous wind and there cometh unto them a billow from every side, and they imagine that they are encompassed therein, they cry unto Allah making there faith pure for Him: If Thou deliverest us from this. we would surely be of those who are thankful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
Then when He delivereth them. they forthwith rebel in the earth without justice. O ye! your rebellion is only against yourselves: a brief enjoyment of the life of the world; thereafter unto Us is Your return; then We will declare unto you that which ye have been working.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The similitude of the life of the world is only as the rain which We send down from heaven, wherewith maingleth the growth of the earth, of which men and cattle eat, until, when the earth putteth on her oranament and is adorned, and the inhabitants thereof imgine that they are potent over it, there cometh unto it Our command by night or by day, then We make it stubble as though it had not flourished yesterday. Thus We detail the signs unto a people who ponder.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
And Allah calleth unto the abode of peace and guideth whomso ever He will to the right path.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
Unto those who have done good is the good (reward) and an increase: neither darkness nor abjection will cover their faces. These are the fellows of the Garden: therein they will be abiders.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And those who have earned misdeeds -the requital of a misdeed is the like thereof and abjection will cover them; no protector they shall have from Allah, though their faces were over cast with pieces of night pitch-dark. These are the fellows of the Fire: therein they will be abiders.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
Remember the Day whereon We shall gather them together, then We shall say un to those who associated: keep your place, ye and your associate gods. Then We shall cause split between them: and their associate-gods will say: it was not us that ye were worshipping.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
And God sufficieth as witness between you and us, of your worship, we have been ever unaware.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
Therein every soul shall prove that which it sent before, and they shall be brcught back to Allah, their rightful Owner, and there shall stray from them that which they were wont to fabriCate.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say thou: who provideth for you from the heaven and the earth, or who owneth the hearing and the sight, and who bringeth forth the living from the lifeless and bringeth forth the lifeless from the living, and who disposeth the affair! They will then surely say: Allah. Say thou: will ye not then fear Him?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is Allah, your rightful Lord. What then is there after the truth but error? Whither away then are ye drifting!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
In this wise is the word of thy Lord justified on those who transgress: that they shall not come to believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say thou: is there any of your associate-gods who originateth the creation and then repeateth it? Say thou: Allah originateth the creation and then shall repeat it. Whither away then are ye deviating?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say thou: is there any of your associate-gods who guideth you to the truth! Say thou: Allah guideth unto the truth. Is He, then, who guideth to the truth more worthy to be followed, or one who findeth not the guidance unless he is guided. What aileth ye then? How ill ye judge!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
And most of them follow naught but an opinion; verily opinion availeth not against the truth; verily Allah is the Knower of that which they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this Qur'an is not such as could be fabricated as against Allah. But it is a confirmation of that a which is before it, and and a d etailing of the Decree, whereof there is no doubt, from the Lord of the worlds.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Say they: he hath fabricated it! Say thou: then bring ye a Surah like thereunto, and call whomsoever ye can beside Allah, if ye say sooth.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Aye! they have belied that of which the knowledge they comprehended not and of which the fulfilment hath not come to them. Likewise belied those who were before them; behold then in what wise hath been the end of the wrongdoers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And of them are some who will believe therein, and of them are some who will not believe therein; and thy Lord is the Best Knower of the corrupters.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they belie thee, say thou: unto me my work, and unto you your work: ye are quit of that which I work and am quit of that which ye work.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And of them are some who hearken unto thee, so canst thou make the deaf hear, even though they apprehend not?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And of them are some who look at thee, so canst thou guide the blind, even though they see not?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Verily Allah wrongeth not mankind in aught but mankind wrong themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And of the Day whereon He shall gather them, as though they had tarried not save an hour of he day they shall mutually recognize. Lost surely are those who belie the meeting with Allah and they were not such as to be guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
And whether We shew thee soome of that which We have promised them, or We cause thee to die, Unto us is their return, and Allah is witness of that which they do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And for each community there hath been sent an apostle; and when their apostle hath arrived, the matter between them is decreed in equity, and they are not wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say: when cometh this promise, if ye say sooth?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say thou: I own not any power of hurt or benefit unto myself, save that which Allah may will. For each community is a term; when their term hath arrived, not an hour can they stay behind nor can they advance.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say thou: bethink ye, if His torment come on you by night or by day which Portion thereof would the culprlts hasten on?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Is It, then, when it hath befallen, that ye will believe therein Now?- whereas ye have surely been hastening it On.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Thereafter, it will be said unto those who wronged themselves: taste the torment everlasting: ye are requited not save for that which ye have been earning.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask thee to tell them if it be-true. Say thou: yeal by my Lord, It, Is the veary truth, and ye shall not be able to escape.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if every one that hath wronged had all that is in the earth, surely he would ransom himself therewith. And they shall conceal remorse when they behold the torment, and the matter will be decreed between them in equity, and they shall not be wronged.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Lo! verily Allah's is whatsoever is In the heavens and the earth, Lo! verily Allah's promise is true; but most of them know not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He giveth life and causeth to die, and unto Him ye shall be returned.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O Mankind! now there hath come unto you an exhortation from your Lord and a healing for that which is in Your breasts, and a guidance and a mercy for the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say thou: in the grace of Allah and in His mercy--therein let them therefore rejoice: far better it is than that which they amass.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say thou: bethink ye of that which Allah hath sent down unto you of provision, and ye have then made thereof allowable and forbidden? Say thou: is it that Allah hath given you leave, or fabricate ye a lie against Allah?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what imagine those who fabricate a lie against Allah of the Day of Resurrection? Verily Allah is the owner of grace unto mankind, but most of them return not thanks.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
Thou art not engaged in any business, nor dost thou recite any part of the Qur'an, nor ye work any work, but We are witnesses over you when ye are engaged therein. And there escapeth not thy Lord the weight of an ant in the earth or the heavens, nor less than that nor greater, but it is in a Book luminous.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Lo! verily the friends of Allah! no fear shall come upon them nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
They who believed and have been fearing God;\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
Unto them is glad tidings in the life of the world and in the Hereafter. No changing is there in the words of Allah. That! it is the mighty achievement.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And let not their saying grieve thee. Verily honour is Allah's wholly. He is the Hearer, the Knower.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Lo! verily Allah's is whosoever is in the heavens and whosoever is on the earth. And what is it that they who call unto associate-gods beside Allah follow They follow but an opinion, and they are but conjecturing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is who hath appointed for you the night that ye may repose therein and the day enlightening. Verily in that are signs for a people who listen.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: God hath taken a son. Hallowed be He-He, the selfesufficient! His is whatsoever is in the heavens and whatsoever is in the earth. No warranty is there with you for this. Ascribe ye falsely unto Allah that which ye know not?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say thou: verily those who fabricate a lie against Allah shall not fare well.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
A brief enjoyment in the world; then unto Us is their return; then We will make them taste a severe torment, in that they have been disbelieving.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And rehearse thou unto them the story of Nuh, when he said unto his people: O my people! if my standing forth and my admonishment with the commandments of Allah be hard upon you, then on Allah I rely; so devise your affair, ye and your associate-gods and let not your affair be dubious unto you, then have it decreed against me, and respite me not.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
If then ye turn away, I have asked of you no hire, my hire is only with Allah, and I am commanded to be of those who submit.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
So they belied him; then We delivered him and those with him in the ark, and We made them successors, while We drowned those who belied Our signs. Behold then what like hath been the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then, We raised after him other apostles to their people, and they brought them evidences, but they were not such as to believe that which they had belied afore. Thus We seal the hearts of the transgressors.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then, after them, We raised Musa and Harun unto Fir'awn and his chiefs with Our signs, but they grew stiff-necked and they were a people guilty.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
Then when there came unto them the truth from Us, they said: verily this is magic manifest.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Musa said: say ye this of the truth after it hath come unto you? Is this magic? and the magicians fare not well.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: art thou come unto us to turn us aside from that faith whereon We found our fathers, and that the greatness in the land shall be unto you twain! And for the sake of you twain we are not going to be believers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Firawn said: bring unto me every magician knowing.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
Then when the magicians were come, Musa said unto them: cast down that which ye are going to cast down.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Then when they had cast down, Musa said: that which ye have brought is magic, verily Allah will soon make it vain; verily Allah setteth not right the work of the corrupters.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
And Allah justifieth the truth according to His words, even though the culprits may detest.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
Then none believed in Musa save a posterity of his people, through fear of Fir'awn and their chiefs, lest he should persecute them; and verily Fir'awn was lofty in the land, and verily he was of the extravagant.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Musa said: my people! if ye have been believing in Allah, then on Him rely, if ye are muslims.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
So they said: on Allah We rely, our Lord! make us not a trial for the wrong-doing people.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
And deliver us in Thine mercy from the disbelieving people.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We Revealed unto Musa and his brother: inhabit houses for your people in Misr, and make your houses a place of Worship, and establish prayer, and give glad tidings to the believers.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Musa said: our Lord! verily Thou! Thou hast vouchsafed unto Fir'awn and his chiefs adornment and riches in the life of the world, Our Lord, that they may lead men astray from Thine way. Our Lord! wipe out their riches, and harden their hearts, so that they may not believe until they behold the torment afflictive.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
Allah said: surely the petition of you twain is accepted, so keep straight on, and follow not the path of those who know not.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We led the Children of Isra'il across the sea; then Fir'awn and his hosts pursued them in rebellion and enmity, until, when the drowning over-took him, he said: I believe that verily He! there is no god but he, in whom the Children of Isra'il believe, and am of the Muslims.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
Now indeed! whereas thou hast rebelled afore, and wast of the corrupters.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
So this day We deliver thee in thy body that thou mayest be a sign unto those after thee, and verily many of mankind are of our signs neglectful.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And assuredly We settled the Children of Isra'il into a secure settlement, and We provided them with good things; nor they differed until there had come unto them the knowledge. Verily thine Lord shall judge between them on the Day of Resurrection as to that wherein they have been differing.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
And if thou be in doubt concerning that which We have sent down unto thee, then ask those who have read the Books before thee. Assuredly hath the truth come unto thee from thy Lord, so be not then of the doubters.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And be not thou of those who belie Allah's signs, lest thou be of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Verily those on whom the word of thy Lord hath been justified shall not believe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even though every sign should come unto them, until they hehold an afflictive torment.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Why then was there not a township which believed, so that its faith might have profited it, except the people of Yunus! When they believed, We removed from them the torment of humiliation in the life of the world, and We let them enjoy for a season.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And had thy Lord willed, those who are on the earth would have believed, all of them, together; canst thou then compel mankind until they become believers?\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
It is not for any soul that it should believe save with Allah's will, and He layeth the abomination upon those who reflect not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say thou: behold that which is in the heavens and the earth; and signs and warnings avail not those who will not believe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Wait they then aught but the days of those who have passed away before them. Say thou: wait then, verily I am with you among those who wait.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Thereafter We delivered Our apostles and those who believed. Even so, as incumbent upon us, We deliver the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say thou: ye men! if ye are in doubt concerning my religion-- then worship not those ye worship beside Allah, but I worship Allah who causeth you to die; and I am commanded that I should be of the believers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
And that: keep thy countenance straight toward the religion, Upright; and by no means be of the associators.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
And invoke not beside Allah that which can neither profit thee nor hurt thee; then if thou dost so, thou art forthwith of the wrong- doers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
And if Allah toucheth thee with hurt there is no remover thereof but he, and if He intendeth any good there is no averter of His grace. He letteth it befall on whomsoever of His bondmen He will; and He is the Forgiving, the Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say thou: O mankind! the truth hath surely come unto you from your Lord: whosoever then is guided, is guided only for himself, and whosoever strayeth, strayeth only against himself; and am not over you a trustee.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow thou whatsoever is revealed unto thee, and endure until Allah judgeth, and He is the Best of judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif. Lam. Ra. A Book this, the verses whereof are guarded, and then detailed, from before the Wise, the Aware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
Saying: ye shall not worship ought except Allah. Verily I am unto you from Him a warner and a bearer of glad tidings.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And that: ask forgiveness of your Lord, then repent toward Him, He will let you enjoy a goodly enjoyment until a term appointed and will vouchsafe unto every owner of grace His grace. And if ye turn away, verily I fear for you the torment of a Great Day.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
Unto Allah is your return, and He is over everything Potent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Lo! they fold their breasts that they may hide from Him. Lo! when they cover themselves with their garments, He knoweth that which they conceal and that which they make known. Verily He is the Knower of the secrets of the breasts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And there is not a moving creature on the earth but upon Allah is the sustenance thereof, and He knoweth its habitation and its resting-place: everything is in a Book luminous.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And He it is who hath created the heavens and the earth in six days -and His throne was upon the water--that he might prove you, as to which of you is excellent in work. And if thou sayest: ye shall verily be raised after death, surely those who disbelieve will say: naught is this but sorcery manifest.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We defer from them the torment until a period determined, they say: What withholdeth it! Lo! the day it betideth them it shall not be averted from them, and shall beset them that whereat they have been mocking.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We let man taste mercy from us, and thereafter withdraw it from him, verily he is despairing, blaspheming.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if We let him taste favour after harm hath touched him, he saith: the ills have departed from me; verily he becometh elated, boastful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Not so are those who persevere and do righteous works. Those! theirs shall be forgivness and a great hire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
So hapoy thou mayest abandon part of that hich hath been revealed unto thee, and thy breast is straitened thereby, because they say: wherefore hath not a treasure been sent down unto him, or an angel come with him! Thou art but a warner, and of everything Allah is the Trustee.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or say they: he hath fabricated it? Say thou: bring ye then ten Surahs the like thereunto fabricated, and call whomsoever ye can beside Allah, if ye say sooth.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
Then if they respond you not, know that it hath been sent down only with the Knowledge of Allah, and that there is no god but he; are ye Muslims then?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whosoever desireth the life of the world and the adornment thereof, We shall repay them in full their works therein, and in it they shall not be defrauded.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
These are they for whom there is not in the Hereafter save the Fire; to naught shall come that which they have performed, and vain is that which they have been working\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Is he like unto him who resteth upon an evidence from His Lord, so and there rehearseth it a witness from Him And before it was the Book of Musa, a pattern and a mercy; these believe therein; and whosoever of the sects disbelieveth therein, the Fire is his promised place. Be then thou not in dubitation thereof, verily it is the truth from thy Lord, yet most of the mankind believe not.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who doth greater wrong than he who fabricateth a lie against Allah! these shall be set before their Lord, and the witnesses shall say; these are they who lied against their Lord. Lo! the curse of Allah shall fall on the wrong-doers-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Who hinder others from the way of Allah and would seek crockedness therein, and they: in the Hereafter they are disbelievers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
These could not escape on the earth, nor could there be for them protectors against Allah; doubled shall be the torment for them; they were notable to hearken, nor would they be clear sighted.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
These are they who have lost their souls, and hath strayed from them that which they have been fabricating.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Undoubtedly they! in the Hereafter they shall be the greatest losers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Verily those who believed and worked righteous works and humbled themselves before their Lord--they shall be the fellows of the Garden: therein they shall be abiders.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The likeness of the two parties is as the blind and deaf, and the seeing and hearing. Are the twain equal in likeness? Admonished are ye not then?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And assuredly We sent Nuh unto his people saying: verily I am unto you a plain warner.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
That ye shall worship none except Allah; verily I fear for you the torment of a Day afflictive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
The chiefs of those who disbelieved among his people said: we behold thee except as a human being like us, and we behold not any follow thee except the meanest of us, by an immature opinion; nor We behold in you any exellency over us; nay! we deem you liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: bethink ye, O my people! if I rested upon an evidence from my Lord, and a mercy hath come unto me from Him, and that hath been obscured unto you, Shall we make you adhere to it while ye are averse thereto?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
And, O my people, I ask not of you any riches therefor; my hire is not but with Allah. And I am not going to drive away those who have believed; verily they are going to meet their Lord; but I behold you a people ignorant!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
O My people! who will succour me against Allah, if I drave them away! Admonished are ye not then?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
And I say not unto you that with me are the treasures of Allah, nor that I know the Unseen; nor I say, I am an angel. And say not of those whom your eyes condemn that Allah shall not bestow on them good - -Allah knoweth best that which is in theeir souls. Verily in that case would be of the wrong-doers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: O Nuh! surely thou hast disputed with us and hath multiplied the disputation with us; now bring us that wherewith thou threatenest us, if thou be of the truth-tellers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said: only Allah will bring it on you if He will, and ye shall not escape.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
Nor would my good counsel profit you, even though I wished to give you good counsel, if Allah willed to keep you astray. He is your Lord, and unto Him ye shall be returned.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or say they: he hath fabricated it? Say thou: on me then be my guilt, and I am quit of that whereof ye are guilty.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed unto Nuh: verily none of thy people will believe save those that have believed already; so be not distressed for that which they have been doing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
And make thou the ark under Our eyes and Our Revelation; and address Me not regarding those that have done wrong; verily they are to be drowned.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
And he was making the ark; and whenever the chiefs of his people passed by him, they scoffed at him. He said: if ye scoff at us, verily we also scoff at you even as ye scoff at us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
So presently ye shall know on whom cometh a torment that humiliateth him, and on whom is let loose a torment lasting.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
Thus were they employed until when Our decree came and the oven boiled over, We said: carry thereon of every kind two, and thy household except him thereof against whom the word hath already gone forth, and whosoever hath believed. And there had not believed with him save a few.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And he said: embark therein; in the name of Allah be its course and its anchorage, verily my Lord is Forgiving, Merciful.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
And it moved on with them amidst waves like mountains. And Nuh called out his son, and he was apart: O my son! embark with us, and be not with the infidels.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
He said: I shall betake me to a mountain which will defend me from the water. Nuh said: there is no defender to-day from the decree of Allah save for one on whom He hath mercy. And a wave intervened betwixt the twain; so he was of the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said: O earth! swallow up thy water, and cease, O heaven! And the water abated; and fulfilled was the decree. And it rested upon the Judi; and it was said: away with the wrong-doing people!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Nuh cried unto his Lord, and said: my Lord! verily my son is of my household, and verily Thine promise is the truth: and Thou art the Greatest of the rulers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: O Nuh! verily he is not of thy household; verily he is of unrighteous Conduct; wherefore ask Me not that whereof thou hast no knowledge; verily I exhort thee not to be of the ignorants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
Nuh said: my Lord! verily take refuge with Thee lest I may ask Thee that whereof I have no knowledge. And if Thou forgivest me not and hast not mercy on me, I shall be of the losers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said: Nuh! get thou down with peace from us and blessings upon thee and the communities with thee. And there shall be communities whom we shall let enjoy themselves, and thereafter there shall befall them from us a torment afflictive.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
That is of the stories of the unseen: We Reveal it unto thee: thou knewest it not, nor thy nation knew it ere this. So be thou patient; verily the happy end is for the God-fearing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And unto 'Aad We sent their brother Hud. He said: O my people! worship Allah; ` there is no god for you but he; ye are but fabricators.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
O My people! I ask of you no hire therefor, my hire is cnly on Him who created me, will ye not then reflect?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
O My people! ask forgiveness of your Lord, then repent tcward Him; He will send the heaven upon you pouring, land He will add ycu strength upon your strength, and turn not away as guilty ones.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They sai: O Hud! thou hast not brought us an evidence, and we are not going to abandon our gods thy saying, nor are we going to be believers in thee.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
All that we say is that some of our gods have smitten thee with evil. He said: verily I call Allah to witness, and bear ye witness, that I am quit of that which ye associate.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
Beside Him, so plot against me all tcgether, and then respite me not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
Verily rely on Allah, my Lord and your Lord; no moving creature is there but he holdeth it by its forelock; verily my Lcrd is on the straight path.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
If then ye turn away, I have surely preached unto you that wherewith I was sent unto you. And my Lord will set up in succession a people other than you, and ye shall not harm Him at all, verily my Lord is over everything a Guardian.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And then when Our decree came to pass, We delivered Hud and these who believed with him by a mercy from us; and We delivered them: from a torment rough.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
And such were 'Aad. They gainsaid the signs of their Lord, and disobeyed His apostles, and followed the bidding of any tyrant froward.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were followed in this world by a curse, and so will they be on the Judgment Day. Lo! verily 'Aad disbelieved in thy Lord. Lo! away with 'Aad, the people of Hud.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And unto Thamud We sent their brother Saleh. He said: O my people! worship Allah; there is no god for you but he. He hath caused you to spring out of the earth, and hath made you dwell therein. Wherefore ask forgiveness of Him, then repent toward Him; verily my Lord is Nigh, Responsive.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: O Saleh! heretofore thou wast amongst us as one hoped for. Forbiddest us thou to worship that which our fathers have worshipped? And verily we are regarding that to which thou callest us in doubt disquieting.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said; O my people! bethink if I rest on an evidence from my Lord, and there hath come to me from Him a mercy, then who will succour me against Allah, if I disobey Him? Ye then increase me not save in loss.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
And O my people! yonder is the she-camel of Allah: a sign unto you; so let her alone, feeding in Allah's land, and touch her not with evil, lest there may overtake you a torment nigh.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
Yet they hamstrang her. Then he said: enjoy yourselves in your dwellings three days: that is a promise, not to be falsified.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
Then when Our decree came to pass We delivered Saleh and those who believed with Him by a mercy from Us, and from the humiliation of that day. Verily thy Lord! He is the Strong, the Mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the shout overtook those who had done wrong; so they lay in their dwellings crouching\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As though they had never lived at ease therein. Lo! verily Thamud disbelieved in their Lord. Lo! away with Thamud.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And assuredly Our messengers came unto Ibrahim with the glad tidings. The said: peace! He said: peace! And he tarried not till he brougt a calf roasted.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
And when he beheld that their hands reached it not he misliked them, and ccnceived a fear of them. They said fear not verily we are sent unto the people of Lut.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing. she laughed. Then We gave her the glad tidings of Is'haq, and after Is'haq, Ya'qub.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said: Oh for me shall bring forth when I am old, and this my husband is advanced in years! Verily a marvellous thing is this!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said marvellest thou at the decree of Allah? Mercy of Allah and His blessings be upon you, people of the house, verily He is Praiseworthy, Glorious.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
Then when the alarm had departed from Ibrahim and the glad tidings had come home unto him, he took to disputing with us for the people of Lut\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Verily Ibrahim was forbearing, long-suffering, penitent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
O Ibrahim! leave off this; verily the decree from thy Lord hath already come, and verily they! upon them is coming a torment unavoidable.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came unto Lut, he was distressed on their account, and he felt straitened on their account, and he said: this is a lay dreadful.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came unto him rushing on toward him, and afore they were wont to work vices. He said. O my people! these are my daughters: purer are they for you; so fear Allah, and humiliate me not in the face of my guests; is there not among you any man right-minded?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: assuredly thou knowest that we have no right to thy daughters, and verily thou knowest that which we would have.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said. Would that I had strength against you or could betake me to a powerful support!\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
They said: O Lut! verily we are messengers of thy Lord; they shall by no means reach thee: go forth thou With thy household in a part of the night, and let none of you look back, save thy wife; verily that which befalleth them shall befall her; verily their appointment is for the morning; is not morning nigh?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
Then when Our decree came to pass, We turned the upside thereof downward, and We rained thereon stones of baked clay, piled up.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked from before thy Lord. Nor are they from the wrong- doers far away.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And unto Madyan We sent their brother Shu'aib. He said: O my people! worship Allah; there is no god for you but he. And give not short measure and weight. Verily I see you in prosperity, and verily I fear for you the torment of a Day encompassing\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
And, O my people! give full measure and weight with equity, and defraud not the people of their things, and commit not mischief on the earth as corrupters.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
And the remainder of Allah is better for you, if ye believers, and I am not over you a guardian.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said: Shu'aib, commandeth thee thy prayer that we should abandon that which our fathers have worshipped, or that we should not do with our riches whatsoever we will! thou, indeed! thou forsooth art forbearing, right-minded!\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: O my people! bethink if I rested on an evidence from my Lord, and He hath provided me with a goodly provision from Himself, shell I fail to deliver His message! And I desire not, in order to oppose you, to do that which I forbid I desire not but rectification, so far you as I am able, and my hope of success is not save with Allah; in Him I rely and unto Him I turn penitently.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
And, O my people! let not the cleavage with me incite you so that there befall you the like of that which befell the people of Nuh and the people of Hud and the people of Saleh; and the people of Lut are not from you far away.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
And ask forgiveness of your Lord, and then repent unto him; verily my Lord is Merciful, Loving.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: O Shu'aib! we understanand not much of that which thou sayest, and verily we see thee weak among us, and were it not for thy company we had surely stoned thee, and thou art not among us mighty.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: O my people! is my company mightier with you than Allah? Him ye have cast behind your backs neglected; verily my Lord is of that which ye work Encompasser.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
And, O my people! work according to your condition, verily I am going to work in my way; presently ye shall know on whom cometh a torment humiliating him and who is a liar. And Watch, verily I also am with you a watcher.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when our decree came to pass, We delivered Shu'aib and those who believed with him by a mercy from Us, and the shout overtook those who did wrong, so they lay in their dwellings crouching.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As though they had never lived at ease therein. Lo! a far removal for Madyan, even as Thamud were removed afar!\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And assuredly We sent Musa with Our signs and a manifest warranty.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
Unto Firawn and his chiefs. But they followed the commandment of Fir'awn, and the commandment of Fir'awn was not right- minded.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He shall head his people on the Day of Resurrection and cause them to descend into the Fire, ill is the descent, descended!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
And they were followed in this world by a curse and so they will be on the Day of Resurrection, ill is the present presented!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is from the stories of the Cities which We recount unto thee: of them some are standing and some mown down.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
And We wronged them not but they wronged themselves. So their gods, whom they called upon beside Allah, availed them not in aught, when there came the decree of thy Lord, and they added unto them naught but perdition.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
And even such is the overtaking of thy Lord when He overtaketh the cities while they are wrong-doers; verily His overtaking is afflictive, severe.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Verily herein is a sign unto him who feareth the torment of the Hereafter. That is a Day whereon mankind shall be gathered together, and that is a Day to be witnessed.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We defer it not but to a term determined.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
The day it cometh no soul shall speak save by His leave: then of them some shall be wretched and some blessed.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who shall be wretched. they shall be in the Fire, wherein for them shall be panting and roaring.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
Abiders they shall be therein, so long as the heavens and the earth remain, save as thy Lord may will. Verily thy Lord is the Doer of whatsoever He intendeth.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for those who shall be blest, they shall be in the Garden, as abiders therein so long as the heavens and the earth remain, save as thy Lord may will. a gift unending.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be not thou in dubitation concerning that which these people worship. They worship not save as their fathers worshipped afore; and verily We will repay unto them in full their portion, undiminished.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And assuredly vouchsafed unto Musa the Book, and disputation arose thereabout; and had not a word preceded from thy Lord, it would have been decreed between them. And verily they are concerning that in doubt disquieting.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And verily unto each will thy Lord repay their works in full; verily of that which they work He is Aware.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So stand thou straight as thou hast been commanded, thou and whosoever repented with thee; and be not arrogant; verily He is of that which ye work Beholder.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And lean not toward those who do wrong, lest the Fire should touch you, and ye have no protectors beside Allah nor ye would then be succoured.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And establish thou the prayer at the two ends of the day, and in the neighbouring watches of the night verily virtues take away vices. That is a reminder unto the mindful.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient thou; verily Allah wasteth not the hire of the welldoers.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
Why were there not of the generations before you owner of wisdom restraining others from corruption on the earth, except a few of those whom We delivered from amongst them! And those who did wrong followed that in which they luxuriated, and they had been sinners.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
And thy Lord is not one to destroy cities wrongously while the inhabitants thereof are rectifiers.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
And had thy Lord Willed, He would surely have made mankind of one community, and they will not cease differing.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Save these on whom thy Lord hath mercy; and for that he hath created them. And fulfilled will be the word of thy Lord: surely I will fill Hell with the jinn and mankind together.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all that We recount unto thee of the stories of the apostles is in order that We may make firm thy heart thereby. And in this there hath come to thee truth and an exhortation and an admonition unto the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say thou unto those who believe not: work according to your condition verily We, going to work in our way.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And await; as verily we are awaiting.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
And Allah's is the Unseen of the heavens and the earth, and unto Him the whole affair shall be brought back. So worship Him thou and rely on Him; and thy Lord is not negligent of that which ye work.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif. Lam. Ra. These are the verses of a Book luminous.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Verily We! We have sent it down, an Arabic Recitation, that haply ye may reflect.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We! We recount unto thee the best of stories, by Revealing unto thee this Our'an, although thou wast before that of the unaware ones.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
Recall what time Yusufj said unto his father:, y father! verily have seen eleven stars and the sun and the moon; I have seen them prostrating themselves unto me.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He said: O my son! recount not thine vision unto thy brethren, lest they plot a plot against thee; verily the Satan is unto man an enemy manifest.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
And Thus will thy Lord choose thee and teach thee of the interpretation of discourses, and will fulfil His favour upon thee and upon the house of Y'aqub even as He fulfilled it upon thy fathers, Ibrahim and Is-haq aforetime; verily thy Lord is Knowing, Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Assuredly in Yusuf and his brethren there have been signs for the inquirers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
Recall what time they said: surely Yusuf and his brother are dearer to our father than we, whereas we are company; verily our father is in error manifest.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
Slay Yusuf or cast him forth to some land; your father's countenance will be free for you, and ye shall be thereafter a people favoured.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
Said a speaker from among them; slay not Yusuf, but cast him into the bottom of a well, some of the caravan will take him up--if ye must be doing.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: our father! wherefore thou intrustest us not with Yusuf, whereas verily we are his well-wishers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him with us tomorrow, that he may refresh himself and play, and verily we are to be his guards.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said: verily it grieveth me that ye should take him away, and I fear lest a wolf may devour him, While ye are negligent of him.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: if the wolf devoured him while we were a company, we must indeed then be the losers!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So when they took him away, and resolved to place him in the bottom of the well, We Revealed unto him: surely thou wilt declare unto them this their affair, while they shall perceive not.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father at nightfall, weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said: our father! we went off competing, and left Yusuf by our stuff, so a wolf devoured him; and thou wilt put no credence in us, even though we are the truth-tellers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt with false blood. He said: nay! your selves have embellished for you an affair; so seemly patience! and Allah is to be implored for help in that which ye ascribe\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And a caravan came, and they sent their water-drawer, and he let down his bucket. He said: glad tidings! here is a youth. And they hid him as merchandise, And Allah was the Knower of that which they worked.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a mean price: a few dirhams numbered and they were in regard to him of the indifferent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And he who bought him in Misr said unto his wife: make his dwelling honourable: belike he may profit us or we may take him as a son. And Thus We made a place for Yusuf in the land, and it was in order that We may teach him the interpretation of discourses. And Allah is Dominant in His purpose, but most of men know not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he reached his maturity We vouchsafed unto him judgement and knowledge; and Thus We recompense the well-doers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she in whose house he was, solicited him against himself; and she fastened the doors, and said: come on, O thou! He said: Allah be my refuge: verily he is my lord; he hath made me a goodly dwelling; verily the wrong-doers fare not well.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And assuredly she besought him, and he would have besoughther were it not that he had seen the argument of his Lord. Thus We did, in order that We might avert from him all evil and indecency; verily he was of our bondmen single-hearted.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
And the twain raced to the door, and she rent his shirt from behind, And the twain met her master at the door. She said: What is the meed of him who intended evil toward thy house hold except that he be imprisoned, or a torment afflictive?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He said: it is she who solicited me against myself And a witness from her own household bare witness: if his shirt be rent in front, then she speaketh the truth and he is of the liars.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
And if his shirt be rent from behind, then she lieth, and he is of the truth-tellers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when he saw his shirt rent from behind, he said: verily it is of the guile of ye women; verily the guile of ye women is mighty.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
Yusuf! turn away therefrom; and, thou woman! ask forgiveness for thy sin; verily thou hast been of the guilty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And women in the city said; the wife of the AZiZ hath solicited her page against himself; he hath inflamed her with love; verily we behold her in error manifest.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
Then, when she heard of their cunning talk, she sent unto them a messenger, and got ready for them a cushioned Couch, and gave a knife to each of them. And she said: come forth to them. Then when they saw him, they were astonished at him, and they made a cut in their hands, and said: how perfect is God! no man is he: he is naught but an angel noble.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: that then is he in regard to whom ye reproached me. Assuredly solicited him against himself but he abstained; and if he doth not that which I command him, he shall surely be imprisoned and he shall surely be of the degraded.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said: my Lord: prison is dearer to me than that to which these women call me; and if Thou avertest not their guile from me should incline toward them and become of the Ignorant.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
Then his Lord answered to him, and averted their guile from him; verily He! He is the Hearer, the Knower!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Thereafter it occurred to them even after they had, the signs, to imprison him for a season.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And there entered with him into the prison two pages. One of them said: verlly I saw myself pressing wine; and the other said: verily I saw myself carrying upon my head bread whereof the birds were eating. declare unto us the interpretation thereof, verily we see thee of the well-doers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: there will not come to you any food wherewith ye are provided but I shall have declared unto the interpretation thereof ere it cometh unto you. that is of that which my Lord hath taught me; verily I have abandoned the creed of a people who believe not in Allah and who in the Hereafter are disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
And I have followed the creed of my fathers, Ibrahim and Is'haq and ya'qub: it is not for us to associate aught with Allah. That is of Allah's and upon mankind; but grace upon us most of mankind thank not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
O My two fellow-prisoners! are sundry lords better of Allah, the One, the Subduer\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
Ye worship not, beside Him, but names ye have named, ye and your fathers: Allah hath not sent down for them any warranty. Judgment is but Allah's; He hath commanded that ye worship not except Him. That is the right religion, but most of the mankind know not.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
O My two fellow-prisoners; as for one of you twain he will pour out wine for his lord; and as for the other, he will be crucified, and the birds will eat from off his head; O Thus is decreed the affair whereof ye twain enquired.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to one of them who he imagined would be saved: mention me in the presence of thy lord. Then the Satan caused him to forget to mention him to his lord, so that he tarried in the prison several years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king said: verily I saw seven fat kine which seven lean ones are devouring and seven green cornears and seven others dry. O ye chiefs! give me an answer in regard to my vision if a vision ye are wont to expound.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: medleys of dreams! and in the interpretation of dreams we are not skilled.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
Then the one of the twain, who was saved, and now recollected himself after a period, said: I, even I, shall declare unto you the interpretation thereof; so send me forth.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
Yusuf, O saint! give an answer unto us in regard to seven fat kine which seven lean ones are devouring and seven green corn-ears and seven others dry; haply may return unto the people; haply they may learn.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He said: ye shall sow seven years as is your went; and that which ye reap leave in its ears, except a little whereof ye may eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then thereafter will come seven hard years which will devour that which ye have laid up beforehand for them except a little which ye shall preserve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then thereafter will come a year wherein mankind will have rain and wherein they will press.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said: bring him Unto me. Then, when the messenger came to him, he said: return to thy lord, and ask him, what about the women who cut their hands! verily my Lord is the Knower of their guile.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
He said: What was the matter with you when ye solicited Yusuf against himself! They said: how perfect is God! we knew not of any evil against him. The wife of the Aziz said: how hath the truth come to light, even I, solicited him against himself, and verily he is of the truth-tellers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
He said: that did in order that he may know that I betrayed him not in secret, and that Allah guideth not the guile of betrayers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
Nor I acquit myself; verily the self ever urgeth to evil save that self on Whom my Lord hath mercy; verily My Lord is Forgiving, Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said: bring him unto me I will single him out for myself Then when he spake unto him, he said: verily thou art to-day with us placed high, intrusted.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
He said: set me over the store houses of the land; verily I shall be a keeper knowing.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus We established Yusuf in the land so that he might settle therein wherever he listed. We bestow of Our mercy on whomsoever We will, and We waste not the hire of the well-doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And surely the hire of the Here after is better for those who believe and ever fear.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And the brethren of Yusuf came and entered unto him, and he recognized them, while they recognized him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had furnished them with their furnishing, he said: bring unto me a brother of your from your father behold ye not that I give full measure and that am the best of entertainers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
But if ye bring him not unto me, there shall be no measuring for you from me, and ye shall not approach me.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: we will surely entice away his father from him; and verily we are doers.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And he said to his pages: place their goods in their packs, haply they will recognize them when they reach back to their household: haply they will return.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
Then when they returned to their father, they said: our father! the measuring hath been denied us, wherefore send thou with us our brother, and we shall get our measure; and verily we shall be his guards.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said: I intrust you with him only as I intrusted you with his brother aforetime; Allah is the best Guard, and He is the Most Merciful of the merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their stuff, they found their goods returned unto them. They said: our father! what more can we desire! here are our goods returned to us; We Shall supply our household and shall guard our brother and shall add anot her measure of a camel load: this is only a small measure.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He said: I will by no means send him with you until ye give me an assurance by Allah that ye will bring him back to me, unless it be that ye are encompassed. Then when they gave him their assurance, he said: Allah is over that which we have said Warden.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said: my sons! enter not by one gate but enter by different gates; and I cannot avail you against Allah at all: judgment is but Allah's; on Him I rely, and on Him let the relying rely.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered as their father had enjoined them, it availed them not against Allah at all; it was only a craving in the soul of Ya qub that he satisfied; verily he was endued with knowledge, for We had taught him; but most of the people know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they entered unto Yusuf, he betook his full brother unto himself, and said: verily I am thine own brother Yusuf, so sorrow not over that which they have been working.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
And when he had furnished them with their furnishing; he placed the drinking-cup in his brother's pack. - Thereafter a crier cried: O caravan! verily ye are thieves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They said while they turned toward them: what is it that ye miss!\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said: we miss the king's cup; and for him who bringeth it shall be a camel-load; and thereof I am a guarantor.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said: by Allah! assuredly ye know that we came not to work corruption in the land, nor we have been thieves.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said: what shall be the meed of him, if ye are found liars!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said: his meed shall be that he, in whose pack it is found, shall himself be recompense thereof. Thus we reccmpense the wrong- doers.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
Then he began with their sacks before the sack of his brother; then he brought it forth from his brothers sack. In this wise We contrived for Yusuf. He was not one to take his brother by the law of the king, except that Allah willed. We exalt in degrees whomsoever We will, and above every knowing one is a Knower.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said: if he stealeth, then surely a brother of him hath stolen afore. But Yusuf concealed it in himself, and discovered it not unto them. He said: ye are in evil plight, and Allah is the Best Knower of that which ye ascribe.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: Aziz! verily he hath a father, an old man very aged; So take one of us in his stead; verily we behold thee to be of the well-doers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said: Allah forbid that we should take anyone but him with whom we found our stuff; verily then we should be the wrong-doers.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
Then when they despaired of him they counselled together privately. The eldest of them said: know ye not that your father hath taken an assurance from you before Allah? and aforetime ye have been remiss in your duty in respect of Yusuf; I so will by no means go forth from the land until my father giveth me leave or Allah judgeth for me, and He is the Best of judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
Return unto your father, and say: our father! verily thy son hath stolen, and we testify not save according to that which we know; and of the unseen we could not be guards.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
And inquire those of the city where we have been and of the caravan with whom we have travelled hither; and verily we are truth- tellers.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
He said: nay! your selves have embellished for you an affair; so seemly patience! Belike Allah may bring them all unto me; verily He! only He Is the Knowing, the Wise.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them, and said: O my grief for Yusuf! and his eyes whitened with grief, while he was filled with suppressed sorrow.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: by Allah! thou wilt not cease remembering Yusuf until thou art wizened or thou be of the dead.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: I only bewail my cogitation and grief unto Allah, and I know from Allah that which ye know not.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
O My sons! go and ascertain about Yusuf and his brother, and despair not of the comfort of Allah; verily none despair of the comfort of Allah except a people disbelieving.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
And when they entered unto him, they said: O Aziz! distress hath touched us and our household, and we have brought poor goods, wherefore give us full measure, and be charitable unto us; verily Allah recompenseth the charitable.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said: remember ye that which ye did Unto Yusuf and his brother while ye were ignorant?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: art thou Yusuf indeed! He said: I am Yusuf and this is my brother; Allah hath surely been gracious unto us; verily whosoever feareth and endureth, then verily Allah wasteth not the hire of the well-doers.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: by Allah! assuredly Allah hath chosen thee above us, and we have been sinners indeed.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said; no reproach upon you today. May Allah forgive you; and He is the Most Merciful of the merciful.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Go with this shirt of mine and cast it upon my father's face; he shall become clear-sighted; and bring unto me all your household.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
And when the caravan had departed, their father said: surely feel the smell of Yusuf, if ye think not that I am doting.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said: by Allah! verily thou art in thine old-time error.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then, when the bringer of the glad tidings came, he cast it upon his face and he became clear-sighted. He said: said I not unto you, verily I know from Allah that which ye know not.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: our father! pray for forgiveness of our sins for us; verily we have been sinners.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: presently I shall pray for forgiveness for you of my Lord; verily He! only He is the Forgiving, the Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
Then when they entered unto Yusuf, he betook his parents unto himself. and said: enter Misr, if Allah will, in security.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he raised his parents to the throne, and they fell down before him prostrate, And he said: O my father! this is the interpretation of my vision aforetime; My Lord hath now made it come true; and surely He did well by me when he took me forth from the prison, and hath brought you from the desert after the Satan had stirred strife between me and my brethren; verily my Lord is subtilel Unto whomsoever He will. Verily He! only He, is the Knowing, the Wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
O My Lord! Thou hast given me of the dominion, and hast taught me of the interpretation of discourses, Creator of the heavens and the earth! Thou art my Patron in the world and the Hereafter. Make me to die a Muslim, and join me with the righteous.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
This is of the tidings of the unseen, which We reveal unto thee; nor wast thou with them when they resolved on their affair while they were plotting.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And most of the people, though thou desiredest ardently, are not going to be believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
And thou askest them not any hire therefor; it is but an admonition unto the worlds.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many a sign in the heavens and the earth they pass by, while they are averters therefrom.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah except as they are associators.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Are they secure then against this, that there may come upon them an overwhelming of Allah's torment, or that there may come upon them the Hour on a sudden while they percieve not?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say thou: this is my way: I call unto Allah resting upon an insight---I, and whosoever followeth me. Hallowed be Allah: and I am not of the associators.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
And We sent not before thee any save men unto whom We revealed from among the people of the towns. Have then they not travelled about in the land that they might observe of what wise hath been the end of those before them! And surely the abode of the, Hereafter is best for those who fear! Reflect then ye not!\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
Respited were they until when the apostles had despaired and imagined that they were deluded, there came unto them Our succour; then whomsoever We willed was delivered. las And Our wrath is not warded off from a people sinful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Assuredly in their stories is a lesson for men of understanding. It is not a discourse fabricated, but a confirmation of that which went before it, and a detailing of everything, and a guidance and a mercy unto a people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif. Lam. Mim. Ra. These are the verses of the Book. And that which is sent down unto thee from thy Lord is the truth, but most of the people believe not.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
Allah it is who hath raised the heavens without pillars that ye can see, then He established Himself on the throne, and subjected the sun and the moon, each running unto a period determined. He disposeth the affair, and detaileth the signs, that haply of the meeting with your Lord ye may be convinced.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And He it is who hath stretched forth the earth, and placed therein firm mountains and rivers; and of every fruit he hath placed therein two in pairs. He covereth the night with the day; verily therein are signs for a people who ponder.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the earth are regions neighbouring and gardens of vines and cornfields, and palm-trees clustered and single, watered by the same water; yet some We make to excel others in food. Verily therein are signs for a people who reflect.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And shouldst thou marvel, then marvellous is their saying: when we have become dust, shall we be in a new creation! ' These are they who disbelieved in their Lord; and these! -- the shackles round their necks; and these shall be the fellows of the Fire as abiders therein.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
And they ask thee to hasten the evil before the good, while examples have already gone forth afore them. And thy Lord is Owner of forgiveness unto mankind despite their wrong-doing; and verily thy Lord is severe in requital\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
And those who disbelieve say: wherefore is not a sign sent down unto him from his Lord! Thou art but a warner; and unto every people there is a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knoweth that which each female beareth and that which the wombs want and that which they exceed, and with Him everything is in due measure:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
Knower of the hidden and the manifest! the Great! the Exalted.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
Equal unto him is he among you who hideth the word and he who publisheth it, and he who hideth himself in the night and he who goeth about freely in the day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For him are angels in succession, before him and behind him; they guard him with Allah's command. Verily Allah altereth not that which is with a people until they alter that which is with themselves. And when Allah intendeth evil unto a people there is no turning it back; nor is for them, beside Him, any patron.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
He It is who sheweth the lightning unto you for fear and for desire, and bringeth up the clouds heavy.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
And the thunder halloweth His praise, and so do the angels in awe of Him; and He sendeth the thunderbolts and smiteth therewith whomsoever He will. And they dispute concerning Allah, and He is strong in prowess.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
Unto Him is the true call, and those whom they call upon beside Him answer them not at all, save as is answered one stretching out his palms to water that it may reach his mouth, while it will reach it not. And the supplication of the infidels only goeth astray.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And unto Allah prostrateth himself whosoever is in the heavens and the earth, willingly or of constraint, and also thir shadows in the moring and the evenings.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say thou: who in the Lord of the heavens and the earth Say thou: Allah. Say thou: have ye then taken beside Him patrons who own not to themselves benefit nor hurt! Say thou: are the blind and the seer equal? Or, the darknesses and light equal? Or have they set up associates unto Allah, who have created even as He hath created, so that the Creation hath become dubious unto them! Say thou: Allah is the Creator of everything; and He is the One, the Subduer.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sendeth down water from the heaven, so that the valleys flow according to their measure; then the torrent beareth the scum on top, and from that over which they kindle a fire seeking ornament or goods- ariseth a scum like thereto: Thus doth Allah propound the truth and falsity. Then as for the scum, it departeth as rubbish, and as for that which benefiteth the mankind, it lasteth on the earth: Thus doth Allah propound the similitudes.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For these who answer their Lord is ordained good. And those who answer not their Lord--if they had all that is in the earth, and therewith the like thereof, they would ransom themselves therewith. These! for them shall be an evil reckoning; and their resort is Hell, a hapless bed!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Shall he then who knoweth that which is sent down unto thee is the truth be like unto him who is blind! Only the men of understanding are admonished\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfil the covenant of Allah, and violate not the bond.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
And those who enjoin that which Allah hath commanded to be enjoined, and fear their Lord, and dread the evil reckoning;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
And those who persevere seeking the countenance of their Lord and establish prayer, and expend out of that wherewith We have provided them, secretly and openly, and combat evil with good. These! for them is the happy end in the Abode:\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Gardens Everlasting; they shall enter them, and also whosoever shall have acted righteously from among their fathers and their spouses and their progeny. And angels shall enter unto them from every portal, saying:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
Peace be upOn you for ye patiently persevered. Excellent then is the happy end in the Abode!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who violate the covenant of Allah after the ratification thereof, and sunder that which Allah hath commanded to be conjoined, and act corruptly in the earth--these! unto them is a curse, and unto them shall be the evil Abode.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah enlargeth the provision for whomsoever He Willeth and, stinteth. And they exult in the life of the world, whereas the life of the world, by the side of the Hereafter, is only a Passing enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And those who disbelieve say: wherefore is not a sign sent down unto him from his Lord! Say thou: verily Allah sendeth astray whomsoever He will and guideth unto Himself whosoever turnoth in penitence--\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
They are those who believe and whose hearts find rest in the remembrance of Allah. Lo! in the remembrance of Allah hearts do find rest.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
Those who believe and work righteous works, for them is bliss and a happy resort.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus We have sent thee unto a community before whom other communities have passed away, in order that thou mayest recite unto them that which We have Revealed unto thee; yet they disbelieve in the Compassionate. Say thou: He is my Lord, there is no god but he; on Him I rely, and unto Him is my return in penitence.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And if there were a Qur'an whereby the mountains could be moved or Whereby the earth could be traversed or whereby the dead could be spoken to, it would be in vain. Aye! the affair belongeth to Allah entirely. Have not then those who believe yet known that had Allah willed, He would have guided all mankind! And a rattling adversity ceaseth not to befall those who disbelieve for that which they have wrought or to alight nigh unto their habitation. until Allah's promise cometh; verily Allah faileth not the tryst.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And assuredly mocked were apostles before thee; then I respited those who disbelieved; thereafter took hold of them; so of what wise hath been My requital.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is He, then, who is ever standing over every soul with that which he earneth, like unto other! And yet they have set up associates unto Allah. Say thou: name them; would ye inform Him of that which He knoweth not on the earth? or is it by way of outward saying? Aye! fair-seeming unto those who disbelieve is made their plotting, and they have been hindered from the way. And whomsoever sendeth astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is torment in the life of the Word, and surely the torment of the Hereafter is harder; and from Allah there is for them no protector.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The case of the Garden which hath been promised unto the God-fearing: rivers flow thereunder; fruit thereof is perpetual, and so is thes hade thereof. This is the ending of those who fear; and the ending of the infidels is the Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
They unto whom We vouchsafed the Book rejoice at that which hath been sent down unto thee; and of their bands are some who deny some of it. Say thou: have only been commanded that: should worship Allah and should associate not with Him. Unto Him I call, and unto Him is my return.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And Thus We have sent it down as a judgment in Arabic, And surely wert thou to follow their vain desires, after that which hath come to thee of knowledge, thou wilt not have against Allah any patron or protector.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And assuredly We sent apostles before thee and We made for them wives and progeny and it is not for an apostle to Produce a verse except by the command of Allah; for everv time there is a Book.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah abolisheth whatsoever He Will and keepeth; and with Him is the mother of the Book.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
And whether We shew thee part of that which We have promised them, or We take thee away, on thee is only the preaching, and on Us is the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Behold they not that We visit the landj diminishing it by the borders thereof Allah judgeth, and there is no reviser of His judgment; and He is swift in reckoning,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
And of a surety there plotted those before them; but unto Allah belongeth the plotting entirely. He knoweth that which each soul earneth. And anon will the infidels know for whom is the happy ending of the Abode.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
And those who disbelieve say: thou art not a sent one. Say thou: Allah is a sufficient witness between me and you, and also he with whom is knowledge of the Book.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif. Lam. Ra. This is a Book which We have sent down unto thee, that thou mayest bring the mankind forth from the darknesses unto the light, by the command of their Lord: unto the path of the Mighty, the Praiseworthy.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah, whose is that which is in the heavens and that which is in the earth; and woe be unto the infidels because of a torment severe\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who prefer the life of the world to the Hereafter, and hinder people from the way of Allah, and seek crookedness therein; these are in error far-off.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We sent not an apostle but with the speech of his people that he might expound unto them. Then Allah sendeth astray whomsoever He will, and guideth whomsoever He will. And He is the Mighty, the Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And assuredly We sent Musa with our signs saying: bring thy people forth from the darknesses unto the light, and remind them of the annals of Allah. Verily therein are signs for everyone patient, and thankful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And recall what time Musa said unto his people: remember the favour of Allah upon you when He delivered you from the house of Fir'awn who were imposing upon you evil torment, slaughtering your sons and letting your women live, and therein was from your Lord a trial terrible.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And what time your Lord proclaimed: if ye give thanks, surely I will increase you, and if ye disbelieve, verily My torment severe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Musa said: if ye disbelive, -- ye and all those who are on the earth-then verily Allah is self-sufficient, Praiseworthy. disquieting.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Hath not the tidings come to you of those before you: the people of Nuh and the 'Aad and the Thamud and those after them! None knoweth them save Allah. There came unto them their apostles with the evidences, but they put their hands to their mouths, and said: verily we disbelieve in that where- with ye have been sent, and verily regarding that to which ye call Us We are in doubt disquieting.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their apostles said: is there doubt about Allah, the Maker of the heavens and the earth? He calleth you that he may forgive you of your sins and retain you till a term fixed. They said: ye are but like us; ye mean to turn us aside from that which our fathers have been worshipping; so bring us a warranty manifest.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their apostles said unto them: we are naught but human beings like but Allah bestoweth favour on you, of His bond whomsoever He willeth and it is not for us to bring you a men command of warrantv except by the Allah. On Allah then let the believers rely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
And wherefore should we not rely on Allah when He hath surely guided us our ways! And surely we shall bear patiently that with which ye afflict us and in Allah then let the trustful put their trust.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And those who disbelieved said to their apostles: we will surely drive you forth from our land, or else ye will have to return to our faith. Then their Lord Revealed unto them: We will surely destroy the wrong-doers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
And We will surely cause you to dwell in the land after them: that is for him who feareth standing before Me and feareth My threat.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they besought judgment, and disappointed was every tyrant obstinate.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Behind him is Hell, and he shall be made to drink of fetid water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
Which he gulpeth, but wellnigh swalloweth not. And death cometh upon him from every side, while yet he is not dead, and behind him is a torment terrible.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The likeness of those who disbelieve in their Lord: their works are like ashes upon which the wind bloweth hard on a stormy day: they shall not be able to get aught of that which they have earned. That! that is the straying far-off\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Beholdest thou not that Allah hath created the heavens and the earth with a purpose? If He willed He would make you pass away and bring a creation new.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And for Allah that is not hard.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
And they all shall appear before Allah, then those who were counted weak shall say to those who were stiff-necked: verily we were unto you a following, are ye going to avail us at all against the torment of AllAh? They Will say: had Allah guided, We would have guided you also; it is equal unto us whether we become impatient or bear patiently; for us there is no place of escape.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And the Satan will say, When the affair hath been decreed: verily Allah promised you a promise of truth; and I promised you, then I failed; and I had over you no authoyourity, save that I called you and ye answered me; wherefore reproach not but reproach yourself. I am not me going to succour you nor are ye going to succour me: verily I disbelieve in your having associated me afore. Verily the wrong-doers! for them is a torment zfflictive.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed and worked righteous works shall be made to enter Gardens whereunder rivers flow as abiders therein by the command of their Lord, their greeting therein will be: peace!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Beholdest thou not how Allah hath propounded the similitude of the clean word? It is like a clean tree, its root firmly fixed, and its branches reaching unto heaven.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
Giving its fruit at every season, by the command of the Lord. And Allah propoundeth similitudes for mankind that haply they may be admonished.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the similitude of the foul word is as a foul tree, uprooted from upon the earth, and there is for it no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah keepeth firm those who believe by the firm Word in the life of the world and in the Hereafter, and Allah sendeth astray the wrong-doers. And Allah doth that which He willeth.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Beholdest thou not those who returned the favour of Allah with infidelity and caused their people to alight in the dwelling of perdition:\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Hell, wherein they shall roast. How ill is the settlement!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they have set up compeers unto Allah, that they may lead men astray from His way. Say thou: enjoy, then verily your vending is unto the Fire.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Say thou unto those of My bond- men who have believed, let them establish prayer and expend of that wherewith We have provided them secretly and openly, ere the Day cometh wherein there will be no bargain nor friendliness.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
Allah it is who hath created the heavens and the earth, and sent down from the heaven water, and hath there by brought forth fruits as a provision for you; and He hath subiected the ships for you that it may run in the sea by His command; and He hath subjected for you the rivers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He hath subjected for you the sun and the moon, two constant toils; and He hath subjected for you the night and the day.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He hath vouchsafed unto you some of everything ye asked Him. And if ye would count Allah's favours, ye can not compute them; verily man is a great wrong-doer, highly ungrateful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And recall what time Ibrahim said: my Lord! make this City secure and keep me and my sons away from worshipping the idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
My Lord! they have sent astray many among mankind; whosoever followeth me, verily he is of me; and whosoever disobeyeth me, then verily Thou art Forgiving, Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
Our Lord! verily have caused some of my progeny to dwell in a valley uncultivable near Thy Sacred House, Our Lord! in order that they may establish prayer; make Thou therefore the hearts of some of mankind to Yearn toward them, and provide them Thou With fruits, haply they may give thanks.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord! verily Thou knowest that which We conceal and that which We make known; and not of aught is concealed from Allah in the earth or in the heaven.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
All praise be unto Allah who hath bestowed upon me, despite old age lsma'il and ls-haq; verily my Lord is the Hearer of supplication.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord! make me establisher of prayer and also from my progeny, our Lord! and accept Thou my supplication.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Our Lord! forgive me and my parents and the believers on the Day whereon will be set up the reckoning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
And deem not Allah negligent of that which the wrong-doers work: He only deferreth them to a Day whereon the sighthall remain staring.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
They hastening forward, their heads upraised, their look returning not unto them and their hearts void.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn thou the mankind of the Day whereon the torment will come unto them; then those who have done wrong shall say: our Lord! defer us to a term near at hand we will answer Thy call and we will follow the apostles. Were ye not wont to swear afore that for you there was to be no decline?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
And ye dwell in the dwellings of those who had wronged themselves and it had become manifest unto you in what wise We had dealt with them, and We had propounded for you similitudes.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
And of a surety theys Plotted their plot, and with Allah was their plot, though their plot was such as to remove thereby mountains.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So deem not thouthat Allah is going to fail His promise to His apostles; verily Allah is Mighty, Lord of vengeance\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the Day whereon the earth will be changed into other than the earth, and the heavens also; and all creatures will appear unto Allah, the One, the Subduer.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And thou wilt see the guilty on that Day bound together in fetters.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their trouser hell be of pitch, and the Fire shall cover their faces.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That Allah may requite each soul according to that which he hath earned: verily Allah is swift in reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a preaching for mankind, and that they may be warned thereby, and that they may know that there is only one God, and that the men of understanding may be admonished.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif. Lam. Ra. These are the verses of the Book, and a Qur'an luminous.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Oft times would those who disbelieve fain that they had been Muslims.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them thou to eat and to enjoy, and let vain hope divert them; presently they will know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And We have not destroyed a town but there was therefor a decree known.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No community precedeth the term thereof nor doth it fall behind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they say: O thou unto whom the Admonition hath been sent down! verily thou art possessed.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why bringest thou not angels unto us if thou art of the truthtellers!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We send not the angels down save with judgment, and then they would not be respited.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Verily We! it is We who have revealed the Admonition, and verily We are the guardians thereof.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
And assuredly We have sent apostles before thee among the sects of the ancients.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And not an apostle came unto them but at him they were wont to mock.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Even so we make a way for it in the hearts of the culprits.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They believe not therein, and already the example of the ancients hath gone forth.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And if We opened upon them a door of the heaven, and they passed the day mounting thereto.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would surely say: intoxicated have been our sights; aye! we are a people enchanted.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And assuredly We have set constellations in the heaven and made it fairseeming unto the beholders\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have guarded it from every Satan damned.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Save him who stealeth the hearing, and him there followeth a flame gleaming.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth! We have stretched it out and have cast thereon mountains firm, and We have caused to spring up thereon everything weighed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And We have appointed thereon for you livelihoods and also for those of whom ye are not the providers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not of aught but with Us are the treasures thereof, and We send it not down save in a measure known\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We send the winds fertilizing, then We send down water from the heaven and We give it to you to drink, and thereof ye could not be the treasurers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And verily We! it is We who give life and death, and We shall be the survivors.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And assuredly We know those of you who have gone before and those who will come hereafter.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
And veriiy thy Lord! He will gather them, and verily He is Wise. Knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
And assuredly We have created human being from ringing clay of loam moulded.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the Jinn, We had created them afore of the fire of the scroching wind.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And recall what time thy Lord said unto the angels: verily I am about to createa man from ringing clay of loam moulded.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
Then when I have formed him and breathed into him of My Spirit fall down unto him prostrate.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels prostrated themselves, all of them together.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
But Iblis did not; he refused to be with the prostrates.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
Allah said: O Iblis! what aileth thou that thou art not with the prostrates?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He said it was not for me that should prostrate myself unto a human being whom Thou hast created from ringing clay of loam moulded.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
Allah said: then get thee forth therefrom; verily thou art one damned.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
And verily on thee shall be the curse till the Day of Requital.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said: my Lord! respite me then till the Day whereon they will be raised up.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Allah said: verily then thou art of the respited:\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
Till the Day of the Time known.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
He said: my Lord! because Thou hast led me to err I will surely make things fairseeming unto them on the earth and will surely seduce them all:\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
But not such of them as are Thy bondmen single-hearted.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
Allah said: this is the path leeding unto Me straight.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
Verily as for My bondmen, no authority shalt thou have over them, except the erring one who follow thee.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And verily Hell is the place promised unto them all.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
Unto it are seven portals; unto each portal is a Portion of them assigned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
Verily the God-fearing shall be amidst gardens and springs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
Enter therein in peace, secure.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We shall have removed whatsoever of grudge may be in their breasts: brethren they. sitting upon couches facing each other.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
There shall touch them no toil therein, nor therefrom they shall ever be driven out.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Declare thou unto My bondmen: verily I! I am the Forgiver, the Merciful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And verily My torment! that is the torment afflictive\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And declare thou unto them of Ibrahim's guests.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered unto him, and said; peace! He said: verily we are afraid of you.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said: be not afraid; verily we bear thou the glad tidings of a boy knowing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said: bear ye me glad tidings when old age hath touched me? of what then ye bear me glad tidings?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said: we bear tidings of a truth; be then thou not of the desponding.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said: and who despondeth of the mercy of his Lord except the astray\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said: what is your errand, sent ones?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said: verily we have been sent unto a people guilty-\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
All except the household of Lut; surely we are going to deliver all of them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
But not his wife; we have decreed that she will be of those staying behind.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
Then when the sent ones entered unto the household of Lut.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said: verily ye are a people stranger.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: nay! we have come to thee with that whereof they have been dubitating.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
And we have brought unto thee the truth, and verily we say sooth.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
So set out thou with thy house hold in a portion of the night, and follow thou their backs, and let not one of you look back, and pass whither ye are commanded.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We decreed unto him this commandment because the last of those was to be cut off in the early morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And there came the people of the city rejoicing\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said: verily these are my guests, so disgace me not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
And fear Allah, and humiliate me not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said: forbade we not thee against the worlds?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said: these are my daughters, if act ye must.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By thy life, in their intoxication they were wandering bewildered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
Then the shout took hold of them at the sunrise.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We made the upside there of downwards, and We rained on them stones of baked clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Verily therein are signs for men of sagacity.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And verily they are on a pathway lasting.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Verily in that is a sign for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the dwellers of the wood surely were wrong-doers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So We took vengeance on them. And verily both are on a high-road open.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And assuredly the dwellers of Hijr belied the sent ones.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And We brought Our signs unto them, yet they were averting themselves therefrom.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they were hewing out houses from mountains feeling secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
Then the shout took hold of them in the early morn.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
Then availed them not that which they had been earning.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
And We have not created the heaven and the earth and that which is in between them save with a purpose. And verily the Hour is surely coming; so overlook thou with a seemly overlooking,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Verify thy Lord! He is the Great Creator, the Knower.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And assuredly We have vouchsafed unto thee seven of the repetitions and the mighty Qur'an.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Cast not thine eyes toward that which We have let classes of them to enjoy; and grieve not over them, and lower thy wing unto the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say thou: verily I! I am a plain warner.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
Even as We sent down on the dividers -\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Those who have made the scripture bits.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
By thy Lord, We will question them all.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
For that which they have been working.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Promulgate thou that which thou art commanded, and turn away from the associaters.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Verily We will suffice unto thee against the mockers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Who set up along with Allah anot her god; presently they shall know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
And assuredly We know that thou straitenest thy breast by that which they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
So hallow thou the praise of thy Lord, and be thou of the prostrate.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And worship thy Lord until there cometh unto thee the certainty.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The affair of Allah cometh, so seek not to hasten it. Hallowed be He and Exalted above that which they associate.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sendeth down the angels with the spirit by His command upon whomsoever of his bondmen He willeth: warn that there is no god but I, wherefore fear Me.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He hath created the heavens and the earth with a purpose. Exalted is He above that which they associate.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He hath created man from a drop, and Lo! he is a disputer open.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle! He hath created them. For you in them there is warmth and other profits and of them ye eat.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And for you there is beauty in them as ye drive them at eventide and as ye drive them out to pasture.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they bear Your loads to a city Which ye could not reach except with travail of souls; verily your Lord is Kind, Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And He hath created horses and mules and asses that ye may ride there on, and as an adornment; and He createth that which ye know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And upon Allah is the direction of the way, and thereof is some crooked; and had He willed He would have guided you all.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
He it is who sendeth down from the heaven water for you, wherefrom is drinking and wherefrom are trees whereas ye pasture your herds.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
He groweth for you thereby the corn and olives and date- palms and grapes and all kinds of fruit. Verily therein is a sign for a people who ponder.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He hath subiected for you the night and the day and the sun and the moon, and the stars are subjected by His command. Verily therein are signs for a people who understand.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And He hath subjected for you whatsoever He hath multiplied for you on the earth of various kinds. Verily therein is a sign for a people who receive admonition.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And He it is who hath subjected the sea that ye may eat thereout flesh fresh and bring forth therefrom ornaments that ye wear. And thou beholdest ships ploughing therein, and it is in order that ye may seek of His grace, and that haply ye may give thanks.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He hath cast on the earth firm mountains lest it move away with you, and rivers and paths that haply ye may be directed.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And also landmarks; and by the stars they are guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is there one who createth like unto one who createth not? Will ye not then be admonished?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if ye would count the favours of Allah ye could not compute them verily Allah is Forgiving, Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knoweth that which ye keep secret and that which ye publish.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
And those upon whom they call beside Allahls have not created aught, and are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
Dead are they, not alive; and they perceive not when they will be raised up.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
God of you all is One God; so those who believe not in the Hereafter-their hearts are perverse and they are stiff-necked.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Undoubtedly Allah knoweth that which they keep secret and that which they publish; verily He loveth not the stiff- necked.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said unto them: what is it that your Lord hath sent down? they say: fables of the ancient.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
That they may bear their burthens in full on the Judgment- Day and also some of the burthens of those whom they have led astray without knowledge. Lo! vile is that which they shall bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Surely there plotted those before them, but Allah came upon their structures from the foundations, so the roof fell down upon them from above them and the torment came upon them whence they perceived not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then on the Judgment-Day He will humiliate them and say: where are My associates regarding whom ye have been causing cleavage? Those who have been vouchsafed knowledge will say: verily the humiliation to-day and ill-hap are upon the infidels-\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
Those whom the angels cause to die while they are wronging them selves, and then they proffer submission: we have not been working any evil. Yea! verily Allah is the Knower of that which ye have been working.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
Wherefore enter the portals of Hell as abiders therein. Vile is the abode of the arrogant\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And when it is said unto those who fear: what is it that your Lord hath sent down? They say: that which is better. For those who do good is good in this world, and the dwelling of the Hereafter is better. Excellent is the dwelling of the God-fearing!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Gardens Everlasting which they shall enter, whereunder rivers flow; theirs therein shall be whatsoever they list; Thus Allah recompenseth the God-fearing-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those whom the angels cause to die while they are clean, saying peace be upon you! enter the Garden for that which ye have working.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Await they aught but that the angels should come unto them or the command of thy Lord should come Likewise did those before them. Allah wronged them not, but they were wont to wrong themselves.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
Then there be-fell them the vices of that which they had worked, and there surrounded them that whereat they had been mocking.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And those who associate say: had God willed we would not have worshipped aught beside Him, neither we nor our fathers, nor we would have forbidden aught without Him. Like-wise did those before them. Naught is then on the apostles except a preaching plain.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And assuredly We have raised in every community an apostle saying: worship Allah and avoid the devil. Then of them were some whom Allah guided, and of them were some upon whom the straying was justified. Wherefore travel about on the earth, and look on what wise hath been the end of the disbelievers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
If thou art solicitous for their guidance, then verily Allah guideth not whomsoever He sendeth astray, and for them there are no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by God the most solemn of oaths that God would not raise him who dieth. Yea! it is a promise on Him incumbent but most of mankind know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
This will be in order that he may manifest unto them that wherein they differ, and that those who disbelieved should come to know that they had been liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
Our only saying unto a thing, when We intend it, is that We say unto it: be, and it becometh.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And those who have emigrated for the sake of Allah after they had been wronged. We shall surely settle them well in the world and the hire of the Hereafter is greater: if they but know!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
They are those who bear with patience, and in their Lord they trust.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We sent not before thee any but men unto whom We Revealed; so ask ye the people of the Admonition if ye know not.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
With evidences and scriptures We sent them. And We have sent down unto thee the Admonition that thou mayest expound unto mankind that which hath been revealed toward them, and that haply they may reflect.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Feel then they secure who have plctted vices that Allah will not sink them into the earth or that the torment may come upon them whence they perceive not?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or, thathe will not take hold of them in their going to and fro! so that they cannot escape.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or, that he will not take hold of them by giving them a fright? verily thy Lord is Kind, Merciful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not observed the things which Allah hath created? shadows thereof turn themselves on the right and on the left. prostrating themselves unto Allah, and they are lowly.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And unto Allah prostrateth itself whatsoever is in the heavens and whatsoever is in the earth of the living creatures and also the angels; and they are not stiff-necked.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them and do that which they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
And Allah hath said: take not two gods; He is only One God so Me alone, Me dread.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
And His is whatsoever is in the heavens and the earth, and unto Him is obedience due perpetually; will ye then fear any other than Allah?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatsoever of favours is with you is from Allah; then when distress toucheth you, unto Him ye cry out.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Then when He removeth the distress from you, forthwith a party of you with their Lord associate.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
That they may show ingratitude for that which We have vouchsafed unto them. Enjoy then, presently ye shall know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they appoint for that which they knew not a portion of that wherewith We have provided them By Allah! ye will surely be questioned regarding that which ye have been fabricating.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they appoint for Allah daughters --hallowed be He! -- and for themselves that which they desire.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when there is announced unto any of them a female his countenance remainoth darkened the whole day and he is wroth inwardly.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
Skulking from the people because of the evil of that which hath been announced unto him: shall he keepit with ignominy or bury it in the dust! Lo'. vile is that which they judge!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
For those who believe not in the Hereafter is an evil similitude, and for Allah is the sublime similitude, and He is the Mighty, the Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
And if Allah were to lay hold of mankind for their wrong- doing, not a living creature He would leave on it, but he deferreth them to a term appointed, then, when their term cometh, they cannot put it off by an hour not anticipate it.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
And they ascribe to Allah that which they detest, and their tongues utter the lie that unto them shall be good; undoubtedly unto them shall be the Fire, and they will be hastened thereto.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah! assuredly We have sent apostles to communities before thee, then the Satan made their works fairseeming unto them, so he is their patron to-day, and unto them shall be a torment afflictive.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have not sent down the Book unto thee save in order that thou mayest expound unto them that wherein they differ, and as a guidance and a mercy unto a people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah hath sent down from the heaven water, then he reviveth the earth thereby after the death thereof; verily therein is a sign for a people who hearken.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And verily there is for you in the cattle a lesson: We give you to drink of that which is in their bellies, from betwixt the dung and the blood: milk Pure and pleasant to swallow for the drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And also a lesson for you in the fruits of the date-palms and the grapes whereof ye take a liquor and a provision goodly; verily therein is a sign far a people who understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And thy Lord inspired the bee saying: take thou for thyself of the mountains houses and of the trees and of that which they erect.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then eat thou of all the fruits and tread the ways of thy Lord made easy. There springeth forth from their bellies a drink varied in colours; therein is healing for mankind; verily therein is a sign for a people who reflect.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah hath created you, then He taketh your souls; of you are some who are brought back to the meanest of age, so that they know not aught after having knowledge; verily Allah is Knowing, Potent.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah hath preferred some of you over some other in provision; then those who are preferred are not going to hand over their provision to those whom their right hands possess as to be equal in respect thereof. Gainsay they then the favour of Allah?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah hath appointed for yourselves spouses, and from your spouses He hath appointed for you sons and grandsons, and He hath provided you with clean foods. In falsehood then believe they, and in Allah's favour disbelieve they?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship, beside Allah, that which owneth them not any provision from the heavens and the earth, and they cannot\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
Propound not then for Allah similitudes, verily Allah knoweth and ye know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah propoundeth a similitude: there is a bondman enslaved who hath not power over aught; and there is one whom We have provided from Ourselves with goodly provision and he expendeth thereof secretly and openly; can they be equal? All praise Unto Allah; but most of them know not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah propoundeth a similitude: there are two men, one of them dumb who hath of Power over aught and is a weariness unto his master, whithersoever he directeth him he bringeth not any good; is he equal with one who commandeth justice and in himself on a straight patht?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And Allah's is the Unseen of the heavens and the earth, and the affair of the Hour will be not but as a flash of the eye, or it is even nearer, verily Allah is over everything Potent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah hath brought you forth from the bellies of your mothers while ye know not aught, and He hath appointed for you hearing and sight and hearts that haply ye might give thanks.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Behold they not the birds subjected in the firmament of the heaven? Naught supporteth them save Allah; verily therein are signs for people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
Allah hath appointed for you from your houses a repose, and He hath appointed for you from the skins of the cattle houses which ye find light, on the day of your flitting and on the day of your stopping, and from their wools and their furs and their hair a furnishing and an enjoyment for a season.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah hath appointed for you, of that which He hath created shades, and He hath appointed for you from the mountains places of retreat, and He hath appointed for you coats protecting you from the heat and coats protecting you from the violence. Thus He perfecteth His favour on you that haply ye may submit.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
Then if they turn away, on thee is only the preaching plain.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize the favour of Allah, then they deny it, and most of them are infidels.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And bewore a Day whereon We will raise up from each community a witness, then those who have disbelieved will not be given leave, nor they will be permitted to please Allah.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when those who have done wrong will behold the torment, it will not be lightened unto them, nor will they be respited.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who have associated will behold their associate-gods, they will say: our Lord! yonder are our associate-gods upon whom we have been calling beside Thee, they Will proffer them the saying: verily ye are liars.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they will proffer sub mission unto Allah on that Day, and there will stray from them that which they have been fabricating.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieved and hindered others from the way of Allah- We shall increase for them torment upon torment for they have been spreading corruption.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And beware a Day whereon We shall raise up in every community a witness regarding them from amongst them selves, and We shall bring thee as a witness regarding these. And We, have revealed unto thee the Book as an exposition of everything and as a guidance and mercy and glad tidings to the Muslims.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Verily Allah commandeth justice and well-doing and giving to kindred; and He prohibiteth lewdness and wickedness and oppression; He exhorteth you that haply ye may beadmonished.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfil the covenant of Allahs when ye have covenanted, and violate not the oaths after the ratification thereof, and surely ye have appointed Allah a surety over you. verily Allah knoweth that which ye do:\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And be not like unto her who unravelleth her yarn into strands after its strength, holding your oaths a means of discord amongst you that a community may be more numerous than anot her community; Allah only proveth you there by; and He will surely manifest unto you on the Judgment Day that wherein ye have been differing.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
And had Allah willed, He would have made you all one community, but he sendeth astray whomsoever He willeth, and guideth whomsoever He willeth; and surely ye shall be questioned regarding that which ye have been working.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And make not your oaths a means of discord amongst you lest a foot may slip after the fixture thereof, and ye may taste evil for having hindered others from the way of Allah, and unto you there shall be a torment mighty.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And barter not the covenant of Allah for a small price; verily that which is with Allah --that is better for you, if ye only know.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
That which is with you is exhausted, and that which is with Allah is lasting. And We will surely recompense those who have been patient their hire for the best of that which they have been working\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whosoever worketh righteously, male or female, and is a believer, We will surely quicken him to a clean life, and will surely recompense them their hire for the best of that which they have been working.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
And when thou wouldst read the Qur'an seek refuge with Allah from Satan the damned.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
Verily he hath no authority over those who believe and in their Lord trust\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His authority is only over those who befriend him and those who are in respect of Him associators.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And whenever We change a verse in place of anot her verse - -and Allah is the Best Knower of that wwhich He revealeth --they say: thou art but a fabricator, Aye! most of them know not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say thou: the Holy Spirit hath brought it down from thy Lord with truth, that it may establish those who believe, and as a guidance and glad tidings unto the Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And assuredly We know that they say: it is only a human being who teachech him. The speech of him unto whom they incline is foreign while this is Arabic speech plain.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Verily those who believe not in the signs of Allah--Allah shall not guide them, and unto them shall be a torment afflictive.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
It is only those who believe not in the signs of Allah who fabricate lie, and those! they are the liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whosoever disbelieveth in Allah after his belief--save him who is constrained and his heart is at rest with the belief -but whosoever expandeth his breast to infidelity, upon them shall be wrath from Allah, and unto them shall be a torment mighty.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they loved the life of the world above the Hereafter, and because Allah guideth not an infidel people.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
These are they upon whose hearts and hearing and sight Allah hath set a seal; and these! they are the negligent.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
Undoubtedly they in the Hereafter shall be the very losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then, verily, thy Lord unto those who have emigrated after they had been tempted and have thereafter striven hard and endured, verily thy Lord thereafter is Forgiving, Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
Beware a Day whereon each soul will come pleading for itself, and each soul will be paid in full that which it hath wrought, and they shall not be wronged.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And Allah propoundeth a similitude: a town which was secure and at rest, to which came the provision thereof plenteously from every place; then it ungratefully denied the favours of Allah; wherefore Allah made it taste the extreme of hunger and fear because of that which they were wont to perform.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And assuredly there came to them an apostle from among them, but they belied him, wherefore the torment took hold of them while yet they were wrong-doers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of that which Allah hath provided you of lawful and clean things, and give thanks for Allah's favour, if it is He whom ye are went to Worship.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He hath only disallowed unto you the dead-meat and blood and swine-flesh and that over which is invoked the name of other than Allah. Then whosoever is driven by necessity, not alusting nor transgressing verily Allah Is Forgiving, Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And say not concerning that wherein Your togues utter a lie: this is lawful, and this is unlawful, that ye may fabricate a lie againt Allah, verily those who fabricate lie against Allah shall not fare well.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A brief enioyment, and unto them shall be a torment afflictive.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And un to those who are Judaised We disallowed that which We have already recounted unto thee; and We wronged them not, but themselves they were wont to Wrong.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then, verily, thy Lord unto those who work evil from ignorance, and then repent thereafter and amend, verily thy Lord thereafter is Forgiving, Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Verily Ibrahim was a pattern, devout unto Allah, upright, and, not of the associaters.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
Grateful for His favours: He chose him and guided him to a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We vouchsafed unto him good in this world, and in the Hereafter he shall be of the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Afterwards We revealed unto thee: follow thou the faith of Ibrahim the upright; and he was not of the associaters.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The sabbath was only appointed for those who differed thereon; and verily thy Lord will judge between them on the Judgment-Day concerning that wherein they have been differing.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Call them unto the way of thy Lord with Wisdom and goodly exhortation, and argue with them with that which is best. Verily thy Lord! He is the Best Knower of him who hath strayed from His way, and He is the Best Knower of the guided ones.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if ye chastise, then chastise with the like of that wherewith ye were afflicted, and if ye endure patiently, then surely it is better for the patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And endure them patiently; and thy patience is not but from Allah; and grieve not over them, and be not thou in straitness because of that which they plot.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Verily Allah is with those who fear and those who are well- doers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Hallowed be He Who translated His bondman in a night from the Sacred Mosque to the Furthest Mosque, the environs whereof We have blest, that We might shew him of Our signs; verily He! He is the Hearer, the Beholder.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We vouchsafed unto Musa the Book and We appointed it as a guidance to the Children of Isra'il: take not beside Me a trustee.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
O progeny of those whom We bare with Nuh: verily he was a bondman grateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed unto the Children of Isra'il in the Book; ye will surely cause corruption in the land twice, l and ye will surely rise to a great height.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
Then when the promise for the first of the two came, We raised against you bondmen of Ours endued with exceeding violence, so they entered the dwellings; and it was a promise fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Thereafter We gave you a return of victory over them, and We supported you with riches and children, and We made you a numerous concourse.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
If ye will do well ye will do well for yourselves, and if ye will do evil it will be against the same. Then when the promise of the second came, We raised up a people that they may disgrace your faces and may enter the Mosque even as they entered it the first time, and that they may destroy with utter destruction whatsoever may fall under their power.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
Belike your Lord may yet have mercy on you; and if ye still revert, We will revert. And We have appointed Hell for the infidels a prison.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Verily this Qur'an guideth unto that path which its sraightest and beareth glad tidings to the believers who work righteous deeds that for them shall be a hire great.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And that those who believe not in the Hereafter--for them We have gotten ready a torment afflictive.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
And man prayeth for evil the prayer he should make for good, and man is ever hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We have appointed the night and the day as two signs; then We blurred the sign of the night and made the sign of the day illuminating that ye may seek grace from Your Lord, and that ye may know the number of the years and the reckoning; and everything We have detailed in full details.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And every man: We have fastened his action round his neck, and We shall bring forth unto him on the Day of Judgment a book proffered him open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
Read thine book; sufficeth to-day thy soul against thee as a reckoner.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whosoever is guided, it is only for himself that he is guided and whosoever Strayeth, it is only against the same that he strayeth; and a burthen-bearer beareth not the burthen of anot her. And We have not been tormentors until We had raised an apostle.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We intend that We shall destroy a town We command the affluent people thereof, then they transgress therein; wherefore the word is justified on them; then We annihilate it with Utter annihilation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many a generation have We destroyed after Nuh; and sufficeth for the offences of His bondmen thy Lord as the Aware, the Beholder.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
- Whosoever intendeth the quick Passing world, We hasten to him therein whatsoever We please unto whomsoever We intend; thereafter We shall appoint for him Hell wherein he shall roast, reproved, rejected.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whosoever intendeth the Hereafter and striveth therefor with due striving, while he is a believer, then those: their striving shall be appreciated.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
To each--these and those--We extend of the bestowment of thy Lord; and the bestowment of thy Lord is never restrained.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
Behold thou! how We have preferred some of them over some others; and surely: the Hereafter is greater in degrees and greater in preferment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Set not up along with Allah anot her god, lest thou sit down reproved, renounced.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
And thy Lord hath decreed that ye shall Worship none but Him, and unto parents shew kindness; and if either of them or both of them attain old age with thee, Say not unto them: pooh: And browbeat them not, and Speak unto them a respectful speech.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower unto them the wing of meekness out of mercy, and say: O my Lord! have mercy on the twain even as they brought me up when young.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord is the Best Knower of that which is in your souls; if ye have been righteous, then He is unto thee Oftreturning, Forgiving.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give thou to the kinsman his due, and also unto the needy and the wayfarer; and squander not in squandering.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Verily the squanderers are ever the brethren of the Satans, and the satan is ever unto his Lord ungrateful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And if thou turnest away from them awaiting a mercy from thy Lord which thou hopest, then speak unto them a gentle speech.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And let not thine hand be chained to thy neck, nor stretch it forth to the utmost stretching, lest thou sit down reproached, impoverished.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Verily thy Lord extendeth the provision for whomsoever He will and He measureth it out; verily He is in respect of His bondmen Aware, Beholder.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And saly not your offspring for fear of want; We provide for them and for yourselves; verily their slaying is a great crime.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And approach not adultery; verily it is ever an abomination and vile as a pathway.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And slay not anyone whom Allah hath forbidden except for justification; and whosoever is slain wrongfully, We have surely given his next-of-kin authority so let him not be extravagant in slaying; verily he is ever succoured.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And approach not the substance of an'orphan save with that which is best, until he attaineth his age of strength. And fulfil the covenant; verily the covenant shall be asked about.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And give full measures when ye measure and weigh with an even balance that is good, and the best interpretation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And go not thou after that where of thou hast no knowledge verily the hearing and the sight and the heart, each of these shall be asked about.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And walk thou not on the earth struttingly; verily thou wilt by no means rend the earth, nor canst thou attain to the mountains in stature.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
Each of these--theyice thereof is unto thy Lord ever detestable.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is Part of that wisdom which thy Lord hath revealed unto thee, and set not up thou along with Allah anot her god, lest thou be cast into Hell, reproved, rejected.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Hath then your Lord distinguished you with sons and taken for Himself females from among the angels? Verily ye say a saying mighty?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
And assurelly We have propounded it variously in this Qur'an that they might be admonished, but it increaseth them only in aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say thou: were there along with Him other gods, as they say, then they would have brought unto the Owner of the Throne a way.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Hallowed be He, and exalted be He above that which they say --a greatheight!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
There hallow Him the seven heavens and the earth and whosoever is therein. And naught there is but halloweth His praise, but ye understand not their hallowing; verily He is ever Forbearing, Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when thou recitest the Qur'an, We set up between thee and those who believe not in the Hereafter a curtain drawn down.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We set up over their hearts veils lest they understand it, and in their ears heaviness and when thou mentionest in reciting the Qur'an thy Lord alone, they turn backward as averters.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We are Best Knower of that wherewith they listen what time they listen to thee and what time they counsel together in secret, when the wrong-doers say: ye but follow a man enchanted.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
Behold! how they propound similitudes for thee! They have strayed and cannot find a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say: when we shall have become bones and fragments, shall we in sooth be raised as a new creation?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say thou: become ye stones or iron.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
Or anything created of the things more remote in your breasts. Then they will say: who will restore us! Say thou: He who created you the first time. Then they will wag their heads at thee and say; when will it be! Say thou: belike it is nigh-\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
The Day whereon He will call you, and ye will answerl with His praise, and ye will imagine that ye had tarried but little.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Say thou unto My bondmen that they should say that which is best, Verily the Satan would stir up strife between them; verily the Satan is unto men ever an enemy manifest.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord is the Best Knower of you; if He willeth He will have mercy upon you, or if He willeth He will torment you. And We have not sent thee over them as a trustee.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And thine Lord is the Best Knower of those who are in the heavens and the earth. And assuredly We have preferred some prophets over some others: and We vouchsafed unto Daud a Scripture.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say thou: call upon those whom ye fancy beside Him; they are able neither to remove the distress from you nor to work a turning off.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they call upon themselves seek access to their Lord, striving which of them shall be the nearest; and they hope for His mercy and fear His torment; verily the torment of thy Lord is ever to be guarded against.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
Not a town is there but VVe are going to destroy it before the Day of Judgment or to torment it With a severe torment; that is in the Book inscribed.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And naught hinderedeth Us from sending the signs except that the ancients belied them. And We vouchsafed unto Thamud a she-camel as an illumination, but they did her wrong. And We send not the signs save to frighten.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And recall what time We said unto thee: verily thy Lord hath encompassed mankind. And We made the vision We shewed thee but a temptation for men, and likewise the tree accurst in the Qur'an. And We frighten them, but it only increaseth them in exorbitance great.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And recall what time We said unto the angels: prostrate youselves before Adam. So they prostrated themselves, but Iblis did not; he said: shall I prostrate myself before one whom Thou hast created of clay?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
lblis said; bethinkest Thou: This one whom Thou hast honoured above me- if Thou deferrest me till the Day of Judgment, shall surely seize his progeny save a few.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
Allah said: be thou gone; then who soever of them followeth thee, Hell is your meed, a meed ample.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
And unsettle thou whomsoever of them thou canst with thy voice, and summon against them thine horse and thine foot, and share with them riches- and children, and promise unto them; and the Satan promiseth not but to delude.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
Verily My bondmen; over them thou hast no authority; and thy Lord sufficeth as a Trustee.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He who speedeth for you the ship in the sea that ye may seek His grace; verily He it unto you ever Merciful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when there toucheth you a distress on the sea, those whom ye call upon fall away except Him alone, then when He delivereth you on the land ye turn away: and man is ever ungrateful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Are ye then secure that he will not cause a side of the land to swallow you up, or send over you a sand-storm, and then ye will not find for yourselves a trustee?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or are ye secure that he will not send you back therein anot her time and then send upon you a gale of wind and drown you for your having disbelieved, so that therein you will not find for yourselves against Us an avenger?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
And assuredly We have honoured the Children of Adam: and We have borne them on the land and the sea, and We have provided them with clean things, and We have preferred them over many of them whom We have created with a preferment.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
Remember the Day whereon We shall call all man kind with their record: then whosoever will be vouchsafed his book in his right hand, those shall read their book, and they shall not be wronged a whit.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
And whosoever hath been in this life blind will in the Hereafter be blind, and far astray from the way.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
And verily they had well-nigh tempted thee away from that which We have revealed unto thee, that thou shouldst fabricate regarding something else; and then surely they would have taken thee as a friend!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And were it not that We had confirmed thee, thou hadst well-nigh leaned toward them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
In that case We would have surely made thee taste the double of the tornment of the life and the double of the torment of death, and then thou wouldst not find against Us a helper.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
And verily they had well-nigh unsettled thee from the land that they might drive thee forth from thence. And in that case they would not have tarried after thee but a little while.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
This was Our dispensation with those whom We sent before thee of Our apostles, and thou wilt not find in this Our dispensation a change.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish thou the prayer from the declination of the sun to the darkening of the night, and the Recitation at the dawn; verily the Recitation at the dawn is ever borne witness to.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And of the night--keep the vigil therein, as an act of supererogation for thee; belike thy Lord will raise thee up in a station praised.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say thou: O my Lord! cause me to enter a rightful entrance and cause me to go forth with a rightful outgoing, and appoint for me from before Thee an authority helpful.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say thou: the truth is come, and falsehood hath vanished; verily falsehood is ever vanishing.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We reveal by means of the Qur'an that which is a healing and a mercy unto the believers, and it only increaseth the wrong- doers in loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We show favour unto he turneth away and withdraweth on his side; and when evil toucheth him he is ever despairing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say thou: everyone worketh after his disposition, and your Lord is the Best Knower of him who is best guided on the Way.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
And they ask thee regarding the spirit, Say thou: the spirit is by the command of my Lord, and ye have not been vouchsafed of knowledge save a little.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We listed, We could surely take away that which We have revealed unto thee: then thou wilt not find in respect thereof against us as trustee.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except as a mercy from thy Lord verily His grace unto thee is ever great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say thou: if the mankind and the jinn leagued together that they might produce the like of this Qur'an, they could nor produce the like thereof, though one to the other were a backer.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And assuredly We have variously propounded for mankind in this Qur'an every kind of similitude, yet most men have refused everything except infidelity.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they say: we shall by no means believe in thee until thou causest for us to gush forth from the earth a foun tain.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
Or there be for thee a garden of date-palms and wine, and thou causest in the midst thereof rivers to gush forth.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
Or thou causest the heaven to fall upon us, as thou assertest, in pieces, or thou bringest God and the angels face to face.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
Or there be for thee a house of gold or thou mountest to the heaven, and we will by no means believe in thy mounting even until thou causest a book to be sent down to us, which we may read. Say thou: hallowed be my Lord! I am naught but a human being sent as an apostle.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And naught hath prevented men from believing when the guidance came Unto them except that they said: hath God sent a human being as apostle?\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say thou: were there in the earth angels walking about contentedly, We would surely have sent down unto them from the heaven an angel as an apostle.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say thou: Allah sufficeth as a witness between me and you; verily He is in respect of His bondmen ever the Aware, the Beholder.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And whomsoever Allah guideth, then he is the guided; and whomsoever He sendeth astray--for such thou wilt by no means find friends beside Him. And We shall gather them on the Day of Judgment on their faces, blind and deaf and dumb; their abode being Hell; so oft as it grosweth dull We shall increase for them the Flame.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
This shall be their meed because they disbelieved in Our signs and said when we have become bones and fragments, shall we in sooth be raised up a new creation!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Behold they not that Allah who created the heavens and the earth is Able to create their likes? And He hath appointed for them a term whereof there is no doubt; yet the wrong-doers have refused everything excepting infidelity.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say thou: if it were ye who owned the treasures of the mercy of my Lord, ye would surely refrain for fear of expending; and man is ever miserly.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And assuredly We vouchsafed unto Musa nine manifest signs - ask thou the Children of Israel--so when he came unto them, Fir'awn said unto him, verily imagine thee, O Musa! enchanted.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
Musa said: assuredly thou knowest that none hath sent down these save the Lord of the heavens and the earth as an enlightenment; and verily imagine thee, Fir'awn, doomed.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
Then he besought to unsettle them from the land; wherefore We drowned him and those with him, all together.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said, after him, unto the Children of Isra'l: dwell on the earth, then when there cometh the promise of the Hereafter, We shall bring you as a crowd.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
And with truth We have sent it down and with truth it hath come down; and We have not sent thee but as a bringer of glad tidings and a warner.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And this is a Recitation which We have made distinct that thou mayest recite it unto mankind with delay, and We have revealed it at intervals.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say thou: whether ye believe it or believe it not, verily those who were vouchsafed knowledge before it, when it is recited unto them, fall down on their chins, prostrating.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say: hallowed be our Lord! the promise of Our Lord was ever to have been fulfilled.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down on their chins weeping, and it increaseth them in humility.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say thou: call upon Allah or call upon Rahman, by whichsoever ye call, His are the excellent names. And shout not thy prayer, nor speak it low, but Seek between these a way.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say thou: all praise is unto Allah who hath not taken a son, and whose is no associate in the dominion, nor hath He a protector through weakness, and magnify Him with all magnificence.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen All praise unto Allah who hath sent down unto His bondman the Book, and hath not placed therein any crookedness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
Straightforward, that it may warn of a severe violence from before Him, and bring glad tidings to the believers who work righteous works that theirs shall be a goodly hire.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
They will abide therein for ever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And that it may warn those who say: God hath taken a son.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
No knowledge thereof have they, nor had their fathers. Odious is the word that cometh out of their mouths; they say not but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Haply thou art going to kill thyself over their footsteps, if they believe not in this discourse, out of sorrow.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Verily We have made whatsoever is on the earth as an adornment thereof, that We may prove them - which of them is best in work.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And verily We are going to make whatsoever is thereon a soil bare.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Deemest thou that the people of the cave and the inscription were of Our signs a wonder?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
Recall what time the youths betook themselves to the cave, then said: our Lord! vouchsafe unto us mercy from before Thee, and prepare for us in our affair a right course.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Wherefore We put a covering over their ears in the cave for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Thereafter We raised them up that We might know which of the two parties was best at reckoning the time that they had tarried.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We recount unto thee their tidings With truth. Verily they were certain youths who believed in their Lord, and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We braced their hearts when they stood forth and said: our Lord is the Lord of the heavens and the earth; never we shall call upon a god beside him; for then we shall be saying an abomination.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
These, our people, have taken for themselves gods beside Him - wherefore bring they not for them an authority manifest? --and who doth greater wrong than he who fabricateth against God a lie?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
And now when ye have withdrawn from them and that which they worship, except God, betake yourselves to the cave; your Lord will unfold for you some of His mercy, and will prepare for you of your affair an easy arrangement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And thou Woudst behold the sun when it riseth veering away from their cave on the right, and when it setteth, passing them by on the left, while they were in the spacious part thereof: that is of the signs of Allah. Whomsoever Allah guideth, he indeed is the guided; and whomsoever He sendeth astray, for him thou wilt never find a directing friend.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And thou wouldst have deemed them awakes whereas they were asleep and We turned them over on the right side and on the left side, while their dog stretched forth his two forelegs on the threshold. If thou hadst observed them, thou wouldst have surely turned away from them in fright, and wouldst have surely been filled with awe of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
And likewise we raised them up that they might question among themselves; there spake a speaker from amongst them: how long have ye tarried? They said we have tarried a day or part of a day. They said, your Lord knoweth best how long ye have tarried; now send one of you with this your money unto the city and let him see which food is purest there, and let him bring you a provision thereof, and let him be circumspect, and let him by no means discover you to anycne.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
Verily they, if they come to know of you, would stone you or make you revert to their faith, and lo! then ye will never fare well.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And likewise We caused their affair to be lit upon that they might know that the promise of Allah is true, and that the Hour- there is no doubt thereof, Recall what time they were disputing among themselves regarding their affair, and then they said: build over them a building--their Lord is the Best Knower about them-then those who prevailed in their affair said: surely we will raise over them a place of worship.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
Anon they will say: they were three the fourth of them their dog. And they will say: they were five, the sixth of them their dog- -guessing at the unknown --and they willl say: they were seven, the eighth of them their dog. Say thou: my Lord is the Best Knower of their number; there knew them only a few; so debate thou not regarding them except an cut ward debating, and ask not regarding them anyone of them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say thou of a thing: verily I am going to do that on the morrow.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except with this reservation that Allah so will. And remember thy Lord when thou forgettest; and say thou belike my Lord will guide me to something nearer than this to right direction.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they tarried in their cave three hundred years and added nine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say thou: Allah knoweth best how long they tarried; His alone is the hidden knowledge of the heavens and the earth. How well He seeth and heareth. They have no patron beside Him, nor in His rule He associateth anyone.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And rehearse thou that which hath been revealed unto thee of the Book of thy Lord; and none may alter His Words, and never wilt thou find beside Him a covert.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And endure thy self in the company of those who call upon their Lord in the morning and evening seeking His and let not thine eyes countenance rove from them seeking the adornment of the life of this world, and obey thou not him whose heart We have made to neglect Our remembrance, and who followeth his lust, and whose affair is exceeding the bound.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And say thou: the truth is from your Lord; let him therefore who will, believe, and let him who will, disbelieve. Verily We have gotten ready for the wrong-doers a Fire the awnings whereof shall encompass them; and if they cry for relief they shall be relieved with water like the dregs of oil scalding their faces. 111 the drink, and vile the resting-place!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Verily those who believe and work the righteous works-- verily We waste not the hire of one who doth well in regard to his work.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
These! for them are Gardens Everlasting whereunder rivers flow; bedecked they shall be therein with bracelets of gold, and wear they shall green robes of satin and brocade, reclining therein on the couches; excellent the reward, and goodly the resting-place!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
Propound thou unto them the similitude of two men. We appointed to one of them two gardens of vine and hedged both with date- palms, and We placed in-between the twain tillage.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of the two gardens brought forth its produce and stinted not aught thereof; and We caused to gush forth in the midst of the twain a river.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had property. Then he Said unto his fellow while he spake with him: I am more than thou in substance and am mightier in respect of retinue.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he entered his garden, while he was a wrong-doer in respect of his own soul; he said: I imagine not that this shall ever perish.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
Nor I imagine that the Hour is going to happen; and if am brought back to my Lord, surely I will find something better than this as a retreat.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His fellow said unto him, while he spake with him: hast thou disbelieved in Him Who created thee of dust, then of a sperm, and formed thee a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
But he is Allah, my Lord; and with my Lord associate not anyone.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
Wherefore saidst thou not, when thou enteredest thy garden: whatsoever Allah may will! there is no power save in Allah! If thou beholdest I am inferior to thee in substance and offspring.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
Then belike my Lord will vouchsafe unto me something better than thy garden and send thereon a belt from the heaven that it become a plane slippery.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
Or the water thereof become deep sunken so that therefor thou canst not make a search.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And his property was encompassed; and lo! he was wringing the palms of his hands over that which he had expended thereon, while itlay fallen down on its trellises, and saying: Oh, would that had not associated with my Lord anyone:\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And there could be no party suceouring him as against Allah, nor could he himself be an avenger.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
Herein is all protection from Allah the True: He is excellent in respect of reward and excellent in respect of the final end!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And propound thou unto them the similitude of the life of the World. It is as water which We send down from the heaven, then there mingleth therewith the vegetation of the earth, and lo! it becometh dry stubble which the winds scatter and Allah is over everything potent.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Substance and sons are the adornment of the life of the World, and the righteous works that last are excellent with thy Lord in respect of reward, and excellent in respect of hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And beware a Day whereon we will make the mountains to pass, and thou wilt see the earth away plain, and We shall gather them, and We shall leave of them not one.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they shall be sent before thy lord in ranks! now are ye come to Us even as We had created you the first time; aye ye fancied that We had appointed for you no tryst.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book shall be placed, and thou wilt see the culprits alarmed at that which is therein, and they will say: Ah! woe unto us! what aileth this book that it leaveth not any sin small or great but it hath computed it! And they shall find all that they had wrought present; and thy Lord wrongeth not any one.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And recall what time we said unto the angels: prostrate yourselves before Adam, and they prostrated themselves, but Iblis did not; he was of the genii; so he trespassed the commandment of his Lord. Would ye then take him and his progeny as patrons instead of Me, whereas they are unto you an enemy III is for the wrong-doers an exchange!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I Made them not present at the creation of the heavens and the earth nor at the creation of themselves; nor was I one to take the seducers as supporters;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And beware a Day whereon He will say: cry unto my associates say cry unto whom ye fancied. So they will call unto them, and they will answer them not, and We shall place between them a partition.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the culprits will behold the Fire and imagine that they are about to fall therein, and they shall not find therefrom a way of escape.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And assuredly We have variously propounded in this Qur'an for mankind every kind of similitude; and man is of all things the most disputing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And naught preventeth mankind from believing when the guidance hath come unto them, and from asking foregiveness of their Lord, but that there may come unto them the dispensation of the ancients, or that the torment may come Unto them face to face.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We send not apostles save as bringers of glad tidings and warners; and those who disbelieve dispute with falsehood that they rebut thereby the truth; and they take My signs and that whereof they are warned as a mockery.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who doth greater wrong than he who is admonished with the signs of His Lord yet turneth away from them and forgetteth that which his hands have sent forth? Verily We have set up veils over lest they should understand it, and in their ears a heaviness; and if thou callest them to the guidance, lo! they will not let themselves be guided ever.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
And thy Lord is the Forgiver, Owner of mercy. Were He to call them to account for that which they have earned; He would have hastened for them torment; but for them is a tryst beside which they cannot find a place to betake themselves to.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And these cities! We destroyed them when they did wrong, and We had appointed for their destruction a tryst.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And recall what time Musa said unto his page: I shall not cease until I reach the confluence of the two seas, or I shall go on for ages.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
And when the twain reached the confluence of the two, they forgot their fish, and it took its way into the sea freely.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
And when the twain had passed by, he said unto his page: bring us our morning-meal, assuredly we have met from this journey of ours, toil\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said: lookest thou! when we betook ourselves to the rock, then forgot the fish; and naught but the Satan made me forget to mention it, and it took its way into the sea--a marvel!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
Musa said: that is that which we have been seeking. So they turned back upon their footsteps, retracing.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then the twain found a bondman from Our bondmen, him We had vouchsafed a mercy from before Us, and him We had taught from Our presence a knowledge.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Musa said unto him: shall I follow thee that thou mayest teach me of that which thou hast been taught a directive knowledge.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said: verily thou wilt not be able to have with me patience;\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
And how canst thou have patience over that which thy knowledge encompasseth not\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
Musa said: thou wilt find me, if Allah will, patient, and shall not disobey thee in any affair.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said: then if thou wilt follow me ask me not of anything until begin thereof some mention.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
Then the twain journeyed until when they embarked in a boat, he scuttled it. Musa said: hast thou scuttled it that thou mayest drown the people thereof? Assuredly thou hast committed a thing grievous.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He said: said I not that thou wouldst not be able to have with me patience?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
Musa said: take me not to task for that forget, and impose not in my affair hardship.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then the twain journeyed until when they met a boy, and he killed him. Musa said: hast thou slain a person innocent not in return for a Person Assuredly thou hast committed a thing formidable.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said: said I not unto thee that thou wouldst by no means be able to have with me patience?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
Musa said: if I ask thee regarding aught after this, company not with me; surely there hath reached to thee from my side an excuse.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
Then the twain journeyed until when they came unto the people of a city, they begged food from the people thereof, but they refused to entertain the twain. Then they found therein a wall, about to fall down, and he set it upright. Musa said: hadst thou willed, thou mightest have taken therefor a hire.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said: this shall be the parting between me and thee; now I shall declare unto thee the interpretation of that wherewith thou wast not able to have patience.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the boat, it belonged to poor men working in the sea, so I intended to damage it, for there was before them a prince taking every boat by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
And as for the boy, his parents were believers, and we apprehended that he might impose upon the twain exorbitance and infidelity.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
So we intended that their Lord should change for the twain one better than he in piety and closer in affection.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
And as for the wall, it belonged to two orphan boys in the town and underneath it was a treasure belonging to them and their father had been righteous. So thy Lord intended that the twain should attain their maturity and bring forth for themselves their treasure as a mercy from thy Lord. And I did it not of mine own command; that is the interpretation of that wherewith thou wast not able to have patience.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask thee of Zul Qarnain. Say thou: shall recite unto you of him some mention.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Verily We! We established him in the earth, and vouchsafed unto him of everything a way.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
Then he followed a way.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until when he reached the setting-place of the sun, he perceived it setting in a miry spring, and he found beside it a nation. We said: Zul Qarnian! either chastise them or take in respect of them the way of kindness.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: as for him who doeth wrong, presently we shall torment him, and thereafter he shall be brought back to his Lord, and He shall torment him with a torment formidable.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
And as for him who believeth and worketh righteously, unto him shall be a goodly hire, and anon we shall speak unto him of our affair something easy.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Thereafter he followed a way.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until when he reached the rising place of the sun, he perceived it rising upon a nation for whom against it We had not set a veil.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
Thus it was. And surely We have encompassed all that was with him, in knowledge\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Thereafter he followed a way.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until when he arrived between the two mountains, he found beside them a people who well-nigh understood not a word.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
`They said: O Zul-Qarnain verily Yajuj and Majuj are working corruption in the land; shall we then pay thee tribute on condition that thou place between us and them a barrier!\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said: better is that where in my Lord hath established me; so help me with might, and I shall place between you and them a rampart.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Bring me lumps of iron. Then when he had evened Up between the two mountain-sides, he said: blow! Then when he had made it fire, he said: bring me and I shall pour thereon molten cOpper.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
Thus they Were not able to mount it, nor Were they able to burrow through it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said: this is a mercy from my Lord; then when the promise of my Lord cometh, He shall make it powder, and the promise of my Lord is ever true.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And We shall leave them on that day surging one against anot her and the trumpet shall be blown, and then We shall assemble them together.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And We shall set hell on that Day unto the infidels with a setting.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
Unto those whose eyes had been under a covering from My remembrance, nor had they been able to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Deem then those who disbelieve that they may take My bondmen, instead of Me, as patrons! Verily We have gotten ready the Hell for the infidels as an entertainment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say thou: shall I declare unto you the greatest losers in respect of works?\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
They are those whose effort is wasted in the life of the world, and they deem that they are doing well in performance.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
They are those who disbelieve in the signs of their Lord and in the meeting with Him; so of non-effect will be made their works, and We shall not allow them on the Day of Judgment any weight.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That shall be their meed--Hell-for they disbelieved and held My revelations and My apostles in mockery.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
Verily those who believe and do righteous works, unto them shall be gardens of Paradise for an entertainment.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
As abiders therein, they shall not seek therefrom any change.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say thou: were the sea to become ink for the words of my Lord, the sea would surely exhaust ere the words of my Lord exhausted, even though We brought onot her like thereof for support.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say thou: I am but a human being like yourselves; revealed unto me is that your God is One God. Whosoever then hopeth for the meeting with his Lord, let him work righteous work, and let him not associate in the worship of his Lord anyone.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf- Ha-Ya-'Ain-Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
Mention of the mercy of thy Lord to His bondman Zakariyya.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
Recall what time he cried unto his Lord with a cry secret.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He said: O my Lord! verily the bones of me have waxen feeble, and the head is glistening with hoariness, and have not yet been in my prayer to thee, my Lord, unblest.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
And verily I fear my kindred after me, and my wife hath been barren; so bestow on me from before Thee an heir.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
Inheriting me and inheriting the Children of Ya'qub; and make him, my Lord, acceptable!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
O Zakariyya! verily We give thee the glad tidings of a boy: his name shall be Yahya; We have not afore-time made his namesake.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: O my Lord! in what wise shall there be for me a boy, whereas my wife hath been barren, and surely have reached an age of extreme degree?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
Allah said: even so! Thy Lord saith: it is unto Me easy, whereas surely I created thee afore when thou wast not aught.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He said: my Lord appoint for me a sign. Allah said: thy sign is that thou shalt not speak unto mankind for three nights, while sound.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Then he came forth to his people from the sanctuary, and he beckoned unto them. hallow your Lord morning and evening.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
O Yahya! se hold fast the book. And We vouchsafed unto him wisdom, while yet a child.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And tenderness from Our presence and purity, and he was God-fearing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And duteous unto his parents, and Was not high-handed rebel.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
And Peace be unto him the day he was born and the day he dieth and the day he will be raised up alive.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention thou in the Book Maryam, what time the retired from her people to a place eastward.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
Then she took beside them a curtain; then We sent unto her Our Spirit, and he took unto her the form of a human being sound.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said: verily seek refuge with the Compassionate from thee if thou art God-fearing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said: I am but a meenger from thy Lord that I may bestow on thee a boy pure.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said: in what wise shall there be a boy unto me, whereas not a human being hath touched me, nor have I been a harlot?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said: even so! Thy Lord saith: it is With Me easy, and it is in order that We may make him a sign unto mankind and a mercy from Us, and it is an affair decreed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
hen she conceived him, and she retired with him to a place far-off.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
Then the birth-pangs drave her to the trunk of a palm- tree; she said: would that had died afore this and become forgotten, lost in oblivion!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Then one cried unto her from underneath her, that grieve not, thy Lord hath placed underneath thou a rivulet.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
And shake toward thee the trunk of the palm-tree it shall drop on thee dates fresh and ripe.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
So eat and drink thou, and cool thine eyes; and if thou beholdest the human beings anyone, say: verily I have vowed to the Compassionate a fast, so I shall not speak today to any human being.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought him to her nation carrying him. They said: Maryam! assuredly thou hast brought a thing unheard Of.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Harun: thy father was not a man of evil, nor was thy mother a harlot.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Then she Pointed to him. They said: how shall we speak to one who is in the cradle, a child?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He Said: verily I am a bondman of Allah; He hath vouchsafed me the Book and made me a prophet.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
And He hath made me blest wheresoever I may be, and enjoined on me the prayer and the poor-rate as long as I am alive.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
And dutecus Unto my mother, and hath not made me high- handed, unblest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
And peace be on me the day was born and the day die and the day I shall be raised up alive.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such is 'lsa, son of Maryam: this Is the word of truth wherein they are doubting.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
Allah is not one to take to Himself a son. Hallowed be He! whensoever He decreeth an affair he only Saith to it: be, and it becometh.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
And verily Allah is my Lord and your Lord; so worship Him; this is a way straight.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
Then the sects have differed among themselves; so woe to those who disbelieve in the witness of a Day Mighty!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How wondrous in their hearing and their sight will they be the Day they come unto Us! But to-day the wrong doers are in error manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn thou them of thy Day of Sighing when the affair shall have been decreed while yet they are in negligence and are not believing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Verily We! We shall inherit the earth and whatsoever is thereon: and Unto Us they shall be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention thou in the Book Ibrahim; verily he was a man of truth, a prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
Recall what time he said unto his father:, O my father! wherefore worshippest thou that which heareth not and seeth not, nor availeth thee at all?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
O My father! verily there hath come to me of the knowledge which hath not come unto thee; so follow me, and I shall guide thee to a path even.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
O My father! worship not the satan; hath been Unto the Compassionate a rebel.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
O My father! verily I fear that there may touch thee a torment from the Compassionate so that thou become to the Satan a companin.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He said: art thou averse to my gods, O Ibrahim? If thou desistest not, surely I shall stone thee; and depart from me for ever so long.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
Ibrahim said: peace be on thee! anon shall ask forgiveness of my Lord for thee; verily He is unto me ever so soicitous.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
And I renounce you and that unto which ye call beside Allah; and I shall call unto my Lord; belike in calling unto my Lord I shall not be unblest.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
Then when he had renounced them and that which they worshipped beside Allah, We best owed on him Ishaq and Yaqub and each one We made a prophet!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We bestowed on them of Our mercy, and We made for them a renown lofty.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention thou in the Book Musa: verily he was single- hearted, and was an apostle, prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And We cried unto him from the right side of the mount, and We drew him nigh for whispering.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We bestowed on him, out of Our mercy, his brother Harun, a prophet.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention thou in the Book lsma'i; verily he was true in promise, and was apostle, prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he was wont to command his household to the Prayer and the poor-rate, and he was with his Lord an approved one. *Chapter: 19\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention thou in the book ldris, verily he was a man of truth, a prophet. *Chapter: 19\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We exalted him to a position lofty. *Chapter: 19\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are they whom Allah hath favoured, from among the prophets, of the progeny of Adam and of them whom We bare with Nuh, and of the progeny of Ibrahim and Isra'il, and of those whom We have guided and chosen; whenever the revelations of the Compassionate were rehearsed unto them, they fell down prostrating themselves and weeping. *Chapter: 19\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
Then there succeeded to them a posterity who neglected the prayers and followed lusts; so presently they shall meet with perdition. *Chapter: 19\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Excepting those who may repent and believe and work righteously; these shall enter the Garden and shall not be wronged at all *Chapter: 19\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Gardens Everlasting, which the Compassionate hath promised unto his bondmen, unseen; verily His premise is ever to be fulfilled. *Chapter: 19\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They shall not hear therein any vain word, but they shall hear only peace; and therein they shall have their provision morning and evening. *Chapter: 19\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Garden which We shall cause those of Our bondmen to inherit who have been God-fearing. *Chapter: 19\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
And we descend not except by the command of thy Lord: his is whatsoever is before us and whatsoever is behind us and whatsoever is in-between; and thy Lord is not a forgetter *Chapter: 19\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and that which is betwixt the twain; so Him worship thou, and endure patiently in His worship; knowest thou any as his compeer? *Chapter: 19\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And man saith: when I am daed, Shall I be presently brought forth alive. *Chapter: 19\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Remembereth not man that We created him afore when he was not aught? *Chapter: 19\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
By thy Lord, then, We shall surely gather them and the satans; thereafter We shall surely bring them round Hell, kneeling. *Chapter: 19\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Thereafter, We shall surely draw aside, from each sect, whichever of them against the Compassionate were most in excess. *Chapter: 19\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
Then surely it is We who are the Best Knower of these worthiest of being therein roasted. *Chapter: 19\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
And not one of you but shall pass over it: it is for thy Lord an ordinance decreed. *Chapter: 19\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall deliver those who have feared, and shall have the wrong-doers therein kneeling. *Chapter: 19\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our manifest revelations are rehearsed unto them, those who disbelieve say unto those who believe: which of the two portions is better in station and goodlier in company? *Chapter: 19\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And how many a generation have We destroyed before these, who were goodlier in goods and outward appearance? *Chapter: 19\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say thou: whosoever is in error--surely unto him the Compassionate lengtheneth a length, until When they behold that wherewith they were threatened, either the torment or the Hour, then they shall come to know whosoever is worse in position and weaker as an army. *Chapter: 19\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And Allah increaseth in guidance those who let themselves be guided, and the righteous works that last are excellent with thy Lord in respect of reward and excellent in respect of return. *Chapter: 19\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Hast thou observed him who disbelieveth in Our signs and saith: surely I shall be vouchsafed riches and children. *Chapter: 19\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Hath he looked unto the Unseen, or hath he taken of the Compassionate a covenant? *Chapter: 19\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
By no means! We shall write down that which he saith; and We shall lengthen for him of the torment a length. *Chapter: 19\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And We shall inherit from him that whereof he spake, and he shall come to us alone. *Chapter: 19\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken gods beside Allah that they might be unto them a glory. *Chapter: 19\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
By no means! anon they shall deny their worship, and become unto them an adversary. *Chapter: 19\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Beholdest thou not that We have sent the satans upon the infidels inciting them by an incitement? *Chapter: 19\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So hasten thou not against them; We are only counting against them a counting. *Chapter: 19\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the Day whereon We shall gather the God-feaing unto the Com- passionate as an embassy. *Chapter: 19\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And shall drive the culprits to Hell as a herd. *Chapter: 19\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
They shall not own intercession, excepting those who have taken of the Compassionate a covenant. *Chapter: 19\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say: the Compassionate hath taken a son. *Chapter: 19\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Assuredly ye have brought a thing monstrous. *Chapter: 19\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
Well-nigh the heavens are rent thereat and the earth cleft in sunder and the mountains fall down in pieces. *Chapter: 19\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That they should ascribe unto the Compassionate a son. *Chapter: 19\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
And it behoveth not the Compassionate that he should take a son. *Chapter: 19\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
None there is in the heavens and the earth but must come unto the Compassionate as a bondman. *Chapter: 19\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
Assuredly He hath comprehanded them and counted them a full Counting. *Chapter: 19\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And each of them is to come to Him on the Day of Judgment alone. *Chapter: 19\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Verily those who believe and do righteOUs works--anon the Compassionate shall appoint for them affection. *Chapter: 19\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
So We have made it easy in thine tongue in order that thou mayest thereby give glad tidings unto the Godfearing and warn thereby a people contentious. *Chapter: 19\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many a generation have We destroyed before them! Perceivest thou of them anyone or hear of them a whisper? *Chapter: 20\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta. Ha. *Chapter: 20\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not Sent down on thee the Qur'an that thou shouldst be distressed. *Chapter: 20\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as an admonition unto him who feareth. *Chapter: 20\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A down-sent from Him who Created the earth and the heavens high.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Compassionate on the Throne is established.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
His is whatsoever is in the heavens and whatsoever on the earth and - whatsoever is in-between. and whatsoever is underneath the earth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if thou speakest the word aloud, then verily He knoweth the secret and the most hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah! no God there is but he! His are the names excellent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Hath there come unto thee the story of Musa?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
Recall what time he saw a fire and said to his household, bide ye! verily I have perceived a fire! haply I may bring you from it a brand or may find at the fire a guidance.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
Then when he was come thereto, he was cried unto. O Musa!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
Verily I! I am thy Lord: so take off thy shoes; verily thou art into the holy valley, Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
And I! I have chosen thee hearken thou then to that which shall be revealed.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Verily I! I am Allah! no God there is butI; so Worship Me, and establish prayer for My remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
Verily the Hour is coming--I wish to conceal it - in Order that every one may be requited according to that which he hath endeavoured.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
So let not him who believeth not therein and followeth his own desire keep thee away therefrom lest thou perish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
And what is that in thy right hand, O Musa!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said: it is my staff; I lean there on; and therewith beat down fodder for my sheep; and for me therein are other purposes.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
Allah said: cast it down, O Musa!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he cast it down, and lo! it was a serpent running along.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
Allah said: take hold of it, and fear not; We shall restore it to its former state.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
And press thy hand to thy side, it will come forth white, without hurt, as anot her sign.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
That We may shew thee of Our Signs the greatest.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
Go thou unto Fir'awn; verily he hath waxen exorbitant.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
He said: my Lord! expand for me my breast.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
And ease for me by affair.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
And loose a knot from my tongue.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
That they may understand my Speech.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
And appoint for me a minister from my household.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Harun, my brother.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
Strengthen by him my back.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
And associate him in my affair.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
That We may hallow Thee oft.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
And may make mention of Thee oft.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
Verily Thou! Thou art of us ever a Beholder.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He said: surely thou art granted thy petition, O Musa!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
And assuredly We conferred a benefit on thee anot her time.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
When We inspired unto thy mother that which We inspired,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
Saying! cast him in the ark, and cast him into the river, and the river will throw him on the bank, and then an enemy of Mine and an enemy of his will take him up. And I cast on thee love from Me in order that thou mayest be formed under Mine eye.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
What time thy sister was walking along and saying: shall I direct you unto one who will take care of him! Thus We returned thee to thy mother that she might cool her eyes and she might not grieve. And thou slewest a person, but We delivered thee from sorrow, and We tried thee with several trials. Then thou tarriedst for years among the people of Madyan then thou camest according to fate, O Musa!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
And formed thee for Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go thou and thy brother with My signs, and slacken not in remembrance of Mine.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go ye twain unto Fir'awn, verily he hath waxen exorbitant,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
Then say to him a gentle saying; haply he may be admonished or he may fear.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
The twain said: O our Lord! verily we fear that he may hasten against us or wax exorbitant.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said; fear not; verily I shall be With you twain: I shall hear and see.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
So go to him, and say: verily we are two apostles of thy Lord, so let go with us the Children of Isra'il, and torment them not; surely we have come unto thee with a sign from thy Lord: and peace be upon him who followeth the guidance.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
Verily We! it hath been revealed unto us that the torment will be for him who belieth and turneth away.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
He said: who is the Lord of you twain, O Musa!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
Musa said: our Lord is He who vouchsafed unto everything its creation, then guided it.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
He said: then what happened to the former generations?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
Musa said: the knowledge there of is with my Lord in the Book; my Lord erreth not, nor He forgetteth.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
Who hath appointed for you the earth as a bed, and hath opened for you therein pathways, and hath sent down from the heaven water, and thereby We have brought forth kinds of plants, various.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat and pasture your cattle: verily therein are signs for men of sagacity.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
Thereof We created you, and thereunto We return you, and therefrom We shall bring You forth once again.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And assuredly We shewed him Our signs, all of them, but he belied and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said: art thou come unto us that thou mayest drive us out of our land by thy magic, O Musa!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
So We shall surely bring unto thee a magic the like thereof; so Make between us and thee an appointment which neither we nor thou shall fail in some open space.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
Musa said: your appointment is the gala day, and that the people be gathered in the forenoon.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
Then Firawn turned away, devised his stratagem; thereafter he came.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Musa said unto them: woe unto you! fabricate not against Allah a lie, lest he extirpate you with a torment, and surely He who fabricateth, loseth.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
Then they wrangled about their affair among themselves, and kept secret their private counsel.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said: verily these two are magicians, intending to drive you forth from your land by their magic and to do away with your superior way.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
Wherefore devise your stratagem, and then come in a row; and prospered to-day is he who overcometh.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said: either thou cast down, or we shall be the first to cast down.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said: nay, cast ye down. And lo! their cords and their staves were made to appear to him by their magic as though they were running.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
Then a kind of fear in his soul Musa felt.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said: fear not! verily thou! thou shalt be the superior.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
And cast thou down that which is in thy right hand: it shall swallow up that which they have wrought; They have wrought only a magician's stratagem; and the magician prospereth not wheresoever he cometh.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
Then the magicians were cast down prostrate; they said: we believe in the Lord of Musa and Harun.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
Fir'awn said; believed ye in him ere I gave you leave! verily he is your chief who hath taught you magic. So I will surely cut off your hands and feet on the opposite sides, and will surely crucify you on the trunks of palm-trees, and ye shall surely know whichever of us is severer in torment and more lasting.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said: we shall by no means prefer thee to that which hath come to us of the evidences, and to Him Who hath created us; so decree thou whatsoever thou shalt decree; thou canst only decree in respect of the life of this world.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
Verily we! we have believed in our Lord, that he may forgive us our faults, and that to which thou hast constrained us in the way of magic; and Allah is Best and Most Lasting.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Verily whosoever cometh unto his lord as a Culprit, for him is Hell wherein he will neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
And whosoever cometh unto Him as a believer, and he hath done righteous works---then these! for them are ranks high.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Gardens Everlasting whereunder rivers flow: abiders therein; that is the meed of him who hath purified himself.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And assuredly We revealed unto Musa, saying: depart in night with my bondmen, and make for them in the sea a parth dry: thou Shalt fear neither overtaking, nor shalt thou be afraid.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Then Fir'awn followed them with his hosts; and there came upon them of the sea that which came upon them.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Fir'awn led his nation astray, and guided them not.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel; We delivered you from your enemy, and treated with you on the right side of the mount and sent down upon you the manna and the quails.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
Saying: eat of the clean things wherewith We have provided you, and wax not exorbitant in respect thereof, lest My wrath alight on you; and upon whomsoever My wrath alighteth, he surely perisheth.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And verily I am the Most Forgiving unto whomsoever repenteth and believeth and worketh righteously, and thereafter letteth himself remain guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
And what hath made thee hasten from thy people, O Musa?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said: those! they are close on my footstep, and hastened to Thee, O my Lord; that Thou mightest be wellpleased.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
He said: verily We have tempted thy people after thee, and the Samiri hath led them astray.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
So Musa returned unto his people, indignant and sorrowful. He said: O my people! promised there not your Lord unto you an excellent promise! Lasted then the covenant too long for you, or desired ye that the wrath from your Lord should alight on you, so that ye failed to keep my appointment?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said: we failed not to keep thy appointment of our own authority, but we were laden with burthens of the people's ornaments; then we threw them, and Thus Samiri cast down.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
And he produced for them a calf: a body with a low. Then they Said: this is your god and the god of Musa, and that he forgat.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Observed they not that it returned not unto them a word, and owned not for them hurt or profit?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And assuredly Harun had said unto them afore: O my people! ye are only being tempted thereby; and verily your Lord is the Compassionate; so follow me and obey my command.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said: we shall by no means cease to be assiduous to it until there returneth to us Musa.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
Musa said: O Harun! what prevented thee, when thou sawest them going astray.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
That thou followedst me not! Hast thou disobeyed my command?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
Harun said: O my mother's son! hold me not by my beard nor by my head verily feared that thou wouldst say, thou hast caused a division among the Children of Israel and hast not guarded my Word.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
Musa said: what was thy object, O Samiri?\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He said: l saw that which they saw not; so I seized a handful from the footstep of the messenger, and then cast it; Thus my soul embellished the affair to me.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
Musa said: begone thou! verily it shall be thine in life to say no contact; and verily thine is an appointment which thou shalt by no means fail. And look at thy god to which thou hast been assidauous; we shall surely burn it, and we shall scatter it into the sea a wide scattering.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your God is only Allah, the One other than whom there is no god. He comprehendeth everything in knowledge.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus We recount unto thee some tidings of that which hath preceded; and surely We have vouchsafed unto thee from before Us an admonition.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whosoever turnoth away therefrom--verily they shall bear on the Day of Judgment a burthen,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
As abiders therein. And vile will load! them on the Day of Judgment as a load!\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day whereon the trumpet will be blown into, and We shall gather the culprits on that Day blear-eyed,\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
Mutterin among themselves: ye tarried not save ten days.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We are the Best Knower of that which they will say, when the best of them in judgment Will say: ye tarried not save for a day.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
And they ask thee regarding the mountains; so say thou: my Lord will scatter them with a total scattering.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
Then He shall leave it a plain, level.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
Wherein thou shalt not see any crookedness or ruggedness.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
That Day they shall follow the caller for Whom there shall be no crookedness; and voices Shall be humbled for the Compassionate; so that thou shalt not hear ought except pattering\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
That Day intercession will Profit not except him for whom the Compassionate giveth leave, and of whom He approveth the Word.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knoweth that which is before them and that which is behind them, and they, encompass it not with their knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And downcast will be faces before the Living, the Self- subsisting, and disappointed will be he who beareth a wrong.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
And whosoever worketh of the righteous works, and is a believer, he will not fear Wrong or begrudging\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
And Thus We have sent it down, an Arabic Recitation, and have propounded variously therein of the threats, that haply they may fear, or that it may generate in them some admonition.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Exalted is Allah, the True King! And hasten thee not with the Qur'an before there is finished to thee the revelation thereof, and say thou: O my Lord! increase me in knowledge!\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And assuredly We covenanted with Adam aforetime, then he forgat, and We found not in him steadiness.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And recall what time We said to the angels: prostrate yourselves before Adam. They fell prostrate, but Iblis did not; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said: Adam! verily this is an enemy unto thee and thine spouse; so let him not drive forth you twain from the Garden, lest thou be destressed.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
Verily it is thine that thou shalt not hunger therein nor go naked.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
Nor that thou shalt thirst therein nor shall suffer from the sun.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
Then the Satan whispered unto him; he said: Adam! shall direct thee to the tree of eternity and a dominion that ageth not!\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
Then the twain ate thereof; so there became disclosed to them their shame, and they began sewing upon them selves some of the leaves of the Garden, so Adam disobeyed his Lord, and erred,\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Thereafter his Lord accepted him, and relented toward him, and guided him.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He said: get ye twain down therefrom together: some of you an enemy unto some others; then if there cometh unto you from Me guidance, whosoever followeth My guidance shall neither go astray nor be distressed.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
And whosoever turneth away from My admonition, for him verily will be a livelihood shrunken, and We shall raise him up on the Day of Judgment sightless.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say: O my Lord! why hast Thou gathered me sightless whereas surely I have been a seer.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
Allah will say: Thus came Our signs Unto thee and thou ignoredst them; so that wise today thou shalt be ignored.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
Thus We requite him who trespasseth and believeth not in the signs of his Lord, and surely the torment of the Hereafter is most severe and most lasting.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Hath it not served as guidance to them how many a generation We have destroyed before them, amidst whose dwellings they Walk! Verily therein are signs for men of sagacity.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And had not a word from thy Lord gone forth, and a term determined, it must necessarily have come.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So bear thou patiently that which they say, and hallow the praise of thy Lord before the rising of the sun and before the setting thereof. And hallow Him in part of the night and the ends of the day, haply thou wilt be pleased.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And strain not thine eyes after that which We have given classes of them to enjoy: the splendour of the life of the World, that We might try them therein; and the provision of thy Lord is the best and most lasting.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And command thy household for prayer, and persevere thou therein; We ask not of thee any provision; we Who provide thee; and the happy end is for piety.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And they Say: wherefore bringeth he not unto us a sign from his Lord? Hath not there came unto them the evidence of that which is in the former Scriptures?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And had We destroyed them With a torment before it, surely they would have said: O our Lord why sent not Thou Unto us an apostle that we might have followed Thy signs before we were disgraced and humiliated.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say thou: everyone Is on the watch; so watch, and anon ye shall know who are the fellows of thee even path and who hath let himself be guided.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen There hath approached unto mankind their reckoning, while they in neglect are turning away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
There cometh not unto them a fresh admonition from their Lord but they listen to it while they are playing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
In sport being their hearts. And those who do wrong keep secret their private discourse this is but a human being like unto yourselves; will ye then betake yourselves to magic while ye know?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
The Prophet said: my Lord knoweth the word in the heavens and the earth, and He is the Hearer, the Knower.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Aye! they say: a medley of dreams; aye! he hath fabricated it; aye! he is a poet; so let him bring us a sign even as the ancients were sent with.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not a city before them which We destroyed believed; will they then believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent not before thee but men unto whom We revealed; so ask the people of the Admonition if ye know not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
And We made them not bodies not eating food; nor were they to be abiders.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We made good unto them the premise; so We delivered them and those whom We willed, and We destroyed the extravagant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
And assuredly We have sent down unto you a Book wherein is admonition for you; will ye not then reflect?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
And how many a city have We overthrown which were doing wrong, and We caused to grow up thereafter anot her nation!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then when they perceived Our violence, lo! they were from it fleeing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
Flee not, and return unto that wherein ye luxuriated and your habitations, haply ye will be questioned.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said: woe unto us! verily we have been wrong-doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And this ceased not to be their cry until We made them a harvestreaped, extinguished.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
And We created not the heaven and the earth and that which is in between in play.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
Had We intended that We should choose a sport, surely We would choose it from before Us--if We were ever going to do that.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Aye! We hurl truth against false hood, so that it braineth it, and lo! it vanisheth; and to you be the woe for that which ye utter!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
And His is whosoever is in the heavens and the earth; and those nigh unto Him are not too stiff-necked for His worship nor are they weary.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
And they hallow Him night and day, and they flag not.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Have they taken gods from the earth who raise the deed?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been in between the twain gods except Allah surely the twain would have gone to ruin. Hallowed be Allah, the Lord of the Throne, from that which they utter!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He shall be questioned not as to that which He doth, while they shall be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Have they taken gods beside Him? Say thou: forth with your proof This is an admonition unto those with me and an admonition unto those before me. But most of them knew not the truth, and so they are averters.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We sent not before thee an apostle but We revealed unto him that there is no god but I, so worship Me.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say; the Compaionate hath taken a son. Hallowed be He! aye! they are bondmen honoured.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They precede Him not in words, and by His command they work.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knoweth whatsoever is before them and whatsoever is behind them; and they intercede not except for him whom He approveth, and in awe of Him they are fearful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And whosoever of them should say: verily I am a god beside Him, such a one We shall requite with Hell; Thus We requite the wrong- doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have not these who disbelieve considered that the heavens and the earth were closed up, then We rent them? And We have made of water everything living; will they not then believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have placed in the earth firm mountains lest it should move away with them, and We placed therein Passages for paths, that haply they may be guided.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We have made the heaven a roof, safe, and from the signs there of they are averters.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And He it is Who hath created the night and the day, and the sun and the moon, each in an orb floating.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
And We appointed not for any human being before thee immortality; if thou then diest, are they to be immortals?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul is going to taste of death, and We shall prove you with evil and good as a temptation; and unto Us ye shall be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when those who disbelieve behold thee they only take thee up for mockery: is this he who mentioneth your gods? while in the mention of the compassionate they are themselves blasphemers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man was created of hast, surely I shall show you MY signs, so ask Me not to hasten.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say: when cometh this torment if ye are truth- tellers!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only those who disbelieve have known of the time when they shall not be able to ward off from their faces the Fire nor from their backs, nor shall they be succoured!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Aye! it would come upon them on a sudden and shall dumbfound them; they shall not be able to avert it, nor shall they be respited.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
And assuredly mocked were the apostles before thee, then there surrounded those of them Who scoffed that whereat they had been mocking!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say thou: who guardeth you by night and by day from the Compassionate! O Yet from the remembrance of their Lord they avert themselves!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Have they gods who defend them beside Us? They are not able to succour themselves, and against Us they cannot be kept company with.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Aye! We let these people and their fathers enjoy until there grew long upon them the life. Behold they not that We come unto the land diminishing it by the borders thereof? Shall they then be the victors?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say thou: I only warn you by the revelation; and the deaf hearken not unto the call when they are warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if a breath of the torment of thy Lord were to touch them, they will say: woe unto us! we have been wrong-doers.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We shall set balances of justice for the Day of Judgment; then no soul shall be wronged at all; and if it be but the weight of a grain of mustard-seed We shall bring it; and We suffice as Reckoners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And assuredly We vcuchsafed unto Musa and Harun the distinction and illumination and an admonition for the God-fearing.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
These who fear their Lord unseen, and who are of the Hour fearful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this is an admonition blest, which We have sent down! will ye then be the rejectors thereof?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And assuredly We vouchsafed un to lbrahim his rectitude aforetime, and him We had ever known.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
Recall what time he said unto his father and his people what are these images to which ye are cleaving?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said: we found our fathers the worshippers thereof.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: assuredlY ye, ye and your fathers, have been in error manifest.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: hast thou come unto us with the truth, or art thou of those who sport?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said: Aye! your Lord is the Lord of the heavens and the earth Who created them, and as to that I am of the witnesses.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
And by Allah I shall surely devise a plot against your idols after ye turned away backward.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
Then he made them fragments, all except the big one of them, that haply unto it they may return.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said: who hath wrought this to our gods? verily he is of the wrong-doers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said: We heard a youth speak of them, who is called Ibrahim.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said: bring him then before the eyes of the people, haply they may bear witness.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said: art thou the one who hath wrought this unto our gods, O Ibrahim?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said: rather he hath wrought it: this big one of them: so question them, if they ever speak.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
They then turned to themselves, and said: verily ye it is who are the wrong-doers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Thereafter they were made to turn over upon their heads, saying, assuredly thou knowest that they speak not.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said: worship ye, then, beside Allah, that which profiteth you not at all, nor it hurteth you\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
Fie upon you and upon that which ye worship beside Allah! Will ye not then reflect?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said: burn him, and succour your gods, if ye will be doing.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said: O fire! be thou cool and peace unto Ibrahim\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they intended to do him an evil, but We made them the worst losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We delivered him and Lut to the land wherein We had placed Our blessings for the worlds.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed upon him ls-haq and Ya qub as a grandson; and each one We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders, guiding by Our command; and We revealed unto them the doing of good deeds and the establishment of prayer, and the giving of poor-rate; and of Us they were the worshippers.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And Lut! We vouchsafed unto him judgment and knowledge, and We delivered him out of the city which had been working foul deeds; verily they were a people evil, wicked.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We caused him to enter into Our mercy; verily he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And Nuh! recall what time he cried aforetime; so we answered him and delivered him and his house hold from a calamity mighty.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
And We succoured him against the people who belied Our signs; verily they were a people evil, so we drowned them all.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And Daud and Sulaiman! recall what time they gave judgment regarding the tillage when certain people's sheep had pastured therein at night; and of the judgment concerning them We were the Witnesses.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
So We gave the understanding thereof unto Sulaiman; and unto each We vouchsafed judgment and knowledge. And We so subjected the mountains that they shall hallow us along with Daud, and also the birds; and We were the doers.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the art of making the coats of mail for you that it may protect you from your violence; are ye then thankful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And unto Sulaiman We subjected the wind, strongly raging, running at his command toward the land wherein We had placed Our blessing; and of evrything We are the knowers.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the satans were some who dove for him, and worked a work beside that; and of them We were the Watchers.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And Ayyub! recall what time he cried unto his Lord: verily hurt hath touched me, and Thou art the Most Merciful of the mercifuls.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We answered him and We removed that which was with him of the hurt, and We vouchsafed unto him his household and the like thereof along with them, as a mercy from us and a remembrance unto the worshippers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And Isma'il and ldris and Zul-Kifl! each were of the patient.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We caused them to enter into our mercy, verily they are of the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And Zun-nun! recall what time he departed in anger and imagined that We could not straiten him, then he cried in the darknesses, that: there is no god but Thou! hallowed be Thou! verily I have been of the wrong-doers.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We answered him, and We delivered him from the distress, and Thus do We deliver the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And Zakariyya! recall what time he cried unto his Lord: my Lord! leave me not solitary, though Thou art the best of heirs.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered him, and We bestowed on him Yahya and We made sound for him his spouse. Verily they Were wont to vie with one anot her in good deeds and to call upon us with longing and dread, and they were ever before us meek.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she who guarded her chastity! Then We breathed into her of Our spirit, and made her and her son a sign unto the worlds.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Verily this community of yours is a single community, and I am your Lord; so worship Me.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
And they cut up their affair among them:, all are unto Us returners.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
Whosoever worketh righteous works, and he is a believer, there shall be no denial of his endeavour; and We are for him the Writers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And a ban is laid on every town which We have destroyed, that they Shall not return.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until when Ya'juj and Ma'juj are let out, and from every mound they are trickling down.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And there shall approach the true promise; and lo! the eyes of those who disbelieved shall be staring: woe unto us! surely we have been in neglect thereof; aye! we have been the wrong-doers.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Verily ye and whatsoever ye worship beside Allah shall be firewood for Hell: thereunto ye shall go down.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these been gods, they would not have gone down thereunto; and all of them therein shall be abiders.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
Theirs therein shall be roaring, and therein they shall hear not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Verily those for whom the good reward hath preceded from Us, they therefrom shall be kept far away.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They shall not hear the least sound thereof, and in that felicity which their souls desire they shall be abiders.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The Great Terror shall grieve them not, and the angels will meet them: this is Your Day which ye were ever promised-\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
The Day whereon We shall roll up the heaven like as the rolling up of a scroll for books. Even as We began the first creation, We shall restore it: a promise binding upon Us; verily We have been the Doers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And assuredly We have prescribed in the Scripture after the admonition, that: the land! there shall inherit it My bondmen righteous.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Verily in this in a preaching for a people who are worshippers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
And We have not sent thee except as a mercy unto the Worlds.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say thou: this only hath been revealed unto me, that your god is only One God. submit ye then?!\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
Then if they turn away, say thou: I have proclaimed unto you all alike, and I know not whether nigh or far is that which ye are promised,\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
Verily He knoweth that which is public in speech, and He knoweth that which ye hide.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
And know not; haply it may be a trial for you, and an enjoyment for a season.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He saith: my Lord! judge Thou with truth. And our Lord is the Compassionate Whose help is to be sought against that which ye utter.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen Mankind! fear your Lord; verily the quake of the Hour shall be a thing mighty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
The Day whereon ye behold it, every suckling woman shall forget that which she suckleth, and every burthened woman shall lay down her burthen; and thou shalt behold mankind as drunken, whereas drunken they will be not, but the torment of Allah shall be severe.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And of mankind is he who disputeth respecting Allah without knowledge, and followeth any Satan froward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
Against whom it is prescribed, that: whosoever befriendeth him, him he shall lead astray and shall guide him on to the torment of the Flame.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O Mankind! if ye be in doubt respecting the Resurrection, then We have created you of the dust, then of a drop, then of clot, then of a piece of flesh, formed and unformed, that We might manifest unto you Our power. And We settle in the wombs that which We will until a term determined. Then We bring you forth as babes, then We let you reach your maturity. And of you is he who dieth, and of you is he who is brought back to the most abject age, so that after knowing he knoweth not aught. Andthou beholdest the earth withered up, and when We send down thereon water, it stirreth and swelleth, and it groweth every luxuriant kind of growth.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That, because Allah! He is The Truth, and He quickeneth the dead, and verily He is over everything Potent.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And because the Hour is coming- there is no doubt thereof-- and because Allah will raise up those who are in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And of mankind is he who disputeth respecting Allah without knowledge or guidance or a Book luminous.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Bending his neck, that he may lead astray from the way of Allah; his shall be humiliation in the world, and We shall make him taste on the Day of Judgment the torment of Burning.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
That is because of that which thy hands have sent forth, and verily Allah is not a wronger of His bondmen.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And of mankind is he who worshippeth Allah as on edge; if there befalleth him good, he in contented therewith, and if there befalleth him a trial, he turneth round on his face; he loseth the world and the Hereafter: that indeed is a loss manifest!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calleth upon that, beside Allah, which can neither hurt him nor profit him! that! it is a straying far-off.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calleth upon him whose hurt is nearer than his profit: surely ill the patron! ill the comrade!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Verily Allah shall cause those who believe and work righteous works to enter Gardens whereunder rivers flow; verily Allah doth whatsoever He intendeth.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whosoever hath been imagining that Allah shall not make him victorious in the world and the Hereafter, let him stretch a cord up to the heaven and let him cut it, and let him look if his stratagem can do away that whereat he enrageth.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
And Thus We have sent it down as evidences, and verily Allah guideth whomsoever He intendeth.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Verily those who believe and those who are Judaised and the Sabians and the Nazarenes and the Magians and those who associate - verily Allah will decide between them on the Day of Judgment; verily Allah is over everything a Witness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Beholdest thou not that Allah unto Him adore whosoever is in the heavens and on the earth, and the sun, and the moon, and the mountains, and the trees and the beasts, and many of mankind! And many are there on whom due is the torment. And whomsoever Allah despiseth, none can honour; verily Allah doth whatsoever He willeth.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These twain are opponents who contended respecting their Lord; then as for those who disbelieved, cut out for them shall be raiments of frre: poured out over their head shall be hot water.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
Molten thereby shall be that which is in their bellies and also their skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for them shall be maces of iron.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
So oft as they would seek to go forth therefrom, because of anguish, they shall be sent back therein, and taste the torment of Burning.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Verily Allah will cause those who believe and work righteous works to enter Gardens whereunder the rivers flow, wherein they will be bedecked with brace lets of gold and with pearls, and their garment therein shall be of silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
And they have been guided unto goodly speech, and they have been guided to the path of the Praiseworthy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Verily those who disbelieve and hinder others from the path of Allah and from the Sacred Mosque which We have appointed for mankind, equal in respect thereunto are the dweller therein and the stranger. And whosoever will seek profanity therein wrongfully, We shall make him taste of a torment afflictive.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And recall what time We settled Ibrahim in the place of the House, Saying: associate not thou with Me aught, and purify My House for these who circumambulate and those who stand up and those who bow and make prostration.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And proclaim thou among mankind the pilgrimage; they shall come unto thee on foot and on any lean mount, coming from every deep defile.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness the benefits to them and may mention the name of Allah on the days known over the beast cattle wherewith He hath provided them. So eat thereof, and feed the hungry poor.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Thereafter let them end their unkemptnesss and fulfil their vows and circumambulate the ancient House.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
Thus it is. And whosoever suspecteth the sacred ordinances of Allah, it shall be better for him with his Lord. And allowed unto you are the cattle, save that which hath been rehearsed unto you; so avoid the pollution of the idols, and avoid the word of falsehood.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Reclining unto Allah, not associating aught with Him. And whosoever associateth aught with Allah, it is as though he had fallen from the heaven and the birds had snatched him, or the wind had blown him to a place remote.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
Thus it is. And whosoever respecteth the rites of Allah, then verily it is from piety of the hearts.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
For you in them are benefits for a term appointed, and thereafter the destination is toward the ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And unto every community We appointed a ritual, that they mention the name of Allah over the beast cattle wherewith He hath provided them: and your God is One God, so unto Him submit. And bear thou glad tidings unto the humble-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Those---whose hearts, when Allah is mentioned, are filled with awe and who patiently endure that which befalleth them, and these who establish the prayer and of that wherewith We have provided them expend.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the camels! We have appointed them for you among the landmarks of Allah; for you is good therein; so mention the name of Allah over them, standing in rows. Then when they fall down on their sides, eat thereof and feed the contented and suppliant. Thus We have subjected them to you, that haply ye may return thanks.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Their flesh reacheth not Allah nor their blood: but it is Piety from you that reacheth Him. Thus He hath subjected them to you, that ye may magnify Allah for He hath guided you; and bear thou glad tidings unto the welldoers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Verily Allah will repel from those who believe: verily Allah loveth not any treacherous, ingrate.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permitted are those who are fought against, because they have been oppressed, and verily to succour them Allah is potent\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who have been driven forth from their abodes without justice, except because they say: our Lord is Allah. And were it not for Allah's repelling of someby means of others, cloisters and churches, synogogues and mosques wherein the name of Allah is mentioned much, would have been pulled down. Surely Allah shall succour whosoever succoureth Him; verily Allah is strong, Mighty\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
Those who if We establish them in the earth, shall establish the prayer and give the poor-rate and command that which is reputable and restrain that which is disreputable and unto Allah is the end of all affairs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
And if they belie thee, then surely there have belied before them the people of Nuh and the 'Aad and the Thamud.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the people of Ibrahim and the people of Lut.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the denizens of Madyan. And belied was Musa. I gave rein to the infidels; then took hold of them; so how hath been My wrath!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many a city have We destroyed, while it was a wrong- doer--and it lieth overturned on its roofs, -and how many a well abandoned and how many a castle fortifred!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not marched forth in the land, so that there might become unto them hearts to understand with or ears re hear with? Verily it is not the sights that are blinded but blinded are the hearts that are in the breasts.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they ask thee to hasten on the torment, whereas Allah shall not fail His promise. And verily a day with thy Lord is as a thousand years of that which ye compute.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And how many a city did give reins to, While it wronged itself, then took hold of it! and unto Me is the return.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say thou: mankind! I am unto you only a warner manifest.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
Then those who believe and work righteous works--for them is forgiveness and a provision honourable.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
And those who endeavour in respect of Our signs to frustrate them- those shall be the fellows of Flaming Fire.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
And We have sent before thee no apostle or prophet but when he read the Satan cast forth suggestions in respect of his reading; then Allah abolisheth that which the Satan casteth forth; then Allah confirmeth His revelations; and Allah is Knowing. Wise;\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
That he may make that which the Satan casteth forth a temptation for those in whose heart is a disease and whose hearts are hardened--and the wrong-doers are in divergence far-off -\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And that those who have been vouchsafed knowledge may know that it is the truth from thy Lord and may believe therein, and so their hearts may submit thereto. And verily Allah is the Guide of those who believe unto a path straight.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And those who disbelieve will not cease to be in doubt thereof until the Hour cometh upon them on a sudden, or there cometh upon them the torment of a Barren Day.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The dominion on that Day will be Allah's; He shall judge between them; then those who believed and worked righteous works shall be in the Gardens of Delight.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And those who disbelieved and belied Our signs--then these! for them will be a torment ignominous.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
And those who emigrated in the way of Allah, and thereafter they were slain or they died - surely Allah will provide them with a goodly provision; and verily Allah! He is the Best Provider.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
Surely He will make them enter an entrance wherewith they will be well pleased and verily Allah is Knowing, Forbearing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That is so. And whosoever Chastiseth the like of that whereby He was injured, and thereafter he hath been ogain oppressed, surely Allah will succour him: verily Allah is Pardoning, Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is to be because Allah plungeth the night into the day and plungeth the day into the night, and because He is Hearing, Beholding.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah! He is the Truth, and because that which they call upon beside Him--it is the false. And verily Allah! He is the High, the Great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Beholdest thou not that Allah sendeth down water from the heaven and the earth becometh green? Verily Allah is subtile, Aware.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
His is whatsoever is in the heavens and whatsoever is on the earth; and verily Allah He is the Self-sufficient, the PraiseWorthy.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Beholdest thou not that Allah hath subjected to Himself for you whatsoever is on the earth and the ships running in the sea by His command? And He with holdeth the heaven that it fall not on the earth save by His leave. Verily Allah is, unto mankind, Clement, Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And He it is who gave you life and will thereafter cause you to die, and will thereafter give you life; verily man is ingrate.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
Unto every community We have appointed a rite which they perform. Let them not therefore contend with thee in the affair; and call them thou unto thy Lord, verily thou art on true guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they dispute with thee, say thou: Allah knoweth best that which ye Work.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
Allah will judge between you on the Day of Judgment concerning that wherein ye have been differing.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Knowest thou of that Allah knoweth whatsoever is in the heaven and the earth? Verily that is in a Book; verily that is for Allah easy.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship, beside Allah, that for which He hath revealed no authority and that whereof they have no knowledge; and for the wrong-doers there shall not be a helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our manifest signs are rehearsed unto them, thou recognizest repugnance on the countenaces of those who disbelieve; well- nigh they rush upon these who rehearse unto them Our Signs. Say thou: shall declare unto you something more grievous than that-the Fire--Allah hath promised it to those who disbelieve? An evil destination!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O Mankind! a similitude is propounded; so hearken thereto. Verily those whom ye call upon beside Allah will by no means create a fly, even though they assembled for that; and if the fly were to snatch away aught from them, they cannot recover it from him: weak the seeker and the sought!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They have not estimated Allah His rightful estimate; verily Allah is strong, Mighty!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooseth from the angels messengers and also from mankind; verily Allah is Hearing, Beholding.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knoweth whatsoever is before them and whatsoever is behind them; and unto Allah are returned all affairs\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O Ye who believe! bow down and prostrate yourselves and worship your Lord, and do the good, that haply ye may thrive.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive hard for Allah as is due unto Him hard striving. He hath distinguished you, and hath not placed upon you any narrowness in the religion the faith of your father, Ibrahim. He hath named you Muslim aforetime and in this, that the apostle may be a witness for you, and that ye may be witnesses against mankind. Wherefore establish the prayer and'give the poor-rate, and hold fast by Allah; He is your Patron: an Excellent Patron and Excellent helper!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Blissful are the believers'-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who in their prayer are lowly.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And those who from everything vain turn away.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And those who for the sake of purification are doers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And those who of their private Parts are guards.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Save in regard to their spouses and those whom their right hands own: so they are not blameworthy-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
And Whosoever seeketh beyond that, then it is these who are the transgressors\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
And those who of their trusts and covenant are keepers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And those who of their prayers are observant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These! they are the inheritors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who shall inherit Paradise; therein they shall be abiders.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
And assuredly We created man of an extract of clay.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Thereafter We made him of a Sperm In a receptacle safe.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
-Thereafter We created the sperm a clot; then We created the clot a lump of flesh; then We created the lump of flesh bones; then We clothed the bones with flesh: thereafter We brought him forth as anot her creature. Blest then be Allah, the Best of creators!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then verily, thereafter, ye are sure to die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then verily on the Day of Judgment ye shall be raised up.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And assuredly We created above you seven paths, and of the creation We have not been neglectful.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down from the heaven water in measure, and We caused it to settle in the earth; and verily to take it away We are Able.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then We brought forth for you therewith gardens of date- palm and vines; for you therein are fruits many, and thereof ye eat.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And also a tree that springeth forth from mount Sinai, that groweth oil and is a sauce for the eaters.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And verily in the cattle for you is a lesson. We give you to drink of that which is in their bellies, and for you in them are advantages many, and of them ye eat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them and on the ship ye are borne.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And assuredly We sent Nuh unto his people, and he said: O my people! worship Allah; for you there is no god but he; will ye not then fear Him!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
Then said the chiefs of those who disbelieved among his people: this is no other than a human being like unto you, he seeketh to make himself superior unto; and if God had willed, He would save sent down angels; we have not heard of this among our fathers ancient.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is only a man in whom is madness wherefore await for him for a season.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
Nuh said: my Lord! vindicate me, for they belie me.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
Then We revealed unto him, saying: build the ark under Our eyes and Our Revelation; then when Our command cometh and the oven boileth over, make way therein of every pair two, and thy household save him thereof against whom there hath already gone forth the word; and address me not in respect of those who have done wrong; verily they are to be drowned.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when thou art settled, thou and those with thee, in the ark, say thou: praise unto Allah who hath delivered us from the wrong doing people.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say thou, my Lord! cause me to land at a landing blest, and thou art the Best of these who bring to land.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Verily in that are signs; verily We have ever been provers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them We brought forth anot her generation.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
Then We sent amongst them an apostle from amongst themselves, saying: worship Allah, for you there is no god but he; will ye then not fear Him?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And said the chiefs of those who disbelieved among his people and belied the meeting of the Hereafter and whom We had luxuriated in the life of the World: this is no other than a human being like unto you: he eateth of that whereof ye eat, and he drinketh of that which ye drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
And were ye to obey a human being like you, ye are forthwith to be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
Promiseth he unto you that ye, when ye have died and have become dust and bones, ye are to be brought forth?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
Away! away with that wherewith ye are promised;\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is nought but our life of the world; we die and we live, and we are not going to be raised Up.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is but a man who hath fabricated against God a lie, and in him we are not going to be believers.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said: my Lord! vindicate for they belie me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
Allah said: after a little while they will become regretful.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
Then the shout laid hold of them in truth, and We made them a refuse; so away with the wrong-doing people!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then after them We brought forth other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No community can anticipate their term, nor can they lay behind.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Thereafter We sent Our apostles, successively. So oft as there came unto a community their apostle, they belied him, so We made them follow one anot her, and We made them bywords: so away with a people who believe not!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Thereafter We sent Musa and his brother Harun with Our signs and an authority manifest.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
Unto Fir'awn and his chiefs, but they grew stiff-necked, and they were a people self-exalting.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
So they said: shall we believe In two human beings like unto us, while their nation are to us slaves?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
Then they belied the twain; so they became of those who were destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And assuredly We vouchsafed unto Musa the Book, that haply they may be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Maryam and his mother a sign; and We sheltered the twain on a height: a quiet abode and running water.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O Ye apostles! eat the good things and work righteously; verily of that which ye work I am the Knower.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And verily this religion of yours is one religion, and I am your Lord, so fear Me.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
Then they cut their affair among them in regard to the Scriptures: each band in that which is with them rejoicing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
Wherefore leave thou them in their bewilderment for a season.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Deem they that in the wealth and sons wherewith We enlarge them.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We are hastening them on to good things? Aye! they perceive not.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Verily those who for fear of their Lord are in awe.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who in the signs of their Lord do believe.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who with their Lord associate not anyone.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give whatsoever they give, while their hearts are anxious that unto their Lord they are to be retutners\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
These are hastening on to good, and they are therein foremost.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And We task not any soul except according to its capacity, and with Us is a book speaking with truth, and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Aye! their hearts are in bewilderment in respect thereof, and they have works beside that, of which they are workers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until when We lay hold of the luxuriant ones of them with the torment, and lo! then they are imploring!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Implore not to-day; verily ye from Us are not to be succoured.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
Surely My signs have been rehearsed unto you, and upon your heel ye were wont to draw back.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
Stiff-necked, discoursing thereof by night, reviling.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Pondered they not over the Word? or came there unto them that which came not unto their fathers ancient?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or, is it that they recognised not their apostle, and so of him they become deniers?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or, say they: in him is madness? O Aye he brought them the truth, and most of them to the truth are averse.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
And were the truth to follow their desires there would have been corrupted the heavens and the earth and whatsoever is therein. Aye! We have come to them with their admonition; so it is from their admonition that they turn away.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or, is it that thou askest of them any maintenance? The maintenance of thy Lord is better, and He is the Best of providers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And verily thou! thou callest them unto a Path straight.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And verily those who believe not in the Hereafter are from the path deviating.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
And though We have mercy on them We may remove whatsoever of hurt is with them, surely they would persist in their exorbitance, wandering perplexed.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
And assuredly We took hold of them with the torment, yet they humbled not themselves to their Lord, nor did they entreat.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until when we shall open upon them a portal of severe torment, and lo! thereat they are desparing\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
And He it is Who brought forth for you hearing and sight and hearts, little thanks ye give!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And He it is Who spread you on the earth, and unto Him ye will be gathered.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And He it is Who quickeneth and causeth to die, and His is the alternation of night and day; will ye not then reflect?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Aye! they say the like of that which said the ancients.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say: when we are dead, and have become dust and bones, shall we verily be raised up?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
Assuredly this we have been promised--we and our fathers-- aforetime: naught is this but the fables of the ancients.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say thou: whose is the earth and whosoever is therein, if you know?\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will surely say: God's. Say thou: will ye not then heed?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say thou: who is Lord of the seven heavens and Lord of the mighty throne?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will surely say: God. Say thou: will ye not then fear?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Saythou: in whose hands is the governance of everything, and who sheltereth but from whom none is sheltered, if ye know?\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will surely say: God's. Say thou: how then are ye turned away?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Aye! We have brought them the truth and verily they are the liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Allah hath not betaken to Himself any son, and there is not along Him any god; else each god would have gone off with that which he had created, and one of them would have exalted himself above the others. Hallowed be Allah above that which they ascribe!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
Knower of the unseen and the seen, Exalted is He above that which they associate!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say thou; my Lord! if Thou wilt shew me that wherewith they are threatened.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
My Lord! then place me not among the wrong-doing people.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And verily to shew them that wherewith We threaten them We are surely Able.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel thou the evil with that which is the best, We are the Best Knower of that which they utter.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say thou: my Lord! I seek refuge with Thee against the whisperings of the satans;\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
And I seek refuge with Thee, my Lord! lest they may be present with me\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
lt ceaseth not until when death cometh to one of them, and he saith: my Lord! send me back.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
That I may work righteously in that which have left. By no means! It is but a word he uttereth; and before them is a barrier until the Day when they shall be raised.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
Then when the Trumpet is blown there will be no lineage among them that Day, nor will they ask of each other.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then he whose balances shall be heavy --these! they are the blissful ones.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
And he whose balances shall be light--these are they who have lost themselves: in Hell they are abiders.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire will scorch their faces, and therein they shall be grinning.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
Have not My revelations been rehearsed unto you, and them ye have been belying?\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: our Lord! our wretchedness overcame, us, and we have been a people erring.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
O our Lord! take us forth from it: then if we return, we shall be wrong-doers indeed.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He shall say: slink away there unto, and speak not unto Me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Verily there was a party of My bondmen who said: our Lord! we have believed, wherefore forgive us and have mercy upon us, and Thou art the Best of the merciful ones!\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
Then ye took them mockingly, so that they caused you to forget remembrance of Me, and at them ye were wont to laugh.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Verily I have recompensed them today for they bear patiently, verily they! are the achievers.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say: how long tarried ye on the earth in number of year?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
-They will say we tarried a day or part of a day; ask those who keep count.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: ye tarried a little indeed; would that ye had known that:\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Deem ye that We have created youl in vain and that unto Us ye are not to be returned?\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So exalted be Allah, the True King! there is no god but he, Lord of the Throne honoured.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And whosoever calleth, along with Allah, unto anot her god, of whom he hath no warranty, then his reckoning is only with his Lord; verily thrive will not the infidels.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say thou: my Lord! forgive and have mercy, and Thou art the Best of the merciful ones.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen This is a chapter which We have sent down, and which We have ordained; and therein We have sent down revelations manifest, that haply ye may be admonished.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The adulteress and the adulterer: scourge each one of the twain with a hundred stripes. And let not tenderness rake hold of you in regarad to the twain in the law of Allah, if ye have come to believe in Allah and the Last Day. And let witness this torment a band of the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The adulterer weddeth not but an adulteress or an associatoress: and the adulteress! --none weddeth her save an adulterer or an associator; and that is forbidden unto the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse clean wowomen and then bring not four eyewitnesses, Scourge them with eighty stripes and accept not their- testimony for Ever. And these! they are the transgressors\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Excepting those who thereafter shall repent and make amends. Verily Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And as for those who accuse their wives and there are not for them witnesses except themselves, the testimony of one of them shall be four testimonies by Allah: that verily he is of the truth-tellers\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth, that the curse of Allah be upon him if he be of the liars.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
And it will revert the chastisement from her if she testifieth by Allah four times that verily he is of the liars.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth that Allah's wrath be upon her if he is of the truthtellers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And had it not been for the grace of Allah and His mercy unto you and that Allah is Relenting, Wise, ye had been lost.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Verily those who brought forward the calumny were a small band among Deem it not an evil for you; nay, it was good for you. Unto every one of them shall be that which he hath earned of the sin, and he among them who undertook the bulk of it---for him shall be a torment mighty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Wherefore, when ye heard it, did not the believing men and believing women imagine best of their own people and say: this is a calumny manifest!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Wherefore did they not bring four witnesses thereof? Then when they brought not the witnesses, those! with Allah they are the liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Had there not been Allah's grace upon you and His mercy in the World and the Hereafter, surely there would have touched you for that whcrein ye had rushed, torment mighty--\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When ye were publishing it with your tongues and saying that with your mouths of which ye had no knowledge. Ye deemed it light, and it was with Allah mighty!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And wherefore, when ye heard it, did ye not say: it is not for us to speak thereof, hallowed be Thou! that is a slander mighty!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah exhorteth you lest ye may ever revert to the like thereof, if ye are believers indeed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah expoundeth unto you the revelations and Allah is Knowing, wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Verily those who love that in decency should be propagated regarding those who believe, for them shall be a torment afflictive in the world and the Hereafter. And Allah knoweth, and ye know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
And had there not been Allah's grace upon you and His mercy, and that Allah was Tender and Merciful, ye had Perished.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O Ye who believe! follow not the footsteps of the Satan. And whosoever followeth the footsteps of the Satan, then he only urgeth to indecency and abomination. And had there not been the grace of Allah upon you and His mercy, not one of you would ever have been cleansed; but Allah cleanseth whomsoever He Will and Allah is Hearing, Knowing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And let not the owners of affluence and amplitude among you swear off from giving unto the kindred and the needy and the emigrants in the way of Allah; let them pardon and overlook. Love ye not that Allah should forgive you And Allah is Forgiving, Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
verily those who accuse chaste. unknowing, - believing women, shall be cursed in the world and the Hereafter; and for them shall be a torment mighty.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day whereon their tongues and their hands and their feet will bear witness against them regarding that which they were wont to work.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day Allah shall pay them in full their recompense, and they shall know that Allah! He is the True, the Manifest.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Vile women are for vile men, and vile men are for vile women, and clean women are for Clean men, and clean men are for clean women; these are quit of that which the people say: for them is forgiveness and a provision honoured.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O Ye who believe! enter not houses other than your own until ye have asked leave and invoked peace on the inmates thereof. That is better for you, haply ye may take heed.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
Then if ye find no one therein, enter not until leave hath been given you. And if it iaid unto you go back, then go back. It is Cleaner for you, and Allah is of that which ye work knower.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
No fault it is upon you that ye enter houses uninhabited wherein there is some property for you; and Allah knoweth that which you disclose and that which ye hide.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Say thou unto the believers that they shall lower their sights and guard their private parts, that is cleaner for them; verlly Allah is Aware of that which they perform.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And say thou unto the believing women that they shall lower their sights and guard their private parts and shall not disclose their adornment except that which appeareth thereof; and they shall draw their scarves over their bosoms; and shall not disclose their adornment except unto their husbands or their fathers or their husbands fathers or their sons or their husbands sons or their brothers or their brothers sons or their sisters sons or their Women or those whom their right hands own or male followers wanting in sex desire or children not acquainted with the privy parts of women; and they Shall not strike their feet so that there be known that which they hide of their adornment. And turn penitently unto Allah ye all, O ye believers, haply ye may thrive!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And wed the single among you and the fit ones among your male and female slaves; if they are poor, Allah will enrich them of His grace; Allah is Ample, Knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And those who find not means to marry shall restrain themselves until Allah enricheth them of His grace. And from among those whom your right hands own those who seek a writing- write it for them if ye know in them any good, and vouchsafe unto them of the wealth of Allah which He hath vouchsafed unto you. And constrain not your bedmaids to harlotry if they would live chastely, in order that ye may seek the chance gain of the life of the world. And whosoever will constrain them, then verily Allah is--after their constraint--Forgiving, Mercifu1.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And assuredly We have sent down unto you revelations illuminating and a similitude for those who passed away before you and an exhortation unto the God-fearing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the light of the heavens and the earth: the likeness of His light is as a niche wherein is a lamp; the lamp is in glass; the glass is as though it were a star brilliant; lit from a tree blest, an olive, neither in the east nor in the west; well-nigh its oil would glow forth even though fire touch it not. light upon light. Allah guideth unto His light whomsoever He will: And Allah propoundeth similitudes for mankind: verily Allah is of everything the Knower.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
They worship in houses which Allah has bidden to be exalted and His name to be remembered therein; they hallow Him therein in mornings and evenings-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
Men whom neither trafficking nor bargaining diverteth from the remembrance of Allah and the establishment of the prayer and the giving of the poor-rate, fearing a Day whereon upset will be the hearts and sights.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may recompense them the best for that which they worked and may increase unto them of His grace, and Allah provideth for whomsoever He will without measure.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
And those who disbelieve--their works are like a mirage in a desert which the thirsty deemeth to be water, until when he cometh thereto he findeth not aught, and findeth Allahs with himself, and He payeth him his account in full; and Allah is swift at reckoning.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or, like the darknesses in a sea deep; there covereth it a wave from above it, a wave from above it, above which is a cloud: darknesses one above anot her: when he putteth out his hand well-nigh he seeth it not. And upto whomsoever Allah shall not appoint a light, his shall be no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Beholdest thou not that Allah --those hallow Him whosoever is in the heavens and the earth and the birds with wings outspread? Surely each one knoweth his prayer and his hallowing; and Allah is the Knower of that which they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And Allah's is the dominion of the heavens and the earth, and unto Allah is the return.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Beholdest thou not that Allah driveth a cloud along, then combineth it, then maketh it a heap, and then thou beholdest the fine rain come forth from the interstices thereof? And He sendeth down from the heaven mountains wherein is hail, then afflicteth therewith whomsoever He will, and averteth it from whomsoever He will: wellnigh the flash of His lightening taketh away the sights.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah turneth the night and the day over and over; verily therein is a lesson for men of insight.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah hath created every moving creature of water; of them is one that walketh upon his belly. and of them is one that walketh upon its two feet; and of them is one that walketh upon four. Allah createth whatsoever He listeth; verily Allah is over everything Potent.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
Assuredly We have sent down revelations illuminating: and Allah guideth whomsoever He listeth unto a path straight.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
And they say: we have believed in Allah and in the apostle and we have obeyed; then there backslide a party of them thereafter: and these are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to Allah and His apostle that he may judge between them, lo! a party of them are averters.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
And if right had been theirs, they would have come to him readily.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is in their hearts a disease? or doubt they? or fear they that Allah shall misjudge them, as also His apostle? Aye! these are the very wrong-doers!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
-The only saying of the believers when they were called to Allah and His apostle thathe might judge between them was that they said: We hear and we obey. And these! they are the very ones blissful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
And whosoever obeyeth Allah and His apostle, and dreadeth Allah and feareth him-these! they are the achievers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
And they swear by Allah with their solemn oaths that, if thou commandest them they will surely go forth. Say thou: swear not, obedience is recognize! verily Allah is Aware of that which ye Work.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say thou: obey Allah and obey the apostle; then if ye turn away, upon him is only that wherewith he hath been laid upon, and upon you is that wherewith ye have been laid upon; if ye obey him, ye will be guided; and naught is upon the apostle except the preaching plain.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah hath promised those of you who believe and work the righteous works that he shall make them successors on the earth even as He had made those before them successors, and that he shall surely establish for them their religion which He hath approved for them, and that he shall surely exchange unto them after their fear a security, provided they worship Me, associating not aught with Me; and whosoever will disbelieve thereafter, then those! they are the transgressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
And establish the prayer and give the poor-rate and obey the apostle, haply ye may be shewn mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Deem not those who disbelieve able to frustrate His Purpose on the earth; and their abode shall be the Fire--an ill retreat!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O Ye who believe! let those whom your right hands own and those of you who have not attained puberty ask leave of you three times before the dawn prayer, and when ye lay aside your garments noonday, and after the night-prayer: three at times of privacy for you. NO fault there is upon you or upon them beyond these times going round upon you, some of you upon some others. In this wise Allah expoundeth unto you the commandments; and Allah is Knowing, Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the children among you attain puberty, then let them ask leave even as those before them asked leave. In this wise Allah expoundeth unto you His commandments; and Allah is Knowing, Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
And past child-bearing women who have no hope of wedlock-- upon them it is no fault that they lay aside their outer garments, not flaunting their adornment. And that they should restrain themselves is better for them; Allah is Hearing, Knowing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
No restriction is there upon the blind, nor is there the restriction upon a lame, nor is there a restriction upon the sick. nor upon yourselves that ye eat in your houses or the houses of your fathers or the houses of your mothers or the houses of your brothers or the houses of your sisters or the houses of your fathers brothers or the houses of your fathers sisters or the houses of your mothers brothers or the houses of your mothers sisters or from that house where of ye own the keys or from the house of a friend. No fault is there upon you whether ye eat together or in separate groups, Then when ye enter houses, salute each other with a greeting from before Allah, blest and goodly. Thus Allah expoundeth unto you the revelations, haply ye may reflect.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are those alone who have believed in Allah and His apostle, and when they are with him on some affair collecting People together they depart not Until they have asked his leave. Verily those who ask thy leave, those are they who believe in Allah and His apostle. So if they ask thy leave for some business of theirs, give thou leave unto whomsoever of them thou wilt, and ask thou forgiveness of Allah for them. Verily Allah is Forgiving, Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Place not the apostle's calling among you on the same footing as your calling of each other. Of a surety Allah knoweth those who slip away privately; let therefore those who oppose His commandment beware lest there befall them a trial or there befall them a torment afflictive.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Lo! verily Allah's is whatsoever is in the heavens and the earth; surely He knoweth that which ye are about and the Day whereon they shall be made to return unto Him; then He shall declare unto them that which they worked; and Allah is of everything the Knower.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blest be He who hath revealed the Criterion unto His bondman thathe may be unto the worlds a warner.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He whose is the dominion of the heavens and the earth, and who hath not taken a son, and for whom there is not an associate in the dominion, and who hath created everything, and measured it according to a measurement.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
And they have taken beside Him gods creating not aught and are themselves created, owning for themselves neither hurt nor benefit, and owning not death nor life nor resurrection.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
And those who disbelieve, say. this is naught but a falsehood thathe hath fabricated and there have assisted him therein other people. so surelythey have aimed at a wrong and a fraud.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say: fables of the ancients which he hath had written down, so they are dictated unto him, morning and evening.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say thou; He hath sent it down Who knoweth the secret of the heavens and the earth; verily He is ever Forgiving, Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say: what aileth this apostle: he eateth food and walketh about the market-places: wherefore is not an angel sent down unto him, so thathe may be along with him a warner '\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or, whereforeis not there cast down unto him a treasure or he has a garden whereof he may eat! And the wrong-doeray: ye follow only a man bewitched.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
Behold how they propound similitudes for thee! so they have strayed and cannot find a way.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blest is He Who, if He willed, shall appoint for them something better than that: gardens whereunder the rivers flow, and appoint for them palaces.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Aye! they belie the Hour; and We have gotten ready for him who belieth the Hour a Flame.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it beholdeth them from afar, they shall hear it raging and roaring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are flung into a strait place thereof, bound Up, they shall call therein unto death.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
Call not to-day for a single death but call for death manifold.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say thou: in that better or Garden of Abidence that hath been promised to the God-fearing! It shall be theirs as a recompense and a retreat.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
Theirs therein shall be all that they wish for, as abiders; a promise from thy Lord to be asked for.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on the Dav whereon He will gather them and that v; hich they worship beside Allah and will say. are ye the ones who sent astray these My bondmen; or strayed they themselves from the way!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say; hallowed be Thou! it behoved us not that we should take beside Thee any patron, but Thou allovvedest them and their fathers enjoyment Until they forgat the admonition, and they were a people doomed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
So now they belie you in that which ye said; so ye are not able to obtain diversion nor help. And who soever of you doth wrong, him We shall make taste a great torment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And We have not sent before thee ony of the sent ones but verily they ate food and walked about in the market places. And We have made some of you unto some others a temptation; will ye have patience! And thy Lord is ever a Beholder. pART XIX\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who fear not the meeting with Usl say: wherefore are not angels sent down unto us or wherefore we see not our Lord! Assuredly they have proven stiff-necked in their souls and have exceeded the bounds with excess great.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
The Day whereon they shall behold the angels on that day there will be nea joy for the culprits, and they will say: away! away!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We shall set upon that which they worked, and shall make it as dust wind-scattered.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
Fellows of the Garden shall be on that Day in a goodly abode and a gocdly re pose.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
And on the Day whereon the heaven shall be rent asunderg from the q clouds and the angelhall be sent downll with a great descending.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The dominion on that Day rhall is; be the true dominion, of the Compassionate, l and it shall be anday upon the infidels hard.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
On the Day when the wrong-doer shall gnaw his hands saying: would that had taken with the apostle a way!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Ah! woe unto me! wouldthat had never taken such a one for a friend!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
Assuredly he misled me from the admonition after it had come unto ine. Verily the Satan is ever unto man a betrayer.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Apostle will say: my lord! verily my people too k this Qur'an as a thing to be shunned.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
And even scals We appointed unto every prophet an enemy from among the culprits. And thine Lord sufficeth as GUide and Helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And those who disbelieve say: wherefore is the Qur'an not revealed unto him entire at once! Thus---We reveal- that We may establish thy heart there with; and We have repeated it with a repetition.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And they come not unto thee with a similitude but We bring thee the truth and an excellent interpretation.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
They who shall be gathered prone on their faces unto Hell-- those shall be worst in respect of place and the most astray in respect of path.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
And assuredly We vouchsafed unto Musa the Book and We placed with him his brother Harun as a minister.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
Then We said: go ye twain unto a people who have belied Our signs. Then We annihilated them an utter annihilation.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Nuh! When they belied the apostles We drowned them, and made them a sign unto mankind. And We have gotten ready unto the wrong-doers a torment afflictive,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And the 'Aad and the Thamud and the dwellers of the pass and generations in-between many.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
And unto each! We propounded similitude thereunto; and each We ruined an utter ruin.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And assuredly they have gone by the township whereon was rained the evil rain. Are they not wont to see it? Aye! they expect not Resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they behold thee, they hold thee up for mockery: is this the one whom Allah hath sent as an apostle\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
Well nigh he had led us astray from our gods if we had not persevered towards them. Presently they shall know, When they behold the torment, who, more astray in respect of path.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Hast thou observed him who hath taken as his god his own desire! wilt thou be over him a trustee?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or deemest thou that most of them hear or understand? They are but like unto the cattle; nay, they are even farther astray from the path.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Hast thou not observed thine lord-how He hath stretched out the shadow? And if He had willed He would have made it still. Then We have made the sun for it an indication.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We draw it toward Us with an easy drawing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He who hath made for you the night a covering, and the sleep; repose, and hath made the day a resurrection.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He who sendeth fort the winds as a herald before His mercy and We send down from the heaven water pure.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That We may quicken thereby a dead land, and We give drink thereof to that which We have created of cattle and human beings many.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And We set it forth among them, that they may be admonished, but most men begrudge aught save infidelity.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
And if We had willed, We would have raised up in each town a warner.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
Se obey not thou the infidels, but strive against them therewith with a great striving.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He who hath mixed the two seas: this, sweet ond thirst quenching; that, saltish ond bitter; and hath placed between the twain a barrier and a great partition complete.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He who hath created man from water, and then made for him kinship by blood and marriage. And thy Lord is ever potent.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And yet they worship, besides Allah, that which can neither benefit them nor hurt them; and the infidel is ever an aider of the devil against his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We sent thee but as a bearer of glad tidings and warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say thou. ask of you no hire for this, save that whosoever will may take unto his Lord a way.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And trust thou in the Living One who dieth not, and hallow His praise; it sufficeth that he of the sins of His bondmen is Aware.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
Who created the heavens and the earth and whatsoever is in- between them in six days, then He established Himself on the Throne -the Compassionate! so, concernin Him, ask any one informed.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said unto them: prostrate yourselves unto the Compassionate, they say: and what is the Compassionate? Shall we prostrate ourselves unto that which thou commandest us? And it increaseth in them aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blest be He Who hath placed big stars in the heaven, and hath placed therein a lamp and a moon enlightening.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He Who hath appointed the night and the day a succession, for him who desireth to consider or desireth to be grateful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the bondmen of the Compassionate are those Who Walk upon the earth meekly and when the ignorant address them, they say peace\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And these who pass the night before their Lord, prostrate and standing up.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And these who say: our Lord! avert from us the torment of Hell verily the torment thereof is perishment.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Verily ill it is as an abode and as a station.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those who when they expend, are neither extravagant nor sparing, and it is a medium in-between.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who call not unto anot her god along with Allah and slay not any soul which Allah hath forbidden, save in justification, and commit not fornication. And Whosoever shall do this, Shall incur the meed.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
Multiplied for him shall be the torment on the Day of Resurrection, and he shall therein abide disgraced.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Save him who repenteth and believeth and worketh righteous work. Then these! for them Allah shall change their vices into virtues. Verily Allah is ever Forgiving, Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whosoever repenteth and worketh righteously, then verily he repenteth toward Allah with a true repentance.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who witness not falsehood, and when they pass by some vanity pass by with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when they are admonished by the commands of Allah, fall not down thereat, deaf and blind.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who say: our Lord bestow on us coolness of eyes from our wives and our offspring, and make us unto the God-fearing a pattern.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those shall be rewarded with the highest apartment, because they persevered. and therein they shall be met with a greeting and salutation-\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiders therein: excellent it is as an abode and as a station.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say thou: my Lord careth not for you were it not for your prayer. whereas ye have even belied, so presently this denial shall come as the cleaving punishment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta. Sin Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are the verses of a Book luminous.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Belike thou shalt kill thyself with grief because they become not believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We list, We can send down unto them a sign from the heaven so that their necks would became to it submissive.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
And there cometh not unto them any fresh admonition from the Compassionate but they are wont to be there from backsliders.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
So they have surely belied; wherefore anon there shall come unto them the truth of that whereat they were wont to mock.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Observe they not the earth, how much We make to grow therein of every fruitful kind?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Verily therein is a sign; yet most of them are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And recall what time thy Lord called unto Musa, saying: go thou unto the wrong-doing people.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
The people of Fir'awn; fear they Me not?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: my Lord! verily I fear they shall belie me.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
And my breast straiteneth, and my tongue moveth not quickly: so send for Harun.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
And they have a crime against me, so I fear that they shall slay me.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said: by no means. so go ye twain with Our signs; verily We shall be with you listening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
So go ye twain unto Fir'awn and say: verily we are the apostles of the Lord of the Worlds,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
Send with us the Children of Isra'il?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
Fir'awn said: brought we not thee up amongst us as a child? And thou tarriedst amongst us for many years of thy life?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
And thou didst that thy deed which thou didst; and thou art of the ingrates.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
He said: I did it then when I was mistaken.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
Then I fled from you when I feared you, and my Lord bestowed on me wisdom and made me one of the sent ones.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
And that favour wherewith thou didst oblige me was that thou hadst enslaved the Children of Isra'il?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Fir'awn said. and what is the Lord of the worlds?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
He said: Lord of the heavens and the earth and whatsoever is in-between, if ye seek to be convinced.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
Fir'awn said unto those around him: hear ye not?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
He said: your Lord and the Lord of your ancient fathers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
Fir'awn said: verily your apostle who hath been sent unto you is mad.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
He said: Lord of the east and the west and whatsoever is in-between, if ye understand.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
Fir'awn said: if thou wilt take a god other than me, I shall surely place thee among the prisoners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
He said: even though I bring unto thee something manifest?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
Fir'awn said: forth with it then, if thou art of the truth- tellers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
Then he cast down his staff, and lo! it was a serpent manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew forth his hand, and lo! it was white unto the beholders.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
Fir'awn said unto the chiefs around him: verily this is a magician knowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
He would drive you out of your land through his magic; what then is it ye command?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: put off him and his brother, and send unto the cities callers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
Thot they may bring to thee every magician knowing.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the magicians were assembled at a set time on a day made known.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said unto the people: are ye going to assemble.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
Belike we may follow the magicians if they are the winners?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
Then when the magicians came, they said unto Fir'awn: will there surely be a big hire for us if we are the winners?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: yea; and ye shall verily then be of those brought nigh.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Musa said unto them: cast whatsoever ye have to cast.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
Then they cast their cords and their staves, and said: by the might of Fir'awn, verily we! we shall be the winners.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Musa cast down his staff, and lo! it swallowed up that which they had devised.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
Then the magicians flung themselves prostrate.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
They said: we believe in the Lord of the worlds.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
The Lord of Musa and Harun.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
Fir'awn said: ye believed in him ere I gave you leave. Verily he is your chief who hath taught you magic, so ye shall surely come to know. Surely I shall cut off your hands and feet on opposite sides and surely I shall crucify you all.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: no harm! verily unto our Lord we are to return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
Verily we long that our Lord shall forgive us our faults because we have been the first of the believers\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We revealed unto Musa saying: go by night with My bondmen verily ye shall be pursued.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Fir'awn sent unto the cities callers:\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
Verily these are but a band small.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
And verily they have enraged US.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
And verily we are host well-provided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
Then We drave them forth from gardens and springs.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
And treasures and a station noble.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Even so. And We caused the Children of Isra'il to inherit them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
Then they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two parties saw each other, the companions of Musa said: verily we are overtaken.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
Musa said: by no means; verily with me is my Lord; He shall guide me.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We revealed unto Musa, saying: smite thou the sea with thy staff. So it became separated, and each part was like unto a cliff mighty.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And We brought near thither the others.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We delivered Musa and those with him together.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Verily herein is a sign; but most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite unto them the story of Ibrahim.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said unto his father and his people: what worship ye?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said: we worship idols, and we are unto them ever devoted\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said: hearken they unto you when ye cry?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
Or, benefit they you or hurt they you?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said: nay; but we found our fathers doing in this wise.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: have ye observed that which ye worship\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
Ye and your fathers of old?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
Verily they are an enemy unto me, save the Lord of the worlds.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
Who hath created me, and He guideth me.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
He Who feedeth me and giveth me to drink.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
And when I sicken, then He healeth me.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
And He Who shall cause me to die, and then shall quicken me.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
And He Who, long, shall forgive me my faults, on the Day of Requital.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord! bestow on me wisdom and join me with the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And appoint for me an honourable mention among the posterity\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And make me one of the inheritors of the Garden of Delight.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father; verily he is of the erring.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And humiliate me not on the Day whereon people shall be raised.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day whereon will profit neither substance nor sons.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
Unless it be he, who shall bring unto Allah a whole heart,\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And the Garden shall be brought nigh to the God, fearing.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And the Fierce Fire shall be made apparent unto the seduced ones.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it shall be said unto them where is that which ye were wont to worship?\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
Beside Allah? Can they succour you or succour themselves?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then they shall be hurled therein, they and the seduced ones.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And the hosts of Iblis together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
And they, While contending therein, shall say:\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
By Allah, we have indeed been in an error manifest.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
When we equalled you with the Lord of the worlds.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
And none led us astray except the Culprits.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
So none we have as intercessors.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
Nor any loving friend.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
Were there for us a return, we would be of the believers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Verily herein is a sign, but most of them are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
And Nuh's people belied the sent ones.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their brother Nuh said Unto them: fear ye not?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
Verily I am unto you an apostle trusted.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
So fear Allah and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
And I ask of you no hire therefor; my hire is but with the Lord of the worlds.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So fear Allah and obey me.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said: shall We believe in thee when the meanest follow thee?\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: I have no knowledge of that which they have been Working.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Their reckoning is upon my Lord, if ye but knew.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
And I am not to drive away the believers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am naught but a warner manifest.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: if thou desistest not, thou shalt surely be of those stoned.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: my Lord! verily my people have belied me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
So decide Thou between me and them with a decision, and deliver me and those who are with me of the believers.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
Wherefore We delivered him and those with him in the laden ark.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then We drowned the rest thereafter.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Verily herein is a sign, yet most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And thy Lord! He is the Mighty, the Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
The'Aad belied the sent ones.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said Unto them: fear ye not?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
Verily I am unto you an apostle trusted.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
So fear Allah and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
And I ask of you no hire therefor: my hire is but with the Lord of the worlds.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
Build ye on every eminence a landmark in vanity?\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
And take ye for yourselves castles that haply ye may abide.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
And when ye seize, ye seize like unto tyrants.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear Allah, and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
And fear Him Who hath aided you with that which ye know.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
He hath aided you With Cattle and sons.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
And gardens and springs.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
Verily I fear for you the torment of a Mighty Day.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said: it is equal unto us whether thou admonishest or art not of the admonishers.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
This in but a custom of the ancients.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
And we are not going to be tormented.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
And they belied him; so We destroyed them. Verily herein is a sign, yet most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And verily thy Lord? He is the Mighty, the Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
The Thamud belied the sent ones\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Salih said unto them: fear ye not?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
Verily I am unto you an apostle trusted.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So fear Allah, and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
And I ask of you no hire therefor; MY hire is but with the Lord of the worlds.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Shall ye be left secure in that which is here before us.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
In gardens and springs.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
And corn-fields and palm-trees whereof the spathes are fine?\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
And hew ye out houses in the mountains skilfully! g\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
So fear Allah, and obey me.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
And obey not the command of the extravagant.\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
Who work corruption in the land and rectify not.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said: thou art but one of the bewitched;\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
Thou art but a human being like unto us. So bring thou a sign if thou art of the truth-tellers.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: yonder is a she-camel; to her a drink, and to you a drink, each on a day known.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
And touch her not with ill, lest there take hold of you the torment of a Mighty Day.\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
Then they hamstrung her; and then they became regretful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So the torment took hold of them: verily herein is a sign, but most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lut belied the sent ones.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lut said unto them: fear ye not?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
Verily I am unto you an apostle trusted.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So fear Allah, and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
And I ask of you no hire there for; my hire is but with the Lord of the worlds.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
Go ye in, of all creatures, unto the males?\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
And leave ye your spouses your Lord hath created for you? Aye! ye are a people trespassing.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: if thou desistest not, O Lut! thou shalt surely be of those driven forth.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: verily I am of those who abhor your work.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
My Lord! deliver me and my household from that which they work.\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We delivered him and his household all.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Save an old woman among the lingerers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Thereafter We annihilated the rest.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained on them a rain. So ill was the rain on those warned?\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Verily herein is a sign, yet most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The dwellers of the wood belied the sent ones.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
What time Shu'aib, said unto them: fear ye not?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
Verily I am unto you an apostle trusted.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So fear Allah, and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
And ask of you no hire therefor; and my hire is but with the Lord of the worlds.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Give full measure, and be not of those who cause others to lose.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
And weigh with a balance straight.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
And defraud not people of their things, and commit not corruption on the earth.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
So fear Him Who created you and the former generations.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: thou art but of the bewitched;\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
And thou art but a human being like unto us, and we deem thee to be of the liars.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
So cause thou a fragment of the heaven to fall upon us, if thou art of the truth-tellers.\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He. said: My Lord is the Best Knower of that which ye work.\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
Thenn they belied him; wherefore there laid hold of -them the torment of day of shadow. Verily it was the torment of a Mighty Day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Verily herein is a sign; but most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And verily thy Lord! He is the Mighty, the Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And verily it is a revelation of the Lord of the worlds.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
The Trusted spirit hath brought it down.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon thy heart, that thou mayest be of the warners,\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In plain Arabic speech.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And verily it is in the Scriptures of the ancients.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a sign unto them that the learned among the Children of Isra'il know it?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And had We revealed it unto any of the ncn-Arabs,\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had-read it unto them, even then they would not have been believers therein.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
In this wise have We made way for it into the hearts of the culprits.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe therein until they behold the torment afflictive.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
It shall come unto them on a sudden, and they shall not perceive.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say: are we to be respited?\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Seek haste then they with our torment?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Beholdest thou? - if We let them enjoy for years.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And then there cometh unto them that which they had been promised.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
What shall that which they enjoyed avail them?\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And We destroyed not a city but it had its warners.\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
By way of admonition, and We have never been oppressors.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
And the satans have not brought it down.\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
It behoveth them not, nor they can.\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Verily far from hearing are they removed.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So call not thou unto anot her god along with Allah, lest thou be of the doomed.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn thou thy clan, the nearest ones.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And lower thou thy Wlng Unto those who follow thee as believers.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
And if they disobey thee, say thou: verily I am quit of that which ye work.\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And rely thou upon the Mighty, the Merciful.\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who seeth thee when thou standest up\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And thy movements among those who fall prostrate.\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Verily He! He is the Hearer, the Knower.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall declare unto you upon whom the satans descend!\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend upon every calumniator, sinner.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
Who give ear, and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
As for the poets -it is the seduced who follow them.\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Observest thou not, that they Wander about every vale.\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And that they say that which they do not?\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Save those who believed and worked righteous works and remembered Allah much, and vindicated themselves after they had been wronged. And anon those who do wrong shall come to know with what a translating they shall be translated.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta. Sin. These are the verses of the Qur'an and a Book luminous.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guidance and glad tidings unto the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Who establish the prayer and give the poor-rate, and of the Hereafter they are convinced.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Verily those who believe not in the Hereafter - fairseeming unto them We have made their works, so that they wander perplexed.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
Those are they for whom shall be an evil torment. And in the Hereafter they shall be the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
And verily thou art receiving the Qur'an) from before the Wise, the Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
Recall what time Musa said unto his household: verily I perceive a fire afar; I shall forthwith bring you tidings thereof, or bring unto you a brand lighted therefrom, haply ye may warm yourselves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
Then when he came unto it, he was cried unto Thus; Blest is whosoever is in the fire and whosoever is around it; and hallowed be Allah, the Lord of the Worlds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
O Musa! verily it is I, Allah, the Mighty the Wise!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
And cast thou down thy staff. Then when he saw it wriggling as though it were a serpent, he turned in flight and looked not back. O Musa! fear thou not; verily in My presence the sent ones fear not.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
Excepting any who may have done wrong and thereafter changeth evil for good then verily I am Forgiving, Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
And put thy hand into thy bosom, it Shall come forth white, with out hurt: amongst nine signs unto Fir'awn and his people. Verily they have been a people transgressing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
Then when Our signs came unto them illuminating, they said: this is a magic manifest.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they gainsaid them, out of spite and arrogance, although their souls were convinced thereof. So behold! what hath been the end of the corruptors.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And assuredly We vouchsafed unto Daud and Sulaiman a knowledge, and the twain said: praise unto Allah Who hath preferred us above many of His believing bondmen!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Sulaiman inherited from Daud. And he said: O mankind! verily have been taught the diction of we birds, and we have been vcuchsafed of every thing; and verily this is grace manifest.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And there were gathered unto Sulaiman his hosts of jinns and mankind and birds, and they were set in bands.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Until when they came unto the valley of the ants, an ant said: O ants! enter Your habitations lest Sulaiman and his hosts crush you while they perceive not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
So he smiled, amused at her speech, and said: my Lord! arouse me that I should be thankful for Thy favour wherewith Thou hast favoured me and my parents, and that I should work righteously pleasing Thee, and out of Thy mercy enter me among Thine righteous bondmen.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he sought after the birds and said: what aileth me that I see not the hoopoe; is he among the absentees?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
Surely I shall torment him with a severe torment, or I shall slaughter him, unless he bringeth unto me a warranty manifest.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
Buthe tarried not far, and he said: I have encompassed that which thou hast- not encompassed, and I come unto thee from Saba with a tidings sure.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
Verily have found a woman ruling over them and she hath been vouchsafed somewhat of everything, and hers is a mighty throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I have found her and her people adoring the sun instead of Allah, and the Satan hath made their works fairseeming unto them, and hath barred them from the way, so they are not guided.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
So that they adore not Allah who bringeth forth the hidden in the heavens and the earth, and knoweth that which conceal and that which ye make known.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah! there is no God but he, the Lord of the Magnificent Throne.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
Sulaiman said: we shall see now whether thou hast spoken the truth or whether thou art of the liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Go thou with this epistle of mine, and cast it down unto them, and turn aside from them, and see how they return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said: O chiefs! verily there hath been cast unto me an honourable epistle.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
Verily it is from Sulaiman, and verily it is: in the name of Allah, the Compassionate, the Merciful.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Saying: exalt not yourselves against me, and come unto me submissive.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: O chiefs! counsel me in my affair. I am wont not to resolve on any affair until ye are present with me.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: we are owners of power and owners of great violence, but the command is with thee; see then whatsoever thou shalt command.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: verily the kings, when they enter a City, despoil it, and make the most powerful inhabitants thereof the most abased; so will they do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
So verily I am going to send a present unto them, and see with what answer the envoys come back.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
Then when he came unto Sulaiman, he said: are ye going to add riches to me. Then that which Allah hath vouchsafed unto me is better than that which He hath vouchsafed unto you. Aye! it is ye who exult in your present.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Go back unto them. Then surely we shall come unto them with hosts which they cannot withstand, and we shall drive them forth therefrom abased and they shall be humbled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said: O chiefs! which of you will bring unto me her throne, ere they come unto me submitting themselves?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
A giant from the jinns said: I shall bring it unto thee ere thou arisest from thy place; verily I am strong for it and trusty.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
The one who had some knowledge of the Book said: I shall bring it unto thee ere thy eye twinkleth. Then when he saw it placed before him, he said: this is of the grace of my Lord that he may prove me whether I give thanks or am ungrateful. Whosoever giveth thanks he only giveth thanks for his own soul; and whosoever is ungrateful then verily my Lord is Self-sufficient, Munificent.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said: disguise for her her throne, that we may see whether she be guided or be of those who are not guided.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
Then when she arrived, it was said: is thy throne like unto? She said: it is as though it were it; and we have been vouchsafed the knowledge before this, and we have been Muslims.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And that which she was wont to worship instead of Allah hindered her; verily she was of an infidel people.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said unto her: enter the palace. Then when she saw it,, he deemed it a pool and bared her shanks. He said: verily it is a palace evenly floored with glass. She said: my Lord! verily I wronged my soul, and now submit myself together with Sulaiman unto Allah, the Lord of the Worlds.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And assuredly We sent unto the Thamud their brother Saleh saying: worship Allah. Then lo! they became two parties contending.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said: O my people! wherefore seek ye to hasten the evil before the good? Wherefore ask ye not forgiveness of Allah, that haply ye may be shewn mercy.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: we augur ill of thee and of those who are with thee. He said: your augury is with Allah. Aye! ye are a people being tested.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were nine of a group in the City, who spread corruption in the land and rectified not.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: swear one to anot her by God that we shall surely fall upon him and his household by night and thereafter we shall surely say unto his heir; We witnessed not the destruction of his household, and verily we are truthtellers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
And they plotted a plot, and We plotted a plot, while they perceived it not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
So behold thou how was the end of their plotting: verily We annihilated them and their nation all together.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
So yonder are their houses overturned, for they did wrong. Verily, herein is a sign unto a people who know.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We delivered those who believed and were wont to fear.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And Lut! what time he said unto his people: commit ye indecency while ye see?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Would ye go in lustfully unto men instead of women? Aye! ye are a people addicted to ignorant ways.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
Then there was no answer of his people save that they said: drive forth the family of Lut from your City, verily they are a people who would be pure!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
Then We delivered him and his household save his wife: We destined hers to be of the lingerers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained upon them a rain; ill was the rain upon the warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say thou: All praise unto Allah, and peace upon His bondmen whom He hath Chosen! Is Allah best, or that which they associate?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Is not he best Who hath created the heavens and the earth, and Who sendeth down water for you from the heaven wherewith We cause beauteous orchards to grow up, whereof it was not possible for you to cause the trees to grow up! Is there any god along with Allah! Nay! but they are a people who equalise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Is not he best Who hath made the earth a fixed abode and placed rivers in the midst thereof and placed Firm mountains thereon, and hath set a barrier between the two seas? IS there any god along with Allah? Nay! but most of them know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Is not he best Who answereth the distressed when he calleth unto Him and removeth the evil, and hath made you the successors in the earth? Is there any god along with Allah? Little ye reflect!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Is not he best Who guideth you in the darknesses of the land and the sea, and Who sendeth the winds as heralds before His mercy Is there any god along with Allah? Exalted be Allah from all that they associate!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Is not he best Who originateth creation, and shall thereafter restoreth it, and Who provideth for you from the heaven and the earth? IS there any godl along with Allah? Say thou: bring your proof, if ye are truth-tellers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say thou: none in the heavens and the earth knoweth the Unseen save Allah; nor can they perceive when they will be raised.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Aye! their knowledge attaineth not to the Hereafter, Aye! they are in doubt thereof. Aye! thereunto they are blind.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
And those who disbelieve say: when we have become dust, we and our fathers, shall we, for sooth, be brought forth?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
Assuredly we have been promised this aforetime, we and our fathers. Naught is this but fables of the ancients.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say thou: travel in the land and behold what like hath been the end of the culprits.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And grieve thou not over them nor be straitened because of that which they plot.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say: when will this Promise be fufilled if ye say sooth?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say thou: belike close behind you may be some of that which ye would hasten on.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
And verily thine Lord is full of grace for mankind, but most of them give not thanks.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And verily thine Lord knoweth whatsoever their breasts conceal and whatsoever they make known.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And naught there is hidden in the heaven or the earth but it is in a Manifest Book.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Verily this Qur'an recounteth with truth unto the Children of Isra'il much of that wherein they differ.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And verily it is a guidance and a mercy unto the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
And verily thine Lord shall decide between them with His judgment, and He is the Mighty, the Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
Wherefore put thy trust in Allah; verily thou art on manifest truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Verily thou canst not make the dead hear, nor canst thou make the deaf hear the call when they flee turning their backs.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor canst thou lead the blind out of their error. Thou canst make none hear save these who believe in Our signs and who have submitted themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the word shall come to be fulfilled concerning them, We shall bring forth a beast of the earth speaking unto them, that the people have not of Our signs been convinced.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And remind them of the Day whereon We shall Rather from every community a troop of those who belied Our signs, and they shall be held in order.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Until when they shall have come, He Shall say: belied ye My signs when ye encompassed them not in Your knowledge; nay, what else was it that ye have been working?\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word shall be fulfilled concerning them, because they did wrong, and they shall not be able to speak.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Observe they not that We have appointed the night that they may repose therein, and the day sight-giving? Verily herein are signs unto a people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And remind them of the Day whereon the trumpet shall be blown, and affrighted will be those who are in the heavens and the earth, save him whom Allah willeth. And all shall come unto Him, lowly.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And thou shalt see the mountains thou deemest solid passing away as the passing away of the clouds: the handiwork of Allah Who hath perfected everything. Verily He is Aware of all that ye do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whosoever will bring good shall have better than the worth thereof; and they from the terror of that Day will be secure.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whosoever will bring evil --their faces shall be cast down into the Fire. Are ye being requited aught save that which ye have been working?\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
I am commanded only to worship the Lord of this city which He hath sanctified, -and His is every thing - and I am commanded to be of the Muslims;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And that I should recite the Qur'an. And whosoever receiveth guidance, receiveth guidance for his own soul, and as for him who strayeth say thou: I am only of the warners.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say thou: All praise unto Allah! Anon He shall shew you His signs, so that ye will recognize them. And thy Lord is not negligent of that which ye Work.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta. Sin. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are verses of the Manifest Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
WE recite unto thee of the story of Musa and Fir'awn with truth fora people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Verily Fir'awn exalted himself in the earth and made the people thereof into sects, weakening a party among them, slaying their sons and letting their women live. Verify he was of the corrupters.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We desired that We should be gracious unto those who were weakened in the land, and We should make them leaders and We should make them the inheritors.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And We should establish them in the earth, and We should let Fir'awn and Haman and their hostee from them that which they dreaded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired the mother of Musa, saying: suckle him, then when thou fearest for him, cast him into the river and fear not, nor grieve. Verily We are going to restore him unto thee, and shall make him one of the sent ones.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
And the household of Fir'awn took him Up, that he should become unto them an enemy and a grief. Verily Fir'awn and Haman and their hosts were sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And the wife of Fir'awn said: a comfort unto me and thee slay him not; belike he shall be of benefit to us or we might like him for a son; and they perceived not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And the heart of the mother of Musa became void, and she had wellnigh disclosed him, had We not fortified her heart, that she might remain one of the believers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said unto his sister: follow him. So she watched him from afar; and they perceived not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had aforetime forbidden foster-mothers for him; so she said: shall direct you unto a household who will rear him for you and who will be unto him good counsellors.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We restored him unto his mother that she might be comforted and not grieve, and that she might know that the promise of Allah is true. Yet most of them know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he attained his full strength and became firm, We vouchsafed unto him wisdom and knowledge; and Thus We reward the well- doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the City at a time of unawareness of the inhabitants thereof, and he found therein two men fighting, one being of his own party, and the other of his enemies. And he who was of his party, called him for help against him who was of his enemies. So Musa truck him with his fist, and put an end of him. He said: this is of the work of the satan, verily he is an enemy, a misleader manifest.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said: my Lord! verily I have wronged my soul, so wherefore forgive me. So He forgave him. Verily He! He is the Forgiving, the Owner of Mercy.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: my Lord! whereas Thou hast favoured me, I shall nevermore be a supporter of the culprits.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
And in the morning he was in the city fearing and looking about, when lo! he who had asked his succour yesterday was crying out unto him. Musa said: verily thou art a seducer manifest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
And when he sought to seize him who was an enemy unto them both, he said: O Musa wouldst thou slay me as thou didst slay a person yesterday? Thou seekest only to be a tyrant in the land, and thou seekest not to be of the reconcilers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And there came a man from the farthest part of the city, running; he said: O Musa! the chiefs are taking counsel together concerning thee, that they might slay thee; wherefore go forth thou, verily I am unto thee of the admonishers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he went forth from thence fearing, looking abcut. He said: my Lord! deliver me from the wrong-doing people.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he betook himself toward Madyan, he said: belike my Lord will guide me even way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he arrived at the water of Madyan, he found there a community of the people watering. And he found, apart from them, two women keeping back their flocks. He said: what aileth you twain! The twain said: we water not until the shepherds have driven away their flocks; and our father is a very old man.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
Then he watered their flocks for the twain. Then he turned aside into the shade, and said: my Lord! I verily of the good which Thou mayest send down for me I am needy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then there came unto him one of the twain walking bashfully, and said: verily my father calleth for thee, that he may recompense thee with a hire for that thou didst water the flock for us. Then, when he was come unto him and had recounted unto him the whole story, he said: fear not; thou hast escaped from the wrong-doing people.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
And said one of the twain: O my father! hire him, for the best that thou canst hire is the strong and trustworthy one.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: verily I wish I would marry thee to one of these two daughters of mine provided that thou hirest thyself to me for eight years. then if thou completest ten it will de of thine own accord, and I would not make it hard for thee; thou Shalt find me, Allah willing, of the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
Musa said: be that between me and thee: whichsoever of the two terms I shall fulfil, it shall be no harshness to me; and of that which we say Allah is Trustee.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
Then when Musa had fulfilled the term, and was journeying with his household, he saw a fire on the side of Tur, and said unto his household: bide ye; verily I see a fire afar, haply I may bring unto you tidings thereon, or a brand out: of the fire, haply ye may warm yourselves.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
Then when he was come thereto, he was called from the right side of the valley in the ground blest from the tree: Musa! verily I! I am Allah, the Lord of the worlds;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
And cast thou down thy staff. And when he saw it stirring, as though it were a serpent, he turned in flight and looked not back. O Musa! draw nigh, and fear not; thou art of the secure ones.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Slip thy hand in thy bosom, it shall come forth white without hurt; and draw back thy arm unto thee for fear. These shall be two proofs from thy Lord unto Fir'awn and his chiefs; verily they have been a people given to transgression.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said: My Lord! verily I have slain a man among them and I fear they shall slay me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
And My brother Harun! He is more eloquent than I in speech; wherefore send him with me as a support, to corroborate me; verily I fear that they shall belie me.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said: We shall indeed strengthen thine arm with thy brother, and We shall vouchsafe unto you authority, so that they shall not be able to come up to you. Go forth with Our signs! Ye twain and those who follow you, shall be the victors.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
Then when Musa came unto them with Our manifest signs, they said: this is naught but magic fabricated; and we heard not of this among our fathers of old.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
And Musa said: My Lord best knoweth him who bringeth guidance from before Him and him whose will be the happy end of the Abode. Verily the wrong-doers shall not thrive.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
And Fir'awn said: O chiefs! know not of a god for you except me. Wherefore light thou for me, O Haman! clay, and make me a lofty tower that I may ascend unto the God of Musa; and verily I imagine him to be of the liars.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his hosts were stiff-necked in the land without right, and imagined that before Us they would not be brought back.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
Wherefore We laid hold of him and his hosts and cast them into the sea. So behold thou what like hath been the end of the wrong- doers!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders calling to the Fire, and on the Day of Resurrection they shall not be succoured.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We caused a curse to follow them in this world, and on the Day of Resurrection they shall be of the castaway.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And assuredly We vouchsafed the the Scripture unto Musa after We had destroyed the generations of old: enlightenment unto mankind and a guidance and a mercy, that haply they might be admonished.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And thou wast not on the western side when We decreed the affair unto Musa, and thou wast not of the witnesses.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We brought forth generations, and prolonged unto them was life; nor wast thou a dweller among the people of Madyan, reciting unto them Our revelations; but it is We who were to send.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
Nor wast thou beside the Tur when We called; but thou art sent as a mercy from thy Lord, that thou mayest warn a people unto whom no warner came before thee, that haply they might be admonished.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
And lest, if an affliction had afflicted them for that which their hands had sent before, they should have said: our Lord! wherefore sent not Thou an apostle unto us that we might have followed Thy revelations and been of the believers!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
Yet when the truth is come unto them from before Us, they say: wherefore hast he not been vouchsafed the like of that which was given unto Musa? Disbelieved they not in that which was given unto Musa aforetime? They say; two magics supporting each other. And they say: verily in all such things we are disbelievers.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say thou: then bring a Book from before Allah, that is better in guidance than these two shall follow it--if ye are truth- tellers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
Then if they answer thee not, know thou that they only follow their own desires; and who is farther astray than he who followeth his desire without guidance from Allah? Verily Allah guideth not a wrong- doing people.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And assuredly We have caused the Word to reach them in succession, that haply they may be admonished.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those unto whom We vouchsafed the Book before it, --they believe therein.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is rehearsed unto them they say: we believe therein: verily it is truth from our Lord: verily we have been even before it of those who submit themselves.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These shall be vouchsafed their hire twice over, because they have persevered, and they repel evil with good, and expend of that wherewith We have provided them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear vain discourse they withdraw therefrom and say: unto US our works, and unto you your works; peace be unto you; we seek not the ignorant.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Verily thou shalt not guide whomsoever thou lovest, but Allah shall guide whomsoever He will. And He knoweth best who are the guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say: were we to follow the guidance with thee, We Shall be snatched away from our land. Have We not established for them an inviolable sanctuary whereunto fruits of every sort are brought: a provision from Our presence? But most of them know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a city have We destroyed that exulted in their living! And yonder are their dwellings which have not been inhabited after them unless for a little while; and verily We! We have been the inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Nor was thy Lord to destroy the Cities, until He had raised up in their mother-city an apostle reciting unto them our revealations. Nor were We to destroy the cities unless the inhabitants thereof were wrong-doers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatsoever ye are vouchsafed is an enjoyment of the life of the world and an adornment thereof; and that which is with Allah is better and more lasting. Will ye not therefore reflect?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Is he, then, whom We have promised an excellent promise which he is going to meet, like unto him whom We have suffered to enjoy awhile the enjoyment of the life of the world, then on the Day of Resurrection he shall be of those brought up!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
And on the Day whereon He shall call unto them and say: where are My associates whom ye were wont to assert?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those upon whom the sentence will be pronounced will say: our Lord these are they whom we seduced, we seduced them even as we our selves were seduced. We declare ourselves quit of them before Thee; not our selves they were wont to worship.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it shall be said: Call upon your associate-gods. And they shall call upon them, and they shall not answer them, and they shall behold the torment. Would that they had received the guidance!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And on the Day whereon He shall call unto them and say: what answer gave ye to the sent ones?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Bedimmed unto them shall be all excuses on that Day, wherefore they shall not be able to ask one of another.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
Howbeit, whosoever shall repent and believe, and work righteous works - belike he shall be of the thrivers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
And thy lord createth whatsoever He listeth and chooseth; no Choice is to be far them. Hallowed be Allah and exalted above that which they associate!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And thy Lord knoweth that which their breasts conceal and that which they make known.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah there is no god but he! His is all praise in the first and in the last, and His is the command, and unto Him ye shall be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say thou: bethink ye, if Allah made night continuous for you till the Day of Resurrection, what god is there beside Allah, who would bring you light? Hearken ye not?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say thou: bethink ye, if Allah made day continuous for you till the Day of Resurrection, what god is there beside Allah, who would bring you night wherein ye have repose? Behold ye not?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is of His mercy He hath appointed for you night and day, that therein ye may have repose, and that ye may seek of His grace, and that haply ye may give thanks.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
And on the Day whereon He shall call unto them and say: where are My associates whom ye were wont to assert?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
We shall take out from every community a witness and We shall say: come forth with your proof; then they shall know that the truth was Allah's, and astray will go from them that which they were wont to fabricate.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Verily Qarun was of the people of Musa; then he behaved arrogantly toward them. And We had vouchsafed him of the treasures whereof the keys would have weighed down a band of strong men. Recall what time his people said unto him: exult not; verily God loveth not the exultant.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
And seek the abode of the Hereafter with that which God hath vouchsafed thee, and forget not thy portion in the World, and be thou bounteous even as God hath been bounteous unto thee, and seek not corruption in the earth; verily Allah loveth not corrupters.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said: I have been vouchsafed this only because of the knowledge that is with me. Knew he not that Allah had destroyed before him, of the generations, those who were stronger than he in might and larger in respect of following? And the culprits shall not be questioned of their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
Then he went forth unto his people in his pomp. Those who sought the life of the world said: would that we had the like of that which hath been vouchsafed unto Qarun! Verily he is the owner of a very great fortune.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
And those who had been vouchsafed the knowledge said: woe unto you! the reward of Allah is best for him who believeth and worketh righteously and none shall attain it except the patient.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
Then We sank the earth with him and his dwelling-place. And he had no host to defend him against Allah, nor was he of those who could defend themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had wished for his place but yesterday began to say: Ah! Allah expandeth the provision for whomsoever He will of His bondmen and stinteth, had not Allah been gracious unto us, He would have sunk the earth with us also. Ah! the infidels thrive not.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
This is the abode of the Hereafter! We appoint it unto those who Seek not exaltation in the earth nor corruption; and the happy end is for the God-fearing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whosoever bringeth good shall have better than it, and whosoever bringeth evil, then those who do ill works shall be rewarded only for that which they have been working.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Verily He who hath imposed the Qur'an on thee Is surely about to bring thee back home. Say thou: my Lord knoweth best who bringeth guidance and who is in an error manifest.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And thou wast not hoping that the Book would be Inspired in thee; but it is a mercy from thy Lord, so be thou not a supporter of the infidels.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let them not turn thee aside from the signs of Allah after they have been sent down unto thee. And call thou men unto thy Lord, and be thou not of the associaters.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And invoke thou not any other god along with Allah. There is no god but he. Everything is perishable save His countenance His is the judgment, and unto Him ye shall be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Bethink men that they shall be left alone because they say: we believe; and that they shall not be tempted?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
And assuredly We have tempted those who were before them. So Allah will surely know those who are true and He will surely know the liars.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or bethink those who work ill deeds that they shall outstrip Us? lll do they judge!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whosoever hopeth for the meeting with Allah, then Allah's term is surely coming, and He is the Hearer, the Knower.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whosoever strive, striveth only for himself: verily Allah is Independent of the worlds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
And whosoever believe and work righteous works, We shall purge away from them their ill-deeds and shall recompense them the best of that which they have been working.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
And We have enjoined on man kindness unto parents. But if the twain strive to make thee associate with Me that of which thou hast no knowledge, obey them not. Unto Me is your return, and I shall declare unto you that which ye have been working.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And those who believe and work righteous works--We shall surely cause them enter among the righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Of mankind are some who say: we believe in Allah; then if they are afflicted in the way of Allah, they take the persecution of men even as the torment of Allah; and then, if succour cometh from thy Lord they say: verily we have been with you. Is not Allah the Best Knower of that which is in the breasts of the creatures?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
And surely Allah shall come to know those who believe, and surely He shall come to know the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And those who disbelieve say unto those who believe: follow our way, and we shall surely bear your sins; whereas they shall not bear aught of their sins; verily they are the liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
And surely they shall bear their loads and other loads beside their own loads, and surely they shall be questioned on the Day of Resurrection concerning that which they were wont to fabricate.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And assuredly We sent Nuh unto his people. Then he tarried among them for a thousand years, save tifty years; and then deluge overtook them, while they were wrong-doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
Then We delivered him and those in the ark, and made it a sign unto the worlds.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And We sent Ibrahim. Recall what time he said unto his people: worship Allah, and fear Him; that is best for you if ye but knew.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
Ye only worship images instead of Allah, and ye create a falsehood. Verily those whom ye worship instead of Allah own no provision for you. Wherefore seek with Allah provision, and worship Him, and give thanks unto Him: unto Him ye shall be returned.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
And if ye belie me, then communities before you have belied: and upon the apostle is naught but a preaching manifest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Observe they not what wise Allah originateth creation? And then He shall restore it. Verily for Allah that is easy.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say thou: go about in the land and behold what wise He hath originated creation; and then Allah shall produce another production; verily Allah is over everything Potent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He shall torment whomsoever He Will, and shall show mercy unto whomsoever He Will, and unto Him ye shall be returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
And ye cannot escape in the earth nor in the heaven, and beside Allah there is for you no friend nor helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who disbelieve in the signs of Allah and in their meeting with Him, they shall despair of My mercy, and they! theirs shall be a torment afflictive.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
Then the answer of his people was naught but that they said: slay him, or burn him. Then Allah delivered him from the fire; verily herein are signs for a people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And he said: ye have taken images instead of Allah out of affection between you in the life of the world; but on the Day of Resurrection ye shall deny each other and ye shall curse each other, and your resort shall be the Fire, and ye shall have no helpers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
And Lut believed in him. And he said: verily I am going to migrate to my Lord; verily He is the Mighty, the Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We bestowed on him Is-haq and Y'aqub, and We placed among his posterity prophethood and the Book, and We vouchsafed unto him his hire in the World, and verily in the Hereafter he shall be of the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And Lut: Recall what time he said unto his people: verily ye commit an indecency wherein none hath preceded you in the Worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
Ye go in indeed unto males, and ye rob on the highway, and ye commit that which is disreputable in your assembly? Then the answer of his people was naught but that they said: bring thou God's torment on us if thou art of the truth-tellers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said: my Lord! give me victory over the corrupt people.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our messengers came unto Ibrahim with the glad tidings, they said: verily we are about to destroy the inhabitants of that city: verily the inhabitants thereof have been wrong-doers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said: verily Lut is therein. They said: we know better who is therein: we are to deliver him and his household, save his wife; she is to be of the lingerers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our messengers came unto Lut, he was distressed on their account and felt straitened on their account. And they said: fear not, nor grieve: verily we are to deliver thee and thy household, save thy wife: she is to be of the lingerers.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
Verily we are about to bring down upon the inhabitants of this city a scourge from the heaven, for they have been transgressing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And assuredly We have left thereof manifest sign for a people who reflect.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And unto Madyan We sent their brother, Shu'aib. He said: my people! worship Allah, and fear the Last Day, and commit not evil on the earth as corrupters.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
Then they belied him; wherefore an earthquake laid hold of them, and they lay in their dwellings, crouching.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And the 'Aad and Thamud and of a surety their destruction is apparent unto you from their dwellings. The Satan made fairseeming their works unto them, and so kept them off from the path, while they were endued with sight.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Qarun and Fir'awn and Haman! And assuredly Musa came unto them with the evidences, yet they were stiff-necked in the land. And they could not outstrip Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
Wherefore each We laid hold of for his sin. Of them were some on whom We sent a violent wind; and of them were some - who were overtaken by a shout; and of them were some - with whom We sank the earth; and of them were some - whom We drowned. Allah was not such as to wrong them, but themselves they were wont to wrong.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who take other patrons than Allah is as the likeness of the spider who taketh unto herself a house. And verily the frailest of all houses is the spider's house - if they but knew!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Verily Allah knoweth whatsoever thing they invoke beside Him. And He is the Mighty, the Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And these similtudes! We propound them for mankind; and none understand them save men of knowledge.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah hath created the heavens and the earth in truth; verily there in is a sign for the believers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite thou that which hath been revealed unto thee of the Book and establish thou the prayer; verily prayer preventeth man from indecency and that which is disreputable: and surely the remembrance of Allah is the greatest. And Allah knoweth that which ye perform.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And dispute not with the people of the Book unless in the best manner, save with those of them who do wrong; and say: we believe in that which hath been sent down unto us and that which hath been sent down unto you: our God and your God is One; and unto Him we are submissive.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And likewise have We sent down unto thee the Book; so those to whom We have vouchsafed the Book believe therein, and of those also some believe therein. And none gainsay Our signs save the infidels.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
And thou hast not been reciting any book before it, nor hast thou been writing it With thine right hand, for then might the followers of falsehood have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Aye! it in itself manifest signs in the breasts of those who have been vouchsafed knowledge, and none gainsay Our signs save the wrong-doers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they say: wherefore are not signs sent down upon him from his Lord! Say thou: signs are with Allah only, and I am but a manifest warner.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Sufficeth it not for them that We have sent down unto thee the Book to be recited unto them? Verily herein is a mercy and an admonition for a people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say thou: Allah sufficeth for witness between me and you: He knoweth whatsoever is in the heavens and the earth. And they who believe in falsehood and disbelieve in Allah, those: they shall be the losers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they ask thee to hasten on the torment. And had not there been a term appointed, the torment would surely have come unto them. And surely it shall come upon them of a sudden while they perceive not.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They ask thee to hasten on the torment; and verily the Hell is about to encompass the infidels.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day whereon the torment shall cover them from above them and from underneath their feet, and He shall say: taste that which ye have been working!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
My bondmen, who believe! verily My earth is wide, so Me alone worship.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul shall taste of death; then unto Us ye shall be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who believe and work righteous works--them We shall surely settle in lofty dwellins of the; they shall be of the Garden whereunder the rivers flow; they shall be abiders therein. Excellent is the hire of the Workers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Who persevere and in their Lord trust!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And how many a moving creature there is that beareth not its provision! Allah provideth for it and for you. And He is the Hearer, the Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
And wert thou to ask them.: who hath created the heavens and the earth and subjected the sun and the moon they would surely say: Allah. How then are they deviating?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah expandeth provision for whomsoever He Will of His bondmen and stinteth it for him. Verily Allah is of everything the Knower.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And wert thou to ask them: who sendeth down water from the heaven, and therewith quickeneth the earth after the death thereof? they would surely say: Allah. Say thou: all praise unto Allah! Aye! most of them reflect not.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
And this life of the world is but: sport and play. Verily the home of the Hereafter--that is life indeed, if they but knew!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
So When they mount upon the ships they call on Allah making pure for Him the religion, then when He delivereth them safely on the land, lo! they associate\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
So that they become ingrate for that which We have vouchsafed unto them, and that they enjoy themselves; but presently they shall know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Behold they not that We have appointed an inviolable sanctuary, while men are being snatched away round about them? in falsehood then believe they, and unto the favour of Allah will they be ingrate?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who is a greater wrong-doer than he who fabricateth a lie against Allah or belieth the truth when it cometh unto him Will there not be in the Hell an abiding-place for the infidels?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
And those who strive hard in us, We shall surely guide them in Our paths; verily Allah is with the welldoers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif. Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Byzantians have been overcome.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In a nearer land; and they, after the overcoming of them, shall soon overcome.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
In some few years. Allah's is the command, before and after. And on that day the believers wiil rejoice.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
In Allah succour. He succoureth whomsoever He will, and He is the Mighty, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
This is Allah's promise; and Allah faileth not His promise. Yet most men know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know only the outward appearance of the life of the world, and they! of the Hereafter, they are neglecetful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Ponder they not in their minds: Allah hath not created the heavens and the earth and whatsoever is in-between the twain save with a purpose and for a term appointed? And verily many men in the meecing of their Lord are unbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not journeyed in the land and observed what wise hath been the end of those before them? They were stronger than they in power and they brake up the earth and they inhabited it with greater affluence than these have inhabited it, and their apostles came unto them with evidences. And Allah was not one to wrong them, but themselves they were wont to wrong.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then the end of those who committed evil was evil, for they belied the signs of Allah and they were wont to mock at them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah originateth the creation, then He shall restore it, then unto Him ye shall be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And on the day whereon the Hour arriveth, dumb-struck will be the culprits.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
And not from their associate-gods, there will be intercessors for them, and unto their associate-gods they will be unbelievers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
On the Day whereon the Hour arriveth, that Day they shall be separated.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
Then as for those who believed and worked righteous works, they shall be in a meadow made happy.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
And as for those who disbelieved and belied Our signs and the meeting of the Hereafter--these to the torment shall be brought.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So hallow Allah when ye enter the night and when ye enter the morning, --\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
And His is all praise in the heavens and the earth! --and at the sun's decline and when ye enter the noon.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He bringeth forth the living from the lifeless, and He bringeth forth the lifeless from the living, and He quickeneth the earth after the death thereof; and even so shall ye be brought forth.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is, that he created you of dust, then lo! ye are humankind spreading yourselves.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is, thathe created for you from yourselves pouses that ye may find repose in them, and He set between you affection and mercy. verily herein are signs for a people who ponder.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His signs are the creation of the heavens and the earth, and the variation of your languages and complexions; verily herein are signs for men of knowledge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs are your sleeping by night and by day, and your seeking of His grace verily herein are signs for a people who hearken.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs is that he sheweth you the lightning for a fear's and for a hope, and sendeth down from the heaven water, and therewith quickeneth the earth after the death thereof; verily herein are signs for a people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is that the heaven and the earth stand fast by His command, and thereafter, when He calleth you, a call from the earth, lo! ye shall come forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
His is whosoever is in the heavens and the earth; all are unto Him obedient.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And He it is who originateth the creation, then shall restore it, and it is easier for Him. His is the most exalted similitude in the heavens and in the earth; and He is the Mighty, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He propoundeth unto you a similitude taken from yourselves. Have you, from among those whom your right hands own, partners in that wherewith We have provided you, so that ye are equal in respect thereof, and ye fear them as ye fear each other? In this wise We detail the signs for a people who reflect.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Aye! those who do wrong follow their own lusts without knowledge. Who, then, will guide him whom Allah hath sent astray? And for them there will be no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
Wherefore set thou thy face towards the true religion uprightly. And follow thou the constitution of Allah according to which He hath constituted mankind. No altering let there be in Allah's creation. That is the right religion, but most men know not.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
And remain turning penitently unto Him, and fear Him, and establish prayer, and be not of the associaters:\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Of those who split up their religion and became sects, each band in that which is with them exulting.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when hurt toucheth mankind they cry unto their Lord, turning penitently unto Him; then when He causeth them to taste of His mercy, lo! a part of them with their Lord associate others.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
So that they may be ungrateful for that which We have vouchsafed to them. So enjoy awhile; presently ye shall come to know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent unto them any authority, so that it speaketh of that which they have been with Him associating?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We cause mankind to taste of mercy they exult thereat; then if an evil befalleth them because of that which their hands have sent forth, lo! they despair.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Behold they not that expandeth the provision for whomsoever He and stinteth? Verily herein are signs for a people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give thou unto the kinsman his due and unto the needy and unto the wayfarer. That is best for those who seek Allah's countenance; and those: they are the blissful ones.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And whatsoever ye give in gift in order that it may increase among the substance of men increaseth not with Allah; and whatsoever ye give in poor-rate seeking the countenance of Allah-then those: they shall, have increase manifold.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
Allah is He Who created you and provided food for you, then He causeth you to die, and then He shall quicken you. Is there any of your associate-gods that doth aught of that? Hallowed and exalted be He above that which they associate!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruptness hath appeared on land and sea because of that which men's hands have earned, so that he may make them taste a part of that which they have worked, in order that haply they may turn.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say thou: go forth in the land and behold what wise hath been the end of those of aforetime? And most of them were associaters.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So set thy face toward the right religion before the Day cometh from which there is no averting, from Allah, on that Day they shall be sundered.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whosoever disbelieveth, on him is his infidelity, and those who work righteously are preparing for themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
So that he shall recompense those who believe and work righteous works out of His grace; verily He loveth not the infidels.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is that he sendeth winds heralding rain and that he may make you taste of His mercy, and that the ships may sail at His command and that ye may seek His grace, and that haply ye may return thanks.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
And assuredly We sent apostles before thee unto their people. They brought them manifest signs. Then We took vengeance upon those who transgressed. And incumbent upon us was avengement of the believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
Allah is He Who sendeth the winds so that they raise a cloud and then spreadeth it along the heaven as He will and breaketh it into fragments, and thou beholdest the rain come forth from the intestines thereof. Then when He maketh it fall upon such of His bondmen as He will, lo! they rejoice.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Even though before it was sent down upon them, before that, they were surely despairing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Look then at the effects of Allah's mercy: what wise He quickeneth the earth after the death thereof. Verily. He is the Quickener of the dead, and He is over every-thing potent.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We send a wind, and they should see their tilth yellow, then they would thereafter remain disbelieving.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
So verily thou canst not make the dead hear, nor canst thou make the deaf hear the call when they turn away in flight.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Nor canst thou be a guide to the blind out of their error; thou canst make none to hear save those who believe in Our signs, and who have surrendered themselves.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah it is Who created you in weakness, then He appointed strength after weakness, then after strength appointed weakness and grey hair. He createth whatsoever He listeth: and He is Knower, the Potent.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And on the Day whereon the Hour arriveth, the Culprits Will swear that they tarried not but an hour: Thus Were they ever deluded.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
And those who have been vouchsafed knowledge and belief will say: assuredly ye have tarried according to the decree of Allah until the Day of Upraising; so this is the Day of Upraising, but ye were wont not to know.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
On that Day the excusing of themselves will not profit those who did wrong, nor shall they be suffered to please Allah.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
And assuredly We have propounded for mankind, in this Qur'an, every kind of similitude; and if thou bringest unto them a sign, those who disbelieve are sure to say: ye are but followers of falsehood.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
In this wise Allah sealeth the hearts of those who believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So have thou patience; verily the promise of Allah is true. And let not make thee impatient those who have no conviction.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif; Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are verses of the Wise Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A guidance and a mercy for the well-doers:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who establish the prayer and give the poor-rate and of the Hereafter are convinced.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
These are on guidance from their Lord, and these! they are the blissful ones.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And of mankind is one who purchaseth an idle discourse, that he may mislead from Allah's way without knowledge, and taketh it by way of mockery. These! for them shall be a torment ignominious.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our revelations are recited unto him he turneth away in his stiff-neckedness as though he heard them not: as though there was a deafness in his ears. So announce thou unto him a torment afflictive.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Verily those who believe and work righteous works, theirs shall be Gardens of Delight.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
Therein they will be abiders: a true promise of Allah. And He is the Mighty, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He hath created the heavens that ye behold without pillars and hath cast Into the earth firm mountains lest it move away with you; and He hath scattered thereon every kind of animal. And We send down water from the heaven and We make grow every kind of goodly growth therein.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is the creation of Allah; shew that which those beside Him me have created. Aye! the wrong-doers are in error manifest.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And assuredly We vouchsafed unto Luqman Wisdom, saying: give thanks unto Allah; and whosoever giveth thanks giveth thanks for his soul; and whosoever is unthankful--then verily Allah is self-sufficient, praiseworthy\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And recall what time Luqman said unto his son, while he was exhorting him: O my son! associate not aught with Allah; verily this associating is surely a tremendous wrong.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined upon man concerning his parents--his mother beareth him in hardship upon hardship and his weaning is in two years: give thanks unto Me and unto thy parents; Unto Me is the goal.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
And if the twain strive with thee to make thee associate with Me that for which thou hast no knowledge, then obey them not. And bear them thou company in the world reputably, and follow thou the path of him who turneth penitently unto Me. Then unto Me is your return, and I shall declare unto you that which ye have been working.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
O my son! though it be but the weight of a grain of mustard-seed, and though it be in a rock or in the heavens, or in the earth, Allah shall bring it forth. Verily Allah is subtile, Aware.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
O My son! establish prayer and command that which is reputable and forbid iniquity, and bear patiently whatsoever may befall thee; verily that is of the firmness of affairs.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
And turn not away thy cheek from men nor walk on the earth stultingly, verily Allah loveth not any vainglorious boaster.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
And be modest in thy gait and lower thy voice; verily the most abominable of voices is the voice of the ass.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Observe ye not that Allah hath subjected for you whatsoever is in the heavens and whatsoever is in the earth, and hath completed His favours on you outwardly and inwardly? And yet of mankind is one who disputeth concerning Allah without knowledge and with neither guidance nor a Book luminous.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said unto them: follow that which Allah hath sent down, they say: nay! we shall follow that which we found our fathers upon. What! even though the Satan had been calling on them unto the torment of the Blaze.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
And whosoever submitteth his countenance unto Allah and he is a well doer, he hath of a surety lain hold of the firm cable. Unto Allah is the end of all affairs.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whosoever disbelieveth, let not his unbelief grieve thee. Unto Us is their return, and We shall declare unto them that which they have worked. Verily Allah is the Knower of that which is in the breasts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We let them enjoy for a while, and then We shall drive them to a torment rough.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And wert thou to ask them: who hath created the heavens and the earth they will surely say: Allah. Say thou: All praise unto Allah! But most of them know not,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
Allah's is whatsoever is in the heavens and the earth. Verily Allah! He is the Self-sufficient, the Praiseworthy.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if whatever trees there are on the earth were pens, and the sea were ink with seven more seas to help it, the words of Allah could not be exhausted; verily Allah is Mighty, Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
And your creation and your upraising are only as though of one soul; verily Allah is Hearing, Beholding.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Observest thou not that Allah plungeth the night into the day and plungeth the day into the night and hath subjected the sun and the moon, each running unto an appointed term, and that Allah is of that which ye work Aware.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because Allah! He is the Truth, because whatsoever they call upon beside Him is falsehood, and because He is the Exalted, the Grand.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Observest thou not that the ship saileth in the sea by the favour of Allah that he may shew you of His signs? Verily therein are signs for every persevering, grateful heart.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And when a wave covereth them like awnings, they call upon Allah, making their religion pure for Him. Then when He delivereth them on the land, only some of them keep to the middle course. And none gainsaith Our signssave each perfidious, ingrate one.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
Mankind! fear your Lord and dread a Day whereon no father shall atone for his son, and no son shall atone for his father at all. Verily the promise of Allahs is true. Let not the life of the world beguile you, and let not the great beguiler beguile you in regard to Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Verily Allah! with Him alone is the knowledge of the Hour, and He it is who sendeth down the rain and knoweth that which is in the wombs: and no person knoweth whatsoever it shall earn on the morrow, and a person knoweth not in whatsoever land he shall die. Verily Allah is Knowing, Aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif. Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
Revelation of this Book, whereof there is no doubt, is from the Lord of the Worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Will they say: he hath fabricated it? Aye! it is the truth from thy Lord, that thou mayest warn therewith a people unto whom no warner came before thee, that haply they may be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
Allah it is Who created the heavens and the earth and whatsoever is betwixt the twain in six days, and then He established Himself on the throne. No patron have ye nor an intercessor, besides Him. Will ye not then be admonished?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He disposeth every affair from the heaven unto the earth; thereafter it shall ascend unto Him in a Day the measure whereof is one thousand years of that which ye compute.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
Such is the Knower of the unseen and the seen, the Mighty, the Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
Who hath made everything exceeding good which He hath created. And He originated the creation of man from clay;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then He made his progeny from an extract of water base.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He fashioned him and breathed into him something of a spirit from Him; and He ordained for you hearing and sight and hearts. Little is the thanks ye return.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say: when we are vanished in the earth, shall we then be raised in a new creation? Aye! in the meeting with their Lord they are disbelieving.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say thou: the angel of death who is set over you shall cause you to die, thereafter unto your Lord ye shall be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
Couldst thou but see when the culprits shall hang their heads before their Lord, saying: our Lord! we have now seen and heard; so send us back; we shall work righteously, verily we are convinced.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And had We listed surely We could have given every soul its guidance; but true must be the word from Me; I shall surely fill Hell with the Jinn and mankind together.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So taste ye the sequel, for as much as ye forgat the meeting of this your day, verily We have forgotten you. Taste the torment abiding for that which ye have been working.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
They alone believe in Our revelations who, when they are reminded thereof, fall down prostrate and hallow the praise of their Lord, and they are not stiff-necked.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides leave off the couches calling upon their Lord in fear and in desire, and of that wherewith We have provided them they expend.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No soul knoweth that which is kept hidden for them of perfect comfort as a recompense for that which they have been working.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Shall he, therefore, who is a believer, be like unto him who is a transgressor? They are not equal.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
And as for those who believe and work rigteous works--for them are Gardens of Abode: an entertainment for that which they have been working.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
And as for those who transgress their abode is the Fire. So oft as they desire to get thereout, they shall be sent back thereto; and it will be said unto them: taste the torment of the Fire which ye were wont to belie.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And surely We shall make them taste of the smaller torment prior to the greater torment, that haply they may yet return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who is a greater wrong-doer than he who is reminded of His signs, then he turneth aside therefrom? Verily unto the culprits We are going to be Avenger.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
Assuredly We vouchsafed the Book Unto Musa; so be thou not in doubt in thy receiving it. And We appointed it to be a guidance unto the Children of Is'rail.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We appointed, from amongst them, leaders guiding others by Our command, when they had persevered, and of Our signs they were convinced.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Verily thy Lord! He shall decide between them on the Day of Judgment concerning that wherein they have been differing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Hath this not guided them: how many generations We have destroyed before them amidst whose dwellings they walk? Verily therein are signs; will they not therefore hearken?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Observe they not that We drive water unto a land bare, and bring forth therewith crops whereof their cattle and they themselves eat? Will they not therefore be enlightened?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
And they say: When will this Decision arrive if ye are truthtellers?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say thou: on the day of the Decision their belief will not profit those who have disbelieved; nor will they be respited.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
Wherefore turn aside thou from them, and await; verily they are awaiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet! fear Allah and obey not the infidels and the hypocrites; verily Allah is ever Knowing, Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow that which is revealed to thee from thy Lord; verily Allah is of that which ye Work ever Aware.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put thy trust in Allah and Allah sufficeth as a Trustee.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah hath not placed unto any man two hearts in his inside, nor hath He made your spouses whom ye declare to be as your mother's backs, your real mothers, nor hath He made your adopted sons your real sons. This is only your saying by your mouths, whereas Allah saith the truth and He guideth the way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them by their fathers: that will be most equitable in the sight of Allah. And if ye know not their fathers then they are your brethren in religion and your friends. And there is no fault upon you in regard to the mistake ye have made therein, but in regard to that which your hearts intend purposely. And Allah is ever Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is nigher unto the believers than themselves, and his wives are their mothers. And kinsmen are nigher one to another in the ordinance of Allah than other believers and the emigrants except that ye may act reputably unto your friends. This hath been written in the Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And recall what time We took a bond from the prophets and from thee and from Nuh and Ibrahim and Musa and 'Isa son of Maryam. And We took from them a solemn bond;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That he may question the truthful of their truth. And for the Infidels He hath gotten ready a torment afflictive.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O Ye who believe! remember Allah's favour unto you when there came unto you hosts, and We sent against them a wind and hosts which ye saw not, and Allah was of that which ye were working a Beholder.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you from above you and from below you, and when eyes turned aside and hearts reached to the gullets, and of Allah ye were imagining various things.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There were the believers proven and shaken with a mighty shaking\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when the hypocrites and those in whose hearts is disease were saying: Allah and His apostle have promised us nought but delusion.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said: O inhabitants of Yathrib! there is no place for you, so return. And a part of them asked leave of the Prophet, saying: verily our houses lie open; whereas they lay not open; they only wished to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if they were to be entered upon from the sides thereof and they were asked to sedition, they would surely have committed it, and they would have tarried therein but slightly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And arruredly they had already covenanted with Allah that they would not turn their backs; verily the covenant with Allah must be questioned about.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say thou: flight shall not profit you if ye flee from death or slaughter, and lo! ye will not enjoy life except for a little.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say thou: who is there that will protect you from Allah if He intendeth to bring evil on you or intendeth mercy for you? And they shall not find for themselves, besides Allah, a patron or helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Surely Allah knoweth those among you who hinder and those who say unto their brethren: come hither unto us; and they themselves come not to the battle save a ittle,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Being niggardly toward you. Then when the fightin cometh, thou beholdest them look unto thee, their eyes rolling about, like the eyes of him who fainteth unto death. Then when the fighting is over they inveigh against you with sharp tongues, being niggardly of the good things. These have not believed; wherefore Allah hath made their works of none effect, and that is with Allah ever easy.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They deem that the confederates have not yet departed; and if the confederates should come, they would fain to be in the desert with the wandering Arabs inquiring for tidings of you. And if they happen to be amongst you, they would fight but little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Assuredly there hath been for you: in the apostle of Allah an excellent pattern for him who hopeth in Allah and the Last Day and remembereth Allah much.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the believers saw the confederates, they said: this is that which Allah and His apostle had promised us; and Allah and His apostle had spoken the truth. And it only increased them in belief and in self-surrender.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Of the believers are men who have fulfilled that which they covenaned with Allah. Some of them have performed their vow, and some of them are waiting, so and they have not changed in the least.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
All this happened in order that Allah may recompense the truthful for their truth, and may punish the hypocrites if He would, or relent toward them. Verily Allah is ever Forgiving, Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah drave baCk those who disbelieved in their rage; they obtained no advantage, and Allah sufficed for the believers in the fighting; and Allah is ever Strong, Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought those of the people of the Book who backed them down from their fortresses and cast into their hearts terror; a part of them ye slew, and ye made captives a part.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He caused you to inherit their land and their houses and their riches, and land which ye have not yet trodden. And Allah is over everything ever potent.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
Prophet! say unto thy wives: if it be that ye seek the world's life and the adornment thereof, then come I shall make a provision for you and I shall release you with a handsome release.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
And if ye seek Allah and His apostle and the abode of the Hereafter, then verily Allah hath gotten ready for the well-doers among you a mighty hire.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O Ye wives of the Prophet! whosoever of you shall commit a manifest Indecency, doubled for her would be the punishment twice over; and with Allah that is easy.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whosoever of you shall be obedient unto Allah and His apostle and shall work righteously, her hire We shall give her twice over, and We have gotten ready for her a generous provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
wives of the prophet! ye are not like any others of women, if ye are God-fearing. So be not soft in speech, lest one in whose heart is disease should be moved with desire, bun speak a reputable speech.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay in Your houses. and display not yourselves! with the display of the times of former Paganism; and establish the prayer and give the poor-rate and obey Allah and His apostle. Allah only desireth to take away uncleanness from you, people of the house-hold, and to purify you with a thorough purification.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And bear in mind that which is rehearsed in your homes of the revelations of Allah and the wisdom. Verily Allah is ever Subtile, Aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Verily the Muslim men and Muslim women, and the believing men and the believing women, and the devout men and the devout women, and the men of veracity and the women of veracity, and the persevering men and the persevering women, and the men of humility and the women of humility and the almsgiving men and the almsgiving women, and the fasting men and the fasting women, and the men who guard their modesty and the women who guard their modesty, and the Allah-remembering men and the Allah remembering women: Allah hath gotten ready for them forgiveness and mighty hire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
And it is not for a believing man or a believing woman, when Allah and His apostle have decreed an affair, that they should have any choice in their affair. And whosoever disobeyeth Allah and His apostle hath strayed with a manifest straying.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And recall what time thou wast saying unto him on whom Allah had conferred favour and thou hadst conferred favour: keep thy wife to thyself and fear Allah; so and thou wast concealing in thy mind that which Allah was going to disclose, and thou wast fearing mankind, whereas Allah had a better right that Him thou shouldst fear. Then when Zaid had performed his purpose concerning her, We wedded her to thee, that there should be no blame for believers in respect of wives of their adopted sons, when they have performed their purpose concerning them. And the ordinance of Allah was to be fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
No blame there is upon the Prophet in that which Allah hath decreed for him. That hath been Allah's dispensation with those who have passed away afore - and the ordinance of Allah hath been a destiny destined\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Those who preached the messages of Allah and feared Him, and feared none save Allah; and Allah sufficeth as a Reckoner.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your males, but the apostle of Allah and the seal of the prophets; and Allah of everything is ever the Knower.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O Ye who believe! remember Allah with much remembrance.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And hallow Him morning and evening.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
He it is Who sendeth His benedictions to you and His angels also that he may bring you forth from darknessess into light; and unto the believers He is ever Merciful.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting on the Day whereon they meet Him will be: peace. And He hath gotten ready for them a generous hire.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
Prophet! verily We have sent thee a witness and a bearer of glad tidings and a warner.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And a summoner unto Allah by His command and an illuminating lamp.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And bear thou unto the believers the glad tidings that theirs is from Allah a great grace.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And obey thou not the infidels and the hypocrites, and heed not their annoyances, and trust in Allah; and Allah sufficeth as a Trustee.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O Ye who believe! when ye marry believing women and then divorce them before ye have touched them, then there is no waiting-period from you incumbent on them that ye should count. So make provision for them and release them with a seemly release.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet! verily We have allowed unto thee thy wives unto whom thou hast given their hires, and also those whomsoever thy right hand ownEth of those whomsoever Allah hath given thee as spoils of war, and the daughters of thy paternal uncle, and the daughters of thy paternal aunts, and the daughters of thy maternal uncle, and the daughters of thy maternal aunts, who migrated with thee, and any believing woman, when she offereth herself unto the Prophet if the Prophet desire to wed her --purely for thee, above the rest of the believers. Surely We know that which We have ordained unto them concerning their wives and those whom their right hands won: in order that there may be no blame upon thee: And Allah is ever Forgiving, Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Thou myest put off such of them as thou wilt, and thou mayest take unto thee such of them as thou wilt; and whomsoever thou desirest if such as thou hadst set aside there is no blame upon thee. This is likelier to cool their eyes and not let them grieve and to keep them pleased with whatsoever thou shalt give every one of them. Allah knoweth that which is in your hearts. and Allah is ever Knowing, Forbearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Women are not allowed unto thee henceforth, nor mayest thou change them for other wives although their beauty please thee, save those whom thy right hand shall own; and Allah is ever over everything a Watcher.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O Ye who believe! enter not the houses of the Prophet, except when leave is given you, for a meal and at a time that ye will have to wait for its preparation; but when ye are invited, then enter, and when ye have eaten, then disperse, without lingering to enter into familiar discourse. Verily that incommodeth the Prophet, and he is shy of asking you to depart, bur Allah is not shy of the truth. And when ye ask of them aught, ask it of them from behind a curtain. That shall be purer for your hearts and for their hearts. And it is not lawful for you that ye should cause annoyance to the apostle of Allah, nor that ye should ever marry his wives after him; verily that in the sight of Allah shall be an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether ye disclose a thing or conceal it, verily Allah is of everything ever Knower.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It is no sin for them in respect to their fathers or their brothers, or their brothers sons, or their sisters sons, or their own women, or those whom their right hands own; and fear Allah; verily Allah is of everything ever a Witness.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Verily Allah and His angels send their benedictions upon the prophet. O ye who believe! send your benedictions upon him and salute him with a goodly Salutation.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Verily those who annoy Allah and His apostle, --Allah hath cursed them in the world and the Hereafter, and hath gotten ready for them a torment Ignominious.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who annoy the believing men and the believing women, without their earning it, shall surely bear the guilt of calumny and manifest sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! say unto thy wives and thy daughters and women of the believers that they should let down upon them their wrapping- garments. That would be more likely to distinguish them so that they will not be affronted. And Allah is ever Forgiving, Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites and those in whose hearts is a disease and the raisers of commotion in Madina desist not, We shall surely set thee up against them; thenceforth they shall not be suffered to neighbour thee therein except for a little while.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed; wherever found they shall be laid hold of and slain with a relentless slaughter.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
That hath been the dispensation of Allah with those who have passed away afore; and thou shalt not find in the dispensation of Allah any change.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask thee ccncerning the Hour. Say thou: the knowledge there of is only with Allah: and what knowest thou! --belike the Hour is nigh.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Verily Allah hath cursed the infidels, and hath gotten ready for them a Blaze.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Abiders therein they shall be for ever, and they shall find neither a protecting friend nor a helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On the Day whereon their faces shall be rolled in the Fire, they will say: Oh that we had obeyed Allah and had obeyed the apostle!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say: our Lord! verily we obeyed our chiefs and our great ones, and they led us astray from the way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord! give them double torment and curse them with a great curse.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O Ye who believe! be not like unto those who annoyed Musa; but Allah cleared him of that which they said, and he was in the sight of Allah illustrious.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O Ye who believe! fear Allah, and speak a straight speech.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He WiLL rectify for you your works, and forgive you your sins. And Whosoever obeyeth Allah and His apostle, he hath indeed achieved a mighty achievement.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
Verily We! We offered the trust unto the heavens and the earth and the mountains, but they refused to bear it and shrank therefor. And man bore it; verily he was very iniquitous and very ignorant-\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
So that Allah will torment the hypocritical men and the hypocritical women and the associators and the associatoresses and Allah will relent toward believing men and the believing women; and Allah is ever Forgiving, Merciful\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen All praise Unto Allah whose is whatsoever is in the heavens and whatsoever is in the earth; and His is the praise in the Hereafter And He is the Wise, the Aware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knoweth whatsoever penetrateth into the earth and whatsoever cometh forth therefrom and whatsoever descendeth from the heaven and whatsoever ascendeth thereto. And He is the Merciful, the Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
Those who disbelieve say: the Hour will not come Unto us. Say thou: yea, by my Lord the Knower of the unseen, it will surely come Unto you. Not the weight of an atom escapeth Him in the heavens or in the earth; nor is there anything less than it nor greater but it is inscribed in a Luminous Book\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may recompense these who believed and worked righteous works. Those! theirs shall be forgiveness and a generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
And those who endeavoured to frustrate Our signs - those! theirs shall be a torment of afflictive calamity.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And who have been vouchsafed knowledge beholding that the Book which hath been sent down Unto thee from thy Lord, - it is the truth and it guideth Unto the path of the Mighty, the Praiseworthy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
And those who disbelieve say: shall we direct you toward a man declaring Unto you that when ye have become dispersed" with full dispersion, then ye will be raised Unto a new creation?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Hath he fabricated a lie against Allah, or is therein him a madness? Nay, but those who disbelieve in the Hereafter are themselves in a torment and error far-reaching:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Behold they not that which is before them and that which is behind them of the heaven and the earth If We will, We shall sink the earth with them or cause a fragment of the heaven to fall on them. Verily therein is a sign Unto every repentant bondman.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And assuredly We vouchsafed Unto Da'ud grace from us,' and said: mountains! repeat Our praise with him; and also ye birds! And We softened for him the iron.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
Saying: make thou complete coats of mail, and rightly dispose the links, and work ye, righteously; verily I am of that which Ye work a Beholder.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And Unto Sulaiman We subjected the wind, whereof the morning journeying was a month and the evening journeying a month. And We made a fount of brass to flow for him. And of the Jinn were some who worked before him by the Will Of his Lord. And whosoever of them swerved from Our command, him We shall cause to taste the torment of the Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They worked for him whatsoever he pleased, of lofty halls and statues and basins like cisterns and cauldrons Standing firm. Work ye, house of Da'ud! with thanksgiving; few of My bondmen are thankful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
Then when We decreed death for him, naught discovered his death to them' save a moving creature of the earth which gnawed away his staff. Then when he fell, the Jinn clearly perceived that, if they had known the unseen they would not have tarried in the ignominious torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
Assuredly there was for Saba a sign in their own dwelling- place: two gardens on the right hand and on the left. And it was said Unto them: eat ye of the provision of your Lord and give thanks Unto Him: a fair land' and a forgiving Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away. Wherefore We sent upon them the inundation of the dam and We exchanged their two gardens for two gardens bearing bitter fruit, and tamarisk. And some few lote-trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
In this wise We requited them for they were ungrateful. And We requite not thus any save the ungrateful infidels.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We had placed between them and the cities" which We had blest cities easy to be seen, and We had made the stages of journey between them easy:" travel in them nights and days secure.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
Then they said: Our Lord make the distance between our journeys longer. And they wronged themselves. Wherefore We made them by words and dispersed them with a total dispersion. Verily herein are signs for every persevering, grateful persons.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And assuredly Iblis found his conjecture true concerning them; and they followed him all save a party of the believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And he hath no authority over them except that We would know him who believeth in the Hereafter from him who is in doubt thereof. And thy Lord is over everything a Warden.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say thou: call upon those whom ye assert beside Allah. They own not an atom's weight either in the heavens or in the earth, nor have they any partnership in either, nor is there for Him from among them any supporter.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
lntercession with Him profiteth not save the intercession of him whom He giveth leave. They hold their peace until when fright is taken off from their hearts, they say: What is it that your Lord hath said? They say: the very truth. And He is the Exalted, the Great.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say thou: who provideth food for you from the heavens and the earth? Say thou: Allah; verily either we or ye are on the guidance or in error manifest.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say thou: ye will not be questioned about that which we have committed, nor shall we be questioned about that which ye work.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say thou: our Lord shall assemble us together, then He shall judge between us with truth; and He is the Great Judge, the Knower.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say thou: show me those whom ye have joined with Him as associates. By no means! Aye! He is Allah, the Mighty, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And We have not sent thee save as a bearer of glad tidings and a warner Unto all mankind; but most of man kind know not.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say: when is this promise to be fulfilled if ye say sooth?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say thou: the appointment to you is for a Day which ye cannot put back for one hour nor can ye anticipate.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And those who disbelieve say: we shall by no means believe in this Qur'an nor in that which hath been before it. Would that thou couldst see when the wrong-doers shall be made to stand before their Lord! They shall cast back the word one to another; those who were deemed weak will say Unto those who were stiff-necked: had it not been for you, surely we should have been believers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those who were stiff-necked will say Unto those who were deemed weak: was it we who prevented you from the guidance after it had come Unto you? Aye! ye have been guilty yourselves.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
And those who were deemed weak will say Unto those who were stiff necked: aye, it was your plotting by night and by day, When ye were commanding us that we should disbelieve in Allah and set up peers Unto Him. And they Will keep secret their shame when they behold the torment. And We shall place shackles on the necks of those who disbelieved. They shall be requited not save according to that which they had been working.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And We sent not a warner Unto a town but the affluent thereof said:' verily in that wherewith ye have been sent we are disbelievers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they said: we are more numerous in riches and children, and we are not going to be tormented.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say thou: verily my Lord expandeth the provision for whomsoever He will and stinteth it; but most of mankind know not.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And it is not your riches nor your children that shall draw you nigh Unto us with a near approach, but whoso ever believeth and worketh righteously- then those! theirs shall be a twofold meed for that which they will have worked, and they will be in upper apartments secure.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And those who endeavour to frustrate Our signs, Unto the torment they will be brought.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say thou: verily my Lord expandeth the provision for whomsoever He listeth of His bondmen, and stinteth it for him. And whatsoever ye expend of aught He shall replace it. And He is the Best of Providers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And on the Day whereon He gathereth them together, then He will say Unto the angels: was it ye that these were wont to worship?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say: hallowed be Thou! Thou art our protecting friend, not they; Aye! they have been worshipping the jinn; In them most of them were believers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
To-day ye own not for one another either benefit or hurt. And We shall say Unto those who did wrong: taste the torment of the Fire which ye were wont to belie.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when there are rehearsed Unto them Our plain revelations, they this messenger is naught but as a man who seeketh to prevent you from that which your fathers have been worshipping. And they say: this message is naught but a fraud fabricated. And those who disbelieve say of the truth When it is come Unto them: this is naught but manifest magic.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We had not vouchsafed Unto them Books they should have been studying, nor had We sent Unto them, before thee, any warner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And those before them belied; and these have not arrived Unto a tithe of that which We vouchsafed Unto them. But they belied My apostles. So how terrible was My disapproval\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say thou: I but exhort you Unto one thing: that ye stand, for Allah's sake, by twos and singly, and then ponder; in your companion there is no madness; he is naught but a warner Unto you preceding a torment severe.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say thou: whatsoever hire might have asked of you is yours; my hire is with Allah only. And He is of everything a Witness.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say thou: verily my Lord hurleth the truth: the Knower of things hidden.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say thou: the truth is come, and falsehood shall neither originate nor be restored."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say thou: if ever I go astray, I shall stray only against myself, and if I remain guided it is because of that which my Lord hath revealed Unto me. Verily He is Hearing, Nigh.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
And couldst thou see the time when they shall be terrified! Then there shall be no escaping, and they shall be laid hold of from a place quite nigh.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And then they will say: we believe therein. But whence can there be the attainment of faith from a place so afar.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
Whereas they disbelieved therein afore, and conjectured about the unseen from a place so afar.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And they will be shut off from that which they will eagerly desire, as shall be done with the likes of them of yore. Verily they have been in doubt perplexing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen All praise Unto Allah, the Creator Of the heavens and the earth, the Appointer of the angels as His messengers, with wings of twos and threes and fours. He addeth in creation what soever He listeth Verily Allah is over everything Potent.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatsoever of mercy Allah may grant Unto mankind none there is to withhold it; and whatsoever He may with hold none there is to release it thereafter. And He is the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O mankind! remember the favour of Allah toward you. Is there any Creator other than Allah who provideth for you from the heaven and the earth? There is no god but He. Wither then are ye deviating?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they belie thee, then surely apostles have been belied before thee. And Unto Allah shall be brought back all affairs.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O mankind! verily the promise of Allah is true. So let not the life of the world beguile you, and with respect to Allah let not beguile you the great be guiler.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Verily the Satan is an enemy Unto you, wherefore hold him for an enemy; he only calleth his confederates that they become of the fellows of the Blaze.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve - theirs shall be a torment severe; and those who believe and work righteous works, - theirs shall be forgiveness and a great hire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Is he, then, whose evil work hath been made fair-seeming unto him, so that he deemeth it good, be as he who rightly perceiveth the truth? Verily Allah sendeth astray whomsoever He listeth, and guideth whomsoever He listeth; so let not thine soul expire after them in sighings; verily Allah is the Knower of that which they perform.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And it is Allah Who sendeth the winds, and they raise a cloud; then We drive it unto a dead land and We quicken thereby the earth after the death thereof. Even so shall be the Resurrection.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whosoever desireth glory, then all glory is Allah's; unto Him mount up the goodly words; and the righteous works exalteth it. And those who plot evils,--theirs shall be a torment severe; and the plotting of those!--it shall perish.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah created you of dust, then of a seed; then He made you pairs. No female beareth or bringeth forth but with His knowledge. And no aged man growth old, nor is aught diminished of his life, but it is in a Book; verily for Allah that is easy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And the two seas are not alike: this, sweet, thirst- quenching, pleasant to drink; and that, saltish and bitter. And yet from each ye eat flesh fresh and bring forth the ornaments that ye wear. And thou seest therein ships cleaving the water, that ye may seek of His graCe, and that haply ye may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He plungeth the night into the day and He plungeth the day into the night, and He hath subjected the sun and moon, each running till an appointed term. Such is Allah, your Lord; His is the dominion; and those whom ye call on besides Him own not even the husk of a date-stone.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If ye call Unto them, they hear not your calling, and even if they heard, they could not answer you. On the Day of Judgment they will deny your associating. And none can declare Unto thee the truth like Him who is Aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O mankind! ye are needers Unto Allah, and Allah! He is the Selfsufficient, the Praiseworthy\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He will, He can take you away and bring about a new creation."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And with Allah that shall not be hard.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And a bearer of burthen will not bear another's burthen, and if one heavy-laden calleth for his load, naught thereof will be borne although he be of kin. Thou canst warn only those who fear their Lord, unseen, and establish prayer. And whosoever becometh clean becometh clean only for himself; and Unto Allah is the return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not alike are the blind and the seeing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Neither darknesses and light,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
- Nor the shade and the sun's heat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor alike are the living and the dead. Verily Allah maketh whomsoever He listeth to hear and thou canst not make them hear who are in the graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
Thou art naught but a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Verily We! We have sent thee with the truth, as a bearer of glad tidings and as a warner; and there is not a community but there hath passed among them a warner.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they belie thee, then surely those before them have also belied. Their apostles came Unto them with evidences and scriptures and a Book luminous.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I took hold of those who disbelieved. So how terrible was My disapproval!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Beholdest thou not that Allah sendeth down water from the heaven, and then We thereby bring fruit of diverse colours? And in the mountains are steaks white and red, of diverse colours, and also intensely black.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And of men and beasts and cattle, likewise of diverse colours. Those only of His bondmen who have knowledge fear Allah Verily Allahis the Mighty, the Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Verily those Who read the book of Allah and establish prayer and expend of that wherewith We have provided them, secretly and in open, hope for a merchandise that shall not perish.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
That He may pay them their hires in full and increase Unto them of His grace; verily, He is Forgiving, Appreciative.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And that which We have revealed Unto thee of the Book - it is the very truth confirming that which hath been before it; verily, Allah is Unto His servants Aware, Beholding.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Thereafter We made inheritors of the book those whom We chose of Our bondmen. Then of them are some who wrong themselves, and of them are some who keep the middle way, and of them are some who, by Allah's leave, go ahead in virtues. That! that is a great grace.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
Gardens Everlasting! these they Shall enter, wearing therein bracelets of gold and pearls, and their raiment therein shall be of silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will Say: all praise Unto Allah who hath taken away grief from us. verily, our Lord is Forgiving, Appreciative.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
Who hath, through His grace, lodged us in the abode of permanence, wherein there will not touch us tall, and wherein there will not touch us weariness.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
And those who disbelieve-for them shall be Hell-Fire. It shall not be decreed to them that they should die, nor shall the torment thereof be lightened for them. Thus We requite Every ingrate.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
And they will be shouting therein: our Lord! take us out; we shall work righteously, not that which we have been working. Gave We not you lives long enough so that whosoever would receive admonition could receive admonition therein? and there came Unto you a warner; taste therefore and for the wrong-doers there will be no helper.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Verily Allah is the Knower of the unseen of the heavens and the earth. Verily, He is the Knower of that which is in the breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
He it is who hath made you successors in the earth. So whosoever disbelieveth, on him will befall his infidelity. And for the infidels their infidelity increaseth with their Lord naught save abhorence. And for the infidels their infidelity increastth naught save loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say thou: what bethink ye of your associate-gods upon which ye call besides Allah? Show me whatsoever they have created of the earth. Or, have they7 any partnership in the heavens? Or have We vouchsafed to them a Book so that they stand on an evidence therefrom? Nay! the wrong-doers promise each other only delusions.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Verily Allah withholdeth the heavens and the earth lest they cease; and should they cease, not any one could withhold them after Him. Verily He is ever Forbearing, Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And`they swear by God with a most solemn oath, that if there came a warnet Unto them, they would surely be better guided than any of the other communities. Then when there did come Unto them a warner, it increased in them naught save aversion,-\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
Through their stiff-neckedness in the land, And the plotting of evil only infoldeth the authors thereof. Wait they, then, but the dispensation of the ancients? And thou wilt not find in dispensation of Allah a change, nor wilt thou find in dispensation of Allah a turning off\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not travelled on the earth, so that they might see what wise hath been the end of those before them. although they were stronger than these in Power? And Allah is not such that aught in the heavens and the earth can frustrate him. Verily, He is ever the Knowing, the potent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
Were Allah to take mankind to task for that which they earn, He would not leave a moving creature on the back thereof; but He putteth them off until a term appointed; then when their term cometh, - then, verily Allah is ever of His bondmen a Beholder.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya-Sin.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Qur'an full of wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Verily thou art of the sent ones,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
upon the straight path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
This is a revelation of the Mighty, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
That thou mayest warn a people whose fathers were not warned; so they are negligent.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Assuredly the word hath been justified against most of them, wherefore they shall not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Verily We have placed on their necks shackles which are up to the chins; so that their heads are forced up.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have placed before them a barrier and behind them a barrier, so We have covered them, so that they see not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
And it is alike Unto them, whather thou warnest them or warnest them not; they shall not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
Thou canst warn only him who followeth the admonition and feareth the Compassionate, unseen. So bear thou Unto him the glad tidings of forgiveness and a generous hire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Verily We! We shall guicken the dead. And We write down that which they send before and their footsteps. And everything We have counted up in a Book luminous.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And propound thou Unto them the similitude of the inhabitants of a town, When there came thereto the sent ones;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
What time We sent Unto them two, then they belied the twain, wherefore We strengthened them with a third, and they said: verily we are Unto you the sent ones.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said: ye are but human beings like ourselves; the Compassionate hath not sent down aught; ye are only lying.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said: our Lord knoweth that we are surely Unto you the sent ones.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
And on us is naught but manifest preaching.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They said: verily we augur ill of you; if ye desist not, we shall surely stone you, and there will befall you from us a torment afflictive.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said: your evil augury be with you. Call ye it an ill- luck because ye are admonished! Aye! ye are a people extravagant.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And there came from the farthest part of the town a man running. He said; O my people! follow the sent ones.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
Follow those who ask not of you any hire, and who are rightly guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
And what aileth me that I should not worship Him who hath created me, and Unto whom ye shall be returned.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
Shall I take beside Him gods when, if the Compassionate should intend me any harm, their intercession will avail me not at all, nor would they save me?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Verily then I should be in error manifest.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
Verily I believe now in your Lord; so hearken Unto me."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said: enter thou the Garden. He said: would that my people knew.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
That my Lord hath forgiven me, and hath made me of the honoured ones.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We sent not against his people after him a host from heaven, nor have We been sending down any such.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was but one shout, and lo! they were extinct.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Ah the misery of the bondmen! there cometh not: Unto them an apostle but him they have been mocking.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Behold they not how many We have destroyed before them of the generations! verily Unto them they shall not return.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
And surely all, every one of them, shall be brought before us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign Unto them is the dead land. We quicken it and therecut We bring forth grain, so that thereof they eat.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We place therein gardens of the date-palms and vines; and We therein cause to gush forth springs.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
That they may eat of the fruit thereof; and their hands worked it not. Will they not, therefore, give thanks?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Hallowed be He who hath created all the pairs of that which the earth groweth, and of themselves and of that which they know not!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign Unto them is the night. We draw off the day therefrom, and lo! they are darkened.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runneth to its appointed term: that is the disposition of the Mighty, the Knowing."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon! For it We have decreed mansions till it reverteth like the old branch of a palm-tree.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not permitted to the sun that it should overtake the moon, nor can the night outstrip the day: each in an orbit, they float.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a sign Unto them is that We bear their offspring in a laden ship.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them of the like thereUnto whereon they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We list, We shall drown them, and there will be no shout for them, nor will they be saved.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
unless it be a mercy from us, and as an enjoyment for a season.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
And when it is said Unto them: fear that which is before you and that which is behind you, that haply ye may find mercy, they withdraw.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
And not a sign cometh Unto them of the signs of their Lord, but they are ever backsliders therefrom.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said Unto them: expend of that wherewith Allah hath provided you, those who disbelieve say Unto those who believe: shall we feed those whom God Himself would have fed, if He listed? Ye are in naught else than error manifest.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say: when will this promise be fulfilled if ye say sooth?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await not but one shout, which shall lay hold of them while they are yet wrangling.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
And they will not be able to make a disposition, nor to their family they return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the trumpet shall be blown, and lo! from the tombs Unto their Lord they shall be hastening.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say: Ah woe Unto us! who hath roused us from our sleeping-place? This is that which the Compassionate had promised, and truly spake the sent ones.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It shall be but one shout; and lo! they shall all be brought together before us.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
To-day no soul will be wronged at all; nor shall ye be requited but for that which ye have been working.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Verily the fellows of the Garden to-day shall be happily employed.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their spouses, in shade on couches shall be reclining.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
Theirs shall be fruit therein and theirs shall be whatsoever they ask for.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
Peace shall be the word from the Lord Merciful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
And separate yourselves this Day, O ye culprits!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Enjoined I not on you, ye children of Adam, that ye shall not worship the Satan - verily he is Unto you manifest foe.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
And that: ye shall worship Me; this is the straight path?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
And yet assuredly he hath led astray of you a great multitude. Wherefore reflect ye not?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
Yonder is Hell, which ye were promised.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Roast therein To-day for that ye have been disbelieving.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
To-day We shall seal upon their mouths, and their hands will speak Unto us, and their feet will bear witness of that which they have been earning.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And if We listed, surely We should wipe out their eyes so that they would struggle for the way how then would they see?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if We listed, surely We should transform them in their places, so that they would be able neither to go forward nor to return\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And whomsoever We grant long life, We reverse him in creation. Reflect then they not?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We have not taught him poetry, nor it befitteth him. This is but an admonition and a Recital luminous:\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
In order that it may warn him who is alive, and that the sentence may be justified on the infidels.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Observe they not that We have created for them, of that which Our hands have worked, cattle: so that they are their owners.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And We have subdued them Unto them, so that some of them they have for riding and on some of them they feed?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And they have therefrom other benefits and drinks. Will they not then give thanks?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And they have taken beside Allah gods, hoping that haply they may be succoured.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They are not able to give them succour; whereas they shall be against them host brought forward.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So let not their speech grieve thee. Verily We! We know whatsoever they keep secret and whatsoever they make known.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Beholdest not man that We have created him from a sperm? Yet lo! he is a manifest disputer?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he propoundeth for us a similitude, and forgetteth his creation, He saith: who shall quicken the bones when they are decayed?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say thou:" He shall quicken them Who brought them forth for the first time, and He is of every kind of creation the Knower!\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
Who giveth you out of the green tree fire, and lo! ye kindle therewith.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He who created the heavens and the earth able to create the like of these? Yea! He is the Supreme Creator, the Knower.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
His affair, when He intendeth a thing, is only that He saith Unto it: be, and it becometh.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
Wherefore hallowed be He in whose hand is the governance of everything, and Unto whom ye shall be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By the angels ranged in ranks.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
By the angels driving away.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
By the angels reciting the praise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Verily your God is One.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and the earth and whatsoever is in- between the twain, and Lord of the easts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
Verily We! We have adorned the nearest heaven with an adornment: the stars.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And have placed therein a guard against any Satan froward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot listen to the exalted assembly, and they are darted at from every side.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
With a driving fusillade, and theirs shall be a torment perpetual;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except him who snatcheth away a word by stealth, and him then pursueth a glowing flame.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Ask them thou: are they stronger in structure or those others whom We have created? Verily We! We have created them of a sticky clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Aye! thou marvellest, and they scoff.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And when they are admonished, they receive not admcnition.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And when they behold a sign, they turn to scoffing.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say: this Qur'an is naught but magic manifest.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
When we have become dead and have become dust and bones, shall we then verily be raised?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
And also our forefathers?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say thou: and verily ye; shall then be despicable.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It shall be but one shout, lo! they shall be staring.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
And they will say: Ah! woe be Unto us! this is the Day of Requital.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
This is the Day of Judgment which ye were wont to belie.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
Gather together those who did wrong and their comrades and that which they were wont to worship\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
Beside Allah, and lead them on to the path of the Flaming Fire.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And stop them; verily they are to be questioned:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
What aileth you that ye succour not one another?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Nay! on that Day they will be entirely submissive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And they will advance toward each other mutually questioning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say: verily ye! ye were wont to come Unto us Imposing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will say: nay! ye yourselves were not believers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
And we had over you no authority, but ye were a people exorbitant.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
So on us hath been justified the sentence of our Lord: verily we are to taste.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
We seduced you astray; verily we were ourselves the seduced ones.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
So verily on that Day they all in the torment will be sharers.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Verily We! in this wise We deal with the culprits.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Verily when it was said Unto them: there is no god but Allah, they ever grew stiff-necked.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And they said: are we going to abandon our gods on account of a Poet distracted?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Aye! he hath come with the truth, and he confesseth to the sent ones.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Verily ye are going to taste a torment afflictive.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
And ye shall be required not except for that which ye have been doing;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
But the bondmen of Allah, the sincere ones -\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
Those! theirs shall be a provision known:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits! And they shall be honoured.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In Gardens of Delight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
On couches, facing one another.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
Round shall be passed a cup Unto them filled with limpid drink:\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White, a pleasure Unto the drinkers.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
No headiness there shall be therein, nor shall they be therewith Inebriated.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them shall be damsels of refraining looks, large- eyed\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
As though they were eggs hidden.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then they will advance Unto each other, mutually questioning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
And a speaker from among them will say: verily there was Unto me a mate.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
Who said: art thou of those who confess to the doctrine of Resurrection:\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
When we are dead and have become dust and bones, are we indeed going to be requited?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
Allah will say: will ye look down?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
Then he will look down and see him in the midst of the Flaming Fire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
And he will say: by Allah, thou hadst wellnigh causedest me to perish.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
And but for the favourcf my lord, I should have been of those brought forward.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
Are we not then to die\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
Save our first death, and are we not to be tormented?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Verily this! that is the supreme achievement.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this, then, let the workers work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is this better as an entertainment or the tree of Zaqqum?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
Verily We! We have made it a temptation for the wrong- doers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Verily it is a tree that springeth forth in the bottom of Flaming Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
The fruit thereof is as though the hoods of the serpents.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
And verily they must eat thereof and fill their bellies therewith.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
And thereafter verily they shall have thereon a draught of balling water.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
And thereafter verily their return is Unto the Flaming Fire.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
Verily they found their fathers gone astray.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they in their footsteps are rushing.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And assuredly there went stray before them many of the ancients.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And assuredly We sent among them warners.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
So behold what wise hath been the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Save the bondmen of Allah sincere.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And assuredly Nuh cried Unto us; and We are the Best of answerers!\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We delivered him and his people from the great affliction.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And his offspring! them We made the survivors.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And We left for him among the posterity.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Peace be on Nuh among the worlds.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Verily We! thus We recompense the well-doers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Verily he was of Our bondmen believing.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We drowned the others.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And verily of his sect was Ibrahim.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
Recall what time he came Unto his lord with a heart whole.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
Recall what time he said Unto his father and his people: What is it that ye worship?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it a falsehood-god beside Allah - that ye desire?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
what, then, is your opinion of the Lord of the worlds?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then he glanced a glance on the stars.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And he said: verily I am about to be sick.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So they departed from him turning their backs.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he slipped Unto their gods and said: eat ye not\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What aileth ye that ye speak not?\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he slipped Unto them striking them with the right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then they advanced toward him, hastening.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: worship ye that which carve.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
Whereas Allah hath created you and that which ye make?\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said. build for him a building and cast him into the flaming fire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
And they devised a plot for him, but We made them the humble.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And he said: verily I am going to my Lord who will guide me.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
My Lord! Bestow on me a son who will be of the righteous.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
Wherefore We gave him the glad tidings of a boy gentle.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And when he attained the age of, running with him, he said: O my son! verily I have seen in a dream that I am slaughtering thee; so look, what considerest thou? He said: O my father! do that which thou art commanded; thou shalt find me, Allah willing, of the patients.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then when the twain had submitted themselves and he had prostrated him upon his temple.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We cried Unto him: O Ibrahim\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
Of a surety thou hast fulfilled the vision. Verily We! thus We recompense the well-doers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Verily that! that was a trial manifest.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a mighty victim.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left for him among the posterity:\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Peace be Unto Ibrahim:\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Verily We! thus We compense the well-doers.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Verily he was one of Our believing bondmen.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the glad tidings of Is-haq, a prophet, and of the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him and Is-haq; and of their offspring are some well-doers and some who wrong themselves manifestly.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And assuredly We gave grace Unto Musa and Harun.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And delivered them and their people from the great affliction.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We succoured them so that they became overcomers.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We vouchsafed Unto the twain a Book luminous.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And We led the twain on Unto the straight path.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left for the twain among the posterity:\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Peace be Unto Musa and Harun.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Verily We! thus We recompense the well-doers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Verily the twain were of Our bondmen believing.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And verily, llyas was one of the sent ones.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
Recall what time he said Unto his people: fear ye not?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Call ye upon Bal and forsake the Best of creators.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah, your Lord and Lord of your forefathers?\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
Then they belied him, so verily they are to be brought up.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except the bondmen of Allah sincere.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left for him among the posterity:\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Peace be Unto Elyasin.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Verily We! thus We recompense the well-doers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
Verily he was one of Our bondmen believing.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And verily Lut was of the sent ones.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
Recall what time We delivered him and his household, all.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Save an old woman among the lingerers.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We annihilated the others.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
And surely ye pass by them in the morning.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night. Will ye not therefore reflect?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And verily Yunus was Of the sent ones.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
Recall what time he ran away Unto a laden ship.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
Then he joined the lots, and was of the condemned.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
And a fish swallowed him, and he was reproaching himself.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
And had he not been of those who hallow Him,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have tarried in the belly thereof till the Day when they are raised.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
Then We cast him on a bare desert whilst he was sick.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused to grow over him a tree, a gourd.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We had sent him to a hundred thousand: rather they exceeded.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed, whrefore We let them enjoy life for a season.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now ask thou them: there for thy Lord daughters and for them sons?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or created We the angels females while they were witnesses?\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Lo! verily it is of their falsehood that they say:\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
God hath begotten. Verily they are the liars.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Hath He chosen daughters above sons?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What aileth you? How judge ye?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will ye not then be admonished?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or, is there for you a clear warranty\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then bring your book, if ye say sooth.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have made a kinship between Him and the jinn a kinship whereas the jinn assuredly know that they are to be brought up\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Hallowed be Allah from that which they ascribe to Him.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except the bondmen of Allah sincere.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
Wherefore verily neither ye nor that which ye worship,\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Can tempt anyone to rebel against Him.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Save him Who is to roast in the Flaming Fire.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
Of us there is none but hath a station assigned.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
And verily we! we are ranged in ranks.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
And verily we! we halloW.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And they surely were wont to say:\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
Had we but an admonition as had the ancients.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
Surefy we would have been the bondmen of God sincere.\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
Yet they disbelieve therein. Presently they shall come to know.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And assuredly Our word hath already gone forth Our bondmen, the sent ones:\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That verily they! they shall be made triumphant.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And verily Our host! they are to be overcome.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So turn thou aside from them for a season.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And see them thou; they themselves shall presently see.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Our torment seek they to hasten on!\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
Then when it descendeth Unto them face to, face, a hapless morn that shall be for those who were Warned.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
And turn thou aside from them for a season.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And see thou: they themselves shall presently see.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Hallowed be thine Lord, the Lord of Majesty, from that which they ascribe!\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace be Unto the sent ones.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And all praise Unto Allah the Lord of the worlds.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad. By the Qur'an full of admonition.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Verily those who disbelieve are in vainglory and shism.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation have We destroyed afore them, and they cried when there was not time of fleeing.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they marvel that there should come Unto them a warner from among themselves. And the infidels say: this is a magician and a liar!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
Maketh he the gods One God? Verily that is a thing astounding!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
The chiefs among them departed saying: go, and persevere in your gods; verily this is a thing designed.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We heard not thereof in the later faith; this is naught but an invention.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
Hath Unto him the admonition been sent down from amongst us! Yea! they are in doubt concerning My admonition. Yea! they have not yet tasted My torment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or, are with them the treasures of the mercy of thy Lord, the Bestower?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or, is theirs the dominion of the heavens and the earth and that which is in-between the twain? If so, let them ascend by steps.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
Here there is a host of the confederates only to be defeated.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them there have belied the people of Nuh and the 'Aad, and Fir'awn the owner of the stakes.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And the Thamud, and the people of Lut, and the dwellers of the wood; these were the confederates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
There was not one but belied the apostles, wherefore justified was My wrath.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
And these wait but for one shout, wherefrom there will be no deferment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
And they say: our Lord! hasten our portion unto us before the Day of Reckoning\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Bear thou with that which they say, and remember Our bondman, Da-ud, endured with strength; verily he was oft-returning onto Us.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Verily We so subjected the mountains that they should hallow Us with him at nightfall and sunrise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And the birds also, gathering all oft-returning onto Him on his account.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
And We made his dominion strong and vouchsafed him wisdom and decisive speech.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And hath the tidings of the contending parties reached thee, when they walled the apartment?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they went in unto Da-ud, he was frightened at them. They said: fear not we are two contending parties; one of us hath oppressed the other, so judge between us with truth, and be not iniquitious, and guide us unto the even path.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Verily this my brother hath nine and ninety ewes while I have one ewe; and he saith: entrust it to me, and he hath prevailed upon me in speech.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
Da-ud said: assuredly he hath wronged thee in demanding thine ewe in addition to his ewes, and verily many of the partners oppress each other save such as believe and work righteous works, and few are they. And Da-ud imagined that We had tried him; so he asked forgiveness of his Lord, and he fell down bowing and turned in penitence.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him that; and verily for him is an approach with us, and a happy retreat.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
O Da-ud! verily We have appointed thee a vicegerent in the earth, so judge between mankind with truth, and follow not desire, lest it cause thee to err from the path of Allah. Verily those who err from the path of Allah - Unto them shall be a severe torment, for they forgat the Day of Reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We have not created the heaven and the earth and whatsoever is in-between the twain in vain." That is the opinion of those who disbelieve. And woe Unto those who disbelieve the Fire."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We make those who believe and work righteous works I i ke Unto the corrupters in the earth; Or Shall We make the God-fearing like Unto the wicked!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
This is a Book We have sent down Unto thee, blest, that they may ponder the revelations thereof, and that there may be admonished men of understanding.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And We vouchsafed Unto Da-ud Sulaiman. How excellent a bondman! j Verily he was oft-returning.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
Recall what time there were presented Unto him, at eventide, s coursers swift-footed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
He said: verily I have loved the love of earthly good above the remembrance of my Lord until the sun hath disappeared behind the veil.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Bring them back Unto me; and he set about slashing their legs and necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And assuredly We tried Sulaiman, and set upon his throne a mere body. Thereafter he was penitent.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: my Lord! forgive me, and bestow on me a dominion which no one may obtain beside me: verily Thou! Thou art the Bestower.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
Then We subjected to him the wind: it ran gently by his command withersoever he directed.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And We subjected to him the evil ones: every builder and diver.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And others bound in fetters.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
This is Our gift, SO bestow thou or withhold, without rendering an account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And verily for him is an approach with us, and a happy end.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember thou Our bondman Ayyub, what time he cried Unto his Lord: verily the Satan hath touched me with affliction and suffering.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
Stamp the ground with thy foot. yonder is water to wash in, cool, and water to drink.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We bestowed on him his household and along with them the like thereof, out of mercy from us, and a remembrance Unto men of understanding.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
And take in thine hand a handful of twigs, and strike therewith, and break not thine oath. Verily We! We found him patient. How excellent a bondman! Verily he was oft-returning.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember thou Our bond men, Ibrahim and Is-haq and Ya'qub. owners of might ana insight.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Verily We! We distinguished them with a distinct quality: the remembrance of the Abode.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
And verily they are with us of the elect of the excellent ones\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Isma'il and Al-Yas'a and Zul-kifl: all of the excellent ones.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is an admonition, and verily for the God-feoring is a happy retreat:\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Gardens Everlasting, whereof the portals remain opened for them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Therein they will recline; therein they will call for plenteous fruit and drink.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And with them will be virgins of refraining looks and of equal age.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This it is that ye are promised for the Day of Reckoning.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Verily this is Our provision: there will be no ceasing thereof.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This: and verily for the exorbitant there shall be an evil retreat:\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell, wherein they roast: a wretched couch.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
This - let them taste it: scalding water and corruption.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other torments, like thereof, conjoined.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
This is a crowd rushing in along with you; no welcome for them; verily they are to roast in the Fire.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They will say nay! it is ye, for whom there is no welcome: it is ye who have brought it upon us. Evil shall be the resting-place.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They Will say: our Lord! whosever hath brought this upon us, - Unto him increase doubly the torment of the Fire.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will Say: what aileth us that we behold not men whom we were wont to count among the evil ones?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Took we them so unjustly for a butt of mockery, or are they deluding our eyes?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Verily this is the very truth: the wrangling of the fellows of the Fire!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say thou: I am but warner, and there is no god but Allah, the One, the Subduer.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
Lord of the heavens and the earth and whatsoever is in- between the twain, the Mighty, the Forgiver.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say thou: it is a tiding mighty.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
Ye are therefrom averting.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I had no knowledge of the chiefs on high when they disputed;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
Naught is revealed Unto me except that I am a warner manifest.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
Recall what time thy Lord said Unto the angels: verily I am about to create a human being from clay;\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
Then when I have formed him and breathed into him of My spirit, fall down before him prostrate.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
The angels prostrated themselves, all of them.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Not so lblis. He grew stiffnecked and became of the infidels.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
Allah said: O Iblis! what preventeth thee from prostrating thyself before that which have created with both my hands? Becomest thou stiff-necked, or art thou of the exalted ones?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He said: I am better than he: me Thou hast created of fire, and him Thou hast created of clay.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
Allah said: get thee forth therefrom verify thou art driven away.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
And verily My curse shall be on thee till the Day of Requital,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He said: my Lord! respite me till the Day whereon they are raised up.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
Allah said: verily, thou art of those respited.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
Until the Day of the time appointed.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
He said: by Thy majesty, then, I shall surely seduce them, all.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
Save Thy bondmen among them Sincere.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
Allah said: the truth is, and it is the truth that I speak, -\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
That I shall fill Hell with thee and such of them as shall follow thee, all together.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say thou: ask of you for it no hire, nor am I of the affecters.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
It is naught but an admonition Unto the worlds.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
And ye shall surely come to know the truth thereof after a season.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of this Book is from Allah, the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Verily We! We have sent down the Book Unto thee With truth: wherefore worship thou Allah, making exclusion for Him in religion.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
LO! for Allah is the religion exclusive. And those who take patrons beside Him, saying: We Worship them not save in order that they may bring us nigh Unto God in approach - -verily Allah will judge between them concerning that wherein they differ. Verily Allah guideth not him who is a liar and ingrate.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Had Allah willed to take a son, He could have chosen whatsoever He pleased out of that which He hath created. Hallowed be He! He is Allah the One, the Subduer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He hath created the heavens and the earth with truth. He rolleth the night around the day, and rolleth the day around the night, and He hath subjected the sun and the moon: each running on for a term appointed! Lo! He is the Mighty, the Forgiver.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you Of a Single soul, and made his spouse therefrom; and of the cattle He sent down Unto you eight pairs. He createth you in the bellies of your mothers, one creation after creation, in a threefold darkness. Such is Allah, your Lord. His is the dominion, there is no god but He. Whither then turn ye away?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If ye disbelieve, then verily Allah is Independent of you. And He approveth not of infidelity in His bondmen. And if ye return thanks He approveth of that in you. No burdened soul shall bear another's burthen. Thereafter Unto your Lord is Your return; and He shall declare Unto you that which ye have been Working. Verily He is the Knower of that which is in the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when some hurt toucheth man, he calleth upon his Lord, turning Unto Him in penitence; then when He bestoweth upon him a favour from Himself, he forgetteth that for which he called on Him afore, and setteth up peers Unto Allah that He may lead astray others from His way Say thou: enjoy thou life in thy infidelity for a while, verily thou art of the fellows of the Fire.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is he who is devout, in the watches of the night prostrating himself and standing, bewaring of the Hereafter and hoping for the mercy of his Lord to be dealt with like a wicked infidel? Say thou: shall they who know and those who know not be held equal? It is only men of understanding who receive admonition.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say thou: O Mine bondmen who believe! fear your Lord. For those who do good in this world there is good: and Allah's earth is spacious. Verily the patient shall be paid in full their hire without reckoning.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say thou: verily I am commanded to worship Allah, making for Him religion exclusive.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
And I am commanded this, in order I may be the first Of those who submit.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say thou: verily fear, if I disobeyed my Lord, torment of a Day mighty.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say thou: it is Allah I worship, making for Him my religion exclusive\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
So worship whatsoever ye will, besidev him. Say thou: verily the losers are those who shall have lost themselves and their household" on the Day of judgment LO! that will be a loss manifest.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
For them! above them shall be coverings of Fire and beneath them coverings. Therewith Allah affrighteth His bondmen. O My bondmen! wherefore fear Me.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
And those who avoid the devils lest they should worship them and turn Unto Allah in penitence, for them are glad tidings. Wherefore give thou glad tidings Unto My bondmen,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Who hearken Unto the word and follow that which is the exceLlent there of. These are they whom Allah hath guided, and those are men of understanding.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Is he then on whom is justified the decree of torment - wilt thou rescue him who is in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those whofear their Lord, for them are lofty chambers with lofty chambers above them, built whereunder rivers flow: the promise of Allah, and Allah faileth not the appointment.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Beholdest thou not that Allah sendeth down water from the heaven, and causeth it to enter springs in the earth, and thereafter produceth thereby corn various coloured. Thereafter it wirhereth, and thou beholdest it turn yellow; then He maketh it chaff. Verily herein is an admonition for men of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Shall he then whose breast Allah hath expanded for Islam, so that he followeth a light from his Lord be as he whose heart is hardened? Then woe Unto those whose hearts are hardened against remembrance of Allah. They are in an error manifest.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah hath revealed the most excellent discourse, a Book consimilar oft-repeated, whereat trembleth the skins of these who fear their Lord; then their skins and their hearts soften at the remembrance of Allah. This is Allah's guidance, wherewith He guideth whomsoever He will. And whomsoever Allah sendeth astray, for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he, then, who will shield himself with his face from the evil of torment on the Day of Resurrection be as he who is secure therefrom And it shall be said Unto the wrong-doers: taste ye that which ye have been earning.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them belied, wherefore the torment came on them whence they knew not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah made them taste humiliation in the life of the world. And surely the torment of the Hereafter is greater - if they but know!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And assuredly We have propounded for mankind in this Qur'an all kinds of similitudes, that haply they may be admonished.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
An Arabic Qur'an, wherein there is no crookedness, that haply they may fear.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah propoundeth a similitude: man having several partners,"quarelling, and a man wholly belonging to one man. Are the two equal in likeness? All praise Unto Allah. But most of them know not.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Verily thou art mortal, and verily they are mortals.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then verily on the Day of Resurrection, before your Lord ye shall contend.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
And who is a greater wrong-doer than he who fabricateth a lie against Allah, and belieth the truth when it cometh Unto him? Will not in Hell be an abode for the infidels?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And whosoever bringeth the truth, and whosoever giveth credence thereto - these! they are the God-fearing.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
Theirs will be whatsoever they will desire with their Lord: that is the hire of the well-doers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
That through this Promise Allah may expiate from them the worst of that which they may have worked, and may recompense them their hire for the best of that which they have been working.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah sufficient for His bondman? Yet they would frighten thee with those beside Him? And whomsoever Allah sendeth astray, for him there shall be no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And whomsoever Allah guideth, for him there shall be no misleader. Is not Allah Mighty, and Lord of Retribution?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And wert thou to ask them: who hath created the heavens and the earth? they will surely say: Allah. Say thou: bethink ye then that those whom ye call upon beside Allah, - could they if Allah intended some hurt for me, remove His hurt? or if He intended some mercy for me, could they withhold His mercy? Say thou: enough for me is Allah; in Him the trusting put their trust.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say thou: my nation! work according to your condition; I am going to work in my way; presently ye shall come to know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
On whom cometh a torment humiliating him, and on whom alighteth a torment lasting.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Verily We! We have sent down Unto thee the Book for mankind? with truth. Then whosoever receiveth guidance, it is for his soul and whosoever strayeth, strayeth only to its hurt; and thou art not over them a trustee.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
Allah it is who taketh away souls at the time of their death, and those which die not in their sleep: then He withhold those on which He hath decreed death, and sendeth back the rest for an appointed term. Verily herein are signs for a people who ponder.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Have they taken others for intercessors beside Allah! Say thou: What! even though they own not aught and understand not?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say thou: Allah's is intercession altogether. His is the dominion of the heavens and the earth; then Unto Him shall ye be returned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah alone is mentioned, then shrink with eversion the hearts of those who believe not in the Hereafter, and when those beside Him are mentioned, lo! they rejoice.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say thou: O Allah! Creator of the heavens and the earth! Knower of the hidden and the open! Thou shalt judge between Thy bondmen concerning that wherein they have been differing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And were those who did wrong to own all that is in the earth, and there with as much again, they shall surely seek to ransom themselves therewith from the evil of the torment on the Day of Judgment; and there shall appear Unto them from Allah that whereon they had not been reckoning,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And there shall appear Unto them the evils that they earned, and there shall surround them that whereat they had been mocking.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When hurt toucheth a man he calleth on us, and thereafter, when We have changed it Unto a favour from Us, he saith: have been given itso only by force of my knowledge. Aye! it is a trial, but most of them know not.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Surely those who were before them said it, yet there availed them not that which they had been earning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
And there befell them the evils of that which they had earned. And of these they who go wrong-anon will befall them the evils of that which they earn; nor can they frustrate.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Know they not that Allahs expandeth provision for whomsoever He will, and stinteth it for whomsoever He will! Verily herein are signs for a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say thou: my bondmen who have committed extravagance against themselves despair not of the mercy of Allah; verily Allah will forgive the sins altogether. Verily He! He is the Forgiving, the Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
And turn penitently Unto your Lord and submit Unto Him ere there cometh Unto you the torment, and then ye shall not be succoured.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
And follow the best of that which hath been sent down Unto you from your Lord there cometh on you torment of a sudden, while ye perceive not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest a soul should say: Alas! for that I have been remiss in respect of Allah, and I was but of the scoffers!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or, lest it should say: had Allah but guided me, I should surely have been of the God-fearing!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or lest it should say, when it will behold the torment: were there for me a return I would be of the well-doers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
Yea! surely there came Unto thee My revelations, but thou beliedest them and wast stiff-necked and wast of the infidels.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And on the Day of Judgment thou Shalt see those who lied against Allah - their faces blackened. Is not in Hell the abode of the stiff-necked?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah will deliver those who feared Him to their place of safety. Evil will not touch them, nor will they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator everything, And He is over everything a Trustee.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
His are the keys of the heavens and the earth and those who disbelieve in the revelations of Allah-those! they are the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say thou: is it other than Allah that ye command me to worship! O ye pagans\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And assuredly it hath been revealed Unto thee and Unto those before thee: if thou associatest surely of non-effect shall be made thy work, and thou shalt surely be of the losers.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Aye! Allah must thou worship, and be among the thankful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
And they estimated not Allah with an estimation due Unto Him whereas the whole earth shall be His handful on the Day of Judgment, and the heavens shall be rolled in His right hand. Hallowed be He and Exalted above that which they associate.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the trumpet will be blown, when whosoever are in the heavens and whosoever are on the earth will swoon away, save him whomsoever Allah willeth. Then it shall be blown again, and lo! They will be standing, looking on.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will gleam with the light of its Lord, and the Record shall be set up, and the prophets and the witnesses will be brought and judgment will be given between them with truth, and they will not be wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And each soul will be paid in full that which it hath worked; and He is the Best Knower of which they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And those who disbelieve will be driven onto Hell in troops till, when they arrive thereto, the portals thereof will be opened, and the keepers thereof will say Unto them: came there not Unto you apostles from amongst you, rehearsing Unto you the revelations of you Lord and warning you of the meeting of this your Day? They shall say: Yea, but the word of torment hath been justified on the Infidels.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said: enter the portals Of Hell to be abiders therein. How ill, then, is the abode of the stiff-necked!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who feared their Lord Will be driven Unto the Garden in troops till, when they arrive thereto, and the portals thereof will be opened, the keepers thereof Will say Unto them: Peace be Unto you! excellent are ye! enter it as abiders.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they Will say: all praise Unto Allah, who hath fulfilled His promise Unto us and made us inherit this land, so that we may dwell in the Garden whereever we will! Excellent then is the hire of the workers!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And thou wilt see the angels thronging round the Throne, hallowing the praise of their Lord. And judgment shall be given between them with truth: and it will be said: all praise Unto Allah, the Lord of the worlds.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Book is from Allah, the Mighty, the Knower. Forgiver of sin, and Accepter of repentance, severe in chastisement, Lord of power. There is no god but He; Unto Him is the journeying.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
Forgiver of sin, and Acceptor of repentance severe in chastisement, Lord of Power. There is no god but He; unto Him is the journeying.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None dispute concerning the revelations of Allah save those who disbelieve, so let not beguile thee their going about in the cities.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The people of Nuh and the confederates after them belied their apostles before these, and each disbelieving community advanced toward their apostle that they may lay hold of him and disputed with vain speech that they may confute the truth thereby. Wherefore I laid hold of them; and how terrible was My chastisement!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
And thus hath the Word of thy Lord been justified on those who disbelieve: that they shall be the fellows of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who bear the Throne and those who are round about it, hallow the praise of their Lord and believe in Him and ask forgiveness for those who believe, saying: our Lord! Thou comprehendest everything in mercy and knowledge, wherefore forgive these who repent and follow Thine path, and protect them from the torment of the Flaming Fire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord! make them enter the Everlasting Gardens Which Thou hast promised them, and also such of their fathers and their spouses and their offspring as verify Thou: Thou art the Mighty, the Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And protect them from evils. And whosoever Thou shalt protect from evils on that Day, him Thou hast of a surety taken into mercy and that: it is an achievement mighty.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Verily those who disbelieve-they will be cried Unto: surely Allah's abhorrence was greater than Is your abhorrence toward yourselves when ye were called Unto the belief, and ye disbelieved.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say: our Lord! Thou hast made us die twice, and Thou hast made us live twice now We confess our sins: there no getting out any way?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
That is because when Allah alone was called upon ye disbelieved, and when some one was associated with Him ye believed. So the judgment is of Allah, the Exalted, the Great.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
He it is who sheweth you His signs and sendeth down for you from the heaven provision. And none receiveth admonition save him who turneth in penitence.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
Wherefore call Unto Allah, making religion for Him pure, though the infidels be averse.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
He is Lofty in degrees, Lord of the Throne. He casteth the spirit of His command upon whomsoever He will of His bondmen, that he may warn people of the Day of Meeting.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day whereon they will appear: naught of them will be concealed from Allah, Whose is the dominion to-day? It is of Allah, the One, the Subduer.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
To-day each soul will be recompensed for that which it hath earned; no wrong-doing to-day; verily Allah is Swift at reckoning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
Wherefore warn them thou of the Day of portending, whereon the hearts will be in the throats, choking: then will be for the wrong- doers no ardent friend nor an intercessor to be given heed to.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knoweth the fraudulence of the eyes, and that which the breasts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
Allah decreeth with truth, while those whom they call upon beside Him cannot decree aught; verily Allah! He is the Hearer, the Beholder!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not travelled about in the land so that they may behold of what wise hath been the end of those who were before them? They were mightier than these in strength and in the traces in the land. Yet Allah laid hold of them for their sins, and from Allah they had none as protector.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because their apostles were wont to bring them evidence, but they disbelieved; wherefore Allah laid hold of them. Verily He is strong, severe in chastisement.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And assuredly We sent Musa with Our signs and a manifest authority.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
Unto Fir'awn and Haman and Qur'an, but they said: a magician, a liar.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
And when he came to them with the truth from before Us, they said: slay the sons of those who have believed with him, and let their women live. And the plot of the infidels was naught but vain.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
And Fir'awn said: let me alone, that may slay Musa, and let him call upon his Lord. Verily fear that he may change your religion or that he may cause to appear in the land corruption.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
And Musa said: verily I seek refuge in my Lord and your Lord from every stiff-necked person who believeth not in a Day of Reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And a believing man of Fir'awn 's household, hiding his belief, said: would ye slay a man because he saith: my Lord is God, and hath come upto you with evidences from your Lord? If he is a liar, then upon him will be his lie, and if he is a truth-teller, then there will befall you some of that wherewith he threateneth you; verily God guideth not one who is an extravagant and a liar.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O My people! yours is the the dominion to-day: ye being overcomers in the land; but who will succour us aginst the scourge of God if it cometh Unto us! Fir'awn said: I shew you only that which see, and I guide you but to the path of rectitude.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And he who believed said: O my people. verily I fear for you a fate like the day of the confederates.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
Like the wont of the people of Nuh and A'ad and Thamud and those after them, and God intendeth not any wrong Unto His bondmen.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
And, O my people! verily fear for you a Day of Mutual Calling.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
A Day whereon ye shall turn away retreating: for you there will be no protector from God; and whomsoever God sendeth astray for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
And assuredly there came Unto you Yusuf aforetime with evidences, yet ye ceased not to be in doubt concerning that which he brought Unto you, until when he died, ye said: God shall by no means raise an apostle after him. Thus Allah keepeth astray one who is extravagant and a doubter.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who wrangle concerning the signs of Allah without any authority that hath come Unto them. It is greatly abhorrent Unto Allah and Unto those who believe. Thus Allah sealeth up the heart of any stiff-necked, high-handed, person.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Fir'awn said: O Haman! build for me a tower that haply I may reach the ways of access\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
The way of access to the heavens so that may be apprised of the God of Musa, and verily I believe him to be a liar. And thus fair- seeming was made Unto FIr'awn the evil of his work, and he was hindered from the path. And the plot of Fir'awn ended only in ruin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And he who believed said: O my people! follow me, I shall guide you to the path of rectitude,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
O My people! this life of the world Is but a possi enjoyment, and verily the Hereafter! that is the Abode of rest.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whosoever worketh an evil, he shallnotberequited except the like thereof; and whosoever, male or female, worketh righteously, and is a believer-they will enter the Garden wherein they will be pro vided for without measure.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
And, O my people! what aileth me that call you Unto deliverance, while ye call me Unto the Fire!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
Ye call me for this, that should O blaspheme against God and associate with Him that whereof have no knowledge, call you onto the Mighty, the\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
Without doubt ye only call me Unto that which is not to be invoked in the world nor in the Hereafter; and verily our return shall be Unto God, and the extravagant! they shall be fellows of the Fire.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
And anon ye shall remember that which am telling you. Confide my affair Unto God; verily God is the Beholder of His bondmen.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
Wherefore Allah protected him from ills which they plotted, and there surrounded the family of Fir'awn the evil of torment.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire! They are exposed thereto morning and evening. And on the Day whereon the Hour will uprise, it will be said: cause the family of Fir'awn to enter the most grievous torment.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And consider what time they will wrangle together in the Fire, and the oppressed will say Unto those who were stiff-necked: verily we have been Unto you a following, are ye going to avail us against a portion of the Fire?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were stiff-necked will say: verily we are all in it; verily Allah hath judged between His bondmen.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say Unto the keepers of Hell: supplicate your Lord that He may lighten for us a day of the torment.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say: came there not your apostles Unto you with evidences? They will say: Yea? They will say: supplicate then yourselves. And supplication of the infidels will be but in wandering.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Verily We! We shall surely succour Our apostles and those who believe, both in the life of the world and on a Day whereon the witnesses will stand forth.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
A Day whereon their excuse will not Profit the wrong- doers; and theirs Will be the curse and theirs the evil Abode.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And assuredly We vouchsafed Unto Musa the guidance, and We caused the Children of Isra'il to inherit the Book.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guidance and an admonition Unto the men of understanding,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Wherefore persevere thou. Verily the Promise of Allah is true and ask forgiveness for thy fault, and hallow the praise of thy Lord in the evening and in the morning.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Verily those who wrangle concerning the revelations of Allah without an authority having come Unto them there is aught in their breasts save greatness Which they shall not reach. Seek refuge thou then in Allah verily He! He is the Hearer, the Beholder.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
The creation of the heavens and the earth is indeed greater than the creation of mankind; but most of man kind know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
Not equal are the blind and the seeing; nor those who believed and Work righteous works and the evil-doer. Little are ye admonished!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Verily the Hour is coming: there is no doubt thereof; yet most of mankind believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord hath said: call Unto Me, and I shall answer your prayer. Verily those who are stiff-necked against My worship, anon they will enter Hell abject.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
Allah it is who hath appointed for you the night that ye may repose therein, and day enlightening. Verily Allah is the Lord of Grace for mankind; bur most of mankind return not thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is Allah. your Lord, the Creator of everything there is no God but He. Wither then are ye straying away?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
In this wise have those strayed who the signs of Allah were away want to gainsay.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
Allah it is Who hath appointed for you the earth for a resting-place and the heaven for a structure, and fashioned you and fashioned you well, and provided you with goodly things. Such is Allah, your Lord. So blessed be Allah, the Lord of the worlds!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living: there is no god but He so call upon Him, making religion pure for Him. All praise Unto Allah, the Lord of the worlds!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say thou: verily I am forbidden that should worship these whom ye call upon beside Allah when evidences have come Unto me from my Lord, and I am commanded that I should submit to the Lord of the Worlds.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
He it is Who created you of dust, and thereafter of a drop, and thereafter of a clot, and thereafter He bringeth you forth as an infant, and thereafter He ordaineth that ye attain your full strength and thereafter that ye become old men-though some of you die before-and that ye attain the appointed term, and that haply ye may reflect.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
He it is Who causeth life and death. Then whensoever He decreeth an affair He only saith Unto it: be, and it becometh.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Observest thou not those who wrangle concerning the revelations of Allah: whither are they turning away?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who belie the Book and that message wherewith We sent Our apostles, presently they shall come to know.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When shackles will be on their necks and also chains; they will be dragged.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
Into the balling water; then into the Fire they will be stocked.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it will be said Unto them: where are those whom ye have been associating\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
Beside Allah? They will say: they have failed us: aye! we have not been calling upon aught afore. Thus doth Allah lead the infidels astray.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
That is because ye had been exulting in the earth without right, and because ye had been strutting.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter ye the gates of Hell as abiders therein. Hapless is the abode of the stiff-necked.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
Wherefore persevere thou; verily the promise of Allah is true; then whether We let thee see a part of that wherewith We have promised them, or whether We cause thee to die, Unto us they all will be caused to retvtn.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
Assuredly We have sent apostlesy before thee, of them are these whose store We have recounted Unto thee and these whose story We have net recounted Unto thee. And it was not possible for anv apostle that he should bring a sign san by Allah's leave. So when the commade of Allah cometh, judgment will be given with truth, and then will lose the followers of falsehood.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
Allah it is Who hath appointed for you cattle, that ye may ride on some of them, and eat of others\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And there are other benefits in them for you and that ye may attain thereby to any need that is in Your breasts and upon them and upon ships ye are borne.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He sheweth you His signs. Which, then, of the signs of Allah shall ya deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not travelled in the earth so that they may behold what wise hath been the end of those before them. They were more numerous than these, and mightier in strength and the traces in the land. But naught availed them of that which they had been earning.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
And when their apostles came Unto them with evidences, they exulted in the knowledge which was with them, and there surrounded them that which they had been mocking.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
Then when they behold Our prowess, they said: we believe in Allah alone, and we disbelieve in that which with Him we have been associating.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their belief profited them naught when they saw our prowess. This hath been Allah's dispensation that hath- been in regard to His bondmen. And then there were lost the infidels.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
This is a revelation from the Compassionate, the Merciful -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book whereof the verses are detailed: an Arabic Qur'an: for a people who know:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
A bearer of glad tidings and a warner. Yet most of them turn aside, so that they hearken not.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say: our hearts are under veils from that whereUnto thou callest us, and in our ears there is heaviness, and betwixt us and thee there is a curtain; work thou then, verily we are Workers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say thou: I am only a human being like Unto you: only it is revealed Unto me that your God is but One God, wherefore take the straight path Unto Him and seek forgiveness of Him. And woe be Unto the associators.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Who give not the poor-rate; and they! in the Hereafter, they are disbelievers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Verily those who believe and work righteous works - Unto them shall be a hire unceasing.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say thou: are ye indeed those who disbelieve in Him who hath created the earth in two days, and set up Unto Him peers? That is the Lord of the worlds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
And He placed therein mountains firmly rooted rising above it, and blessed it, and ordained therein the sustenance thereof, all this in four days: comglete: this for the inquirers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Thereafter turned He to the heaven and it was as smoke, and said Unto it and Unto the earth: come ye twain, willingly or loth. They said: we come willingly.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
Then He decreed them as seven heavens in two days, and revealed Unto each heaven the command thereof; and We bedecked the nether heaven with lamps and placed therein a guard. That is the ordinance of the Mighty, the Knower.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
Then if they Still turn away, say thou; I warn you of a calamity like the calamity of the 'Aad and Thamud.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
Recall what time the apostles came Unto them from before them and behind them, saying: worship none save Allah. They said: had our Lord listed, He surely would have sent down angels, so verily in that wherewith ye have been sent we are disbelievers altogether.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for the tribe of 'Aad - they grew stiff-necked on the earth without justification, and said: who is mightier than we in strength? Saw they not that Allah who created them,-He was Mightier than they in strength? And Our signs they were wont to gainsay.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
Wherefore We sent upon them a raging wind in days inauspicious, that We might make them taste the torment of humiliation in the life of the world; and surely the torment of the Hereafter will be more humiliating, nor will they be succoured.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for the tribe of the Thamud We guided them but they preferred blindness to the guidance, wherefore the bolt of the torment of abjection laid hold of them because of that which they had been earning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We delivered those who believed and had been fearing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And warn them of the Day whereon the enemies of Allah will be gathered Unto the Fire; and they will be set in bands.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Until when they come to it, their ears and their sights and their skins will bear witness against them of that which they had been working.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say Unto their skins: wherefore bear ye witness against us They will say: Allah hath caused us to speak, Who causeth everything to speak, and Who created you the first time and Unto whom ye are now caused to return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
Ye have not been taking cover against yourselves lest your ears and your eyes and your skins should bear witness against you, but ye imagined that Allah not much knew of that which ye were working.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
That thought of yours which ye formed concerning Your Lord, hath ruined you, and ye have become of the losers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Then if they are patient, the Fire is their home, and if they seek to please Allah, they will not be of those who are allowed to please Allah.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We have assigned Unto them some companions who made fairseeming Unto them that which was before them and that which was behind them justified upon them was the Word Pronounced on the communities of the jinn and mankind who passed away before them; verily they were the losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
And those who disbelieve say: hearken not Unto this Qur'an and babble therein, haply ye may overcome.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
Wherefore We will surely cause those who disbelieve to taste a severe tor ment, and We will surely requite them the worst of that which they have been working.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the meed of the enemies of Allah: the Fire. Therein is their home of Abidence: a meed forasmuch as Our revelations they were wont to gainsay.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And those who disbelieve will say: our Lord! show us those, of the jinn and mankind, who led us astray and we will place them underneath our feet that they may be of the nithermost.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Verily those who say: our Lord is Allah, and have thereafter stood fast by it,- upon them there shall come down the angels: fear not, nor grieve, and rejoice in the tidings of the Garden which ye have been promised.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your friends in the life of the world and in the Hereafter; there in yours will be whatsoever your souls desire, and therein yours shall be whatsoever ye call for.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
And entertainment from the Forgiving, the Merciful.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than he who summoneth Unto Allah, and worketh righteously, and saith: verily I am one of the Muslims.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
Nor can good and evil be equal. Repel thou evil with that which is goodly then behold he between whom and thee there was enmity, will be as though he was a warm friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
And none attaineth that except those who are patient; and none attaineth that except the owner of mighty good fortune,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if there inciteth thee an incitement from the Satan then seek refuge in Allah. Verily He! He is the Hearer, the Knower.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His signs are the night and the day and the sun and the moon. So prostrate not yourselves Unto the sun nor the moon. but prostrate yourselves Unto Allah who hath created them, if it is He alone whom ye are worshipping.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
And if they grow stiff-necked, then verily those who are with thy Lord, hallow Him night and day, and they weary not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His signs is that thou beholdest the earth lowly, and when We send down thereon water, it stirreth to life and groweth. Verily He who quickeneth is the Quickener of the dead. Verily He is over everything Potent.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Verily those who blaspheme Our revelations are not hid from Us. Is he then who will be cast into the Fire better or he who cometh secure on the Day of Resurrection? Work whatsoever ye will; Verily He is of that which ye work the Beholder.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Verily those who disbelieve in the Admonition when it cometh Unto them are themselves to blame. Verily it is a Book mighty.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot come at it from before it or behind it It, a revelation from One Wise and Praiseworthy.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Naught is said Unto thee save that which was said Unto the apostles afore thee. Verily thy Lord is Owner of forgiveness and Owner of afflictive chastisement.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And had We made it a recital in a foreign tongue, they would have surely said: wherefore are the verses thereof not detailed? A foreign tongue and an Arab! Say thou: Unto those who have believed it is a guidance and a healing: and those who believe not, - in their ears there is a heaviness, and Unto them it is blindness. These are they who are cried Unto from a place far-off.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And assuredly We vouchsafed Unto Musa the Book, and difference arose concerning it; and had not a word gone forth from thy Lord, the affair would have been decreed between them. And verily they are in regard thereto in doubt and dubitating.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whosoever worketh righteously it is for his soul, and whosoever worketh evil it is against it. And thine Lord is not an oppressor Unto His bondmen.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
Unto Himl is remitted the knowledge of the Hour. And not a fruit cometh forth from the knops thereof; neither doth a female bear or bring forth but with His knowledge. And on the Day whereon He will call Unto them: where are my associates. they will say: we protet Unto Thee, none of us is a witness thereof.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And there will fail them those whom they had been calling upon aforetime, and they will perceive that there is for them no shelter.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man is not wearied of praying for worldly good, and if there tcucheth him an evil, he is despondent, despairing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And, surely, if We cause him to taste mercy from Us after affliction hath touched him, he is sure to say: this is my own, and I deem not that the Hour will everarise, and were I to be brought back to my Lord, verily there will be for me, with Him, an excellent condition. But We shall surely declare Unto those who disbelieve that which they have worked, and We shall surely make them taste a torment rough..\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We shew favour Unto man, he turneth aside and withdraweth on his side, and when evil toucheth him, then he is full of prolonged prayer.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say thou: bethink ye! if it is really from Allah and then ye disbelieve therein, then who is further astray than one who is in schism far-off?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
Anon We shall shew them Our signs in the regions and in their ownselves until it becometh manifest Unto them that it is the truth. Sufficeth it not in regard to thy Lord, that He is over everything Witness?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Lo! they are in doubt concerning the meeting with their Lord: Lo! He Is of everything the Encompasser!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
Ain. Sin. Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
In this wise revealeth Unto thee and Unto those before thee, Allah the Mighty, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
His is whatsoever is in the heavens and whatsoever is in the earth, and He is the Exalted, the Grand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
Well-nigh the heavens might be rent in sunder from above them. And the angels hallow the praise of their lord and ask forgiveness for these on the earth. Lo! Verily Allah! He is the Forgiver, the Merciful!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And those who take Patrons beside Him, Allah is Warden over them, and thou art not over them a trustee.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus We have revealed Unto thee a Qur'an in Arabic, that thou mayest warn the mother of towns and those around it, and that thou mayest warn them of a Day of Assembling whereof there is no doubt. A party will be in the Garden, and a party in the Blaze.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
And had Allah willed, He would have made them one community; but He causeth whomsoever He will to enter into His mercy. And the wrong doers! for them there shall be no patron or helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Have they taken patrons besides Him! But Allah! He is the Patron, HE quickeneth the dead, and He is over every-thing Potent.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And whatsoever it be wherein ye differ the decision thereof is with Allah; such is Allah, my Lord: in Him put my trust and Unto Him I turn in penitenance.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Creator of the heavens and the earth: He hath made for you mates of yourselves, and of the cattle also mates, whereby He diffuseth you. Not like Unto Him is aught, and He is the Hearer, the Beholder!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
His are the keys of the heavens and the earth. He expandeth provision for whomsoever He will and stinteth. Verily; He is of everything the Knower.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He hath instituted for you in religion that which He had enjoined upon Nuh, and which We have revealed Unto thee, and which We had enjoined upon Ibrahim and Musa and Isa, saying: establish the religion, and be not divided therein. Grievous Unto the associaters is that Unto which thou callest them. Allah chooseth for Himself whomsoever He will and guideth Unto Himself whomsoever turneth in penitence.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they divided not until after knowledge had come to them, through spite between themselves; And had not a word gone forth from thy Lord for an appointed term, the affair would surely have been judged between them. And verily those who have been made inheritors of the Book after them are in doubt thereof dubitating.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
Wherefore Unto that summon thou, and be steadfast as thou hast been commanded, and follow not their desires. And say thou: I believe in whatsoever Allah hath sent down of the Book, and I am commanded that I should do justice between you; Allah is our Lord and your Lord; Unto us our works, and Unto you your works; let there be no contention between us and you; Allah will assemble us, and Unto Him is the return.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who contend respecting the religion of Allah after it hath been acknowledged, their contention is void in the sight of their Lord, and upon them shall befall wrath, and theirs shall be a severe torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
Allah it is Who hath sent down the Book with the truth and the balance. And what shall make thee know the Hour may haply be nigh.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Only those who believe not therein seek to hasten it, and those who believe are fearful thereof and know that it is the truth. Lo! verily these who debate concerning the Hour are in error far-off.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is Gentle Unto His bondmen: He provideth for whomsoever He will, and He is the Strong, the Mighty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whosoever seeketh the tillage of the Hereafter Unto him We shall give increase in his tillage; and whosoever seeketh the tillage of the world We shall give him somewhat thereof, and in the Hereafter his shall be no portion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Have they associate-gods who have instituted for them a religion which Allah hath not allowed? And had there net been a decisive Word, the affair would have been judged between them. And verily the wrong-doers? theirs shall be a torment afflictive.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
Thou shalt see the wrong-doers fearful on account of that which they have earned, and it is sure to befall them. And those who believe and work righteous works will be in meadows of the Gardens theirs will be whatsoever they list, in the presence of their Lord. That! that is the supreme grace.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is that whereof Allah giveth the glad tidings Unto His bondmen who believe and work righteous works, Say thou: I ask of you no hire therefor save affection in respect of kinship. And whoso ever earneth a good deed We shall increase Unto him good in respect thereof; verily Allah is Forgiving, Appreciative.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Say they: he hath fabricated a lie concerning God! Now, if Allah willed, He would seal thine heart. And Allah abolisheth falsehood and establisheth truth by His words; verily He is the Knower of that which is in the breasts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And He it is Who accepteth repentances from His bondmen, and pardoneth the evil deeds and knoweth that which ye do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answereth those who believe and work righteous works and increaseth Unto them of His grace. And the infidels! theirs shall be a severe torment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And had Allah expanded the provision for His bondmen they surely would have rebelled in the earth, but He sendeth down by measure as He willeth; verily He is, in respect of His bondmen. Aware and Beholder.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And He it is Who sendeth down the rain after men have despaired, and spreadeth abroad His mercy. And He is the Patron of all, the Praiseworthy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of His signs is the creation of the heavens and the earth and of the moving creatures which He hath dispersed in the twain. And He is for their assembling whensoever He will Potent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
And whatsoever of affliction befalleth you is owing to that which your hands have earned; and He pardoneth much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
And ye cannot frustrate His Punishment in the earth; and there is for you beside Allah neither protector nor helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His signs are the ships in the sea like landmarks.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He willeth He causeth the wind to cease so that they keep still on the back thereof; verily therein are signs for every patient, grateful person.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He may destroy them because of that which they have earned, and He may pardon many of them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And those who dispute in respect of Our revelations may know that for them there is a place of shelter.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
So whatsoever things are vouchsafed Unto you are but a Passing enjoyment for the life of the world, and that which is with Allah, better and more lasting, is for those who believe and in their Lord put their trust.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid heinous sins and indecencies, and when they are wroth forgive.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who answer the call of their Lord and establish prayer and whose affair being matter of counsel among themselves, and who of that wherewith We have provided them expend.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when they are oppressed vindicate themselves.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The meed of an ill-deed is an ill the like thereUnto; but whosoever pardoneth and amendeth, his hire is on Allah; verily He approveth not the wrong-doers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And whosoever vindicateth him self after wrong done him these! against them there is no way of blame.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The way of blame is only against those who wrong mankind, and rebel in the earth without justice; these! for them is a torment afflictive.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And whosoever forbeareth and forgiveth -that verily is of the firmness of affairs.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
And whomsoever Allah will send astray, for him there will be no protecting friend to take His place. And thou wilt behold the wrong- doers when they behold the torment saying: is there Unto return any way?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And thou wilt behold them set up before it, downcast with ingominy ond looking with stealthy glance. And those who believe will say: verily the losers are they who have lost themselves and their housefolk on the Day of Resurrection. Lo! verily the wrong-doers will be in a a torment lasting.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And they shall have no patrons succouring them beside Allah. And whomsoever Allah sendeth astray for him there will be no way.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer the call of Your Lord afore there cometh Unto you a Day for which there is no averting from Allah. Ye will have no place of refuge on that Day, nor there will be for you any denying of Your guilt.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
If then they turn away, then We have not sent thee to be a warden over them, on thee is naught but preaching. And verily We! when We cause man to taste of mercy from Us he exulteth thereat; and if an ill befalleth them because of that which their hands have sent on, then verily man becometh ingrate.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
Allah's is the dominion of the heavens and the earth. He createth whatsoever He Will. He bestoweth females upon whomsoever He will, and bestoweth males upon whomsoever He Will.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He conjoineth them males and females; and He maketh barren whomsoever He will; verily He is Knower, Petent.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
And it is not Possible for a human being that Allah should speak Unto him otherwise than by revelation or from behind a veil, or that He sendeth a messenger, so that he revealeth by His command whatsoever He will; verily He is Exalted, Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
Even so We have revealed Unto thee a spirit of Our command; thou knewest not whatsoever the Book was, nor whatsoever the faith; We have made it a light wherewith We guide whomsoever We will of Our bondmen. And verily thou guidest Unto a straight path.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of Allah, Whose is whatsoever is in the heavens and whatsoever is in the earth. Lo! Unto Allah trend all affairs.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By this luminous Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
Verily We! We have made it an Arabic Qur'an that haply ye may reflect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And verily it is, in the Original Book before Us, indeed exalted.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We then take away from you the Admonition because ye are a people extravagant?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
And how many a prophet We sent among the ancients.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And not a prophet came Unto them but him they were wont to mock.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
Wherefore We destroyed peoples mightier than these in prowess; and there hath gone forth the example of the ancients.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And if thou askest them: who hath created the heavens and the earth? they will surely say: created them the Mighty, the Knower.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
Who hath made for you the earth a bed, and hath made for you paths therein that haply ye may be directed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And Who sendeth down from the heaven water in measure; then We quicken a dead land therewith: even so ye shall be brought forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And Who hath treated the pairs, all of them, and appointed for you from ships and cattle things whereon ye ride.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
That ye mount firmly on the backs thereof, and then may remember the favour of your Lord When ye mount thereon, and may say: hallowed be He Who hath subjected this Unto us, and we for it were not fit.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And verily Unto our Lord we are to return.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
And they appoint for Him from His bondmen a part! Verily man is an ingrate manifest.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Hath He taken for Himself from whatsoever He hath created daughters, and hath honoured you with sons.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And when there is announced Unto any of them the birth of that which he likeneth Unto the Compassionate, his countenance remaineth darkened the whole day and he is wroth inwardly."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
Hath He taken to Himself that which is reared in ornaments, and is in contention not plain?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they make the angels who are the bondmen of the Compassionate females. Have they witnessed their creation? Their testimony will be written down, and they will be questioned.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they say: had the Compassionate willed we should not have worshipped them. They have no knowledge thereof; they are only guessing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Have We vouchsafed Unto them any Book before this, so that they are to it holding fast?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay! they say: verily we have found our fathers on a certain way, and verily by their footsteps we are guided.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And in this wise We sent not before thee into any city a warner but the affluent thereof said: verily we! we found our fathers on a certain way and verily their footsteps we are following.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
The warner said: What! even though bring you a better guidance than that which ye found your fathers upon They said: verily in that wherewith ye are sent we are disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
Wherefore We took revenge on them. Behold, then how hath been the end of the beliers?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And recall what time Ibrahim said Unto his father and his people: verily I am quit of that which ye worship.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
Save Him Who hath created me, and then He would guide me.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it a word lasting among his posterity that haply they should return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Aye! I let these and their fathers enjoy life, until there hath come Unto them the truth and an apostle manifest.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the truth cometh Unto them, they say this is magic, and verily we are therein disbelievers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they say: wherefore hath not this Qur'an been revealed to a man of the two cities who was great.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Shall they apportion their Lord's mercy? It is We Who have apportioned among them their livelihood in the life of the War, and raised some of them over others in degrees, so that one of them may take another as a serf; and the mercy of thy Lord is better than that which they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that mankind would have become one community, We should make for those who disbelieve in the Compassionate roofs of silver for their houses and silver stair ways whereby they ascend.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And silver doors for their houses, and silver couches whereon they recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And ornament of gold. And yet all that would have been but a pro vision Of the life of the World; and the Hereafter with thy Lord is for the Godfearing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And whosoever blindeth himself to the admonition of the Compassionate, We assign Unto him a Satan, and he becometh his companion.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And verily they hinder them from the way, whilst they deem that they are rightly guided.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Until when he cometh Unto Us, he will say. Ah! would that there had been between me and thee, the distance of the east and the west an evil companion\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
And it Will profit you not today, because ye have done wrong, that ye are in the torment sharers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Wherefore canst thou make the deaf to hear, or canst thou guide the blind or him who is is error manifest?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
And if We take thee away. We shall surely take vengeance on them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or if We shew thee that wherewith We threaten them, verily We are going to prevail over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
Hold thou fast wherefore to that which is revealed Unto thee: verily thou art on the straight path. s\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And verily it is an admonition Unto thee and thy people; and presently ye will be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask thou Our apostles whom We sent before thee: appointed We gods, beside the Compassionate, to be worshipped?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And assuredly We sent Musa with Our signs Unto Fir'awn and his chiefs, and he said: verily I am an apostle of the Lord of the worlds.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
Then when he came Unto them with Our signs, behold! at them they were laughing.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And not a sign We shewed them but it was greater than the like thereof; and We laid hold of them with the torment that haply they might turn.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said: magician! supplicate thy Lord for us for that which He hath covenanted with thee; verily we shall let ourselves be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
Then When We had removed from them the torment, behold they were breaking their promise.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Fir'awn proclaimed among his people, saying: O my people! is not mine the dominion of Mis and witness yonder rivers flowing underneath me? See ye not?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Aye! I am better than this one who is depicable, and well- nigh cannot make himself plain.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Wherefore, then, have bracelets of gold not been set upon him, and wherefore have not angels come with him accompanying\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Then he incited his people and they obeyed him; verily they were ever a transgressing people.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So when they vexed Us, We took vengeance on them, and We drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them a precedent and an ensample Unto those after.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Maryam is held up, an example, behold! thy people thereat cry out.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And they say: are our gods better, or is he? They mention him not to thee save for disputation. Aye! they are a people contentious.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He is naught but a bondman: him We favoured, and him We made an ensample Unto the Children of Israil.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And had We willed We could have appointed angels born of you in the earth to succeed each other.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And verily he is a sign of the Hour wherefore dubitate not thereof, and follow Me: this is the straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And let not the Satan hinder you; verily he is Unto you an enemy manifest.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when Isa came with; evidences, he said: of a surety I have come Unto you with Wisdom, and to expound Unto you some of that wherein ye differ; so fear Allah and obey me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Verily Allah! He is my lord and your Lord, so worship Him: this is the straight path.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
Then the sects differed among themselves. Woe then Unto those who do Wrong because of the torment of an afflictive Day.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
They await but the Hour: that it should come upon them of a sudden, while they perceive not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
The intimate friends on that Day Will be hostile Unto one another save the God-fearing.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
O My bondmen! no fear shall be on you Today, nor shall ye grieve\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
Ye who believed in Our revelations and were Muslims.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter the Garden, ye and your spouses, joyfully.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Passed round amongst them will be dishes of gold and goblets, and therein will be whatsoever souls desire and eyes delight in; and ye will be therein abiders.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
This is the Garden which ye have been made to inherit for that which ye have been working.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
For you therein will be fruits in plenty whereof ye will eat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Verily the culprits in Hell's torment will be abiders.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
It shall not be abated from off them, and they will be therein despondent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
And We wronged them not, but they have been the wrong- doers themselves.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And -they will cry: O keeper let thy Lord make an end of us. He will say: verily ye shall bide\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
Assuredly We brought the truth Unto you, but most Of you are to the truth averse.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Have they determined an affair? then verily We are also determining.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Bethink they that We hear not their secrets and whispers? Yea! We do, and Our messengers present with them write down.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say thou: had the Compassionate a son, shall be the first of his worshippers.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Hallowed be the Lord of the heavens and the earth, the Lord of the Throne, from that which they ascribe!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So let them thou alone wading and sporting until hey meet the Day which they are promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
And He it is Who is God in the heavens and God in the earth, and He is the Wise, the Knower.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blest be He Whose is the dominion of the heavens and the earth and whatsoever is in-between the twain, and with Him is knowledge of the Hour, and Unto Him ye will be made to return.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those whom they call upon beside Him own not the power of intercession save those who have borne witness to the truth and who know.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And wert thou to ask them who created them, they will surely say: God. Witherward then are they deviating!\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And We hear his saying: my Lord! verily these are a people who believe not.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
Wherefore turn thou aside from them, and say: peace. presently they shall come to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the luminious Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
Verily We have sent it down on a blessed night, verily We were to become warners.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
Therein is decreed every affair of wisdom\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
As a command from before Us. Verily We were to become senders:\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
A mercy from thy Lord. Verily He! He is the Hearer, the Knower.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and the earth and whatsoever is in- between the twain, if only ye would be convinced.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god but He. He quickeneth and causeth to die: your Lord and Lord of your forefathers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Aye! they're in doubt sporting.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
So wait thou day whereon the heaven will bring forth a manifest smoke:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Covering the people's this shall be a torment afflictive.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
Our Lord! remove from us the torment, verily we shall become believers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How can there be an admonition Unto them, when surely there came Unto them an apostle manifest!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Yet they turned away from him and said: one tutored, one distraced.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Verily We shall remove the torment for a while; but verily ye shall revert.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
On the Day whereon We assault them with the greatest assault, verily We shall take vengeance.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And assuredly afore them We proved Fir'awn's people, and there came Unto them an apostle honoured.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying: restore to me the bondmen of Allah, verily I am Unto you an apostle trusted.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
And saying exalt not yourselves against Allah; verily I have come Unto you with an authority manifest.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
And verily I have sought refuge in my Lord and your Lord lest ye stone me.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
And if ye will not believe in me, then let me alone.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
Then he called upon his Lord. these are a people guilty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
So depart thou with My bondmen by night; verily ye shall be pursued.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And leave thou the sea divided: verily they are a host to be drowned.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
They left - how many! - of gardens and springs.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And cornfields and goodly positions.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And the delights which they had been enjoying!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Even so And We caused to inherit them another people.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And the heavens and the earth wept not over them, nor were they respited.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And assuredly We delivered the Children of Isra'il from an ignominous torment\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Fir'awn; verily he was haughty and of the extravagant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And assuredly We elected them with knowledge above the worlds.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And We vouchsafed Unto them signs wherein was a manifest favour.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Verily these! they say:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
There is naught but our first death, and we shall not be raised again.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring then our fathers if ye say so.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better Or the people of Tubba and those afore them? We destroyed them; verily they were culprits.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We created not the heavens and the earth and all that is in-between the twain sporting.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not save with a purpose but most of them know not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Verily the Day of Distinction is the term appointed for all of them.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
A Day whereon a friend shall not avail a friend at all, nor shall they be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Save those on whom Allah will have mercy. Verily He! He is the Mighty, the Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Verily the tree of Zaqqum:\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Food of the sinner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like the dregs of all! It shall seethe in the bellies:\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
As the seething of boiling water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
Lay hold of him, and drag him Unto the midst of the Flaming Fire.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
Then pour upon his head the torment of balling water.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
Taste thou! thou art indeed mighty, honoured!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
Verily this is that whereof ye were wont to doubt.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Verily the God-fearing will be in a place secure\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Amidst gardens and springs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Attired in fine silk and brocade, facing each other.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
Even so. And We shall pair them with fair damsels large- eyed.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They will call therein for every kind of fruit in security.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They will not taste death therein, except the first death; and He will preserve them from the torment of the Flaming Fire.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
A bounty from thy Lord. That! that is the supreme achievement.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
And We have made it easy in thy language; they might haply be admonished.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Wait thou then; verily they also are waiting.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book is from Allah, the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Verily in the heavens and the earth are signs Unto the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in the creation of yourselves and of the beasts that He hath scattered over the earth, are signs Unto a people who are convinced.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of night and day and that which Allah sendeth down of provision from the heaven and thereby quickeneth the earth after the death thereof and the turning about of the winds, are signs Unto a people who reflect.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the revelations of Allah which We rehearse Unto thee with truth: in what discourse then, after Allah and His revelations, will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe Unto every liar, sinner!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who heareth the revelations of Allah rehearsed Unto him, and yet persisteth with stiff-neckedness as though he heard them not. Announce thou Unto him, then, a torment afflictive.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he cometh to know aught of Our revelations, he taketh it scoffingly. These! theirs shall be a torment ignominous;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Before them is Hell; naught will avail them of that which they earned, nor those whom they took for patrons beside Allah. Theirs shall be a torment mighty.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This Book is guidance, and those who disbelieve in the revelations of their Lord, theirs shall be torment of calamity, afflictive.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
Allah it is Who hath subjected the sea for your sake, that the ships may run thereon by His command and that ye may seek of His grace, and that haply ye may return thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And He hath subjected for your sake whatsoever is in the heavens and whatsoever is in the earth, the whole from Himself. Verily herein are signs Unto a people who ponder.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Say thou Unto those who believe, let them forgive those who hope not for the days of Allah, that He may requite a community for that which they have been earning.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whosoever worketh righteously, worketh for himself; and whosoever doth evil, doth against himself; then Unto your Lord ye will be made to return.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And assuredly. We vouchsafed Unto the Children of Israil the Book and the wisdom and the propherhood, and We provided them with good things and preferred them above the worlds.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And We vouchsafed Unto them evidences of the affair. And they differed not except after the knowledge had come Unto them, through spite among themselves. Verily thy Lord will decide between them on the DaY of Judgment concerning that wherein they have been differing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
And thereafter We have placed thee upon the law of the religion; so follow it thou, and follow not the vain desires of those who know not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Verily they cannot avail thee at all against Allah. And verily the wrong doers! friends are they one Unto another. And Allah is the Friend of the God-fearing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This Book is an enlightenment Unto mankind and a guidance, and a mercy Unto a People who are convinced.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Deem those who commit ill deeds that We shall make them as those who believe and work righteous Works? Equal is their life and their death! How ill they judge!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah hath created the heavens and the earth with purpose and that every soul may be recompensed for that which it hath earned. And they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Beholdest thou him who taketh for his god his own vain desire, and Allah hath sent him astray despite his knowledge, and hath sealed up his hearing and his heart, and hath set on his sight a covering? Who will guide him after Allah? Will ye not then be admonished?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say: there is no naught but our life of the world; die and we live; and naught destroyeth us save Time. And they have no knowledge thereof: they do but guess.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our manifest revelations are rehearsed Unto them, their argument is no other than that they say bring our fathers, if ye say sooth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say thou: Allah keepeth you alive, then He shall cause you to die, then He shall assemble you on the Day of Resurrection whereof there is no doubt; but most of mankind know not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And Allah's is the dominion of the heavens and the earth; and on the Day whereon the Hour arriveth, then shall lose the followers of falsehood.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And thou shalt behold each community kneeling; each community shall be summoned to its Book. Today, shall be recompensed for that which ye have been working.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This Book of Ours speaketh against you with truth; verily We have been setting down whatsoever ye have been working.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
Then, as for those who believed and worked righteous works, their Lord will cause them to enter into His mercy: that is a manifest achievement.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
And as for those who disbelieved: Were not My revelations rehearsed Unto you? but ye were stiff necked, and ye were a people guilty.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said; verily Allah's promise is, true, and the Hour! there is no doubt thereof, ye said: we know not what the Hour is, we imagine it naught but an opinion, and we are not convinced.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And there will appear Unto them the evils Of that which they had worked, and there will surround them that whereat they had been mocking.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said: Today shall forget you, even as ye forgat the meeting of this your Day, and your abode will be the Fire, and none ye will have as helpers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
That is because ye took the revelations of Allah scoffingly, and there beguiled you the life of the world. Today, therefore, they will not be taken forth therefrom, nor will they be suffered to please Allah.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
All praise, then, Unto Allah, Lord of the heavens and Lord of the earth, Lord of the worlds.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And His alone is the Majesty in the heavens and the earth, and He is the Mighty, the Wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of the Book is from Allah, the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We created not the heavens and the earth and whatsoever is in-between the twain save with truth, and for a term stated. And those who disbelieve are from that whereof they are warned backsliders.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say thou: bethink ye: whatsoever ye call upon beside Allah- show me whatsoever they have created of the earth? Or have they any partnership in the heavens? Bring me a Book before this, Or some trace of knowledges if ye say sooth.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than he who calleth beside Allah, Unto such as will answer it not till the Day of Resurrection and who are of their call unaware.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when mankind will be gathered they will become Unto them enemies and of their worship they will become deniers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our manifest revelations are rehearsed Unto them those who disbelieve say of the truth when it hath come to them: this is magic manifest.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Say they: he hath fabricated it. Say thou: if I have fabricated it, then ye cannot avail me against Allah in aught. He is the Knower of that which ye utter thereof; He sufficeth as a witness between me and you; and He is Forgiving, Merciful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say thou: I am not an innovator among the apostles, nor I know whatsoever shall be done with me or with you; I only follow that which is revealed Unto me, and am but a warner manifest.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say thou: bethink ye: if it is from Allah while ye disbelieve therein and a witness from the Children of Isra'il beareth witness to the like thereof and believeth, while ye are still stiff necked, then who is further astray than you? Verily Allah guideth not a wrong-doing people.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And those who disbelieve say of those who believe: had it been good, they would not have preceded us thereto. And when they have not let themselves be guided thereby, they say: this is an ancient falsehood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before it there hath been the Book of Musa, a guide and a mercy. And this a Book confirming it, in Arabic speech, that it may warn those who have done wrong and as glad tidings Unto the well-doers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Verily those who say: our Lord is Allah, and thereafter stand fast thereto, no fear shall come upon them, nor shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Those are the fellows of the Carden: abiders therein: a recompense for that which they have been working.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have enjoined upon man kindness Unto the parents: with hardship his mother beareth him and with hardship she bringeth him forth, and the bearing of him and the weaning of him is thirty months, until, when he attaineth his full strength and attaineth the age of forty years, he saith: my Lord! grant me that may give thanks for the favour wherewith. Thou hast favoured me and my parents and that may work righteously such as Thou mayest approve; and be Thou good Unto me in my progeny, verily have turned Unto Thee repentant, and verily I am of those who submit.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Those are they from whom We shall accept the best of that which they have worked, and their misdeeds We shall pass by: among the fellows of the Garden: a true promise this, which they have been promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
And he who saith Unto his parents: fie upon you both! threaten me ye that I shall be taken forth, whereas generations have passed away before me? and the twain implore Allah's assistance woe Unto thee! come to believe! verily the promise of Allah is true; yet he saith: naught is this but fables of the ancients."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Those are they upon whom hath been justified the saying about the communities of the Jinn and mankind who have passed away before them; verily they are ever the losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for each are ranks according to that which they have worked, that He may repay them in full for their works; and they shall not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And on the Day whereon those who disbelieve shall be placed before the Fire: ye made away with your good things in your life of the world, and ye enjoyed yourselves therewith so Today ye shall be requited with the torment of ignominy, for that ye have been growing stiff-necked on the earth without justification, and for that ye have been transgressing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And remember thou the brother of the Aad when We warned his people in the sandhills - and surely there have passed away warners before him and after him - saying: worship none save Allah, verily I fear for you the torment of a mighty Day.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: art thou come Unto us that thou mayest turn us aside from our gods? then bring thou upon us that wherewith thou threatenest us, if thou art of the truth-tellers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said: the knowledge is only with Allah, and I preach Unto you that wherewith I have been sent, but I see you are a people given to ignorance.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then when they beheld it as an overpeering cloud tending toward their valleys they said: yonder is an overpeering cloud bringing us rain. Nay it is that which ye sought to be hastened: a wind wherein is a torment afflictive.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
It shall annihilate everything by the command of its Lord. Wherefore they became such that naught could be seen save their dwellings Thus We requite a nation of the culprits.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And assuredly We had established them in that flourishing condition wherein We have not established you, and We had appointed for them hearing and sight and hearts; yet their hearing and sight and heart availed them not at all, they became wont to gainsay the revelations of Allah, and surrounded them that whereat they had been mocking.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And assuredly We have destroyed the cities round about you. and We have variously propounded our signs, that haply they might return.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Then wherefore succoured them not those whom they had taken for gods beside Allah, as a means of approach? Aye! they failed them. And that was their lie, that which they had been fabricating.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And recall what time We turned towards thee a company Of the Jinns hearkening Unto the Qur'an. So when they came in the presence thereof they said: give ear. Then when it was ended, they turned back to their people as warners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said: O our people! verily we have hearkened Unto a Book sent down after Musa, confirming that which was before it, guiding Unto the truth and a straight path.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people! answer Allah's summoner and believe in him; He shall forgive you your sins and shall shelter you from a torment afflictive.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
And whosoever answereth not Allah's summoner, he cannot frustrate His vengeAnce on the earth, and for him there will be, beside Him, no patrons. Those are in error manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Bethink they not that Allah Who created the heavens and the earth and was not fatigued with the creation thereof, is able to quicken the dead? Aye! verily He is over everything Potent.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the Day whereon those who disbelieve will be placed before the Fire: is this not real? They will say: yea, by our Lord. He will say: taste wherefore the torment, for ye have been disbelieving.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Bear thou then with patience even as the apostles, endued with resolution bear with patience, and seek not to hasten on for them. On the Day whereon they will behold that wherewith they are threatened, it will seem to them as though they had tarried but an hour of the day. A proclamation this: so none will be destroyed save the nation of transgressors.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and hinder others from the way of Allah, He shall send their works astray.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
And those who believe and work righteous works and believe in that which hath been revealed Unto Muhammad -and it is the truth from their Lord- He shall expiate their misdeeds from them and shall make good their state.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow the falsehood, and those who believe follow the truth from their Lord. And thus Allah propoundeth Unto mankind their similitude.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
Now when ye meet those who disbelieve, smite their necks until when ye have slain them greatly, then make fast the bonds; then, thereafter let them off either freely or by ransom, until the war layeth down the burthens thereof. That ye shall do. And had Allah willed, He would have vindicated Himself against them, but He ordained fighting in order that He may prove you one by the other. And those who are slain in the way of Allah, He shall not send their works astray.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
Anon He shall guide them, and shall make good their state.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And He shall make them enter the Garden; He shall have made it known, Unto them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O ye who believe! if ye and shall succour Allah, He shall succour you make firm your feet.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
And those who disbelieve, downfall shall be theirs, and He shall send astray their Works.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they detest that which Allah hath sent down, and so He shall make of non-effect their works.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not travelled then on the earth so that they might see how hath been the end of those before them! Allah annihilated them. And for the infidels theirs shall be the like fate therefore.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the patron of those who believe, and because the infidels! no patron is theirs.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Verily Allah shall cause those who believe and work righteous works to enter Gardens whereunder rivers flow. And those who disbelieve enjoy themselves and eat even as the cattle eat, and the Fire shall be the abode for them.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And many a city, mightier In strength than the city which drave thee forth, We destroyed them, and there was no helper of theirs.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is he then who standeth, on an evidence from his Lord like Unto him whose evil of work is made fair-seeming for him and those who follow their lusts?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
A likeness of the Garden which hath been promised to the God-fearing: therein are rivers of water incorruptible, and rivers of milk whereof the flavour changeth not, and rivers of wine: a joy Unto the drinkers; and rivers of honey clarified. theirs therein shall be every kind of fruit, and forgiveness from their Lord. ShAll Persons enjoying such bliss be like Unto those who are abiders in the Fire and are given to drink boiling water so that it mangleth their entrails?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
Of them are some who listen to thee, until, when they go forth from before thee, they say Unto those who have been vouchsafed knowledge, what is that he hath said just now? Those are they whose hearts Allah hath sealed up and they follow their lusts.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
And those who are guided He increaseth Unto them guidance, and giveth them their piety.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Await they but the Hour, that it should come upon them on a sudden? Tokens thereof are already come, so how shall it be with them when there cometh Unto them their admonition!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
So know thou that there is no god save Allah, and ask forgiveness for thy fault and for believing men and believing women. And Allah knoweth well your moving about and your place of rest.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
And those who believe say wherefore hath not a Surah been revealed? Then when there is sent down a Surah firmly constructed, and fighting is mentioned therein, thou seest those in whose hearts is a disease looking at thee with the look of one swooning Unto death. So also for them!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Their obedience and speech are known. Then when the affair is determined, if even then they gave credence Unto Allah, it would have been better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Then, belike ye are, if ye turn to cause corruption in the earth away, and to sever your kinship.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Those are they whom Allah hath cursed, and then hath deafened them and blinded their sights.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Ponder then they not on the Qur'an, or are on the hearts locks thereof?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Verily those who have apostated on their backs after the guidance had become manifest Unto them, the devil hath embellished this apostacy for them and hath given them false hopes.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they said Unto those who detest that which Allah hath revealed: we shall obey you in part of the affair; and Allah knoweth their talking in secret.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
How then shall it be when the angels shall take them away at death smiting their faces and their backs!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they followed that which angered Allah and detested His good-will; so He made their works of non-effect.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Deem those in whose hearts is a disease that Allah will never bring to light their secret malevolence?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
And if We willed, We would surely shew them Unto thee, so that thou shouldst surely know them by their marks. And thou shalt surely know them by the mode of their speech. And Allah knoweth your works.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And of a surety We shall prove you all until We know the strivers among you and the steadfast, and We shall prove your states.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Verily those who have disbelieved and have hindered others from the way of Allah and have opposed the apostle after the guidance had become manifest Unto them, shall not hurt Allah at all, and anon He shall render their works of non effect.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
Ye who believe! obey Allah and obey the apostle, and render not Your works vain.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Verily those who disbelieve and hinder others from the way of Allah and then die as infidels, Allah shall by no means forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
Wherefore faint not, nor cry out for peace; and ye shall be triumphant. And Allah is with you, and He will not defraud you of your works.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of the world is but a sport and a pastime. And if ye believe and fear, He will give you your hire, and will not require of you your substance.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He required it of you and importuned you, ye would be niggardly, and He will bring to light your secret malevolence.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Behold! ye are those who are called to expend in the way of Allah, then there are of you some who are niggardly. And whosoever is niggardly is niggardly only to himself. And Allah is Self-sufficient, and ye are the needy. And if ye turn away, He will substitute for you another people, and then they will not be the likes of you.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Verily We! a victory We have given thee, a manifest victory.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive thee that which hath preceded of thy fault and that which may come later, and may accomplish the more His favour on thee, and may keep thee guided on the straight path.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And that Allah may succour thee with a mighty succour.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
He it is Who sent down tranquillity into the hearts of the believers that they might increase belief Unto their belief. And Allah's are the hosts of the heavens and the earth and Allah is ever Knowing, Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
He hath ordained war in order that He may cause the believing men and the believing women enter Gardens whereunder rivers flow, as abiders therein, and that He may expiate from them their misdeeds. And that is with Allah ever an achievement mighty.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And that He may chastise the hypocritical men and the hypocritical women and the associaters and the associatresses, the thinkers of evil thought concerning Allah. Unto them shall befell the evil turn of fortune, and Allah shall be wroth with them and shall curse them, and He hath gotten ready for them Hell: an ill destination!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
And Allah's are the hosts of the heavens and the earth, and Allah is ever Mighty, Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Verily We! We have sent thee as a witness and a bearer of glad tidings and a warner.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
That ye may believe in Allah and His apostle, and may assist Him and honour Him, and may hallow Him at dawn and evening.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Verily those who swear fealty Unto thee, only swear fealty Unto Allah: the hand of Allah is over their hands. So whosoever breaketh his oath, breaketh it only to his soul's hurt; and whosoever fulfilleth that which he hath convenanted with Allah, him anon He shall give a mighty hire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
Those who lagged behind of the desert Arabs Will presently say Unto thee: our properties and our households kept us occupied, so ask thou forgiveness for Us. They say with their tongues that which is not in their hearts. Say thou: who can avail you in aught against Allah, if He intended you hurt or intended you benefit? Yea! Allah is of that which ye work ever Aware.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
Yea! ye imagined that the apostle and the believers would never return to their households, and that became fair-seeming in your hearts, and ye bethought an evil thought, and ye became a people doomed.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And whosoever believeth not in Allah and His apostle then verily We have gotten ready for the infidels a Blaze.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And Allah's is the dominion of the heavens and the earth. He forgivEth whomsoever He Will and tormenteth whomsoever he will; and Allah is ever Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who lagged behind will presently, When ye march forth to take spoils, leave us, we shall follow say you. They intend to change the word of Allah. Say thou: ye shall by no means follow us; thus hath Allah said afore. Then they will say: Aye! ye envy us. Aye! little it is they are wont to understand.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say thou Unto those who lagged behind of the desert Arabs: surely ye shall be summoned against a people endued with exceeding violence then ye will fight them or they will submit. Then if ye obey, Allah will give ye a goodly hire; but if ye turn away even as ye turned away aforetime. He will torment you with a torment afflictive.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no blame upon the blind, nor is there blame upon the lame, nor is there blame upon the sick. And whosoever obeyeth Allah and His apostle, He will cause him enter Gardens where under rivers flow; and whosoever turneth away, him He shall torment with a torment afflictive.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Assuredly well-pleased was Allah with the believers when they sware fealty Unto thee under the tree, and he knew that which was in their hearts, wherefore He sent down tranquillity on them, and rewarded them with a victory near at hand.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And spoils in abundance that they are taking. And Allah is ever Mighty, Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah hath promised you abundant spoils that ye shall take, and these He hath hastened to you, and hath restrained the hands of people from you, that it may be a sign Unto the believers, and that He may guide you to a straight path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And He promiseth another victory, over which ye have as yet no power: Allah hath surely encompassed it; and Allah is over everything ever Potent.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And had those who disbelieve fought against you, surely they would have turned their backs, and then they would have found no patron nor helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
That hath been the dispensation of Allah with those who passed away aforetime; and thou shalt not find in the dispensation of Allah any change.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And He it is Who restrained their hands from you and Your hands from them, in the vale of Makka so, after He had made you superior to them; and Allah is of that which ye work ever a Beholder.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They were those who disbelieved and hindered you from the Sacred Mosque and hindered the detained offering that it should arrive at the goal thereof. And had it not been for believing men and believin women whom ye knew not, and that ye might have trampled on them and thus there might have befallen you crime on their account unwittingly. He had not restrained your hands from them. But this He did that He might bring into His mercy whomsoever He will. Had they been distinguished one from another, surely We had tormented those who disbelieved among them with a torment afflictive.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When those who disbelieve had put in their hearts a zeal, the zeal of Paganism, then Allah sent down His tranquillity upon His apostle and upon the believers, and kept them fixed on the way of piety, and they were worthy thereof and meet therefor; and Allah is of everything ever Knower.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Assuredly did Allah shew a true vision to His apostle in very truth; ye shall surely enter the Sacred Mosque, if Allah willeth, secure, having your heads shaven and your hair cut, and ye shall not fear. He knoweth that which ye know not; wherefore He appointed, beside that, a victory near at hand.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
He it is Who hath sent His apostle with the guidance and the true religion that He may make it prevail over all other religions, and Allah sufficeth as a Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the apostle of Allah. And those who are with him are stern against the infidels and merciful among themselves; Thou beholdest them bowing down and falling prostrate, seeking grace from Allah and His goodWill Mark of them is on their faces from the effect of prostration: such is their similitude in the Taurat. And their similitude in the lnjil: like Unto a sown corn that putteth forth its shoot and strengtheneth it, and swelieth, and riseth upon the stalk thereof delighting the sowers. Such are the early Muslims described that He may enrage the infidels with them. Allah hath promised Unto those among them who believe and work righteous works, forgiveness and a mighty hire.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O ye who believe! be not forward in the presence of Allah and His apostle, and fear Allah; verily Allah is Hearing, Knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
Ye who believe raise not your voices above the voice of the prophet, nor shout loud Unto him in discourse as ye shout loud Unto one another, lest your works may be rendered of non-effect, while ye perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Verily those who lower their voices in the presence of the apostle of Allah -those are they whose hearts Allah hath disposed Unto piety: theirs will be forgiveness and a mighty hire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Verily those who call aloud Unto thee from without the inner apartments, most of them reflect not."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And had they had patience till thou camest forth Unto them, it had surely been best for them; and Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
ye who believe! if an evil-doer Came Unto you with a report, then inquire strictly, lest ye hurt a people in ignorance and repent thereafter of that which ye have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that verily among you is the apostle of Allah. Were he to obey you in many affairs, ye would surely be in trouble but Allah hath endeared belief to you and hath made it fair-seeming in your hearts, and hath rendered detestable Unto you infidelity and wickedness and disobedience. These! they are the men of rectitude.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
Through grace from Allah and His favour; and Allah is Knowing, Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two parties of the believers fall to mutual fighting, then make reconciliation between the twain. Then if one of them rebelleth against the other, fight that Party which rebelleth till it returneth Unto the affair of Allah; then if it returneth, make reconciliation between the twain with justice and be equitable; verily Allah loveth the equitable.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are but brethren; wherefore make reconciliation between your brethren and fear Allah, that haply ye may be shewn mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O ye who believe! let not one group scoff at another group, belike they may be better than they are, nor let some women scoff at other women, belike they may be better than they are. And traduce not one another, nor revile one another by odious appellations! ill is the name of sin after belief. And whosoever will not repent, then those, they are the wrong-doers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O ye who believe! avoid much suspicion; verily some suspicion is a sin. And espy not, nor backbite one another: would any of you love to eat the flesh of his dead brother? Ye detest that. And fear Allah verily Allah is Relenting, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O Humankind verily We! We have created you Of a male and female, and We have made you nations and tribes that ye might know one another. Verily the noblest of you with Allah is the most God-fearing of you; verily Allah is Knowing, Aware,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The desert Arabs say: we have believed. Say thou: believe not, but rather say: We have submitted; and belief hath not yet entered into your hearts. And if ye obey Allah and His apostle, He shall not diminish from you aught Of you, wOrks verily Allah is Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The believers are only those who believed in Allah and His apostle and thereafter doubted not, and strave with their riches and their persons in the cause of Allah. Those! they are the truthful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say thou: Would ye appraise Allah of your religion, whereas Allah knoweth whatsoever is in the heavens and whatsoever is in the earth, and Allah is of everything Aware!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They make it a favour Unto thee that they have surrendered. Say thou: deem not your surrender a favour Unto me; nay! Allah hath conferred a favour Unto you inasmuch as He hath guided you to belief, if ye are sincere.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Verily Allah knoweth the Unseen of the heavens and the earth; and Allah is the Beholder of that which ye work.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the Qur'an glorious, We have sent thee as a warner.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Aye! they marvel that there hath come Unto them a warner from among themselves; so the infidels Say: this is a thing wondrous!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
Shell We be brought back when we are dead and have become dust? That is a return remote!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
Surely We know that which the earth consumeth of them, and with Us is, Book preserved.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Aye! they belie the truth when it cometh Unto them; wherefore they are in an affair confused.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not looked up to the heaven above them, in what wise We have constructed and bedecked it, and that therein is no rift?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth! We have spread it forth, and have cast therein firm mountains, and have caused to grow therein of every beauteous kind of plants:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
An insight and an admonition for every bondman penitent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We have sent down from the heaven water brest wherewith We have caused gardens to grow and the grain reaped.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And tall date-palms laden with clusters ranged.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
As a provision for our bondmen; and therewith We have quickened a dead land. Even so will be the coming forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
And before them the people of Nuh belied, and so did the dwellers Of Rass and the Thamud.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And the A-ad, and Fir'awn. and the brethren of Lut.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the dwellers in the wood, and the people of Tubba. Each one belied the apostles, wherefore fulfilled was My judgement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Are We then wearied with the first creation? Aye! they are in dubiety regarding a new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
And assuredly We have created man and We know whatsoever his soul whispereth Unto him, and We are nigher Unto him than his jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
Behold! when the two receivers receive-one on the right hand and one on the left a sitter.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Not a word he uttereth but there is with him a watcher ready.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the stupor of death will come in truth: this is that which thou hast been shunning.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the trumpet will be blown: this is the Day of the Threatening.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And there shall come every soul therewith shall be a driver and a witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
Assuredly thou wast in neglect thereof; now We have removed from off thee thy veil, so thy sight Today is piercing.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his companion will say: this is that which with me is ready.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
Cast ye twain into Hell every Person rebellious, contumacious.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
Hinderer o fgood, trespasser, doubter\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
Who set up with Allah another god. So cast him ye twain into the torment severe.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His companion will say: O our Lord! caused him not to transgress but he was himself in error far off.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
Allah will say: wrangle not in My presence, and had already proferred Unto you the threat.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The Word will not be changed in My presence, nor am an oppressor at all Unto My bondmen.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
Mention the Day whereon We shall say Unto the Hell: art thou filled? and it will say: is there yet any addition?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And brought nigh will be the Garden Unto the God-fearing, not far-off.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
This is that which ye were promised: for every oft- returning heedful one.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
That feareth the Compassionate in the unseen and cometh to Him with a heart penitent:\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter it in peace. This is the Day of Abidence.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
Theirs therein will be whatsoever they list; and with Us will be yet more.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And how many a generation have We destroyed before them, who were mightier in power than they, and they traversed the cities! No place of refuge could they find.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Verily herein is an admonition Unto him who hath a heart, or giveth ear while he is heedful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And assuredly We created the heavens and the earth and whatsoever is in between the twain in six days, and there touched Us naught of weariness.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So bear thou patiently with that which they say, and hallow the praise of thine Lord before the rising of the sun and before its setting.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And in the night-time hallow Him, and also after the prescribed prostration.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And hearken thou: the Day whereon the caller will call from a place quite near.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day whereon they will surely hear the shout - that is the Day of coming forth.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Verily We! it is We Who give life and cause death, and Unto Us is the journeying.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
That shall be the Day whereon the earth will be cleft from off them as they hasten forth. That shall be a gathering Unto Us easy.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We are the best Knower of that which they say, and thou art not over them over them tyrant. Wherefore admonish thou by the Qur'an him who feareth My threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the dipersing winds that disperse.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And the clouds bearing a load.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And the ships that glide with ease.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And the angels who distribute the affair.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Verily that wherewith ye are threatened is surely true.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And verily the Requital is surely to befall.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven full of paths.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Verily ye are in a divided opinion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Turned aside therefrom is who is turned aside.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Perish the conjecturers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Those who are in heedlessness neglectful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask: when is the Day of Requital coming?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
It will be the Day whereon in the Fire they will be burned\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
Taste your burning: this is that which ye sought to be hastened.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Verily the God-fearing will be amid Gardens and water- springs.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Taking that which their Lord will vouchsafe Unto hem. Verily they have been before that well-doers.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
Little of the night they were wont to slumber.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And in the dawns they prayed for forgiveness.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their substance was the right of the beggar and non- beggar.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And on the earth there are signs for those who would be convinced.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And also in Your own selves. Behold ye not?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is Your provision and that which ye are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
By the Lord of the heaven and the earth it is sure, even as it is a fact that ye are speaking.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Hath there come Unto thee the story of Ibrahim's honoured guests?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came in Unto him, and said:'peace!' he said: 'peace'! - people unknown.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he turned away privately Unto his household, and brought a calf fatted.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And he set it before them, and said: wherefore eat ye not?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived a fear of them. They said: fear not. And they gave him the tidings of a youth knowing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
Then his wife drew near vociferating, and smote her face, and said: an old barren woman!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said: even so saith thine Lords Verily He! He is the Wise, the Knower.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
He said: what then is your errand! O ye sent ones!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said: verily we are sent Unto a people, guilty.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
That we may send down upon them stones of baked clay.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
Marked, from before thy Lord, for extravagant.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
Thus We brought forth from there in who were believers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
And We found not therein more than one house of the Muslims.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We left therein a sign for those who fear the afflictive torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Musa also was a lesson, when We sent him Unto Fir'awn with authority manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
Then he turned away with his court, and said: a magician or a madman.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
Then We laid hold of him and his hosts and flung them into the sea, and he was reproachable.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in `A-ad also was a lesson, when We sent against them the barren wind.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It left not aught whereon it came but it made it as matter decayed.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamud's also was a lesson, when it was said Unto them: enjoy yourselves for a season.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
Then they disdained the command of their Lord; wherefore the bolt laid hold of them even while they looked on.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
So they were not able to stand, nor could they help themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And the people of Nuh We destroyed aforetime; verily they were a people transgressing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
And the heaven! We have built it with might, and verily We are powerful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth! We have stretched it forth beneath; an excellent Spreader are We!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of every thing We have created pairs, that haply ye may remember.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Flee therefore Unto Allah; verily I am Unto you from Him a warner manifest.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And set not up another god with Allah; verily I am Unto you from Him a warner manifest.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Likewise, there came not an apostle Unto those before them but they said: a magician or a madman!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they bequeathed its Unto each other! Nay! they are a people contumacious.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away thou from them, not thou art blameworthy.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And admonish, for verily admonition profiteth the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
And have not created the Jinn and mankind but that they should worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I seek not any provision from them, nor I desire that they should feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Verily Allah! He is the Provider, Owner of power, Firm.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
So verily Unto those who do wrong there is a portion like Unto the portion of their fellows; wherefore let them not ask Me to hasten on.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Woe, then, Unto those who disbelieve in their Day which they are promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the mount.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
By the book inscribed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In parchment unrolled.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
By the House Frequented.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
By the roof elevated.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
By the sea overflowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Verily the torment of thine Lord is sure to befalls\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
Of it there is no averter.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day whereon the heaven will shake with an awful shaking.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains will move away with an awful movement.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Woe, then, will be on that Day to the beliers\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Those who in wading sport themselves.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
On the Day whereon they will be pushed into Hell-Fire with a dreadful push.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
This is the Fire which ye were wont to believe.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic? or ye still see not clearly!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Roast therein; endure it or endure it not, thereof it is equal Unto you. Ye are only being requited for that which ye have been working.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Verily the God-fearing will bein Gardens and Delight.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Rejoicing in that which their Lord hath vouchsafed Unto them; and their Lord will protect them from the torment of the Flame.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
Eat and drink with relish for that which ye have been working.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
Reclining on couches ranged. And We shall couple them with maidens wide eyed.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believe and whose progeny follow them in belief. We shall cause their progeny to join them, and We shall not diminish Unto them aught of their own work. Every man is for that which he hath earned a pledge.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We shall increasingly give them fruit and meat such as they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
They will therein snatch from one another a cup; therein will be neither vain babble nor sin.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
And there will go round on them youths appointed to attend them as though they were pearls hidden.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And they will advance Unto each other asking questions.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They will say: verily we were aforetime, midst our household, ever in dread.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
Wherefore Allah hath obliged us, and hath protected us from the torment of the Scorch.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Verily we were wont to pray Unto Him aforetime; verily He! it is He, the Benign, the Merciful.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Wherefore admonish thou! thou art not, by the grace of thy Lord, a soothsayer or a madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or say they: a poet for whom we wait some adverse turn of fortune!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say thou: waits verily I am, with you, among the waiters.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Enjoin them their understandings to this? or are they a people conumacious?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or say they: he hath fabricated it: aye they will not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Let them bring a discourse like thereUnto, if they say sooth.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Have they not been created by aught, or are they the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Created they the heavens and the earth! Aye! they will not be convinced.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Are with them the treasures of thy Lord! or are they the dispensers?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Have they a stairway whereby they overhear? Then let their listener bring an authority manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Hath He daughters and ye sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or askest thou a hire from them so that they are with debt laden?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Is with them the Unseen, and they write it down!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Seek they to lay a plot? Then those who disbelieve it is they who shall be plotted against.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Is theirs a god beside Allah? Hallowed be Allah from that which they associate!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And if they should see a fragment of the heaven falling down, they would say: it is only clouds piled up.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
Wherefore let them alone, till they meet their Day whereon they shall swoon.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
A Day whereon their plotting will avail them not at all, nor will they be succoured.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And verily for those who do wrong there is a torment before that; but most of them know not.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
And wait thou patiently the judgment of thy Lord; verily thou art before Our eyes; and hallow the praise of thy Lord when thou uprisest.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And in the night also hallow Him, and at the setting of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it setteth.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your companion hath not gone astray, nor hath he erred.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
And he speaketh not of his own desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is but a revelation revealed.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
One of mighty powers hath taught it him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
One strong of make. Then he stood straight.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he was on the uppermost horizon.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Thereafter he drew nigh, then he let himself down.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
Till he was two bows length off or yet nearer.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
Thus He revealed Unto His bondman whatsoever He revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart lied not in that which he saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will ye therefore dispute with him concerning that which he hath Seen?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And assuredly he saw him at another descent.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
Nigh Unto the lote-tree at the boundary.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Nigh thereto is the Garden of Abode.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When that covered the lote-tree which covered it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight turned not aside, nor it exceeded.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Assuredly he beheld of the sign of his Lord, the greatest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have ye then considered Al-Lat and AL-'uzza:\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat the other third?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
What!-Unto YOu the males and Unto Him the females?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That indeed is a division unfair!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are but names which ye have named, ye and your fathers, for which Allah hath sent down no authority. They follow but their fancy, and that which pleaseth their souls; whereas assuredly there hath come Unto them from their Lord the guidance.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Shall man have whatsoever he wisheth for!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
Allah's is the last and the first.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And many soever are angels in the heavens whose intercession shall not avail at all save after Allah hath given leave for whomsoever He listeth and pleaseth.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Verily those who believe not in the Hereafter name the angels with the names of females.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
And they have no knowledge thereof; they follow but a vain opinion, and verily a vain opinion attaineth not aught of the truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Wherefore withdraw thou from him who turneth away from Our admonition and seeketh not but the life of the world.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is their highest point of knowledge. Verily thine Lord! it is He Who is the Best Knower of him who strayeth from His way, and He is the Best Knower of him who letteth himself be guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And Allah's is whatsoever is in the heavens and whatsoever is in the earth, that He may recompense those who do evil for that which they worked and reward those who do good with good.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
They are those who avoid enormities of sin and abominations save the minor offences. Verily thy Lord is of vast for giveness: He is Best Knower of you when He produced you out Of the earth, and when ye were embryos in the bellies of your mothers. So justify not yourselves; He is the Best Knower of him who feareth Him.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Observedest thou him who turned away?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave little, and then stopped?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Is with him knowledge of the unseen so that he seeth?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Hath he not been told of that which is in the writs of Musa.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Ibrahim who faithfully fulfilled?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
To wit, that a burthened soul shall not bear the burthen of another.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that for man shall be naught save that wherefor he endeavoureth.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his endeavour shall be presently observed.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Thereafter he shall be recompensed therefor with the fullest recompense.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that Unto thy Lord is the goal.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He Who causeth to laugh and causeth to weep.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He Who causeth to die and causeth to live.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that He createth the pair, the male and the female.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From seed when it is emitted.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that upon Him is another bringing forth.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He Who enricheth and preserveth property.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that it is He Who is the Lord of Sirius.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that He destroyed the former 'A-ad.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And that Thamud! He left not.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And also the people of Nuh aforetime. Verily they were even greater wrong-doers and more contumacious.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And the subverted cities He overthrew.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
Then covered them with that which covered them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Which then of thy Lord's benefits wilt thou doubt?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warner of the warners of old.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
There hath approached the approaching Hour.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None, except Allah, can avert it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
At this discourse then marvel ye?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And laugh and not weep?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
And ye are behaving proudly.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So prostrate yourselves before Allah and worship.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour hath drawn nigh, and the moon hath been rent in sunder.. And if they behold a sign, they turn away and say: magic continuous.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And if they behold a sign, they turn away and say: ``magic continous"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
And they belied, and they followed their lusts; and every affair cometh to a final goal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And assuredly there hath come Unto them tidings wherein is a deterrent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Wisdom consummate. But warnings avail not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
Wherefore withdrew thou from them. The Day whereon the sum- moner Will summon mankind Unto a thing unpleasant.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
With looks downcast they will come forth, from the tombs, as though they were locusts scattered abroad.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Hastening toward the summoner. The infidels will say: this is a day diffrcult.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
There belied before them the people of Nuh. So they belied Our bondman Nuh and said: `a madman;' and moreover he was reproven.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Thereupon he prayed Unto his Lord: verily am overcome, so vindicate me.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
Then We opened the portals of heaven with water poured out.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And We made the earth break forth with springs; SO that the water met for an affair already decreed.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We bare him on a thing of planks and nails.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Moving forward under Our eyes: a requital for him who had been rejected.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And assuredly We left it for a sign. Is there then anyone who would be admonished?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
So how dreadful have been My torment and My warning!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And assuredly We have made the Qur'an easy for admonition; is there then any one who would be admonished?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
And there belied the 'A-ad; so how dreadful have been My torment and warning!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
Verily We! We sent against them a raging Wind On a day of calamity continuous.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Carrying men away as though they were trunks of palm-trees uprooted.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
So how dreodful have been My torment and My warning.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And assuredly We have made the Qur'an easy for admonition; is therethen any one who would be admonished!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
And the Thamud belied the warnings.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
And they said: a mere humanbeing from amongst us, and single! shall we follow him! verily then we should fall in error and madness.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Hath the Admonition been laid upon him from amongst us! Aye! he is a liar insolent.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
They shall know tomorrow whichsoever is a liar insolent.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
Verify We are sending the she-camel as a test for them, so watch them thou and have patience.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And declare thou Unto them that water hath been divided between them; every drinking shall be by turns.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
Then they called their fellow, and he took the sword and hamstrung her,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
So how dreadful have been My torment and My warnings.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Verily We We sent upon them one shout, and they became as the stubble of a fold-builder.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And assuredly We have made the Qur'an eary for admanirion: is there then any one who would be admonished.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lut belied the warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Verily We! We sent upon them a gravel-storm save the household of Lut; them We delivered at early dawn.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As a favour from us. Thus We recompense him who giveth thanks.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And assuredly he had warned them of Our grasp, but: they doubted the warnings.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And assuredly they solicited him for his guests: then We wiped out their eyes: taste then My torment and My warnings.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And assuredly there met them early in the morning a torment settled.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
Taste then My torment and My warnings.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And assuredly We have made the Qur'an easy for admonition; is there then any one who would be admonished.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And assuredly Unto the household of Fir'awn came the warning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
They belied Our signs everyone thereof; whereof We laid hold of them with the grip of our Mighty, Powerful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your infidels better than these? Or is there an immunity for you in the Writs?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or is it that they say: we are a multitude prevailing!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Anon will their multitude be vanquished, and they will turn the back.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Aye! the Hour is their appointed term, and the Hour shall be far more grievous and far more bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Verily the culprits shall be in great error and madness.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
On the Day whereon they shall be dragged into the Fire upon their faces, it shall be said Unto them: taste the touch of the Scorching.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Veriiy everything! We have created it by a measure.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our commandment shall be but one, as the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And assuredly We have destroyed your likes; so is there any one who shall be admonished?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And everything they have wrought is in the Writs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And everything, small and great, hath been written down.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Verily the God-fearing will be in Gardens and among rivers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In a good seat, near a Sovereign Omnipotent.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Compassionate.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Hath taught the Qur'an.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created man.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
He taught distinctness.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon are in a reckoning.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the herbs and the trees do obe isance."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the heaven! He hath elevated it, and He hath set the balance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
That ye should not trespass in respect of the balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
And observe the weight with equity, and make not deficient the balance.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth! He hath lain it out for the creatures.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein are fruit and palm-trees sheathed.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And grain chaffed and other food.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Which, then, of the benefits of your Lord, will ye twain belie?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man of clay like, Unto pottery.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And He created the Jinn of a flame of fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Which, then, of the benefits of your Lord will ye twain belie\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
He is Lord of the two easts and Lord of the two wests.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He hath let loose the two seas.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
In-between the twain is a barrier which they pass not.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
There come forth from the twain the pearl and the coral.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
His are the ships with elevated sails upon the sea like mountains.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Everyone that is thereon will Pass away.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
And there will remain the countenance of thine Lord, Owner of Majesty and Beneficence.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Which, then, of the benefits of your Lord, will ye twain belie?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Of Him beggeth whosoever is in the heavens and the earth; every day He is in a new affair.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
Anon We shall direct Our selves to you, O ye two classes.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O assembly of Jinn and man! if ye be able to pass out of the regions of the heavens and the earth, then pass out; ye can not pass out except with authority.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
There shall be sent against you both flame of fire and smoke, and ye shall not be able to defend yourselves.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
And when the heaven will be rent in sunder and will become rosy like Unto red hide.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Whfch, then, of the benefits of your Lord will ye twain belie!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
Of his sin will be questioned that Day neither man nor jinn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The culprits will be recognised by their marks, and will be lain hold of by the forelocks and the feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
Yonder is the Hell which the culprits belied.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
Going round between it and balling water fierce.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
And for him who dreadeth the standing before his Lord will be two Gardens.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
With spreading branches.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In which, will be two fountains running.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In which will be of every fruit two kinds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining on carpets whereof the linings will be of brocade; and the fruit of the two Gardens shall be near at hand.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Therein shall be those of refraining looks whom before them hath deflowered neither man nor jinn.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Which, then, of the benefits of Your Lord will ye twain belie?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
As though they are jacinth and coral.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Shall the recompense of kindness be aught save kindness?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And beside the two there will be two other Gardens.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Which, then, of the benefits of your Lord will ye twain beli?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Dark-green.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In which will be two fountains gushing forth.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In which will be fruit, the date-palm and pomegranate.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Which, then, of the benefits of Your Lord will ye twain belie?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
Therein will be damsels agreeable and beauteous.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Fair ones, confined in tents.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Which, then, of the benefits of Your Lord will ye twain belie?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
There hath deflowered them neither man nor jinn.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Which, then, of the benefits of Your Lord will ye twain belie?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining upon cushions green and carpets beauteous.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Which, then, of the benefits of your Lord will ye twain belie?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blest be the name of thine Lord, Owner Of Majesty and Beneficence!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When there happeneth Event.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
There is about its happening no lie.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
Abasing exalting.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
This will happen when the earth is shaken, shaken\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains are crumbled, crumbled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
So that they become dust seattered.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And ye are classes three.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Those on the right hand; how happy shall those on the right hand be!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And those on the left hand; how miserable shall those on the left hand be!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And the preceders are the pre-ceders.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
Those! they shall be the brought nigh,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In Gardens of Delight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A multitude from the ancients.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few from the later generations.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
On couches in wrought with gold.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining thereon facing each other.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
There shall go round Unto them youths ever-young.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With goblets and ewers and a cup of limpid drink.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Whereby there shall be neither headiness nor will they be inebriated.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And with fruit from that which they choose.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And with flesh of fowls from that Which they desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And there will be fair ones large eyed.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
The likes Unto pearls hidden.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
A recompense for that which they have been working.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
Therein they hear no vain or sinful discourse.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
Nought but the saying: peace! peace!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And the fellows on the right hand; how be happy shall the fellows on the right hand be!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
Midst lote-trees thornless.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And plantains laden with fruit.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And a shade ever-spread.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And water everflowing.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit abundant.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Neither ending nor forbidden.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And carpets raised.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Verily We! We have created those maidens by a creation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And have made them virgins.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Loving, of equal age.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For the fellows on the right hand.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A multitude from the ancients.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a multitude from the later generations.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And the fellows on the left hand; how miserable Shall the fellows on the left hand be!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
Amidst scorching wind and scalding water.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And the shade of black smoke.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Neither cool nor pleasant.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Verily they have been heretofore affluent.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And they have been persisting in the heinous offence.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they were wont to say: when we have died and become dust and bones, shall we, then, verily be raised?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
We and our fathers of old?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say thou: verily the ancients and those of later generations:\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
Are going to be assembled on the appointed time of a Day Known.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then verily ye, O ye erring, denying people.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
Shall surely eat of the tree of Az-Zqqum.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
And shall fill therewith your bellies.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
And shall be drinkers thereon of boiling water.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
Drinkers even as the drinking of thirsty camels.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
This shall be their entertainment on the Day of Requital.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We! it is We Who created you: wherefore confess ye not?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Behold! - that which ye emit.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Create him ye, or are We the Creator?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We! it is We Who have decreed death Unto you all. And We are not to be outrun.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
That We may substitute others like Unto you and produce you into that which ye know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And assuredly ye have fully known the first Production Wherefore heed ye not?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Behold! - that which ye sow.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Cause it ye to grow, or are We the Grower?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We willed, surely We would make it chaff, so that ye would be left wondering.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
Verily we are undone.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
Aye! we are deprived!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Behold! - the water which ye drink:\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Send it down ye from the raincloud, or are We the Sender down?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We willed, surely We would make it brackish. Wherefore give ye not thanks?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Behold! - the fire which ye strike out:\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Produce ye the tree thereof, or are We the Producer?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We! it is We Who made it a reminder and a provision Unto the campers.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Wherefore hallow thou the name of thy Lord, the Mighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
I swear by the setting of the stars -\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And verily that is a mighty oath, if ye but knew!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
That it is a Recitation honourable.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a Book Hidden.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
Which none can touch except the purified.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
It is a revelation from the Lord of the worlds.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it this discourse that ye hold lightly?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And make it your provision that ye should belie it?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Wherefore then - when the soul cometh up to the wind-pipe -\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And ye are then looking on.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
And We are nigher Unto him than ye are, but ye behold not-\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Wherefore then, if ye are not to be requited\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Cause ye it not to return, if ye say sooth?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Then if he be of the broughtnigh.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
For him shall be comfort, and fragrance and a Garden of Delight.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he be of the fellows on the right hand,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then: peace Unto thee, for thou art of those on the right hand.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
And if he be of the beliers, the erring,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then an entertainment of boiling water.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And roasting in a Blaze.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Verily this! this is the very truth.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
Wherefore hallow thou the name of thy Lord, the Mighty!\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Whatsoever is in the heavens and the earth halloweth Allah; and He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the dominion of the heavens and the earth; He giveth life and He causeth to die; and He is over everything Potent.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, and the OutWard and the inward, and He is of everything the Knower.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in six days; then He established Himself on the Throne. He knoweth whatsoever plungeth into the earth and whatsoever cometh forth therefrom, and whatsoever descendeth from the heaven and whatsoever ascendeth thereto; and He is with you wheresoever ye be. And Allah is of whatsoever ye work a Beholder.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the dominion of the heavens and the earth, and Unto Allah will all affairs be brought back.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He plungeth the night into the day, and plungeth the day into the night, and He is the Knower of whatsoever is in the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His apostle, and expend of that whereof He hath made you successors to. Those of you who believe and expend - theirs shall be a great hire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
And what aileth you that ye believe not in Allah whereas the apostle is calling you to believe in your Lord, and He hath already taken your bond, if ye are going to be believers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
He it is Who sendeth down Unto His bondman manifest signs that He may bring you forth from darknesses into the light; and verily Allah is Unto you Tender, Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what aileth you that ye expend not in the way of Allah, when Allah's shall be the inheritance of the heavens and the earth! Those among you who expended and fought before the victory shall not be held equal They are mightier in rank than those who expended and fought afterwards; Unto each hath Allah promised good; and Allah is of whatsoever ye work Aware.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will lend Allah a goodly loan, so that He may multiply it for him, and his shall be a hire honourable?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
Mention the Day whereon thou shalt see the believing men and believing women, their light running before them and on their right hands: glad tidings Unto you To-day: Gardens whereunder rivers flow, abiders therein they will be. That! it is the mighty achievement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
It shall be the Day whereon the hypocritical men and hypocritical women will say Unto those who believe: wait for us that we may borrow some of your light. Then betwixt them there will be set a high wall, wherein will be a door, the inside whereof hath mercy, while the outside thereof is toward the torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
They will cry unto them: have we not been with you? They will say: 'yea! but ye tempted your souls, and ye Waited, and ye dubitated, and your vain desires beguiled you until the affair of Allah came, and in respect to Allah the beguiler beguiled you.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
To-day therefore no ransom will be accepted of you nor of those who openly disbelieved; your abode is the Fire; that is your companion; a hapless destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is not the time yet come unto those who believe, that their hearts should humble themselves to the admonition of Allah and to the truth which hath come down, and that they become not as those who were vouchsafed the Book aforetime, and the time become extended unto them, and so their hearts became hard? And many of them are transgressors\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah quickeneth earth after the death thereof. Surely We have propounded unto you the signs, that haply ye may reflect.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Verily the alms-giving men and alms-giving women--and they are lending unto Allah a goodly lone--it shall be multiplied for them and theirs shall be a hire honourable.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in Allah and His apostles - those! they are the saints and martyrs in the sight of their Lord; theirs will be their full hire and their light. And those who disbelieved and belied Our signs--they shall be the fellows of the Blaze.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of the world is but a play and a pastime, and an adornment and a self-glorification among you and vying in respect of riches and children; as the likeness of vegetation after rains whereof the growth pleaseth the husbandmen, then it withereth and thou seest it becoming yellow, then it becometh chaff. And in the Hereafter there is both a grievous torment and forgiveness from Allah and His pleasure, and the life of the world is but a vain bauble.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Strive with one another in hastening toward forgiveness from your Lord and toward a Garden whereof the width is as the width of the heavens and the earth, gotten ready for those who beiieve in Allah and His apostles. This is the grace of Allah; He vouchsafeth It Unto whomsoever He will; and Allah is Owner of mighty grace.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
Naught of distress befalleth the earth or your persons but it is inscribed in the Book even before We have created them. Verily with Allahs that is easy.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
This is announced lest ye sorrow for the sake of that which hath escaped you, or exult over that which He hath vouchsafed Unto you: And Allah loveth not any vainglorious boaster:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Ihey who are niggardly and command mankind to niggardliness. And whosoever turneth away, then verily Allah! He is the Self-sufficient, the praise-worthy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Assuredly We sent Our apostles with evidences, and We sent down With them the book and the balance, that people might observe equity. And We sent down iron wherein is great violence and also advantages Unto mankind, and that Allah may know him who succoureth Him, unseen, and His apostles. Verily Allah is Strong, Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And assuredly We sent Nuh and Ibrahim, and We placed in the posterity of the twain the prophecy and the Book. Then of them some are guided ones, and many of them are transgressors.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Thereafter in their footsteps We caused Our apostles to follow, and We caused lsa, son Of Maryam, to follow them, and We vouchsafed Unto him the Injil, and We placed In the hearts of those who followed him tenderness and mercy. And asceticism! they innovated it- We prescribed it not for them Only seeking Allah's pleasure yet they tended it not with tendence due thereto. So We vouchsafed Unto such of them as believed their hire, and many of them are transgressors.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O ye who believe! fear Aliah and believe in His apostle; He will vouch safe Unto you two portions of His mercy and will appoint for you a light wherewith ye will walk, and He will forgive you. And Allah is Forgiving, Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
This He will award that the people of the Book may know that they control naught of the grace of Allah, and that the grace is in Allah's hand; He vouchsafeth it Unto whomsoever He wilt, And Allah is Owner of mighty grace.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Of a surety Allah hath heard the saying of her that disputed with thee concerning her husband and bewailed Unto Allah; and Allah hath heard your mutual discourse. Verlly Allah Is Hearing, Beholding.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
As to those among you who put away their wives by pronouncing zihar their mothers they are not. Their mothers are but those who gave them birth; and verily they utter a saying disputable and false. And verily Allah is Pardoning, Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
Those who put away their wives by pronouncing zihar and thereafter would retract that which they have said, then upon them is the freeing of a slave before the twain touch each other. That is that wherewith ye are exhorted; and Allah is of whatsoever ye work Aware.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And whosoever findeth not a slave to free on him is the fasting for two months in succession before the twain touch each other, and on him who is not able to do so is the feeding of sixty needy ones. That is in order that ye may believe in Allah and His apostle; and these are the ordinances of Allah. And for the infidels is a torment afflictive.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Verily those who oppose Allah and His apostle shall be abased even as those before them were abased; and of a surety We have sent down manifest signs. And for the infidels will be a torment ignominious.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day whereon Allah will raise them all together and declare Unto them that which they have worked. Allah hath taken count thereof, whilst they forget it. And Allah is over everything a Witness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Observest thou not that Allah knoweth whatsoever is in the heavens and whatsoever is in the earth! There is no whispering among three but He is their fourth, nor among five but He is their sixth, nor fewer than that nor more but He is with them wheresoever they may be; and thereafter He will declare Unto them, on the Day of Judgment, that which they have worked. Verily Allah is of everything Knower.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Observest thou not those who were forbidden whispering and they afterwards returned to that which they had been forbidden; and they whisper Unto each Other of sin, transgression and disobedience reward the apostle! And when they came Unto thee, they greet thee with that wherewith Allah greeteth thee not, and say within themselves: wherefore god tormented us not for that which we say? Sufficient Unto them is Hell, where in they will roast: a hapless destination!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O ye who believe! when ye whisper together, whisper not of sin, transgression and disobedience toward the apostle; but whisper for virtue and piety. And fear Allah Unto Whom ye will be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Whisper is only from the Satan that he may grieve those who believe; and he can harm them not at all save with the leave of Allah. Wherefore in Allah let the believers trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O ye who believe! when it is said Unto you: make room in your assemblies, then make room; Allah will make room for you. And when it is said: rise up, then rise up; Allah will exalt those who believe among you and those who are vouchsafed knowledge, in degrees. And Allah is of whatsoever ye work Aware.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O ye who believe! when ye go to whisper with the apostle, offer alms before your whispering; that is better for you and purer. Then if ye find not the wherewith, then verily Allah is Forgiving, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Shrink ye at your offering the alms before your whispering! Then, when ye could do it not, and Allah relented toward you, establish prayer and pay the poor-rate and obey Allah and His apostle. And Allah is Aware of that which ye work.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Beholdest thou not those who take for friends a people with whom Allah is angered? They are neither of you nor of them, and they swear to a lie while they know.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah hath gotten ready for them a torment grievous; verily vile is that which they have been working.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have taken their oaths as a shield, and they have hindered others from the way of Allah; wherefore theirs shall be a torment ignominious.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
There will not avail them against Allah their riches or their children at all. Th are the fellows of the Fire; therein they will be abiders.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
This shall befall on a Day whereon Allah shall raise them all together; then they will swear Unto Him even as they swear Unto you, deeming themselves up on aught. Lo! verily they! they are the liars.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
The Satan hath overpowered them, and so hath caused them to forget the remembrance of Allah. These are the band of the Satan. Lo! verily it is the Satan's band that shall be the losers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Verily those; who oppose Allah and His apostle - they are among the lowest.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah hath prescribed: surely shall overcome, and My apostles. Verily Allah is strong, Mighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
Thou shalt not find a people who believe in Allah and the Last Day befriending those who oppose Allah and His apostle, even though they be their fathers or their sons or their brethren or their kindred. These! He hath inscribed faith on their hearts and hath strengthened them with a spirit from Him: and He shall make them enter Gardens whereunder rivers flow as abiders therein. Allah is well pleased with them, and they are well pleased with Him. These are Allah's band. Lo! verily it is the Allah's band that are the blissful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Whatsoever is in the heavens and whatsoever is in the earth halloweth Allah, and He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
He it is that drave forth those of the people of the Book who disbelieved from their homes at the first gathering, Ye imagined no that they would go -forth; and they imagined that their fortresses would protect them against Allah. Wherefore Allah came upon them whence they reckoned not, and cast terror in their hearts so that they made their houses desolate with their own hands and the hands of the believers. So learn a lesson. O ye endued with insight!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And had not Allahg prescribed banishment for them, surely He would have tormented them in the world; and theirs in the Hereafter is the torment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they opposed Allah and His apostle, and whosoever opposeth Allah, then verily Allah is Stern in chastisement.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whatsoever fine palms ye cut down or left standing on roots there of, it was by the leave of Allah, and in order that He might abase the transgressors.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And as to that which Allah restored Unto His apostle from them, ye rushed neither horse nor camel upon it but Allah giveth His apostles mastery over whomsoever He will. And Allah Is -over everything potent.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
Whatsoever Allah may restore Unto His apostle from the people of the cities is due Unto Allah and Unto the apostle and Unto the near of kin and the orphans and the needy and the wayfarer, so that it may not be confined to the rich among you. And whatsoever the apostle giveth you, take; and whatsoever he forbiddeth you, refrain from. And fear Allah; verily Allah is Stern in chastisement.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
And it is due Unto the poor Muhajirs who have been driven forth from their homes and their substance, seeking grace from Allah and His goodwill and succouring Allah and His apostle. These! they are the truthful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And it is also due Unto those who are settled in the dwelling and the faith before them, loving those who have migrated Unto them, and finding in their breasts no desire for that which hath been given them, and preferring them above themselves even though there was want amongst them. And whosoever is Preserved from covetousness of his soul, then those! - they are the blissful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And it is also due Unto those who came after them, saying: 'Our Lord! forgive us and our brethren who have preceded us in the faith, and place not in our hearts any rancour toward those who had believed. Our Lord! verily Thou art Tender, Merciful.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Beholdest thou not: those who dissemble saying Unto their brethren who disbelieve among the people of the Book: if ye are driven forth we shall surely go forth with you, and we, shall not ever obey anyone in your respect, and if ye are attacked, we shall surely succour you. And Allah beareth witness that surely they are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
Surely if they are driven forth, they shall not; go forth with them, and surely if they are attacked, they shall succour them, not, and even ifs they succoured them they would turn their backs; and then they shall not be succoured.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Surely ye are more awful in their breasts than Allah. That is because they are a people who understand not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They shall not fight against you, not even together, except in fenced townships or from behind walls. Their violence among themselves is strong; thou deemest them enjoined, whereas their hearts are diverse. That is because they are a people who reflect not.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
They are like those a little before them; they tasted the ill-effect of their affair, and theirs shall be a torment afflictive.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
They are like the Satan, when he saith Unto man: 'disbelieve,' then, when he disbelieveth, saith: verily I am quit of thee, verily I fear Allah, the Lord of the Worlds.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
Wherefore the end of the twain will be that they will be in the Fire, as abiders there in; that is the meed of the wrong-doers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O ye who believe! fear Allah, and let every soul look to that which it sendeth forward for the morrow. And fear Allah; veril Allah is Aware of that which ye work.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not as those who forgot Allah, wherefore He caused them to forget their own souls. Those! they are the transgressors.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the fellows of the Fire and the fellows of the Garden. Fellows of the Garden! they are the achievers!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Qur'an upon a mountain, thou wouldst surely have seen it humbling itself and cleaving in sunder for fear of Allah. Such similitudes We propound Unto mankind that haply they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, there is no God but He; Knower of the unseen and the seen. He is the Compassionate, the Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah, there is no God but He, the Sovereign, the Holy, the Author of Safety, the Giver of Peace, the Protector, the Mighty, the Mender, the Majestic. Hallowed be Allah from all that they associate!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Maker, the Fashioner; His are the excellent names. Him halloweth whatsoever is in the heavens and the earth, and He is the Mighty, the Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O ye who believe! take not Mine enemy and your enemy for friends, showing affection toward them, whilst they of a surety disbelieve in that which hath come Unto you of the truth, and have driven forth the apostle and yourselves because ye believe in Allah, your Lord, if ye have come forth to strive in My way and to seek My goodwill. Ye secretly show them affection, while I am best Knower of that which ye conceal and that which ya make known! And whosoever of you doth this, he hath surely strayed from the straight path.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
Should they come upon you, they will be enemies Unto you and will stretch out against you their hands and their tongues with evil; and fain would they that ye should disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
There will profit you neither your kindred nor your children on the Day of Resurrection. He shall decide between; and Allah is of that which ye you work Beholder.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
Surely there hath been an excellent pattern for you in Ibrahim and those with him, when they said Unto their people; verily we are quit of you and of that which ye worship beside Allah; we renounce you; and surely there hath appeared between us and you hostility and hatred for evermore until ye believe in Allah alone, - except the saying of Ibrahim Unto his father: surely I shall beg forgiveness for thee, and I have no power with Allah for thee at all. Our Lord! in Thee we put our trust, and Unto Thee we turn, and Unto Thee is the journeying.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord! make us not a trial for those who disbelieve, and forgive us, our Lord! verily Thou! Thou art the Mighty, the Wise.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Assuredly there hath been in them for you an excellent pattern-for him who hopeth for Allah and the last Day. And whosoever turneth away, then verily Allah! He is the Self-sufficient, the Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
Belike Allah may appoint between you and those of them whom ye hold as enemies affection. And Allah is Potent, and Allah is Forgiving, Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah forbiddeth you not that ye should deal benevolently and equitably with those who fought not against you on accouct of religion nor drave you out from your homes; verily Allah loveth the equitable,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah only forbiddeth you with regard to those who fought against you on account of religion and drave you out from your homes and helped in driving you out, that ye should befriend them. And whosoever shall befriend them, then those! they are the wrong-doers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O ye who believe! when believing women come Unto you as emigrants examine them. Allah is the best Knower of their faith. Then if ye know them to be true believers, send them not back Unto the infidels; they are not lawful Unto them, nor are they lawful Unto them. And give them that which they have expended. Nor is it any crime in you if ye marry them when ye have given their hires. And hold not to the ties of the infidel women, and ask back that which ye have expended, and let them ask back that which they have expended. That is the judgment of Allah; He judgeth between you, And Allah is Knowing, Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives hath been left with the infidels, and then ye have retaliated, then give Unto those whose wives have gone away the like of that which they have expended, and fear Allah in whom ye are believers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet! when believing women come Unto thee swearing fealty Unto thee, that they shall not associate aught with Allah, nor they shall steal, nor they shall commit fornication, nor they shall slay their children, nor they shall produce any falsehood that they have fabricated between their hands and feet, nor they shall disobey thee in anything reputable, then accept thou their fealty, and pray to Allah for their forgiveness. Verily Allah is Forgiving, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O ye who believe! befriend not a people against whom Allah is Wroth. Surely they have despaired of tHe Hereafter even as have despaired the entombed of the infidels. S\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Whatsoever is in the heavens and whatsoever is in the earth halloweth Allah. And He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O ye who believe! wherefore say ye that which ye do not?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Most odious it is Unto Allah that ye should Say that which ye do not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Verily Allah loveth those who fight in His way drown up in ranks, as though they were a structure well compacted.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And recall what time Musa said Unto his people: O my people! wherefore hurt ye me, When surely ye know that verily I am Allah's apostle Unto you! Then when they sweryed, Allah made their hearts swerve; and Allah guideth not a transgressing people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And recall what time Isa, son of Maryam, said: children of Israi'l! verily I am Allah's apostle Unto you, confirming the Taurat which was before me, and giving the glad tidings of an apostle who cometh after me: his name will be Ahmad. Then when he brought Unto them evidences, they said: this is magic manifest.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who is a greater wrong-doer than he who fabricateth against Allah a lie even as he is summoned Unto Islam? And Allah guideth not a wrongdoing people.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
Fain would they extinguish the light of Allah is with their mouths and Allah is going to perfect His light, even though averse may be the infidels.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
He it is Who hath sent His apostle with the guidance and the true religion, that He may make it triumph over all religion, even though averse may be associaters.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O ye who believe! shall direct you to a merchandise that will deliver you from a torment afflictive?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
It is that ye should believe in Allah and His apostle and strive in the way of Allah with your riches and Your lives That is best for you, if ye only knew!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins, and make YOu enter Gardens whereunder rivers flow, and happy abodes in Gardens Everlasting. That is the mighty achievement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And also another blessing which ye love: succour from Allah and a speedy victory. And bear thou the glad tidings Unto the believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O ye who believe! be Allah's helpers, even as 'Isa, son of Maryam, said Unto the disciples: who shall be my helpers Unto Allah? The disciples said: we are Allah's helpers. Then a part of the Children of Israil believed, and part disbelieved. Then We strengthened those who believed against their foe; wherefore they became triumphant.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Whatsoever is in the heavens and whatsoever is in the earth halloweth Allah, the Sovereign, the Holy, the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
He it is Who hath raised amdist the unlettered ones an apostle from among themselves, rehearsing Unto them His revelations and purifying them and teaching them the Book and Wisdom, though they have been aforetime in error manifest.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And also others of them who have not yet joined them. And He is the Mighty; the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the grace of Allah: He vouchsafeth it on whomsoever He will. And Allah is the Owner of mighty Grace.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who were laden with the Taurat and then they bare it not, is as the likeness of the ass bearing tomes. Hapless is the likeness of the people who belie the signs of Allah. And Allah guideth not a wrong doing people. J\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say thou: O ye e who are Judaised! if ye imagine at ye are the friends of Allah above mankind, then wish for death if ye be truthful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
And they will never wish there for, because of that which their hands have sent forward. And Allah is the Knower of he wrong-doers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say thou: verily the death which ye flee from! then verily it will meet you and thereafter ye will be brought back Unto the Knower of the unseen and the seen, and He will declare Unto you that which ye have been working.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O ye who believe! when the call to prayer is made on the day of Friday then repair Unto the remembrance of Allah and leave off bargaining. That is better for you if ye know\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then, when the prayer is ended, disperse in the land and seek of Allah's grace, and remember Allah much, that haply ye may thrive.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
And when they beheld merchandise or sport, they flocked thereto, and left thee standing. Say thou: that which is with Allah is better than sport and better than merchandise; and Allah is the Best of providers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come Unto thee, they say: we bear witness that thou art indeed the apostle of Allah. Allah knoweth that thou art indeed His apostle, and Allah beareth witness that; the hypocrites are indeed liars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have taken their oaths for a shield; then they turn away men from the way of Allah. Verily vile is that which they have been working.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is, because they believed, and thereafter disbelieved, wherefore their hearts are sealed, so that they understand not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when thou beholdest them, their persons please thee: and if they speak, thou listenest to their discourse; they are as though they were blocks of wood propped up. They deem every shout to be against them. They are the enemy; so beware of them. Perish them Allah! whither are they deviating!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said Unto them: come! that the apostle of Allah may ask forgiveness for you, they twist their heads, and thou beholdest them retire, while they are stiff-necked.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
Equal it is Unto them: whether thou askest forgiveness for them or askest not forgiveness for them, Allah shall forgive them not. Verily Allah guideth not a transgressing people.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They are the ones who say: expend not on those who are with Allah's apostle, that they may disperse; whereas Allah's are the treasures of the heavens and the earth; yet the hypocrites understand not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say: surely, if we return to Madina the mightier shall drive out the meaner thence: whereas might is Allah's and His apostle's and the believers; yet the hypocrites know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O ye who believe let not your riches or your children divert you from the remembrance of Allah. And whosoever doth that then those! they are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And expend of that wherewith We have provided you afore death cometh Unto one of you, and he saith: 'my Lord! wouldst Thou not defer me for a short term, so that I would give alms and become of the righteous.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
And Allah deferreth not a soul when its term- hath come; and Allah is Aware of that which ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Whatsoever is in the heavens and whatsoever is in the earth halloweth Allah. His is the dominion; and His is the praise; and He is over everything potent.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
He it is Who hath created you; then of you some are Infidels and of you some are believers; and Allah is of that which ye Work Beholder.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He hath created the heavens and the earth with truth, and hath formed you, and hath made-your forms goodly; and Unto Him Is the return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knoweth whatsoever is In the heavens and the earth, and He knoweth whatsoever ye keep secret, and whatsoever ye make known; and Allah is the Knower of whatsoever is in the breasts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Hath not the tidings reached you of those who disbelieved aforetime, and so tasted the evil consequence of their affair, and theirs will be a torment afflictive?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That was because their apostles were wont to come Unto them with evidences, but they said: shall a mere human bein guide us? Wherefore they disbelieved and turned away; and Allah needed them not. And Allah is Self Sufficient, Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
Those who dlsbelieve assert that they shall not be raised. Say thou 'Yea! by my Lord, ye shall surely be raised, and then Unto you shall be declared that which ye have worked; and that is for Allah easy.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Wherefore believe in Allah and His apostle and the Light which We have sent down: And Allah is of that which ye work Aware.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
Remember the Day whereon He shall assemble you, the Day of Assembly; that shall be the Day of Mutual Loss and Gain. And whosoever believeth in Allah and worketh righteously from him He will expiate His misdeeds and will make him enter Gardens whereunder rivers flow, as abiders therein for evermore. That is the mighty achievement.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
And they who disbelieve and belie Our Signs! those shall be fellows of the Fire, as abiders therein; a hapless destination.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No calamity befalleth save by Allah's leave. And whosoever believeth in Allah, his heart He guideth. And Allah is of everything Knower.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah and obey the apostlle; then if ye turn away, on Our apostle is only the preaching manifest.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah! there is no God but He! In Allah, therefore, let the believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O ye who believe! verily of your wives and your children there is an enemy Unto you; wherefore beware of them. And if ye pardon and pass over and forgive, then verily Allah is Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your riches and your children are but a temptation; and Allah! with Him is a mighty hire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
Wherefore fear Allah as much as ye are able, and hearken and obey, and expend, for the benefit of your souls. And whosoever is protected from niggardliness of his soul - those! they are the blissful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If ye lend Unto Allah a goodly loan, He will multiply it Unto you and will forgive you; and Allah is Appreciator, Forbearing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
Knower of the unseen and the seen, the Mighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet! when ye divorce women, divorce them before their waitrng-period; and count the waiting period; and fear Allah, your Lord. Drive them not out of their houses, nor should they go forth, unless they commit a manifest indecency. These are the bounds of Allah; and whosoever trespasseth the bounds of Allah, hath surely wronged himself. Thou knowest not, that haply Allah may hereafter bring something new to pass.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Then when they have attained their term, either retain them reputably, or part from them reputably, and take as witnesses two just men from among you, and set up your testimony for Ailah. Thus is exhorted he who believeth in Allah and the Last Day. And whosoever feareth Allah He maketh for him an outlet.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And He provideth for him from whence he reckoneth not upon. And whosoever putteth his trust in Allah He will suffice him. Verily Allah is sure to attain His purpose, and Allah hath appointed Unto everything a measure.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
And as to such of your women as have despaired of menstruation, if ye be in doubt thereof, their waiting period is three months, as also of those who have not yet menstruated. And as to those with burthens, their term is when they lay down their burthen. And whosoever feareth Allah, He maketh his affair Unto him easy.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the commandment of Allah which He hath sent down Unto you. And whosoever feareth Allah, He Will expiate his misdeeds from him, and will magnify for him his hire.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them wheresoever ye lodge yourselves; according to your means; and hurt them not so as to straiten them. And if they are with burthen, expend on them until they lay down their burthen. Then, if they suckle their children for you, give them their hire, and take counsel together reputably. And if ye make hardship for one another, then another woman will suckle for him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the man of means expend according to his means; and whosoever is stinted in his subsistence let him expend of that which Allah hath given him. Allah tasketh not a soul except according to that which He hath vouchsafed it. Anon Allah will appoint after hardship ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And how many a city trespassed the commandment of its Lord and His apostles! Wherefore We reckoned with them a stern reckoning, and We tormented them With a torment unheard of.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
Wherefore they tasted the evil consequence of their affair, and the end of their affair was loss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah hath gotten ready for them a grievous torment; so fear Allah, O men of understanding! those who have believed. Surely He hath sent down Unto you an admonition.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
An apostle reciting Unto you the revelations of Allah as evidences, that he may bring forth those who believe and work righteous works from darknesses into light. And whosoever believeth in Allah and worketh righteously, him He will cause to enter Gardens whereunder rivers flow, as abiders for evermore. Surely Allah hath made for him an excellent provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
Allah it is Who hath created seven heavens, and of the earth the like thereof; the commandment cometh down between them, that ye may know that Allah is over everything Potent, and that Allah! He encompasseth everything in knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O prophet! why makest thou unlawful that which Allah hath made lawful Unto thee, seeking the good-will of thy wives! And Allah is Forgiving, Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Surely Allah hath ordained for you absolution from your oaths; and Allah is your Patron and He is the Knower, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And recall what time the Prophet confided a story Unto one of his spouses, then she disclosed it, and Allah apprised him thereof, he made known part thereof and Withheld part. Then, when he had apprised her of it, she said: who hath acquainted thee therewith! He said the Knower, the Aware hath acquainted me.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If ye twain turn Unto Allah repentant, it is well, surely your hearts are so inclined, and if ye support each other against him, then verily Allah! his friend is He and Jibril and so are the righteous believers; and furthermore the angels are his aiders.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
Belike his Lord, if he divorce you, will give him in exchange wives better than you, Muslims, believers, devout, penitent, worshippers, given to fasting, both non-virgins and virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O ye who believe! protect yourselves and your households from a Fire the fuel whereof is mankind and stones, over which are angels, stern, strong; they disobey not Allah in that which He commandeth them, and do that which they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
O ye who disbelieve! excuse not yourselves To-day; ye are only being requited for that which ye have been working.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O ye who believe! turn Unto Allah with a sincere repentance. Belike your Lord will expiate from you your misdeeds and cause you to enter Gardens whereunder rivers flow, on the Day whereon Allah will not humiliate the prophet and those who believe with him. Their light will be running before them and on their right hands, and they will say: our Lord! perfect for us our light, and forgive us; verily Thou art over everything Potent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet! strive hard against the infidels and the hypocrites, and be stern Unto them. And their abode is Hell: a hapless destination!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah propoundeth for those who disbelieve the similitude of the wife of Nuh and the wife of Lut. They were under two of our righteous bondmen; then they defrauded them. Wherefore the twain availed them naught against Allah, and it was said: enter ye twain the Fire with those who enter.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah propoundeth for those who believe the similitude of the wife Of Fir'awn, when she said: 'my Lord! build me in Thine presence a house in the Garden, and deliver me from Fir'awn and his handiwork, and deliver me from the transgressing people.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And the similitude of Maryram daughter of lmran, who preserved her chastity, wherefore We breathed in it Of Our Spirit. And she testified to the words of her Lord and His Books and she was of the devout.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blest be He in whose hand is the dominion, and He is over everything Potent.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
Who hath created death and life that He might prove you, as to which of you is excellent in work. And He is the Mighty, the Forgiver.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
Who hath created seven heavens in storeys. Thou shalt not behold in the Compassionates creation any over-sight; then repeat thy look, beholdest thou any crack?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then repeat thy look twice over, and thy look will return Unto thee dim and It will have become wearied out.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And assuredly We have bedecked the nearest heaven with lamps, and We have made them missiles for satans: and for them We have gotten ready the torment of the Blaze.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord will be the torment of Hell; and a hapless destination!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they will be cast thereinto, they will hear thereof a braying even as it balleth up,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
Well-nigh it bursteth with rage. So oft as a company is cast thereinto, the keepers thereof will ask them: came there not Unto you a warner?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say: yea! surely there came a warner Unto us, but we belied, and said: God hath not sent down aught, are naught but in a great error.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say: had we been wont to hearken or to reflect, we had not been among the fellows of the Blaze.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So they shall confess their sin. Far away they-be, the fellows of the Blaze!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Verily those who dread their Lord unseen, theirs shall be forgiveness and a great hire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And whather ye keep your discourse secret or publish it, verily He is the Knower of that which is in the breasts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Shall not He Who hath created know? And He is the Subtile, the Aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
He it is Who hath made the earth Unto you subservient, so go forth in the regions thereof, and eat of His provision. And Unto Him is the Resurrection.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Are ye secure that He who is in the heaven will not sink the earth with you and then it should quake?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or are ye secure that He Who is in the heaven will not send against you a whirlwind? Anon ye shall know what wise hath been My warning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And assuredly those before them belied; then what wise hath been My wrath!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Behold they not the birds above them, outstretching their wings and they also withdraw them? Naught holdeth them except the Compassionate. Verily He is of everything Beholder.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Who. is he that can be an army Unto you and succour you, beside the Compassionate! The infidelsjb are but in delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Who is he that can provide for you, should He withhold His provision? Aye! they persists in perverseness and aversion.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is he, then, who goeth about grovelling upon his face better directed, or he who walketh evenly on a straight path?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say thou: He it is who hath brought you forth and hath endowed you with hearing and sights and hearts. Little thanks it is ye give!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say thou: He it is Who hath spread you over the earth, and Unto Him ye shall be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
And they say: when will this promise be fulfilled, if ye say sooth?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say thou: the knowledge is only with Allah, and but a warner manifest.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they will behold it proximating sad will be the countenances of those who disbelieve, and it will be said: this is that which ye have been calling for.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say thou: bethink ye if Allah destroy me and those with me; or have mercy on us, who will protect the infidels from a torment afflictive?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say thou: He is the Compassionate; in Him we have believed, and in Him we have put our trust. -And anon ye will know who it is that is in error manifest.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say thou: bethink ye, were your water to be sunk away, who then could bring you water welling-up?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun By the pen and by that which they inscribe.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
Thou art nor, through the grace of thy Lord, mad.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And verily thine shall be a hire unending."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And verily thou art of a high and noble disposition.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
Anon thou wilt see and they will see:\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is afflicted with madness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Verily thy Lord! He is the best Knower of him who strayeth from His path, and He is the best Knower of the guided one,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Wherefore obey not thou the beliers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
Fain would they that thou shouldst be pliant, so that they will be pliant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And obey not: thou any swearer ignominous.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
A defamer, spreader abroad of slander.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
Hinderer of the good, trespasser; sinner.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Gross, and therewithal ignoble-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
Because he is owner of riches and children.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our revelations are rehearsed Unto him, he saith: fables of the ancients.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
Anon We shall brand him on snout.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Verily We! We have proved them even as We proved the fellows of a garden when they swarethat they would surely reap it in the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
And they made not the exception.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Wherefore an encircling visitation visited it even as they slept on.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
Then in the morning it became as though it had been reaped.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
Then they cried out Unto each other in the morning,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
Saying: go out betimes to your tilth if ye would reap.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they went off speaking to each other in a low voice:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
Let there not enter upon you today any needy man.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went out betimes determined in purpose.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
Then when they beheld it, they said: verily we have strayed.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
Aye! it is we who are deprived!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The most moderate of them said: said I not Unto you, wherefore hallow him ye not!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said: hallowed be Our Lord! verily we have been wrong- doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they turned to each other reproaching\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: woe Unto us! verily we! we have been arrogant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
Belike our Lord may exchange for us better garden than this; verily we are Unto our Lord beseechers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the torment. And the torment of the Hereafter is far greater; if they but knew.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Verily for the God-fearing, are with their Lord Gardens of Delight.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We then make the Muslims like the culprits?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What aileth you? How ill ye judge!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Is there with you a Book wherein ye study:\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That therein is yours that which. ye may choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have ye oaths from us reaching to the Day of Resurrection, that you shall be that which ye judge?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask then, which of them will stand thereof a surety?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Have they associate gods? Then let them produce their associate gods if they say sooth!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
Remember the Day whereon the shank shall be bared and they shall be called upon to Prostrate themselves, but they shall not be able.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Downcast will be their looks; abjectness will overspread them. Surely they had been called upon to Prostrate themselves while yet they were whole.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Let Me alone with him who belieth this discourse; step by step We lead them on when they perceive not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I bear with them; verily My contrivance is sure.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Askest thou a hire from them so that they are laden with debt?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Is with them the unseen, so that they write down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
Be patient thou, then, with thy Lord's judgment, and be thou not like him of the fish, when he cried out while he was in anguish.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had not grace from his Lord reached him, he had surely been cast into the wilderness in a plight.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
Then his Lord chose him and made him of the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And those who disbelieve well-nigh cause thee to stumble with their looks when they hear the Admonition, and they say: verily he is mad.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
While it is naught but an admonition Unto the worlds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Inevitable Calamity!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Inevitable Calamity?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what shall make thee know that which the Inevitable Calamity is.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
The tribes of Thamud and 'Aad belied the Striking Day.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamud, they were destroyed by the outburst.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for 'Aad they were destroyed by a wind, furious. roaring.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
To which He subjected them for seven nights and eight days in succession, so that thou mightest have seen men during it lying prostrate, as though they were stumps of palms ruined.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Beholdest thou any of them remaining?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Fir'awn and those before him and the overturned cities committed sin.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And they disobeyed their Lord's apostle, so He laid hold of them with a grip increasing.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Verily We! when the water rose, We bare you upon the traversing ark.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it Unto you an admonition, and thot it might be retained by the retaining ears.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
And when the Trumpet shall sound a single blast.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains shall be borne and the twain shall be crushed with a single crash.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
Then on that Day shall happen the Event.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven shall be rent in sunder, it on that Day shall be frail.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels shall be on the borders thereof; and on that Day eight shall bear over them the Throne of thy Lord.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
The Day whereon ye shall be mustered nothing hidden by you shall be hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then as to him who will be vouchsafed his book in his right hand, he shall say: here! read my book!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Verily I was sure that I should be a meeter of my reckoning.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
Then he shall be in a life well-pleasing -\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a Garden lofty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
Clusters whereof shall be near at hand.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
Eat and drink with benefit for that which ye sent on beforehand in dayspast.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
Then as to him who shall be vouchsafed his book in his left hand, he shall say: Oh! would that I had not been vouchsafed my book.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
Nor known whatever was my reckoning!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
Oh, would that it had been the ending!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My riches have: availed me not;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
There hath perished from me my authority.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
Lay hold of him and chain him;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
Then in the Scorch roast him\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
Then, in a chain whereof the length is seventy Cubits, bind him.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Verily he was wont not to believe in Allah, the Mighty.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
Nor he urged on others the feeding of the poor.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
Wherefore for him here this Day there is no friend.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
Nor any food save filthy corruption.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
None shall eat it but the sinners.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
I swear by that which ye see.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And that which ye see not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
That it is surely the speech brought by messenger honourable.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
And it is not the speech of a poet. Little it is that ye believe\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the speech of a sooth- sayer. Little are ye admonished.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
It is a Revelation from the Lord of the worlds.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if he had forged concerning us some discourses.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We surely had lain hold of him by the right hand.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
And then severed his life-vein.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And not one of you would have withheld us from punishing him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And verily it is an Admonition Unto the God-fearing.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And verily We! We know that some among you are beliers thereof.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And verily it shall be an occasion of anguish Unto the infidels.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And verily it is the truth of assured certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
Wherefore hallow thou the name of thy Lord, the Mighty.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen There hath asked an asker for the torment about to befall.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
The infidels, of which there is no averter.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From Allah, Owner of the ascending steps.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
Whereby the angels ascend Unto Him and also the spirit, On a Day whereof the measure is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
Wherefore be thou patient with a becoming patience.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Verily they behold it afar off.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
And We behold it nigh.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
It shall befall on a Day whereon the heaven shall become like Unto dregs of oil.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And then the mountains shall become like Unto wool dyed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And not a friend shall ask a friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
Though they shall be made to see one another. Fain would the guilty ransom himself from the torment of that Day by his children.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his spouse and his brother.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his kin that sheltered him.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all who are on the earth; so that this might deliver him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! Verily it is a Flame.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
Flaying off the scalp-skin.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It shall calll him who turneth back and backslideth.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And masseth and then hoardeth.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Verily man is formed impatient.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
When evil toucheth him, he is bewailing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And when good toucheth him he is begrudging.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Not so are the prayerful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Who are at their prayer constant.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose riches is a known right.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the beggar and the destitute.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who testify to the Day of Requital.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who are fearful of their Lord's torment -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Verily the torment of their Lord is not a thing to feel secure from.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who of their private parts are guards.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Save in regard to their spouses or those whom their right hands own; so verily they are not blameworthy -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
And whosoever seeketh beyond that, then it is those who are the trespassers\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who of their trusts and their covenant are keepers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand firm in their testimonies.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who of their prayer are observant.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Those shall dwell in Gardens, honoured.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
What aileth those who disbelieve, toward thee hastening.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
On the right and on the left, in companies?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Coveteth every man of them, that he shall enter the Garden of Delight?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
By no means! veriiy We! We have created them from that which they know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
I swear by the Lord of the easts and the wests, that, vierly We are Able.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them by others better than they; and We are not to be outrun.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
Wherefore let thou them alone plunging in vanity and sporting until they meet their Day which they are promised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day whereon they shall come forth from the sepulchres hastily, as though they were to an altar hurrying.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
Downcast shall be their looks; abjectness shall overspread them. Such is the Day which they are promised.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Verily We! We sent Nuh Unto his people saying: warn thy people ere there come Unto them torment afflictive.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: O my people! verily I am Unto you a warner manifest.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
Worship Allah, and fear Him, and obey me.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
He will forgive you your sins, and will defer you to an appointed term. Verily the term of Allah when it cometh shall not be deferred, if ye but knew.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: my Lord! verily have called my people night and day.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
And my calling hath only increased them in fleeing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And verily so oft as I call them, that Thou mayest forgive them, they place their fingers into their ears, and wrap themselves with their garments, and persist, and are stiff-necked.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then verily have called Unto them publicly:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
Then verily spake Unto them openly, and secretly also I addressed them.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
And I said: ask forgiveness of your Lord; verily He is ever Most Forgiving.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will send the heaven upon you copiously;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
And He will add Unto you riches and children and will appoint Unto you gardens and will appoint Unto you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What aileth you that ye expect not in Allah majesty!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
And surely He hath created you by stages.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Behold ye not in what wise Allah hath created seven heavens in storeys.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And hath placed the moon therein for a light, and hath made the sun a lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah hath caused you to grow from the earth as a growth.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
And thereafter He will cause you to return thereinto, and He will bring you forth a forthbringing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And Allah hath made the earth Unto you an expanse.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That of it ye may traverse the ways open.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Nuh said. my Lord! verily they have disobeyed me and followed them whose riches and children have only increased them in loss.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
And who have plotted a tremendous plot\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
And who have said: ye shall not leave your gods; nor Shall ye leave Wadd nor Suwa', nor Yaghuth, nor Ya'uq nor Nasr.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
And surely they have misled many. And increase Thou these wrong-doers in naught save error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
And because of their misdeeds they were drowned, and then they were made to enter a Fire. Then they found not for themselves, beside Allah, any helpers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Nuh said: my Lord! leave not upon the earth of the infidels one inhabitant.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
Verily if Thou shouldst leave them, they Will mislead Thine bondmen and will beget not save sinning infidels,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord! forgive me and my parents and him who entereth my house as a believer, and believing men and believing women, and increase not the wrong-doers in aught save ruin!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say thou: it hath been revealed Unto me that a company of the Jinn listened, and said, verily we have listened to a Recitation wondrous.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
Guiding Unto rectitude; wherefore we have believed therein, and we shall by no means associate with our Lord anyone.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
And He - exalted be the majesty of our Lord!-hath taken neither a spouse nor a son.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
And the foolish among us were wont to forge lie against Allah exceedingly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
And verily we! we had imagined that humankind and Jinn would never forge against Allah a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
And persons among humankind have been seeking refuge with persons of the Jinn, so that they increased them in evil disposition.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
And indeed they imagined, even as ye imagined, that Allah will not raise any one.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
And we sought to reach the heaven; then we found it filled with a strong guard and darting meteors.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
And we were wont to sit on seats therein to listen; but whosoever listeneth now findeth for him a dartin meteor in wait.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
And we know not whether evil is boded for those who are on the earth, or whether their Lord intendeth for them a right direction.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
And of us there are some righteous, and of us are some otherwise; we have been following very diverse.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
And we known that we cannot frustrate Allah in the earth, nor can we frustrate Him by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
And when we heard the Message of guidance, we believed therein; and whosoever believeth in his Lord, he shall fear neither diminution nor wrong.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
And of us some are Muslims, and of us some are deviators. Then whosoever hath embraced Islam - such have endeavoured after a Path of rectitude.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
And as for the deviators, for Hell they shall be fuel.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
And had they kept to the path surely We would have watered them with rain plenteous.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
That We might try them there by. And whosoever turneth aside from the remembrance of his Lord, him He shall thrust into a torment vehement.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
And the prostrations are for Allah; wherefore call not along with Allah anyone.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
And when the bondman of Allah stood calling upon Him, they well nigh pressed on him stifling.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say thou: I simply call upon Allah, and I associate not with Him any-one.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say thou: 'verily own not for you power of hurt nor of benefit\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say thou: 'verily none can protect me from Allah, nor can I find beside Him any refuge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
Mine is but the publishing from Allah and His messages; and whosoever disobeyeth Allah and His apostle, his portion verily is the Hell-Fire as abiders therein for evermore.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
They shall go on denying until they; behold that which they are promised wherefore then they shall know who were weaker in protectors and fewer in number.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say thou: know not whather that which ye are promised is nigh, or whether my Lord hath appointed for it a distant term.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
He is the Knower of the unseen, and He discloseth not His unseen Unto anyone.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Save Unto an apostle chosen. And then He causeth to go before him and behind him a guard.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
That He may know that they have preached the message of their Lord. And He comprehendeth whatever is with them, and He keepeth count of everything numbered.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O thou enwrapped!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stay up the night long save a little -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
A half thereof, or abate a little thereof,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or increase thereto. And intone the Qur'an with a measured intontion. s\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Verily We! anon We shall cast upon thee a weighty word.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Verily the rising by night! it is most curbing and most conducive to right speech.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Verily there is for thee by day occupation prolonged.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember thou the name of thy Lord, and devote thyself to Him with an exclusive devotion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the east and the west! No God is there but He! Wherefore take Him for thy trustee.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And bear thou with patience whatsoever they say, and depart from them with a becoming departure.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And let Me alone with the beliers, owners of ease: and respite thou them a little.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Verily with us are heavy fetters and Scorch.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And a food that choketh and a torment afflictive.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On a Day whereon the earth and the mountains shall quake, and the mountains shall become a sand-heap poured forth.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Verily We! We have sent Unto you an apostle, a witness over you, even as We sent Unto Fir'awn an apostle.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
Then Fir'awn disobeyed the apostle, wherefore We laid hold of him with a painful hold.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
How then, if ye disbelieve, shall ye escape, on a Day which shall make children grey-headed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
And the heaven shall be split there in. His promise needs must be fulfilled.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Verily this is an admonition; let him therefore, who will, choose a way Unto his Lord.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Verily thy Lord knoweth that thou stayest up near two- thirds of the night, Or half thereof, or a third thereof, and also a party of those who are with thee. And Allah measureth the night and the day. He knoweth that ye can compute it not, He hath relented toward you. Wherefore recite now of the Qur'an, so much as is easy. He knoweth that there will be among you some diseased, and others shall be travelling in the land seeking grace of Allah, and others shall be fighting in the way of Allah. Wherefore recite thereof so much as is easy; and establish the prayer and give the poor-rate and lend Unto Allah a goodly loan. Whatsoever good ye shall send on for your souls, ye shall find it with Allah, better and greater in reward. And ask forgiveness of Allah; verily Allah is Forgiving, Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O thou enveloped?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise, and warn.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And thine Lord magnify!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And thine raiment purify.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And pollution shun.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And bestow not favour that thou mayest receive more.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
And for the good-will of thy Lord be thou patient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
Then when the horn shall be blown,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
That shall be - that Day-a day hard.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
For the infidels, not easy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Let Me alone with him whom I created lonely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And for whom I appointed wealth extended.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And sons present by his side.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And for whom I smoothed everything.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
And who yet coveteth that shall increase.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
By no means! Verily he hath been Unto Our signs a foe.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
Anon I shall afflict him with a fearful woe.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Verily he considered, and devised.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
Perish he! How moliciously he devised!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
And again perish he! How maliciously he devised!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then looked he,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then frowned he and scowled.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then turned he back, and grew stiff-necked.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
Then he said: naught is this but magic from of old;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
Naught is this but the word of Man.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
Anon shall I roast him into the Scorching Fire.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what knoweth thou that which the Scorching Fire?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It shall not spare, nor leave.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
. Scorching the skin.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are appointed nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
And We have appointed none but the angels to be wardens of the Fire. And their number we have made only a trial for those who disbelieve, so that those who are vouchsafed the Book may be convinced, and that those who believe may increase in faith, and that those who are vouchsafed the Book and the believers may not doubt, and that those in whose hearts is a disease and the infidels may say: what meaneth Allah by this description! In this wise Allah sendeth astray whomsoever He will, and guideth whomsoever He will. And none knoweth the hosts of thy Lord but He. And it is naught but an admonition Unto man.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
By no means! By the moon,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
By the night when it with draweth.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
By the morning when it brighteneth.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Verily it is one of the greatest woes.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
A warning Unto humankind -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
A warning Unto him of you who shall go forward or who chooseth to lag behind.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul will be a pledge for that which it hath earned,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Save the fellows of the right.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens; they shall be asking,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
Concerning the culprits:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
What led you into the Scorching Fire?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say. 'we have not been of those who prayed.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
And we have not been feeding the poor.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
And we have been wading with the waders.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
And we have been belying the Day of Requital.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
until there came to us the certainty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
Then there will not Profit them intercision of the interceders,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
What aileth them, therefore, that they are from the Admonition turning away?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As though they were asses startled."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing away from a lion.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Aye! every one of them desireth that: he should be vouchsafed scrolls expanded.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
By no means! Aye, they fear not the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
By no means! Verily this Qur'an is an Admonition.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So whosoever willeth may heed it.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they shall not heed unless Allah Willeth. He is the Lord of piety. and the Lord of forgiveness\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I swear by the Day of Resurrection.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And I swear by the self-reproaching soul.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Deemest man that We shall not assemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yea! WE are Able to put together evenly his finger-tips.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
Aye! man desireth that he may sin before him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asketh: when will the Day of Resurrection be?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
When, then, the sight shall be confounded.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon shall be ecliped.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and the moon shall be joined.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that Day shall man say: whither is the fleeing.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
By no means! NO refuge!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Unto thy Lord that Day is the recourse.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
To man will be declared on that Day that which he hath sent on and left behind.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Aye! man against himself shall be an enlightenment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Although he may put forth his pleas.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not thy tongue therewith that thou mayest hasten therewith.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Verily upon us is the collecting thereof and the reciting thereof.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
Wherefore when We reciteit, follow thou the reciting thereof.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
And thereafter verily upon us is is the expounding thereof.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
By no means! Verily ye love the Herein.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And leave the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Countenances on that Day shall be resplendent,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking toward their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And countenances on that Day shall be scowling.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Imagining that there will befall them a waiste-breaking calomity.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
By no means! When it cometh up to he collar-bone.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And it is cried. who can charm?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he bethinketh that it is the time of parting.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And one shank is entangled with the other shank.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
Unto thy Lord that Day is the drive.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
He neither believed nor prayed,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But he belied and turned away.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then he departed Unto his house hold conceitedly.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe Unto thee; woe!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again, woe Unto thee, woe!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Deemest man that he is to be left uncontrolled?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a sperm of emission emitted?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he became a clot; then He created him and formed him.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made of him the two sexes, male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is not That One then Able to quicken the dead?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Surely there hath come upon man a space of time when he was not a thing worth mentioning.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Verily We! We created man from a sperm of mixtures, that We might prove him, wherefore We made him hearing, seeing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Verily We! We shewed him the way; then he becometh either thankful or ingrate.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Verily We! We have gotten ready for the infidels chains and collars and a Blaze.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Verily the pious shall drink of a cup whereof the admixture is like Unto camphor.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
From a fountain whence the bondmen of Allah will drink, causing it to gush abundantly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They fulfill their vow and dread a Day the evil whereof shall be widespreading.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they feed with food, for love of Him, the needy, and the orphan and the captive.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
Saying: we feed you only for the sake of Allah; we desire not from you any recompense or thanks.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
Verily we dread from our Lord a Day grim and distressful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
Wherefore Allah shall preserve them from the evil of that Day, and shall cause them to meet brightness and joy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And shall recompense them for that which they patiently bare with a Garden and silken garment.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining therein upon couches, they shall behold therein neither sun nor hurting cold.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And close upon them will be the shades thereof, and low will hang the clusters thereof greatly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
And brought round amongst them will be vessels of silver and also goblets of glass.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Godblets of silver, they shall have filled them to exact measure.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And therein they shall be given to drink of a cup whereof the admixture will be ginger.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
From a fountain therein, named Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
And there shall go round Unto them youths ever-young. When thou seest them thou wouldst deem them pearls unstrung.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when thou lookest them thou shalt behold delight and a dominion magnificent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon them shall be garments of fine green silk and of brocades. And adorned they shall be with bracelets of silver: and their Lord shall give them drink a beverage pure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
Verily this is for you by way of recompense, and your endeavour hath been accepted.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Verily We! it is We Who have revealed Unto thee the Qur'an, a gradual revelation.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
Wherefore persevere thou with the commandment of thy Lord, and obey not thou of them, any sinner or ingrate.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And remember thou the name of thy Lord in the morning and in the evening.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And during the night - worship Him; and hallow Him the livelong night.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Verily those love the Herein, and leave in front of them a heavy day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
It it We Who creared them and made them firm of make. And whenever We list, We can replace them with others like Unto them.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Verily this is an admonition; then whosoever Will, may choose a way Unto his Lord.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
And ye will not, unless Allah willeth. Verily Allah is ever Knowing, Wise.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He maketh whomsoever He listeth to enter His mercy. And the wrong-doers! for them He hath gotten ready a torment afflective.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the winds sent forth with beneficence.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
And those raging swiftly;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
By the spreading winds spreading.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
And the scattering wind scattering.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
And those winds that bring down the remembrance.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
By way of excuse or warning.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Verily that which ye are promised is about to befall.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
So when stars are effaced.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when the heaven is cloven asunder.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are carried away by wind.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the apostles are collected at the appointed time,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what day is it timed?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Decision.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what knowest thou what the Day of Decision is?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe on that day Unto the beliers\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Destroyed We not the ancients?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
Thereafter We shall cause to follow them the latter ones.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
In this wise We do with the culprits.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe on that day Unto the beliers!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Created We you not of water despicable,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
Which We placed in a depository safe.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
Till a limit known?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
So We decreed. How excellent are We as decreers!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe on that day Unto the beliers!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth a receptacle.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
Both for the living and the dead,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And have placed therein firm and tall mountains and given you to drink of water fresh\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe on that day Unto the beliers!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
'Depart Unto that which ye were wont to belie.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
Depart Unto the shadow three branched:\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
Neither shading nor availing against the flame.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Verily it shall cast forth sparks like Unto a castle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
As though they were camels yellow tawny.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe on that day Unto the beliers!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is a Day whereon they shall not be able to speak.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
Nor shall they be permitted so that they might excuse themselves.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe on that day Unto the beliers!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
This is the Day of Decision, We have assembled both ye and the ancients.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
If now ye have any craft, try that craft upon Me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe on the day Unto the beliers!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Verily the God-fearing shall be amid shades and springs,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits such as they shall desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
'Eat and drink with relish that which ye have been working.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Verily We! in this wise We recompense the well-doers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe on that day Unto the beliers!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
'Eat and enjoy a little; verily ye are culprits.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe on that day Unto the beliers!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said Unto them: 'bow down, they bow not down.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe on that day Unto the beliers!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
In what discourse, then, after it, will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen Of what ask they?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
Of the mighty Announcement,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
Concerning which they differ.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
By no means! anon they shall know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Again, by no means! anon they shall know.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth an expanse.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as stakes?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We have created you in pairs.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And We have made your sleep as a rest.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And We have made the night a covering.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And We have made the day for seeking livelihood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We have builded over you seven strong heavens.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And We have set therein lamps glowing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And We have sent down from the rain-clouds water plenteous.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
So that We bring forth thereby corn and vegetation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens thick with trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Verily the Day of Decision is a time appointed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
It is a Day whereon the trumpet will be blown, and ye will come in multitudes.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven will have been opened, and it will have become doors.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains will have been removed away, and they will have become as mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Verily the Hell is an ambuscade:\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
For the exorbitant a receptacle.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will tarry therein for ages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
They will not taste therein cool or any drink.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Save scalding water and corruption.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
Recompense fitted!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
Verily they were wont not to look for a reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
And they belied Our revelations with strong belying.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And everything We have recorded in a book.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
Taste therefore. We shall not increase you in aught but torment.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Verily for the God-fearing is an achievement.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens enclosed and vineyards,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And full-breasted maidens of equal age.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a cup overflowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
They will hear therein no babble nor falsehood:\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
A recompense from thy Lord-a gift sufficient -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
From the Lord of the heavens and the earth and of whatsoever is in bet-ween them, the Compassionate with Whom they can demand not audience.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
On the Day whereon the spirits and the angels will stand arrayed, they will not be able to speak save him whom the Compassionate giveth leave and who speaketh aright.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the Sure Day. Whosoever therefore willeth, let him betake Unto his Lord a resort.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Verily We! We have warned you of a torment nigh at hand, a Day whereon a man shall behold that which his hands have sent forth, and the infidel will say: would that I were dust!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By the angels who drag forth vehemently.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
By the angels who release with gentle release.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
By the angels who glide swimmingiy,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And then they speed with foremost speed.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And then they manage the affair,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
A Day shall come whereon the quaking will quake,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
And there will follow it the next blast.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Hearts on that Day will be throbbing;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Their looks will be downcast.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say: shall we indeed be restored to the first state,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
When we have become bones decayed!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: that then shall be a losing return.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
It will be only one scaring shout,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
And lo! they all shall appear on the surface.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Hath there come Unto thee the story of Musa!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
Recall what time his Lord called Unto him in the holy vale of Tuwa.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
Saying:'go thou Unto Fir'awn; verily he hath waxen exorbitant.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
Then say thou: 'wouldst thou to be purified?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
Then shall guide thee Unto thy Lord so that thou shalt fear.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
Then he shewed him the great sign.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
Yet he belied and disobeyed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then he turned back striving.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
Then he gathered and cried aloud,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
And he said: I am Your Lord, most high.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
Wherefore Allah laid hold of him with the punishment of the Hereafter and of the present.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Verily herein is lesson for him who feareth.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are ye harder to create or the heaven which He hath builded?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He hath raised the height thereof and perfected it.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
And He made dark its night, and brought forth its sunshine.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And the earth!- thereafter He stretched it out.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And he brought forth therefrom its water, and its pasture.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains! - He established them firm:\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
A provision for you and your cattle.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
Then when the Grand Calamity shall come\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The Day whereon man shall rember whatsoever he had striven for.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And the Scorch will be made apparent to any one who beholdeth.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
Then as for him who waxed exorbitant,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And who chose the life of the world,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Verily the Scorch! that shall be his resort.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
And as for him who dreaded standing before his Lord, and restrained his soul from lust,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Verily the Garden! -that shall be his resort.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They question thee of the Hour:'when will its arrival be?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
Wherein art thou concerred with the declaration thereof!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Unto thy Lord is the Knowledge of the limit fixed therefor.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
Thou art but a warner Unto him who feareth.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
On the Day whereon they behold it, it will appear to them as though they had not tarried save an evening or the morn thereof.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because there came Unto him a blind man.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
How canst thou know, whether haply he might be cleansed,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or be admonished, so that the admonition might have profited him?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for him who regardeth himself self-sufficient-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
Unto him thou attendest.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
Whereas it is not on thee that he is not cleansed.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
And as for him who cometh Unto thee running,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And he feareth'-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
Him thou neglectest!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
By no means! Verily it is an admonition.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So whosoever willeth-let him be admonished therewlth.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
Inscribed in Writs honoured,"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted, Purified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
By the hands of scribes.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Honourable and virtuous.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Perish man! how ungrateful he is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
Of what thing hath He created him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
Of a drop of seed. He created him and formed him according to a measure.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then the way He made easy.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He caused him to die and made him to be buried.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then when He listeth, He shall raise him to life.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
By no means He performed not that which He had commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Let man look at his food:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
It is We Who pour forth water, pouring,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
Thereafter We cleave the earth in clefts,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
Then We cause therein the grain to grow,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and vegetables\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olives and palms\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And enclosed gardens luxuriant.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and herbage:\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
A provision for you and for your cattle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
Then when cometh the Deafening Cry-\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
On the Day whereon a man shall flee from his brother,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And his mother and his father,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And his wife and his sons;\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
For every one of them on that Day shall be business enough to occupy\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Faces on that Day shall be beaming,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And faces on that Day! upon them shall be gloom.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Dust shall cover them\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Those! they are the infidels, the ungodly.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun shall be wound round,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars shall dart down,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the mountains shall be made to pass away,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when the she-camels big with young shall be abandoned,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when the wild beasts shall be gathered together,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas shall be filled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when the souls he paired,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the girl buried alive shall be asked:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what sin she was slain.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the Writs shall be lain open,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the heaven shall be stripped,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when the Scorch shall be made to blaze,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when the Garden shall be brought nigh,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
Then every soul shall know that which it: hath presented.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
I swear by the receding stars.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Moving swiftly and hiding themselves,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by the night when it departeth,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by the morning when it shineth forth,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
Verily it is a Word brought by a messenger honoured,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Owner of strength, of established dignity with the Lord of the Throne.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
Obeyed one there; trustWorthy.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
Nor is your companion distracted.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
Assuredly he beheld him in the horizon manifest.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And he is of the unseen not a tenacious concealer.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
Nor is it the word of a Satan accursed.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Whither then go ye?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
This is naught but an Admonition Unto the worlds-\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
Unto whomsoever of you willeth to walk straight.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And ye shall not will unless it be that Allah, the Lord of the worlds, willeth.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven shall be cleft,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
And when the stars shall be scattered,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
And when the seas are flowed out,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the graves are ransacked,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
Each soul shall know that which it sent afore and that which it left behind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! what hath beguiled thee concerning thy Lord, the Bountiful,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created thee, then moulded thee, then proportioned thee?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatsoever form He listed He constructed thee.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
By no means! Aye, ye belie the the Requital.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
Verify there are for you guardians,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Honourablel scribes.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know whatsoever ye do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Verily the pious shall be in Delight.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And verily the ungodly shall be in a Scorch.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
Roasted they shall be therein on the Day of Requital.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And thence they shall not be allowed to be absent.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what shall make thee know whatsoever the Day of Requital is?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what shall make thee know whatsoever the Day of Requital is?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
It is a Day whereon no soul shall own aught of power for any soul; and the command on that Day will be Allah's.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe Unto the scrimpers:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who, when they take by measure from mankind, exact the full,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
And who, when they measure Unto them or weigh for them, diminish.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Imagine such men not that they shall be raised up?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
On a mighty Day.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
A Day whereon mankind shall stand before the Lord of the worlds?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
By no means! Verily the record of the ungodly is in Sijjin.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what will make thee know whatsoever the record in Sijjin is?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A record of misdeeds written.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe on that Day unto the belviers-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who belie the Day of Requital.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none belieth it save each trespasser, sinner.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
And when Our revelations are rehearsed Unto him, she saith:'fables of the ancients!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
By no means!' Aye! encrusted upon their hearts is that which they have been earning.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
By no means! Verily on that Day from their Lord they will be shut Out.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then verily they will be roasted into the Scorch.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then it will be said: 'this is that which ye were wont to belie.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
By no means! Verily the record of the virtuous shall be in 'Illiyun.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what will make thee know whatsoever the record in Illiyun is?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A record of good deeds written.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
To which bear witness those brought nigh.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Verily the virtuous shall be in Delight,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
Reclining on couches, looking on.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
Thou wilt recognize in their faces the brightness of delight.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given to drink of pure wine, sealed.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
The seal thereof will be of musk and to this end let the aspirers aspire -\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
And admixture thereof will be Water of Tasnim:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A fountain whereof will drink those brought nigh.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Veriiy those who have sinned were wont at those who had believed to laugh,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And, when they passed them, to wink at each other,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their household they returned jesting.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And when they saw them, they said: verily these are the strayed ones.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Whereas they were not sent over them as watchers.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
Wherefore Today, those who believed at the infidels are laughing,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
Reclining on couches, looking on.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
The infidels have indeed been rewarded for that which they had been doing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the heaven is sundered.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And it hearkeneth to its Lord, and is duteous,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth shall be stretched forth.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And shall cast forth that which is therein, and shall become empty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And it hearkeneth to its Lord, and is duteous.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man! verily thou art toiling toward thy Lord a painful toiling, and art about to meet Him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then as to him who shall be given his book in his right hand -\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
His account shall presently be taken by an easy reckoning.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And he shall return Unto his people joyfully.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
And as to him who shall be given his book from behind his back-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He shall presently call for death,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And he shall roast into a Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Verily he was among his people joyous.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
Verily he imagined that he would not be back.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Yea! his Lord had ever been beholding him.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
I swear by the afterglow of sunset,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And by the night and that which it driveth together,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And by the moon when she becometh full.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
Surely ye shall ride layer upon layer.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What aileth them then, that they believe not,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And that, when the Qur'an is read Unto them, they prostrate not them-selves!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Yea those who disbelieve belie.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
Whereas Allah knoweth best that which they cherish.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
Wherefore announce thou Unto them a torment afflictive.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
But those who believe and work righteous works, theirs shall be a hire unending.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven adorned with big stars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by the Day promised,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by the Day witnessing and the Day witnessed,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Perish the fellows of the ditch,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
Of fire fuel-fed,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they sat by it\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And to that which they did to the believers were witnesses.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
And they persecuted them for naught save that they believed in Allah, the Mighty, the Praiseworthy\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
Him, Whose is the dominion of heavens and the earth. And Allah is over everything a Witness.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Verily those who affected the believing men and the believing women, and then repented not, theirs shall be the torment of Hell, and theirs shall be the torment of burning.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Verily those who believed and worked righteons works, theirs shall be Gardens whereunder the rivers flow; that is the supreme achievement.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Verily the grip of thine Lord is severe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Verily He! He it is who beginneth and repeateth it.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Fogiving, the Loving,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Lord of the Throne, the Glorious,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Doer of whatsoever He intendeth.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Hath there come Unto thee the story of the hosts-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of the Fir'awn and the Thamud?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
But those who disbelieve are engaged in denial.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
Whereas Allah is, from behind them, Encompassing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Aye! it is a Recitation glorious,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
Inscribed in a tablet preserved.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the heaven and the night-comer\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what shall make thee know that which the night-comer is?-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
It is the star shing brightly.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
No soul is there but hath over it a watcher.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man look - from what is he created.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He is created from a water drip-ping,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
That issueth from between the loins and the breast-bones.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Verily He is Able to restore him,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
On a Day whereon secrets shall be out.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
Then he shall have no power nor any helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the heaven which returneth,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And by the earth which splitteth,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Verily, it is a discourse distinguishing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
And it is not a frivolity.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Verily they are plotting a plot.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I am plotting a plot.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So respite thou the infidels - respite them gently,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Hallow thou the name of thine Lord, the Most High,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who hath created and then proportioned,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
And Who hath disposed and then guided,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
And Who bringeth forth the pasturage,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
Then maketh it to stubble dusky.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall enable thee to recite, and then thou shalt not forget,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Save that which Allah may will. Verily He knoweth the public and that which is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We shall make easy Unto thee the easy way.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Wherefore admonish thou; admonition hath surely profited,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
Admonished is he indeed who feareth,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
And the wretched shunneth it-.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
He Who shall roast into the Great Fire,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Wherein he shall neither die nor live,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
He indeed hath attained bliss who hath cleansed himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And who remembereth the name of his Lord, and then prayeth.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But ye prefer the life of this world,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Whereas the Hereafter is better and more lasting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Verily this is in Writs ancient\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
Writs of Ibrahim and Musa.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Hath there come Unto thee the story of the Enveloping Event?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Faces on that Day shall be downcast,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Travailing, worn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
They shall roast into the scalding Fire,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
Given to drink of a spring fiercely boiling.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
No food shall be theirs save bitter thorn,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which shall neither nourish nor avail against hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
Faces on that Day shall be de lighted,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
With their endeavour well pleased.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
They shall be in a Garden lofty:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
They shall hear therein no vain discourse;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Therein shall be a spring running!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Therein shall be couches elevated!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And goblets ready placed!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions ranged!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And carpets ready spread,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Look they not at the camels, how they are created?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the heaven, how it is raised?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the mountains, how they are rooted?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the earth, how it is outspread?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Admonish thou then; thou art but an admonisher.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
Thou art not over them a warden.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But whosoever will turn back and disbelieve -\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Him Allah shall torment with the greatest torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Verily Unto us is their reckoning.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then verily on us is their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And by ten nights,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And by the even and the odd,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And by the night when it departeth,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Indeed in that there is an oath for a man of sense.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Bethinkest thou not in what wise thy Lord did with the 'A'ad:\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
The people of many-columned lram.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which was not built in the cities,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And With Thamud who hewed out rocks in the vale,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And with Fir'awn, owner of the stakes -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Who all waxed exorbitant in the cities,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And multiplied therein corruption.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Wherefore thy Lord poured on them the scourge of His torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Verily thy Lord is in an ambuscade,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man - when his Lord proveth him and so honoureth him and is bounteous Unto him, then he saith: 'my Lord hath honoured me,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
And when He proveth him, and so stinteth Unto him his provision, he saith: 'my Lord hath despised me.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
By no means! But ye honour not the orphan,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
Nor urge upon each other the feeding of the poor,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And devour the inheritance devouring greedily,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And ye love riches with exceeding love.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
By no means! when the earth shall be ground with grinding, grinding,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And thy Lord shall come and the angels, rank on rank.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And the Hell on that Day shall be brought nigh. On that Day man shall remember, but how will remembrance avail him?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say. 'would that I had sent before for this life of mine!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
Wherefore on that Day none shall torment with His torment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
Nor shall any bind with His bond.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
O thou peaceful soul!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return Unto thine Lord well pleased and well-pleasing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Enter thou among My righteous bondmen!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
And enter thou My Garden.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I swear by yonder city\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And thou shalt be allowed in yonder city -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by the begetter and that which he begat,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
Assuredly We have created man in trouble.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Deemest he that none will overpower him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He saith: 'I have wasted riches plenteous.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Deemest he that none beholdeth him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not, made for him two eyes\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and two lips,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And shown Unto him the two highways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
Yet he attempteth not the steep,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what shall make thee understand that which the steep is?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
It is freeing the neck,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or, feeding, in a day of privation,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
An orphan, of kin,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or a poor man cleaving to the dust.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
Then he became of those who believed and enjoined on each other steadfastness and enjoined on each other compassion.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
These are the fellows of the righthand.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
And those who disbelieve Our signs - they are the fellows of the lefthand.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Over them shall be Fire closing round.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and his morning bright-ness,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
By the moon, when she followeth him,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
By the day when it glorifieth him.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
By the night; when it envelopeth him,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
By the heaven and Him Who builded it,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
By the earth and Him Who spread it forth,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
By the soul and Him Who propertioned it,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And inspired it with the wickedness thereof and the piety thereof,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Surely blissful is he who hath cleansed, it,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And miserable is he who hath buried it.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamud belied in their exorbitance.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
What time the greatest wretch of them rose up.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
Then the apostle of Allah said Unto them: beware of the she-camel of Allah and her drink.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
Then they belied him, and they hamstrung her; wherefore their Lord overwhelmed them for their crime, and made it equal.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He feared not the consequence thereof\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night when it envelopeth,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
By the day when it appeareth in glory,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
By Him Who hath created the male and the female,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Verily your endeavour is diverse.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
Then as for him who giveths and feareth Him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And testifieth to the Good,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
Unto him therefore We shall indeed make easy the path to ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
And as for him who stinteth and is heedless,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And who belieth the Good,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
Unto him therefore We shall Indeed make easy the path to hardship.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
And his substance will avail him not when he perisheth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Verify on us is the guidance\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And verify Ours is both the Hereafter and the life present.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Wherefore have warned you of Fire flaming,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None shall roast therein but the most wretched,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
Who belieth and turneth away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
And avoid it shall the most pious,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
Who giveth away his substance that he may be cleansed,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And who hath no favour from anyone to recompense.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
But only seeking the Countenance of his Lord the Most High.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
And presently he shall become wellpleased.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the morning brightness,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
By the night when it darkeneth,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Thy Lord hath not forsaken thee, nor is He displeased.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And the Hereafter is indeed better Unto thee than the life present.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And presently thy Lord shall give Unto thee so that thou shalt be be well-pleased.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Found He not thee an orphan, so He sheltered thee?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And He found thee wandering, so He guided thee,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And He found thee destitute, so He enriched thee.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Wherefore as to the orphan, be thou not Unto him overbearing.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
And as to the beggar, chide thou him not.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
And as to the favour of thine Lord discourse thou thereof.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not opened forth for thee thy breast?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And We have taken off from thee thy burthen,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which weighed down thy back.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And We have upraised for thee thy renown.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
Then verily along with every hardship is ease.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Verily along with every hardship is ease.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
Then when thou becometh relieved, toil;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And Unto thine Lord, attend.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig, by the olive,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
By Mount Sinai,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
By the yonder secure city,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
Assuredly We have created man in goodliest mould,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Thereafter We cause him to return to the lowest of the low,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Save those who believe and work righteous Works. Theirs shall be hire unending.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
What hencefort shall make thee belie the Requital?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the Greatest of the rulers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Recite thou in the name of thy Lord Who hath created -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Hath created man from a clot!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Recite thou: And thy Lord is the Most Bounteous,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who hath taught mankind by the pen -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Hath taught man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
By no means: Verily man exorbitateth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
As he bethinkest himself selfsufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Verily Unto thy Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Bethinkest thou him who forbiddeth,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A bondman of Ours when he prayeth *\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Bethinkest thou, if he is himself guided,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or he commandeth piety?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Bethinkest thou, if he belieth and turneth away?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Knoweth he not that Allah beholdeth?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
By no means! If he desist not We shall seize and deal him by the forelock -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A forelock, lying, sinning.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then, let him call his assembly,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We also shall call the infernal guards.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
By no means! Obey not thou him. Continue to adore, and continue to draw nigh.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Verily We! We have sent it down on the night of Power.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what shall make thee know that which the night of Power is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The night of Power is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
The angels and the spirit descend therein by the command of their Lord with His decrees for every affair.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
It is all peace, until the rising of the dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieved from among the People of the Book and the associaters could not break off, until there had come Unto them the evidence.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
An apostle from Allah rehearsing Writs cleansed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Wherein are discourses eternal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
And those who are vouchsafed the Book divided not save after there had come Unto them the evidence.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they were commanded not but that they should worship Allah, keeping religion pure for him, as upright men, and that they should establish prayer and give the poor-rate, And that is the right religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Verily those who disbelieve from among the people of the Book and the associaters shall be cast into the Hell-fire, as abiders therein. These! they are the worst of the creation.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Verily those who believe and work righteous works - these! they are the best of the creation.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their recompense with their Lord shall be Gardens Everlasting, whereunder rivers flow - as abiders therein for evermore. Well-pleases will be Allah with them and well-pleased will be they with Him, That is for him who feareth his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken by the shaking thereof,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And the earth bringeth forth her burthens,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man saith: what aileth her?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that Day she will tell out the tidings thereof.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because thy Lord will inspire her.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that Day mankind will proceed in bands, that they may be shewn their works.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
Then whosoever hath worked good of an atom's weight shall behold it\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whosoever hath worked ill Of an atom's weight shall behold it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the chargers panting,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
And striking off fire by dashing their hoofs.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And raiding at dawn\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
And therein raising dust.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
And cleaving their way therein into the host,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Verily man is Unto his Lord ungrateful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And verily to that he is witness.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And verily in the love of wealth he is vehement,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Knoweth he not - when that which is in the graves, shall be ransacked?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And there shall be brounht to light that which is in the breasts?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Verily their Lord on that Day will be of them Aware.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Striking!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Striking?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
What shall Make thee know that which the Striking is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
A Day whereon mankind shall become as moths scattered,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains shall become as wool carded,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then as for him whose balances are heavy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He shall be in a lifewell-pleasing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
And as for him whose balances are light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
His dwelling shall be the Abyss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what shall make thee know that which she is?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A Fire vehemently hot!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The emulous desire of abundance engrosseth you,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until ye visit the graves.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Lo! presently ye shall know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again lo! presently ye shall know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Lo! would that ye knew now with the surety of knowledge!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
Surely ye shall behold theScorch.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Then ye shall surely beholdwith the surety of vision.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that Day, ye shall surely be asked of the delights.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By the time,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Verily man is in loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
But not those who themselves believe and work righteous works, and enjoin upon each other the truth, and enjoin upon each other endurance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe Unto every slanderer, traducer,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who amasseth wealth; and counteth it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He bethinketh that his wealth shall abide for him.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
By no means! He shall surely be cast into the Crushing Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what shall make thee know that which the Crushing Fire is?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
Fire of Allah, Kindled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which mounteth up to the hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Verily it shall close upon them,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In pillars stretched forth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Hast thou not observed what wise thy Lord dealt with the fellows of the elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Put He not their stratagem to straying.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them birds in flocks.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
They hurled upon them stones of baked clay;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
Then He rendered them as stubble devoured.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the keeping of the Quraish\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
For their keeping to the journey in the winter and the summer-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
Let them worship the Lord of this House,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who hath fed them against hunger; and hath rendered them secure from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Beholdest thou him who belieth the Requital?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
It is he who pusheth away the orphan,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And urgeth not the feeding of the poor,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
Woe, therefore, Unto such performers of prayer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
As are of their prayer careless.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
They who would be seen,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And who withholds even common necessaries.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Verily We! We have given thee Kauthar.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
Wherefore pray thou Unto thy Lord, and sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Verily it is thy traducer who shall be tail-less.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say thou: O ye infidels!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I worship not, that which ye worship.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor are ye the worshippers of that which I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
And I shall not be a worshipper of that which ye have worshipped,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor will ye be worshippers of that which I worship,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
Yours shall be your requital, and mine shall be my requital.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When there cometh the succour of Allah and the victory,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And thou beholdest mankind entering the religion of Allah in crowds,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Then hallow the praise of thy Lord, and ask forgiveness of Him. Verily He is ever Relenting.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the two hands of Abu Lahab, and perish he!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His substance availed him not, nor that which he earned.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
Anon he shall roast into Fire having flame.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife also: the firewood carrier;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
On her neck shall be a cord of twisted fibre.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say thou: He is Allah, the One!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
Allah, the Independent,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He begetteth not, nor Was He begotten.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
And there hath never been co-equal with Him anyone.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say thou; I seek refuge with the Lord of the daybreak.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
From the evil of that which He hath created,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
And from the evil of the darken when it cometh,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
And from the evil of the women blowers upon knots,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
And from the evil of the envier when he envieth.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say thou: I seek refuge with the Lord of mankind,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
The King of mankind,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
The God of mankind,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
From the evil of the sneaking whisperer\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
Who whispereth Unto the breasts of mankind,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
Whether of Jinn or of mankind.\qt@no{6}}%
%% End of file `qurantext-eniv.translation.def'
