\qt@newcmd\qurantrans@en@i{%
In the name of Allah, Most Gracious, Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
Praise be to Allah, the Cherisher and Sustainer of the worlds;\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
Most Gracious, Most Merciful;\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
Master of the Day of Judgment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
Thee do we worship, and Thine aid we seek.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Show us the straight way,\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The way of those on whom Thou hast bestowed Thy Grace, those whose (portion) is not wrath, and who go not astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Book; in it is guidance sure, without doubt, to those who fear Allah;\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the Unseen, are steadfast in prayer, and spend out of what We have provided for them;\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in the Revelation sent to thee, and sent before thy time, and (in their hearts) have the assurance of the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
They are on (true) guidance, from their Lord, and it is these who will prosper.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
As to those who reject Faith, it is the same to them whether thou warn them or do not warn them; they will not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah hath set a seal on their hearts and on their hearing, and on their eyes is a veil; great is the penalty they (incur).\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
Of the people there are some who say: ``We believe in Allah and the Last Day;" but they do not (really) believe.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
Fain would they deceive Allah and those who believe, but they only deceive themselves, and realise (it) not!\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease; and Allah has increased their disease: And grievous is the penalty they (incur), because they are false (to themselves).\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
When it is said to them: ``Make not mischief on the earth," they say: ``Why, we only Want to make peace!"\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Of a surety, they are the ones who make mischief, but they realise (it) not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
When it is said to them: ``Believe as the others believe:" They say: ``Shall we believe as the fools believe?" Nay, of a surety they are the fools, but they do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
When they meet those who believe, they say: ``We believe;" but when they are alone with their evil ones, they say: ``We are really with you: We (were) only jesting."\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah will throw back their mockery on them, and give them rope in their trespasses; so they will wander like blind ones (To and fro).\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are they who have bartered Guidance for error: But their traffic is profitless, and they have lost true direction,\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their similitude is that of a man who kindled a fire; when it lighted all around him, Allah took away their light and left them in utter darkness. So they could not see.\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb, and blind, they will not return (to the path).\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or (another similitude) is that of a rain-laden cloud from the sky: In it are zones of darkness, and thunder and lightning: They press their fingers in their ears to keep out the stunning thunder-clap, the while they are in terror of death. But Allah is ever round the rejecters of Faith!\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning all but snatches away their sight; every time the light (Helps) them, they walk therein, and when the darkness grows on them, they stand still. And if Allah willed, He could take away their faculty of hearing and seeing; for Allah hath power over all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O ye people! Adore your Guardian-Lord, who created you and those who came before you, that ye may have the chance to learn righteousness;\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
Who has made the earth your couch, and the heavens your canopy; and sent down rain from the heavens; and brought forth therewith Fruits for your sustenance; then set not up rivals unto Allah when ye know (the truth).\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if ye are in doubt as to what We have revealed from time to time to Our servant, then produce a Sura like thereunto; and call your witnesses or helpers (If there are any) besides Allah, if your (doubts) are true.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if ye cannot- and of a surety ye cannot- then fear the Fire whose fuel is men and stones,- which is prepared for those who reject Faith.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
But give glad tidings to those who believe and work righteousness, that their portion is Gardens, beneath which rivers flow. Every time they are fed with fruits therefrom, they say: ``Why, this is what we were fed with before," for they are given things in similitude; and they have therein companions pure (and holy); and they abide therein (for ever).\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Allah disdains not to use the similitude of things, lowest as well as highest. Those who believe know that it is truth from their Lord; but those who reject Faith say: ``What means Allah by this similitude?" By it He causes many to stray, and many He leads into the right path; but He causes not to stray, except those who forsake (the path),-\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who break Allah's Covenant after it is ratified, and who sunder what Allah Has ordered to be joined, and do mischief on earth: These cause loss (only) to themselves.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can ye reject the faith in Allah?- seeing that ye were without life, and He gave you life; then will He cause you to die, and will again bring you to life; and again to Him will ye return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
It is He Who hath created for you all things that are on earth; Moreover His design comprehended the heavens, for He gave order and perfection to the seven firmaments; and of all things He hath perfect knowledge.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
Behold, thy Lord said to the angels: ``I will create a vicegerent on earth." They said: ``Wilt Thou place therein one who will make mischief therein and shed blood?- whilst we do celebrate Thy praises and glorify Thy holy (name)?" He said: ``I know what ye know not."\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam the names of all things; then He placed them before the angels, and said: ``Tell me the names of these if ye are right."\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said: ``Glory to Thee, of knowledge We have none, save what Thou Hast taught us: In truth it is Thou Who art perfect in knowledge and wisdom."\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said: ``O Adam! Tell them their names." When he had told them, Allah said: ``Did I not tell you that I know the secrets of heaven and earth, and I know what ye reveal and what ye conceal?"\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And behold, We said to the angels: ``Bow down to Adam" and they bowed down. Not so Iblis: he refused and was haughty: He was of those who reject Faith.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
We said: ``O Adam! dwell thou and thy wife in the Garden; and eat of the bountiful things therein as (where and when) ye will; but approach not this tree, or ye run into harm and transgression."\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
Then did Satan make them slip from the (garden), and get them out of the state (of felicity) in which they had been. We said: ``Get ye down, all (ye people), with enmity between yourselves. On earth will be your dwelling-place and your means of livelihood - for a time."\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then learnt Adam from his Lord words of inspiration, and his Lord Turned towards him; for He is Oft-Returning, Most Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said: ``Get ye down all from here; and if, as is sure, there comes to you Guidance from me, whosoever follows My guidance, on them shall be no fear, nor shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
``But those who reject Faith and belie Our Signs, they shall be companions of the Fire; they shall abide therein."\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel! call to mind the (special) favour which I bestowed upon you, and fulfil your covenant with Me as I fulfil My Covenant with you, and fear none but Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I reveal, confirming the revelation which is with you, and be not the first to reject Faith therein, nor sell My Signs for a small price; and fear Me, and Me alone.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And cover not Truth with falsehood, nor conceal the Truth when ye know (what it is).\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And be steadfast in prayer; practise regular charity; and bow down your heads with those who bow down (in worship).\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Do ye enjoin right conduct on the people, and forget (To practise it) yourselves, and yet ye study the Scripture? Will ye not understand?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
Nay, seek (Allah's) help with patient perseverance and prayer: It is indeed hard, except to those who bring a lowly spirit,-\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
Who bear in mind the certainty that they are to meet their Lord, and that they are to return to Him.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
Children of Israel! call to mind the (special) favour which I bestowed upon you, and that I preferred you to all other (for My Message).\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
Then guard yourselves against a day when one soul shall not avail another nor shall intercession be accepted for her, nor shall compensation be taken from her, nor shall anyone be helped (from outside).\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And remember, We delivered you from the people of Pharaoh: They set you hard tasks and punishments, slaughtered your sons and let your women-folk live; therein was a tremendous trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And remember We divided the sea for you and saved you and drowned Pharaoh's people within your very sight.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And remember We appointed forty nights for Moses, and in his absence ye took the calf (for worship), and ye did grievous wrong.\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Even then We did forgive you; there was a chance for you to be grateful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And remember We gave Moses the Scripture and the Criterion (Between right and wrong): There was a chance for you to be guided aright.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And remember Moses said to his people: ``O my people! Ye have indeed wronged yourselves by your worship of the calf: So turn (in repentance) to your Maker, and slay yourselves (the wrong-doers); that will be better for you in the sight of your Maker." Then He turned towards you (in forgiveness): For He is Oft-Returning, Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And remember ye said: ``O Moses! We shall never believe in thee until we see Allah manifestly," but ye were dazed with thunder and lighting even as ye looked on.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you up after your death: Ye had the chance to be grateful.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We gave you the shade of clouds and sent down to you Manna and quails, saying: ``Eat of the good things We have provided for you:" (But they rebelled); to us they did no harm, but they harmed their own souls.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And remember We said: ``Enter this town, and eat of the plenty therein as ye wish; but enter the gate with humility, in posture and in words, and We shall forgive you your faults and increase (the portion of) those who do good."\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But the transgressors changed the word from that which had been given them; so We sent on the transgressors a plague from heaven, for that they infringed (Our command) repeatedly.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And remember Moses prayed for water for his people; We said: ``Strike the rock with thy staff." Then gushed forth therefrom twelve springs. Each group knew its own place for water. So eat and drink of the sustenance provided by Allah, and do no evil nor mischief on the (face of the) earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And remember ye said: ``O Moses! we cannot endure one kind of food (always); so beseech thy Lord for us to produce for us of what the earth groweth, -its pot-herbs, and cucumbers, Its garlic, lentils, and onions." He said: ``Will ye exchange the better for the worse? Go ye down to any town, and ye shall find what ye want!" They were covered with humiliation and misery; they drew on themselves the wrath of Allah. This because they went on rejecting the Signs of Allah and slaying His Messengers without just cause. This because they rebelled and went on transgressing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Those who believe (in the Qur'an), and those who follow the Jewish (scriptures), and the Christians and the Sabians,- any who believe in Allah and the Last Day, and work righteousness, shall have their reward with their Lord; on them shall be no fear, nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And remember We took your covenant and We raised above you (The towering height) of Mount (Sinai): (Saying): ``Hold firmly to what We have given you and bring (ever) to remembrance what is therein: Perchance ye may fear Allah."\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
But ye turned back thereafter: Had it not been for the Grace and Mercy of Allah to you, ye had surely been among the lost.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And well ye knew those amongst you who transgressed in the matter of the Sabbath: We said to them: ``Be ye apes, despised and rejected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
So We made it an example to their own time and to their posterity, and a lesson to those who fear Allah.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And remember Moses said to his people: ``Allah commands that ye sacrifice a heifer." They said: ``Makest thou a laughing-stock of us?" He said: ``Allah save me from being an ignorant (fool)!"\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said: ``Beseech on our behalf Thy Lord to make plain to us what (heifer) it is!" He said; ``He says: The heifer should be neither too old nor too young, but of middling age. Now do what ye are commanded!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said: ``Beseech on our behalf Thy Lord to make plain to us Her colour." He said: ``He says: A fawn-coloured heifer, pure and rich in tone, the admiration of beholders!"\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said: ``Beseech on our behalf Thy Lord to make plain to us what she is: To us are all heifers alike: We wish indeed for guidance, if Allah wills."\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He said: ``He says: A heifer not trained to till the soil or water the fields; sound and without blemish." They said: ``Now hast thou brought the truth." Then they offered her in sacrifice, but not with good-will.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
Remember ye slew a man and fell into a dispute among yourselves as to the crime: But Allah was to bring forth what ye did hide.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
So We said: ``Strike the (body) with a piece of the (heifer)." Thus Allah bringeth the dead to life and showeth you His Signs: Perchance ye may understand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Thenceforth were your hearts hardened: They became like a rock and even worse in hardness. For among rocks there are some from which rivers gush forth; others there are which when split asunder send forth water; and others which sink for fear of Allah. And Allah is not unmindful of what ye do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Can ye (o ye men of Faith) entertain the hope that they will believe in you?- Seeing that a party of them heard the Word of Allah, and perverted it knowingly after they understood it.\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
Behold! when they meet the men of Faith, they say: ``We believe": But when they meet each other in private, they say: ``Shall you tell them what Allah hath revealed to you, that they may engage you in argument about it before your Lord?"- Do ye not understand (their aim)?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Know they not that Allah knoweth what they conceal and what they reveal?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And there are among them illiterates, who know not the Book, but (see therein their own) desires, and they do nothing but conjecture.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Then woe to those who write the Book with their own hands, and then say:"This is from Allah," to traffic with it for miserable price!- Woe to them for what their hands do write, and for the gain they make thereby.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say: ``The Fire shall not touch us but for a few numbered days:" Say: ``Have ye taken a promise from Allah, for He never breaks His promise? or is it that ye say of Allah what ye do not know?"\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Nay, those who seek gain in evil, and are girt round by their sins,- they are companions of the Fire: Therein shall they abide (For ever).\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
But those who have faith and work righteousness, they are companions of the Garden: Therein shall they abide (For ever).\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And remember We took a covenant from the Children of Israel (to this effect): Worship none but Allah; treat with kindness your parents and kindred, and orphans and those in need; speak fair to the people; be steadfast in prayer; and practise regular charity. Then did ye turn back, except a few among you, and ye backslide (even now).\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And remember We took your covenant (to this effect): Shed no blood amongst you, nor turn out your own people from your homes: and this ye solemnly ratified, and to this ye can bear witness.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
After this it is ye, the same people, who slay among yourselves, and banish a party of you from their homes; assist (Their enemies) against them, in guilt and rancour; and if they come to you as captives, ye ransom them, though it was not lawful for you to banish them. Then is it only a part of the Book that ye believe in, and do ye reject the rest? but what is the reward for those among you who behave like this but disgrace in this life?- and on the Day of Judgment they shall be consigned to the most grievous penalty. For Allah is not unmindful of what ye do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
These are the people who buy the life of this world at the price of the Hereafter: their penalty shall not be lightened nor shall they be helped.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
We gave Moses the Book and followed him up with a succession of messengers; We gave Jesus the son of Mary Clear (Signs) and strengthened him with the holy spirit. Is it that whenever there comes to you a messenger with what ye yourselves desire not, ye are puffed up with pride?- Some ye called impostors, and others ye slay!\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
They say, ``Our hearts are the wrappings (which preserve Allah's Word: we need no more)." Nay, Allah's curse is on them for their blasphemy: Little is it they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there comes to them a Book from Allah, confirming what is with them,- although from of old they had prayed for victory against those without Faith,- when there comes to them that which they (should) have recognised, they refuse to believe in it but the curse of Allah is on those without Faith.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
Miserable is the price for which they have sold their souls, in that they deny (the revelation) which Allah has sent down, in insolent envy that Allah of His Grace should send it to any of His servants He pleases: Thus have they drawn on themselves Wrath upon Wrath. And humiliating is the punishment of those who reject Faith.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
When it is said to them, ``Believe in what Allah Hath sent down, ``they say, ``We believe in what was sent down to us:" yet they reject all besides, even if it be Truth confirming what is with them. Say: ``Why then have ye slain the prophets of Allah in times gone by, if ye did indeed believe?"\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
There came to you Moses with clear (Signs); yet ye worshipped the calf (Even) after that, and ye did behave wrongfully.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And remember We took your covenant and We raised above you (the towering height) of Mount (Sinai): (Saying): ``Hold firmly to what We have given you, and hearken (to the Law)": They said:" We hear, and we disobey:" And they had to drink into their hearts (of the taint) of the calf because of their Faithlessness. Say: ``Vile indeed are the behests of your Faith if ye have any faith!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say: ``If the last Home, with Allah, be for you specially, and not for anyone else, then seek ye for death, if ye are sincere."\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never seek for death, on account of the (sins) which their hands have sent on before them. and Allah is well-acquainted with the wrong-doers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
Thou wilt indeed find them, of all people, most greedy of life,-even more than the idolaters: Each one of them wishes He could be given a life of a thousand years: But the grant of such life will not save him from (due) punishment. For Allah sees well all that they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say: Whoever is an enemy to Gabriel-for he brings down the (revelation) to thy heart by Allah's will, a confirmation of what went before, and guidance and glad tidings for those who believe,-\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Whoever is an enemy to Allah and His angels and messengers, to Gabriel and Michael,- Lo! Allah is an enemy to those who reject Faith.\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
We have sent down to thee Manifest Signs (ayat); and none reject them but those who are perverse.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it not (the case) that every time they make a covenant, some party among them throw it aside?- Nay, Most of them are faithless.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when there came to them a messenger from Allah, confirming what was with them, a party of the people of the Book threw away the Book of Allah behind their backs, as if (it had been something) they did not know!\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
They followed what the evil ones gave out (falsely) against the power of Solomon: the blasphemers Were, not Solomon, but the evil ones, teaching men Magic, and such things as came down at babylon to the angels Harut and Marut. But neither of these taught anyone (Such things) without saying: ``We are only for trial; so do not blaspheme." They learned from them the means to sow discord between man and wife. But they could not thus harm anyone except by Allah's permission. And they learned what harmed them, not what profited them. And they knew that the buyers of (magic) would have no share in the happiness of the Hereafter. And vile was the price for which they did sell their souls, if they but knew!\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
If they had kept their Faith and guarded themselves from evil, far better had been the reward from their Lord, if they but knew!\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O ye of Faith! Say not (to the Messenger) words of ambiguous import, but words of respect; and hearken (to him): To those without Faith is a grievous punishment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
It is never the wish of those without Faith among the People of the Book, nor of the Pagans, that anything good should come down to you from your Lord. But Allah will choose for His special Mercy whom He will - for Allah is Lord of grace abounding.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
None of Our revelations do We abrogate or cause to be forgotten, but We substitute something better or similar: Knowest thou not that Allah Hath power over all things?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Knowest thou not that to Allah belongeth the dominion of the heavens and the earth? And besides Him ye have neither patron nor helper.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Would ye question your Messenger as Moses was questioned of old? but whoever changeth from Faith to Unbelief, Hath strayed without doubt from the even way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Quite a number of the People of the Book wish they could Turn you (people) back to infidelity after ye have believed, from selfish envy, after the Truth hath become Manifest unto them: But forgive and overlook, Till Allah accomplish His purpose; for Allah Hath power over all things.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And be steadfast in prayer and regular in charity: And whatever good ye send forth for your souls before you, ye shall find it with Allah: for Allah sees Well all that ye do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say: ``None shall enter Paradise unless he be a Jew or a Christian." Those are their (vain) desires. Say: ``Produce your proof if ye are truthful."\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Nay,-whoever submits His whole self to Allah and is a doer of good,- He will get his reward with his Lord; on such shall be no fear, nor shall they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say: ``The Christians have naught (to stand) upon; and the Christians say: ``The Jews have naught (To stand) upon." Yet they (Profess to) study the (same) Book. Like unto their word is what those say who know not; but Allah will judge between them in their quarrel on the Day of Judgment.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who is more unjust than he who forbids that in places for the worship of Allah, Allah's name should be celebrated?-whose zeal is (in fact) to ruin them? It was not fitting that such should themselves enter them except in fear. For them there is nothing but disgrace in this world, and in the world to come, an exceeding torment.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
To Allah belong the east and the West: Whithersoever ye turn, there is the presence of Allah. For Allah is all-Pervading, all-Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
They say: ``Allah hath begotten a son": Glory be to Him.-Nay, to Him belongs all that is in the heavens and on earth: everything renders worship to Him.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
To Him is due the primal origin of the heavens and the earth: When He decreeth a matter, He saith to it: ``Be," and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
Say those without knowledge: ``Why speaketh not Allah unto us? or why cometh not unto us a Sign?" So said the people before them words of similar import. Their hearts are alike. We have indeed made clear the Signs unto any people who hold firmly to Faith (in their hearts).\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Verily We have sent thee in truth as a bearer of glad tidings and a warner: But of thee no question shall be asked of the Companions of the Blazing Fire.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
Never will the Jews or the Christians be satisfied with thee unless thou follow their form of religion. Say: ``The Guidance of Allah,-that is the (only) Guidance." Wert thou to follow their desires after the knowledge which hath reached thee, then wouldst thou find neither Protector nor helper against Allah.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have sent the Book study it as it should be studied: They are the ones that believe therein: Those who reject faith therein,- the loss is their own.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel! call to mind the special favour which I bestowed upon you, and that I preferred you to all others (for My Message).\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
Then guard yourselves against a Day when one soul shall not avail another, nor shall compensation be accepted from her nor shall intercession profit her nor shall anyone be helped (from outside).\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And remember that Abraham was tried by his Lord with certain commands, which he fulfilled: He said: ``I will make thee an Imam to the Nations." He pleaded: ``And also (Imams) from my offspring!" He answered: ``But My Promise is not within the reach of evil-doers."\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
Remember We made the House a place of assembly for men and a place of safety; and take ye the station of Abraham as a place of prayer; and We covenanted with Abraham and Isma'il, that they should sanctify My House for those who compass it round, or use it as a retreat, or bow, or prostrate themselves (therein in prayer).\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And remember Abraham said: ``My Lord, make this a City of Peace, and feed its people with fruits,-such of them as believe in Allah and the Last Day." He said: ``(Yea), and such as reject Faith,-for a while will I grant them their pleasure, but will soon drive them to the torment of Fire,- an evil destination (indeed)!"\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And remember Abraham and Isma'il raised the foundations of the House (With this prayer): ``Our Lord! Accept (this service) from us: For Thou art the All-Hearing, the All-knowing.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
``Our Lord! make of us Muslims, bowing to Thy (Will), and of our progeny a people Muslim, bowing to Thy (will); and show us our place for the celebration of (due) rites; and turn unto us (in Mercy); for Thou art the Oft-Returning, Most Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
``Our Lord! send amongst them a Messenger of their own, who shall rehearse Thy Signs to them and instruct them in scripture and wisdom, and sanctify them: For Thou art the Exalted in Might, the Wise."\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who turns away from the religion of Abraham but such as debase their souls with folly? Him We chose and rendered pure in this world: And he will be in the Hereafter in the ranks of the Righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
Behold! his Lord said to him: ``Bow (thy will to Me):" He said: ``I bow (my will) to the Lord and Cherisher of the Universe."\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And this was the legacy that Abraham left to his sons, and so did Jacob; ``Oh my sons! Allah hath chosen the Faith for you; then die not except in the Faith of Islam."\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Were ye witnesses when death appeared before Jacob? Behold, he said to his sons: ``What will ye worship after me?" They said: ``We shall worship Thy god and the god of thy fathers, of Abraham, Isma'il and Isaac,- the one (True) Allah: To Him we bow (in Islam)."\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a people that hath passed away. They shall reap the fruit of what they did, and ye of what ye do! Of their merits there is no question in your case!\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
They say: ``Become Jews or Christians if ye would be guided (To salvation)." Say thou: ``Nay! (I would rather) the Religion of Abraham the True, and he joined not gods with Allah."\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say ye: ``We believe in Allah, and the revelation given to us, and to Abraham, Isma'il, Isaac, Jacob, and the Tribes, and that given to Moses and Jesus, and that given to (all) prophets from their Lord: We make no difference between one and another of them: And we bow to Allah (in Islam)."\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
So if they believe as ye believe, they are indeed on the right path; but if they turn back, it is they who are in schism; but Allah will suffice thee as against them, and He is the All-Hearing, the All-Knowing.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
(Our religion is) the Baptism of Allah: And who can baptize better than Allah? And it is He Whom we worship.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say: Will ye dispute with us about Allah, seeing that He is our Lord and your Lord; that we are responsible for our doings and ye for yours; and that We are sincere (in our faith) in Him?\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do ye say that Abraham, Isma'il Isaac, Jacob and the Tribes were Jews or Christians? Say: Do ye know better than Allah? Ah! who is more unjust than those who conceal the testimony they have from Allah? but Allah is not unmindful of what ye do!\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That was a people that hath passed away. They shall reap the fruit of what they did, and ye of what ye do! Of their merits there is no question in your case:\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The fools among the people will say: ``What hath turned them from the Qibla to which they were used?" Say: To Allah belong both east and West: He guideth whom He will to a Way that is straight.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus, have We made of you an Ummat justly balanced, that ye might be witnesses over the nations, and the Messenger a witness over yourselves; and We appointed the Qibla to which thou wast used, only to test those who followed the Messenger from those who would turn on their heels (From the Faith). Indeed it was (A change) momentous, except to those guided by Allah. And never would Allah Make your faith of no effect. For Allah is to all people Most surely full of kindness, Most Merciful.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
We see the turning of thy face (for guidance to the heavens: now Shall We turn thee to a Qibla that shall please thee. Turn then Thy face in the direction of the sacred Mosque: Wherever ye are, turn your faces in that direction. The people of the Book know well that that is the truth from their Lord. Nor is Allah unmindful of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
Even if thou wert to bring to the people of the Book all the Signs (together), they would not follow Thy Qibla; nor art thou going to follow their Qibla; nor indeed will they follow each other's Qibla. If thou after the knowledge hath reached thee, Wert to follow their (vain) desires,-then wert thou Indeed (clearly) in the wrong.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
The people of the Book know this as they know their own sons; but some of them conceal the truth which they themselves know.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
The Truth is from thy Lord; so be not at all in doubt.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
To each is a goal to which Allah turns him; then strive together (as in a race) Towards all that is good. Wheresoever ye are, Allah will bring you Together. For Allah Hath power over all things.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
From whencesoever Thou startest forth, turn Thy face in the direction of the sacred Mosque; that is indeed the truth from the Lord. And Allah is not unmindful of what ye do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
So from whencesoever Thou startest forth, turn Thy face in the direction of the sacred Mosque; and wheresoever ye are, Turn your face thither: that there be no ground of dispute against you among the people, except those of them that are bent on wickedness; so fear them not, but fear Me; and that I may complete My favours on you, and ye May (consent to) be guided;\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
A similar (favour have ye already received) in that We have sent among you a Messenger of your own, rehearsing to you Our Signs, and sanctifying you, and instructing you in Scripture and Wisdom, and in new knowledge.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
Then do ye remember Me; I will remember you. Be grateful to Me, and reject not Faith.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O ye who believe! seek help with patient perseverance and prayer; for Allah is with those who patiently persevere.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And say not of those who are slain in the way of Allah: ``They are dead." Nay, they are living, though ye perceive (it) not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
Be sure we shall test you with something of fear and hunger, some loss in goods or lives or the fruits (of your toil), but give glad tidings to those who patiently persevere,\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who say, when afflicted with calamity: ``To Allah We belong, and to Him is our return":-\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
They are those on whom (Descend) blessings from Allah, and Mercy, and they are the ones that receive guidance.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Behold! Safa and Marwa are among the Symbols of Allah. So if those who visit the House in the Season or at other times, should compass them round, it is no sin in them. And if any one obeyeth his own impulse to good,- be sure that Allah is He Who recogniseth and knoweth.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Those who conceal the clear (Signs) We have sent down, and the Guidance, after We have made it clear for the people in the Book,-on them shall be Allah's curse, and the curse of those entitled to curse,-\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent and make amends and openly declare (the Truth): To them I turn; for I am Oft-returning, Most Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Those who reject Faith, and die rejecting,- on them is Allah's curse, and the curse of angels, and of all mankind;\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They will abide therein: Their penalty will not be lightened, nor will respite be their (lot).\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
And your Allah is One Allah: There is no god but He, Most Gracious, Most Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Behold! in the creation of the heavens and the earth; in the alternation of the night and the day; in the sailing of the ships through the ocean for the profit of mankind; in the rain which Allah Sends down from the skies, and the life which He gives therewith to an earth that is dead; in the beasts of all kinds that He scatters through the earth; in the change of the winds, and the clouds which they Trail like their slaves between the sky and the earth;- (Here) indeed are Signs for a people that are wise.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
Yet there are men who take (for worship) others besides Allah, as equal (with Allah): They love them as they should love Allah. But those of Faith are overflowing in their love for Allah. If only the unrighteous could see, behold, they would see the penalty: that to Allah belongs all power, and Allah will strongly enforce the penalty.\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
Then would those who are followed clear themselves of those who follow (them): They would see the penalty, and all relations between them would be cut off.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And those who followed would say: ``If only We had one more chance, We would clear ourselves of them, as they have cleared themselves of us." Thus will Allah show them (The fruits of) their deeds as (nothing but) regrets. Nor will there be a way for them out of the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O ye people! Eat of what is on earth, Lawful and good; and do not follow the footsteps of the evil one, for he is to you an avowed enemy.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
For he commands you what is evil and shameful, and that ye should say of Allah that of which ye have no knowledge.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
When it is said to them: ``Follow what Allah hath revealed:" They say: ``Nay! we shall follow the ways of our fathers." What! even though their fathers Were void of wisdom and guidance?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The parable of those who reject Faith is as if one were to shout Like a goat-herd, to things that listen to nothing but calls and cries: Deaf, dumb, and blind, they are void of wisdom.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O ye who believe! Eat of the good things that We have provided for you, and be grateful to Allah, if it is Him ye worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He hath only forbidden you dead meat, and blood, and the flesh of swine, and that on which any other name hath been invoked besides that of Allah. But if one is forced by necessity, without wilful disobedience, nor transgressing due limits,- then is he guiltless. For Allah is Oft-forgiving Most Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Those who conceal Allah's revelations in the Book, and purchase for them a miserable profit,- they swallow into themselves naught but Fire; Allah will not address them on the Day of Resurrection. Nor purify them: Grievous will be their penalty.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
They are the ones who buy Error in place of Guidance and Torment in place of Forgiveness. Ah! what boldness (They show) for the Fire!\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
(Their doom is) because Allah sent down the Book in truth but those who seek causes of dispute in the Book are in a schism Far (from the purpose).\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is not righteousness that ye turn your faces Towards east or West; but it is righteousness- to believe in Allah and the Last Day, and the Angels, and the Book, and the Messengers; to spend of your substance, out of love for Him, for your kin, for orphans, for the needy, for the wayfarer, for those who ask, and for the ransom of slaves; to be steadfast in prayer, and practice regular charity; to fulfil the contracts which ye have made; and to be firm and patient, in pain (or suffering) and adversity, and throughout all periods of panic. Such are the people of truth, the Allah-fearing.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O ye who believe! the law of equality is prescribed to you in cases of murder: the free for the free, the slave for the slave, the woman for the woman. But if any remission is made by the brother of the slain, then grant any reasonable demand, and compensate him with handsome gratitude, this is a concession and a Mercy from your Lord. After this whoever exceeds the limits shall be in grave penalty.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
In the Law of Equality there is (saving of) Life to you, o ye men of understanding; that ye may restrain yourselves.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is prescribed, when death approaches any of you, if he leave any goods that he make a bequest to parents and next of kin, according to reasonable usage; this is due from the Allah-fearing.\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
If anyone changes the bequest after hearing it, the guilt shall be on those who make the change. For Allah hears and knows (All things).\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But if anyone fears partiality or wrong-doing on the part of the testator, and makes peace between (The parties concerned), there is no wrong in him: For Allah is Oft-forgiving, Most Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O ye who believe! Fasting is prescribed to you as it was prescribed to those before you, that ye may (learn) self-restraint,-\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
(Fasting) for a fixed number of days; but if any of you is ill, or on a journey, the prescribed number (Should be made up) from days later. For those who can do it (With hardship), is a ransom, the feeding of one that is indigent. But he that will give more, of his own free will,- it is better for him. And it is better for you that ye fast, if ye only knew.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
Ramadhan is the (month) in which was sent down the Qur'an, as a guide to mankind, also clear (Signs) for guidance and judgment (Between right and wrong). So every one of you who is present (at his home) during that month should spend it in fasting, but if any one is ill, or on a journey, the prescribed period (Should be made up) by days later. Allah intends every facility for you; He does not want to put to difficulties. (He wants you) to complete the prescribed period, and to glorify Him in that He has guided you; and perchance ye shall be grateful.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
When My servants ask thee concerning Me, I am indeed close (to them): I listen to the prayer of every suppliant when he calleth on Me: Let them also, with a will, Listen to My call, and believe in Me: That they may walk in the right way.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
Permitted to you, on the night of the fasts, is the approach to your wives. They are your garments and ye are their garments. Allah knoweth what ye used to do secretly among yourselves; but He turned to you and forgave you; so now associate with them, and seek what Allah Hath ordained for you, and eat and drink, until the white thread of dawn appear to you distinct from its black thread; then complete your fast Till the night appears; but do not associate with your wives while ye are in retreat in the mosques. Those are Limits (set by) Allah: Approach not nigh thereto. Thus doth Allah make clear His Signs to men: that they may learn self-restraint.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And do not eat up your property among yourselves for vanities, nor use it as bait for the judges, with intent that ye may eat up wrongfully and knowingly a little of (other) people's property.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask thee concerning the New Moons. Say: They are but signs to mark fixed periods of time in (the affairs of) men, and for Pilgrimage. It is no virtue if ye enter your houses from the back: It is virtue if ye fear Allah. Enter houses through the proper doors: And fear Allah: That ye may prosper.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
Fight in the cause of Allah those who fight you, but do not transgress limits; for Allah loveth not transgressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And slay them wherever ye catch them, and turn them out from where they have Turned you out; for tumult and oppression are worse than slaughter; but fight them not at the Sacred Mosque, unless they (first) fight you there; but if they fight you, slay them. Such is the reward of those who suppress faith.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
But if they cease, Allah is Oft-forgiving, Most Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them on until there is no more Tumult or oppression, and there prevail justice and faith in Allah; but if they cease, Let there be no hostility except to those who practise oppression.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The prohibited month for the prohibited month,- and so for all things prohibited,- there is the law of equality. If then any one transgresses the prohibition against you, Transgress ye likewise against him. But fear Allah, and know that Allah is with those who restrain themselves.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend of your substance in the cause of Allah, and make not your own hands contribute to (your) destruction; but do good; for Allah loveth those who do good.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And complete the Hajj or 'umra in the service of Allah. But if ye are prevented (From completing it), send an offering for sacrifice, such as ye may find, and do not shave your heads until the offering reaches the place of sacrifice. And if any of you is ill, or has an ailment in his scalp, (Necessitating shaving), (He should) in compensation either fast, or feed the poor, or offer sacrifice; and when ye are in peaceful conditions (again), if any one wishes to continue the 'umra on to the hajj, He must make an offering, such as he can afford, but if he cannot afford it, He should fast three days during the hajj and seven days on his return, Making ten days in all. This is for those whose household is not in (the precincts of) the Sacred Mosque. And fear Allah, and know that Allah Is strict in punishment.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
For Hajj are the months well known. If any one undertakes that duty therein, Let there be no obscenity, nor wickedness, nor wrangling in the Hajj. And whatever good ye do, (be sure) Allah knoweth it. And take a provision (With you) for the journey, but the best of provisions is right conduct. So fear Me, o ye that are wise.\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
It is no crime in you if ye seek of the bounty of your Lord (during pilgrimage). Then when ye pour down from (Mount) Arafat, celebrate the praises of Allah at the Sacred Monument, and celebrate His praises as He has directed you, even though, before this, ye went astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then pass on at a quick pace from the place whence it is usual for the multitude so to do, and ask for Allah's forgiveness. For Allah is Oft-forgiving, Most Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
So when ye have accomplished your holy rites, celebrate the praises of Allah, as ye used to celebrate the praises of your fathers,- yea, with far more Heart and soul. There are men who say: ``Our Lord! Give us (Thy bounties) in this world!" but they will have no portion in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And there are men who say: ``Our Lord! Give us good in this world and good in the Hereafter, and defend us from the torment of the Fire!"\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
To these will be allotted what they have earned; and Allah is quick in account.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
Celebrate the praises of Allah during the Appointed Days. But if any one hastens to leave in two days, there is no blame on him, and if any one stays on, there is no blame on him, if his aim is to do right. Then fear Allah, and know that ye will surely be gathered unto Him.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
There is the type of man whose speech about this world's life May dazzle thee, and he calls Allah to witness about what is in his heart; yet is he the most contentious of enemies.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
When he turns his back, His aim everywhere is to spread mischief through the earth and destroy crops and cattle. But Allah loveth not mischief.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
When it is said to him, ``Fear Allah", He is led by arrogance to (more) crime. Enough for him is Hell;-An evil bed indeed (To lie on)!\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And there is the type of man who gives his life to earn the pleasure of Allah: And Allah is full of kindness to (His) devotees.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O ye who believe! Enter into Islam whole-heartedly; and follow not the footsteps of the evil one; for he is to you an avowed enemy.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
If ye backslide after the clear (Signs) have come to you, then know that Allah is Exalted in Power, Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Will they wait until Allah comes to them in canopies of clouds, with angels (in His train) and the question is (thus) settled? but to Allah do all questions go back (for decision).\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many clear (Signs) We have sent them. But if any one, after Allah's favour has come to him, substitutes (something else), Allah is strict in punishment.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
The life of this world is alluring to those who reject faith, and they scoff at those who believe. But the righteous will be above them on the Day of Resurrection; for Allah bestows His abundance without measure on whom He will.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind was one single nation, and Allah sent Messengers with glad tidings and warnings; and with them He sent the Book in truth, to judge between people in matters wherein they differed; but the People of the Book, after the clear Signs came to them, did not differ among themselves, except through selfish contumacy. Allah by His Grace Guided the believers to the Truth, concerning that wherein they differed. For Allah guided whom He will to a path that is straight.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or do ye think that ye shall enter the Garden (of bliss) without such (trials) as came to those who passed away before you? they encountered suffering and adversity, and were so shaken in spirit that even the Messenger and those of faith who were with him cried: ``When (will come) the help of Allah?" Ah! Verily, the help of Allah is (always) near!\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask thee what they should spend (In charity). Say: Whatever ye spend that is good, is for parents and kindred and orphans and those in want and for wayfarers. And whatever ye do that is good, -Allah knoweth it well.\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Fighting is prescribed for you, and ye dislike it. But it is possible that ye dislike a thing which is good for you, and that ye love a thing which is bad for you. But Allah knoweth, and ye know not.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask thee concerning fighting in the Prohibited Month. Say: ``Fighting therein is a grave (offence); but graver is it in the sight of Allah to prevent access to the path of Allah, to deny Him, to prevent access to the Sacred Mosque, and drive out its members." Tumult and oppression are worse than slaughter. Nor will they cease fighting you until they turn you back from your faith if they can. And if any of you Turn back from their faith and die in unbelief, their works will bear no fruit in this life and in the Hereafter; they will be companions of the Fire and will abide therein.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Those who believed and those who suffered exile and fought (and strove and struggled) in the path of Allah,- they have the hope of the Mercy of Allah: And Allah is Oft-forgiving, Most Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask thee concerning wine and gambling. Say: ``In them is great sin, and some profit, for men; but the sin is greater than the profit." They ask thee how much they are to spend; Say: ``What is beyond your needs." Thus doth Allah Make clear to you His Signs: In order that ye may consider-\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
(Their bearings) on this life and the Hereafter. They ask thee concerning orphans. Say: ``The best thing to do is what is for their good; if ye mix their affairs with yours, they are your brethren; but Allah knows the man who means mischief from the man who means good. And if Allah had wished, He could have put you into difficulties: He is indeed Exalted in Power, Wise."\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Do not marry unbelieving women (idolaters), until they believe: A slave woman who believes is better than an unbelieving woman, even though she allures you. Nor marry (your girls) to unbelievers until they believe: A man slave who believes is better than an unbeliever, even though he allures you. Unbelievers do (but) beckon you to the Fire. But Allah beckons by His Grace to the Garden (of bliss) and forgiveness, and makes His Signs clear to mankind: That they may celebrate His praise.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They ask thee concerning women's courses. Say: They are a hurt and a pollution: So keep away from women in their courses, and do not approach them until they are clean. But when they have purified themselves, ye may approach them in any manner, time, or place ordained for you by Allah. For Allah loves those who turn to Him constantly and He loves those who keep themselves pure and clean.\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your wives are as a tilth unto you; so approach your tilth when or how ye will; but do some good act for your souls beforehand; and fear Allah. And know that ye are to meet Him (in the Hereafter), and give (these) good tidings to those who believe.\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And make not Allah's (name) an excuse in your oaths against doing good, or acting rightly, or making peace between persons; for Allah is One Who heareth and knoweth all things.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not call you to account for thoughtlessness in your oaths, but for the intention in your hearts; and He is Oft-forgiving, Most Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
For those who take an oath for abstention from their wives, a waiting for four months is ordained; if then they return, Allah is Oft-forgiving, Most Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
But if their intention is firm for divorce, Allah heareth and knoweth all things.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women shall wait concerning themselves for three monthly periods. Nor is it lawful for them to hide what Allah Hath created in their wombs, if they have faith in Allah and the Last Day. And their husbands have the better right to take them back in that period, if they wish for reconciliation. And women shall have rights similar to the rights against them, according to what is equitable; but men have a degree (of advantage) over them. And Allah is Exalted in Power, Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
A divorce is only permissible twice: after that, the parties should either hold Together on equitable terms, or separate with kindness. It is not lawful for you, (Men), to take back any of your gifts (from your wives), except when both parties fear that they would be unable to keep the limits ordained by Allah. If ye (judges) do indeed fear that they would be unable to keep the limits ordained by Allah, there is no blame on either of them if she give something for her freedom. These are the limits ordained by Allah; so do not transgress them if any do transgress the limits ordained by Allah, such persons wrong (Themselves as well as others).\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
So if a husband divorces his wife (irrevocably), He cannot, after that, re-marry her until after she has married another husband and He has divorced her. In that case there is no blame on either of them if they re-unite, provided they feel that they can keep the limits ordained by Allah. Such are the limits ordained by Allah, which He makes plain to those who understand.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
When ye divorce women, and they fulfil the term of their ('Iddat), either take them back on equitable terms or set them free on equitable terms; but do not take them back to injure them, (or) to take undue advantage; if any one does that; He wrongs his own soul. Do not treat Allah's Signs as a jest, but solemnly rehearse Allah's favours on you, and the fact that He sent down to you the Book and Wisdom, for your instruction. And fear Allah, and know that Allah is well acquainted with all things.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
When ye divorce women, and they fulfil the term of their ('Iddat), do not prevent them from marrying their (former) husbands, if they mutually agree on equitable terms. This instruction is for all amongst you, who believe in Allah and the Last Day. That is (the course Making for) most virtue and purity amongst you and Allah knows, and ye know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
The mothers shall give such to their offspring for two whole years, if the father desires to complete the term. But he shall bear the cost of their food and clothing on equitable terms. No soul shall have a burden laid on it greater than it can bear. No mother shall be Treated unfairly on account of her child. Nor father on account of his child, an heir shall be chargeable in the same way. If they both decide on weaning, by mutual consent, and after due consultation, there is no blame on them. If ye decide on a foster-mother for your offspring, there is no blame on you, provided ye pay (the mother) what ye offered, on equitable terms. But fear Allah and know that Allah sees well what ye do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
If any of you die and leave widows behind, they shall wait concerning themselves four months and ten days: When they have fulfilled their term, there is no blame on you if they dispose of themselves in a just and reasonable manner. And Allah is well acquainted with what ye do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
There is no blame on you if ye make an offer of betrothal or hold it in your hearts. Allah knows that ye cherish them in your hearts: But do not make a secret contract with them except in terms Honourable, nor resolve on the tie of marriage till the term prescribed is fulfilled. And know that Allah Knoweth what is in your hearts, and take heed of Him; and know that Allah is Oft-forgiving, Most Forbearing.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no blame on you if ye divorce women before consummation or the fixation of their dower; but bestow on them (A suitable gift), the wealthy according to his means, and the poor according to his means;- A gift of a reasonable amount is due from those who wish to do the right thing.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if ye divorce them before consummation, but after the fixation of a dower for them, then the half of the dower (Is due to them), unless they remit it or (the man's half) is remitted by him in whose hands is the marriage tie; and the remission (of the man's half) is the nearest to righteousness. And do not forget Liberality between yourselves. For Allah sees well all that ye do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard strictly your (habit of) prayers, especially the Middle Prayer; and stand before Allah in a devout (frame of mind).\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
If ye fear (an enemy), pray on foot, or riding, (as may be most convenient), but when ye are in security, celebrate Allah's praises in the manner He has taught you, which ye knew not (before).\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
Those of you who die and leave widows should bequeath for their widows a year's maintenance and residence; but if they leave (The residence), there is no blame on you for what they do with themselves, provided it is reasonable. And Allah is Exalted in Power, Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
For divorced women Maintenance (should be provided) on a reasonable (scale). This is a duty on the righteous.\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus doth Allah Make clear His Signs to you: In order that ye may understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Didst thou not Turn by vision to those who abandoned their homes, though they were thousands (In number), for fear of death? Allah said to them: ``Die": Then He restored them to life. For Allah is full of bounty to mankind, but Most of them are ungrateful.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
Then fight in the cause of Allah, and know that Allah Heareth and knoweth all things.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will loan to Allah a beautiful loan, which Allah will double unto his credit and multiply many times? It is Allah that giveth (you) Want or plenty, and to Him shall be your return.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Hast thou not Turned thy vision to the Chiefs of the Children of Israel after (the time of) Moses? they said to a prophet (That was) among them: ``Appoint for us a king, that we May fight in the cause of Allah." He said: ``Is it not possible, if ye were commanded to fight, that that ye will not fight?" They said: ``How could we refuse to fight in the cause of Allah, seeing that we were turned out of our homes and our families?" but when they were commanded to fight, they turned back, except a small band among them. But Allah Has full knowledge of those who do wrong.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
Their Prophet said to them: ``Allah hath appointed Talut as king over you." They said: ``How can he exercise authority over us when we are better fitted than he to exercise authority, and he is not even gifted, with wealth in abundance?" He said: ``Allah hath Chosen him above you, and hath gifted him abundantly with knowledge and bodily prowess: Allah Granteth His authority to whom He pleaseth. Allah careth for all, and He knoweth all things."\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And (further) their Prophet said to them: ``A Sign of his authority is that there shall come to you the Ark of the covenant, with (an assurance) therein of security from your Lord, and the relics left by the family of Moses and the family of Aaron, carried by angels. In this is a symbol for you if ye indeed have faith."\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
When Talut set forth with the armies, he said: ``Allah will test you at the stream: if any drinks of its water, He goes not with my army: Only those who taste not of it go with me: A mere sip out of the hand is excused." but they all drank of it, except a few. When they crossed the river,- He and the faithful ones with him,- they said: ``This day We cannot cope with Goliath and his forces." but those who were convinced that they must meet Allah, said: ``How oft, by Allah's will, Hath a small force vanquished a big one? Allah is with those who steadfastly persevere."\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
When they advanced to meet Goliath and his forces, they prayed: ``Our Lord! Pour out constancy on us and make our steps firm: Help us against those that reject faith."\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
By Allah's will they routed them; and David slew Goliath; and Allah gave him power and wisdom and taught him whatever (else) He willed. And did not Allah Check one set of people by means of another, the earth would indeed be full of mischief: But Allah is full of bounty to all the worlds.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the Signs of Allah: we rehearse them to thee in truth: verily Thou art one of the messengers.\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
Those messengers We endowed with gifts, some above others: To one of them Allah spoke; others He raised to degrees (of honour); to Jesus the son of Mary We gave clear (Signs), and strengthened him with the holy spirit. If Allah had so willed, succeeding generations would not have fought among each other, after clear (Signs) had come to them, but they (chose) to wrangle, some believing and others rejecting. If Allah had so willed, they would not have fought each other; but Allah Fulfilleth His plan.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O ye who believe! Spend out of (the bounties) We have provided for you, before the Day comes when no bargaining (Will avail), nor friendship nor intercession. Those who reject Faith they are the wrong-doers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah! There is no god but He,-the Living, the Self-subsisting, Eternal. No slumber can seize Him nor sleep. His are all things in the heavens and on earth. Who is there can intercede in His presence except as He permitteth? He knoweth what (appeareth to His creatures as) before or after or behind them. Nor shall they compass aught of His knowledge except as He willeth. His Throne doth extend over the heavens and the earth, and He feeleth no fatigue in guarding and preserving them for He is the Most High, the Supreme (in glory).\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
Let there be no compulsion in religion: Truth stands out clear from Error: whoever rejects evil and believes in Allah hath grasped the most trustworthy hand-hold, that never breaks. And Allah heareth and knoweth all things.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Protector of those who have faith: from the depths of darkness He will lead them forth into light. Of those who reject faith the patrons are the evil ones: from light they will lead them forth into the depths of darkness. They will be companions of the fire, to dwell therein (For ever).\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Hast thou not Turned thy vision to one who disputed with Abraham About his Lord, because Allah had granted him power? Abraham said: ``My Lord is He Who Giveth life and death." He said: ``I give life and death". Said Abraham: ``But it is Allah that causeth the sun to rise from the east: Do thou then cause him to rise from the West." Thus was he confounded who (in arrogance) rejected faith. Nor doth Allah Give guidance to a people unjust.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or (take) the similitude of one who passed by a hamlet, all in ruins to its roofs. He said: ``Oh! how shall Allah bring it (ever) to life, after (this) its death?" but Allah caused him to die for a hundred years, then raised him up (again). He said: ``How long didst thou tarry (thus)?" He said: (Perhaps) a day or part of a day." He said: ``Nay, thou hast tarried thus a hundred years; but look at thy food and thy drink; they show no signs of age; and look at thy donkey: And that We may make of thee a sign unto the people, Look further at the bones, how We bring them together and clothe them with flesh." When this was shown clearly to him, he said: ``I know that Allah hath power over all things."\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
When Abraham said: ``Show me, Lord, how You will raise the dead, `` He replied: ``Have you no faith?" He said ``Yes, but just to reassure my heart." Allah said, ``Take four birds, draw them to you, and cut their bodies to pieces. Scatter them over the mountain-tops, then call them back. They will come swiftly to you. Know that Allah is Mighty, Wise."\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The parable of those who spend their substance in the way of Allah is that of a grain of corn: it groweth seven ears, and each ear Hath a hundred grains. Allah giveth manifold increase to whom He pleaseth: And Allah careth for all and He knoweth all things.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their substance in the cause of Allah, and follow not up their gifts with reminders of their generosity or with injury,-for them their reward is with their Lord: on them shall be no fear, nor shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Kind words and the covering of faults are better than charity followed by injury. Allah is free of all wants, and He is Most-Forbearing.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O ye who believe! cancel not your charity by reminders of your generosity or by injury,- like those who spend their substance to be seen of men, but believe neither in Allah nor in the Last Day. They are in parable like a hard, barren rock, on which is a little soil: on it falls heavy rain, which leaves it (Just) a bare stone. They will be able to do nothing with aught they have earned. And Allah guideth not those who reject faith.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the likeness of those who spend their substance, seeking to please Allah and to strengthen their souls, is as a garden, high and fertile: heavy rain falls on it but makes it yield a double increase of harvest, and if it receives not Heavy rain, light moisture sufficeth it. Allah seeth well whatever ye do.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Does any of you wish that he should have a garden with date-palms and vines and streams flowing underneath, and all kinds of fruit, while he is stricken with old age, and his children are not strong (enough to look after themselves)- that it should be caught in a whirlwind, with fire therein, and be burnt up? Thus doth Allah make clear to you (His) Signs; that ye may consider.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O ye who believe! Give of the good things which ye have (honourably) earned, and of the fruits of the earth which We have produced for you, and do not even aim at getting anything which is bad, in order that out of it ye may give away something, when ye yourselves would not receive it except with closed eyes. And know that Allah is Free of all wants, and worthy of all praise.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
The Evil one threatens you with poverty and bids you to conduct unseemly. Allah promiseth you His forgiveness and bounties. And Allah careth for all and He knoweth all things.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He granteth wisdom to whom He pleaseth; and he to whom wisdom is granted receiveth indeed a benefit overflowing; but none will grasp the Message but men of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever ye spend in charity or devotion, be sure Allah knows it all. But the wrong-doers have no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If ye disclose (acts of) charity, even so it is well, but if ye conceal them, and make them reach those (really) in need, that is best for you: It will remove from you some of your (stains of) evil. And Allah is well acquainted with what ye do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
It is not required of thee (O Messenger), to set them on the right path, but Allah sets on the right path whom He pleaseth. Whatever of good ye give benefits your own souls, and ye shall only do so seeking the ``Face" of Allah. Whatever good ye give, shall be rendered back to you, and ye shall not Be dealt with unjustly.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Charity is) for those in need, who, in Allah's cause are restricted (from travel), and cannot move about in the land, seeking (For trade or work): the ignorant man thinks, because of their modesty, that they are free from want. Thou shalt know them by their (Unfailing) mark: They beg not importunately from all the sundry. And whatever of good ye give, be assured Allah knoweth it well.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who (in charity) spend of their goods by night and by day, in secret and in public, have their reward with their Lord: on them shall be no fear, nor shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who devour usury will not stand except as stand one whom the Evil one by his touch Hath driven to madness. That is because they say: ``Trade is like usury," but Allah hath permitted trade and forbidden usury. Those who after receiving direction from their Lord, desist, shall be pardoned for the past; their case is for Allah (to judge); but those who repeat (The offence) are companions of the Fire: They will abide therein (for ever).\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah will deprive usury of all blessing, but will give increase for deeds of charity: For He loveth not creatures ungrateful and wicked.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Those who believe, and do deeds of righteousness, and establish regular prayers and regular charity, will have their reward with their Lord: on them shall be no fear, nor shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O ye who believe! Fear Allah, and give up what remains of your demand for usury, if ye are indeed believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
If ye do it not, Take notice of war from Allah and His Messenger: But if ye turn back, ye shall have your capital sums: Deal not unjustly, and ye shall not be dealt with unjustly.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
If the debtor is in a difficulty, grant him time Till it is easy for him to repay. But if ye remit it by way of charity, that is best for you if ye only knew.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And fear the Day when ye shall be brought back to Allah. Then shall every soul be paid what it earned, and none shall be dealt with unjustly.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O ye who believe! When ye deal with each other, in transactions involving future obligations in a fixed period of time, reduce them to writing Let a scribe write down faithfully as between the parties: let not the scribe refuse to write: as Allah Has taught him, so let him write. Let him who incurs the liability dictate, but let him fear His Lord Allah, and not diminish aught of what he owes. If they party liable is mentally deficient, or weak, or unable Himself to dictate, Let his guardian dictate faithfully, and get two witnesses, out of your own men, and if there are not two men, then a man and two women, such as ye choose, for witnesses, so that if one of them errs, the other can remind her. The witnesses should not refuse when they are called on (For evidence). Disdain not to reduce to writing (your contract) for a future period, whether it be small or big: it is juster in the sight of Allah, More suitable as evidence, and more convenient to prevent doubts among yourselves but if it be a transaction which ye carry out on the spot among yourselves, there is no blame on you if ye reduce it not to writing. But take witness whenever ye make a commercial contract; and let neither scribe nor witness suffer harm. If ye do (such harm), it would be wickedness in you. So fear Allah; For it is Good that teaches you. And Allah is well acquainted with all things. If ye are on a journey, and cannot find a scribe, a pledge with possession (may serve the purpose). And if one of you deposits a thing on trust with another, let the trustee (faithfully) discharge his trust, and let him Fear his Lord conceal not evidence; for whoever conceals it, - his heart is tainted with sin. And Allah knoweth all that ye do.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
If ye are on a journey, and cannot find a scribe, a pledge with possession (may serve the purpose). And if one of you deposits a thing on trust with another, Let the trustee (Faithfully) discharge His trust, and let him fear his Lord. Conceal not evidence; for whoever conceals it,- His heart is tainted with sin. And Allah Knoweth all that ye do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongeth all that is in the heavens and on earth. Whether ye show what is in your minds or conceal it, Allah Calleth you to account for it. He forgiveth whom He pleaseth, and punisheth whom He pleaseth, for Allah hath power over all things.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger believeth in what hath been revealed to him from his Lord, as do the men of faith. Each one (of them) believeth in Allah, His angels, His books, and His messengers. ``We make no distinction (they say) between one and another of His messengers." And they say: ``We hear, and we obey: (We seek) Thy forgiveness, our Lord, and to Thee is the end of all journeys."\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
On no soul doth Allah Place a burden greater than it can bear. It gets every good that it earns, and it suffers every ill that it earns. (Pray:) ``Our Lord! Condemn us not if we forget or fall into error; our Lord! Lay not on us a burden Like that which Thou didst lay on those before us; Our Lord! Lay not on us a burden greater than we have strength to bear. Blot out our sins, and grant us forgiveness. Have mercy on us. Thou art our Protector; Help us against those who stand against faith."\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah! There is no god but He,-the Living, the Self-Subsisting, Eternal.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
It is He Who sent down to thee (step by step), in truth, the Book, confirming what went before it; and He sent down the Law (of Moses) and the Gospel (of Jesus) before this, as a guide to mankind, and He sent down the criterion (of judgment between right and wrong).\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Then those who reject Faith in the Signs of Allah will suffer the severest penalty, and Allah is Exalted in Might, Lord of Retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
From Allah, verily nothing is hidden on earth or in the heavens.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
He it is Who shapes you in the wombs as He pleases. There is no god but He, the Exalted in Might, the Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
He it is Who has sent down to thee the Book: In it are verses basic or fundamental (of established meaning); they are the foundation of the Book: others are allegorical. But those in whose hearts is perversity follow the part thereof that is allegorical, seeking discord, and searching for its hidden meanings, but no one knows its hidden meanings except Allah. And those who are firmly grounded in knowledge say: ``We believe in the Book; the whole of it is from our Lord:" and none will grasp the Message except men of understanding.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
``Our Lord!" (they say), ``Let not our hearts deviate now after Thou hast guided us, but grant us mercy from Thine own Presence; for Thou art the Grantor of bounties without measure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
``Our Lord! Thou art He that will gather mankind Together against a day about which there is no doubt; for Allah never fails in His promise."\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
Those who reject Faith,- neither their possessions nor their (numerous) progeny will avail them aught against Allah: They are themselves but fuel for the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
(Their plight will be) no better than that of the people of Pharaoh, and their predecessors: They denied our Signs, and Allah called them to account for their sins. For Allah is strict in punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to those who reject Faith: ``Soon will ye be vanquished and gathered together to Hell,-an evil bed indeed (to lie on)!\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
``There has already been for you a Sign in the two armies that met (in combat): One was fighting in the cause of Allah, the other resisting Allah; these saw with their own eyes Twice their number. But Allah doth support with His aid whom He pleaseth. In this is a warning for such as have eyes to see."\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Fair in the eyes of men is the love of things they covet: Women and sons; Heaped-up hoards of gold and silver; horses branded (for blood and excellence); and (wealth of) cattle and well-tilled land. Such are the possessions of this world's life; but in nearness to Allah is the best of the goals (To return to).\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: Shall I give you glad tidings of things Far better than those? For the righteous are Gardens in nearness to their Lord, with rivers flowing beneath; therein is their eternal home; with companions pure (and holy); and the good pleasure of Allah. For in Allah's sight are (all) His servants,-\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
(Namely), those who say: ``Our Lord! we have indeed believed: forgive us, then, our sins, and save us from the agony of the Fire;"-\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
Those who show patience, Firmness and self-control; who are true (in word and deed); who worship devoutly; who spend (in the way of Allah); and who pray for forgiveness in the early hours of the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
There is no god but He: That is the witness of Allah, His angels, and those endued with knowledge, standing firm on justice. There is no god but He, the Exalted in Power, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
The Religion before Allah is Islam (submission to His Will): Nor did the People of the Book dissent therefrom except through envy of each other, after knowledge had come to them. But if any deny the Signs of Allah, Allah is swift in calling to account.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
So if they dispute with thee, say: ``I have submitted My whole self to Allah and so have those who follow me." And say to the People of the Book and to those who are unlearned: ``Do ye (also) submit yourselves?" If they do, they are in right guidance, but if they turn back, Thy duty is to convey the Message; and in Allah's sight are (all) His servants.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
As to those who deny the Signs of Allah and in defiance of right, slay the prophets, and slay those who teach just dealing with mankind, announce to them a grievous penalty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are those whose works will bear no fruit in this world and in the Hereafter nor will they have anyone to help.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Hast thou not turned Thy vision to those who have been given a portion of the Book? They are invited to the Book of Allah, to settle their dispute, but a party of them Turn back and decline (The arbitration).\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
This because they say: ``The Fire shall not touch us but for a few numbered days": For their forgeries deceive them as to their own religion.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
But how (will they fare) when we gather them together against a day about which there is no doubt, and each soul will be paid out just what it has earned, without (favour or) injustice?\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: ``O Allah! Lord of Power (And Rule), Thou givest power to whom Thou pleasest, and Thou strippest off power from whom Thou pleasest: Thou enduest with honour whom Thou pleasest, and Thou bringest low whom Thou pleasest: In Thy hand is all good. Verily, over all things Thou hast power.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
``Thou causest the night to gain on the day, and thou causest the day to gain on the night; Thou bringest the Living out of the dead, and Thou bringest the dead out of the Living; and Thou givest sustenance to whom Thou pleasest, without measure."\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers Take for friends or helpers Unbelievers rather than believers: if any do that, in nothing will there be help from Allah: except by way of precaution, that ye may Guard yourselves from them. But Allah cautions you (To remember) Himself; for the final goal is to Allah.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say: ``Whether ye hide what is in your hearts or reveal it, Allah knows it all: He knows what is in the heavens, and what is on earth. And Allah has power over all things.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
``On the Day when every soul will be confronted with all the good it has done, and all the evil it has done, it will wish there were a great distance between it and its evil. But Allah cautions you (To remember) Himself. And Allah is full of kindness to those that serve Him."\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say: ``If ye do love Allah, Follow me: Allah will love you and forgive you your sins: For Allah is Oft-Forgiving, Most Merciful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: ``Obey Allah and His Messenger": But if they turn back, Allah loveth not those who reject Faith.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Allah did choose Adam and Noah, the family of Abraham, and the family of 'Imran above all people,-\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Offspring, one of the other: And Allah heareth and knoweth all things.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
Behold! a woman of 'Imran said: ``O my Lord! I do dedicate unto Thee what is in my womb for Thy special service: So accept this of me: For Thou hearest and knowest all things."\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
When she was delivered, she said: ``O my Lord! Behold! I am delivered of a female child!"- and Allah knew best what she brought forth- ``And no wise is the male Like the female. I have named her Mary, and I commend her and her offspring to Thy protection from the Evil One, the Rejected."\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Right graciously did her Lord accept her: He made her grow in purity and beauty: To the care of Zakariya was she assigned. Every time that he entered (Her) chamber to see her, He found her supplied with sustenance. He said: ``O Mary! Whence (comes) this to you?" She said: ``From Allah: for Allah Provides sustenance to whom He pleases without measure."\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
There did Zakariya pray to his Lord, saying: ``O my Lord! Grant unto me from Thee a progeny that is pure: for Thou art He that heareth prayer!\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
While he was standing in prayer in the chamber, the angels called unto him: ``Allah doth give thee glad tidings of Yahya, witnessing the truth of a Word from Allah, and (be besides) noble, chaste, and a prophet,- of the (goodly) company of the righteous."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: ``O my Lord! How shall I have son, seeing I am very old, and my wife is barren?" ``Thus," was the answer, ``Doth Allah accomplish what He willeth."\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: ``O my Lord! Give me a Sign!" ``Thy Sign," was the answer, ``Shall be that thou shalt speak to no man for three days but with signals. Then celebrate the praises of thy Lord again and again, and glorify Him in the evening and in the morning."\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
Behold! the angels said: ``O Mary! Allah hath chosen thee and purified thee- chosen thee above the women of all nations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
``O Mary! worship Thy Lord devoutly: Prostrate thyself, and bow down (in prayer) with those who bow down."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is part of the tidings of the things unseen, which We reveal unto thee (O Messenger!) by inspiration: Thou wast not with them when they cast lots with arrows, as to which of them should be charged with the care of Mary: Nor wast thou with them when they disputed (the point).\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
Behold! the angels said: ``O Mary! Allah giveth thee glad tidings of a Word from Him: his name will be Christ Jesus, the son of Mary, held in honour in this world and the Hereafter and of (the company of) those nearest to Allah;\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
``He shall speak to the people in childhood and in maturity. And he shall be (of the company) of the righteous."\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: ``O my Lord! How shall I have a son when no man hath touched me?" He said: ``Even so: Allah createth what He willeth: When He hath decreed a plan, He but saith to it, 'Be,' and it is!\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
``And Allah will teach him the Book and Wisdom, the Law and the Gospel,\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
``And (appoint him) a messenger to the Children of Israel, (with this message): ``'I have come to you, with a Sign from your Lord, in that I make for you out of clay, as it were, the figure of a bird, and breathe into it, and it becomes a bird by Allah's leave: And I heal those born blind, and the lepers, and I quicken the dead, by Allah's leave; and I declare to you what ye eat, and what ye store in your houses. Surely therein is a Sign for you if ye did believe;\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
``'(I have come to you), to attest the Law which was before me. And to make lawful to you part of what was (Before) forbidden to you; I have come to you with a Sign from your Lord. So fear Allah, and obey me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
``'It is Allah Who is my Lord and your Lord; then worship Him. This is a Way that is straight.'"\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
When Jesus found Unbelief on their part He said: ``Who will be My helpers to (the work of) Allah?" Said the disciples: ``We are Allah's helpers: We believe in Allah, and do thou bear witness that we are Muslims.\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
``Our Lord! we believe in what Thou hast revealed, and we follow the Messenger; then write us down among those who bear witness."\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And (the unbelievers) plotted and planned, and Allah too planned, and the best of planners is Allah.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
Behold! Allah said: ``O Jesus! I will take thee and raise thee to Myself and clear thee (of the falsehoods) of those who blaspheme; I will make those who follow thee superior to those who reject faith, to the Day of Resurrection: Then shall ye all return unto me, and I will judge between you of the matters wherein ye dispute.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
``As to those who reject faith, I will punish them with terrible agony in this world and in the Hereafter, nor will they have anyone to help."\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
``As to those who believe and work righteousness, Allah will pay them (in full) their reward; but Allah loveth not those who do wrong."\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
``This is what we rehearse unto thee of the Signs and the Message of Wisdom."\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
The similitude of Jesus before Allah is as that of Adam; He created him from dust, then said to him: ``Be". And he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
The Truth (comes) from Allah alone; so be not of those who doubt.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
If any one disputes in this matter with thee, now after (full) knowledge Hath come to thee, say: ``Come! let us gather together,- our sons and your sons, our women and your women, ourselves and yourselves: Then let us earnestly pray, and invoke the curse of Allah on those who lie!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
This is the true account: There is no god except Allah; and Allah-He is indeed the Exalted in Power, the Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
But if they turn back, Allah hath full knowledge of those who do mischief.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: ``O People of the Book! come to common terms as between us and you: That we worship none but Allah; that we associate no partners with him; that we erect not, from among ourselves, Lords and patrons other than Allah." If then they turn back, say ye: ``Bear witness that we (at least) are Muslims (bowing to Allah's Will).\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
Ye People of the Book! Why dispute ye about Abraham, when the Law and the Gospel Were not revealed Till after him? Have ye no understanding?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Ah! Ye are those who fell to disputing (Even) in matters of which ye had some knowledge! but why dispute ye in matters of which ye have no knowledge? It is Allah Who knows, and ye who know not!\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Abraham was not a Jew nor yet a Christian; but he was true in Faith, and bowed his will to Allah's (Which is Islam), and he joined not gods with Allah.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Without doubt, among men, the nearest of kin to Abraham, are those who follow him, as are also this Prophet and those who believe: And Allah is the Protector of those who have faith.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
It is the wish of a section of the People of the Book to lead you astray. But they shall lead astray (Not you), but themselves, and they do not perceive!\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
Ye People of the Book! Why reject ye the Signs of Allah, of which ye are (Yourselves) witnesses?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
Ye People of the Book! Why do ye clothe Truth with falsehood, and conceal the Truth, while ye have knowledge?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
A section of the People of the Book say: ``Believe in the morning what is revealed to the believers, but reject it at the end of the day; perchance they may (themselves) Turn back;\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
``And believe no one unless he follows your religion." Say: ``True guidance is the Guidance of Allah: (Fear ye) Lest a revelation be sent to someone (else) Like unto that which was sent unto you? or that those (Receiving such revelation) should engage you in argument before your Lord?" Say: ``All bounties are in the hand of Allah: He granteth them to whom He pleaseth: And Allah careth for all, and He knoweth all things."\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
For His Mercy He specially chooseth whom He pleaseth; for Allah is the Lord of bounties unbounded.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People of the Book are some who, if entrusted with a hoard of gold, will (readily) pay it back; others, who, if entrusted with a single silver coin, will not repay it unless thou constantly stoodest demanding, because, they say, ``there is no call on us (to keep faith) with these ignorant (Pagans)." but they tell a lie against Allah, and (well) they know it.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Nay.- Those that keep their plighted faith and act aright,-verily Allah loves those who act aright.\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
As for those who sell the faith they owe to Allah and their own plighted word for a small price, they shall have no portion in the Hereafter: Nor will Allah (Deign to) speak to them or look at them on the Day of Judgment, nor will He cleans them (of sin): They shall have a grievous penalty.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
There is among them a section who distort the Book with their tongues: (As they read) you would think it is a part of the Book, but it is no part of the Book; and they say, ``That is from Allah," but it is not from Allah: It is they who tell a lie against Allah, and (well) they know it!\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not (possible) that a man, to whom is given the Book, and Wisdom, and the prophetic office, should say to people: ``Be ye my worshippers rather than Allah's": on the contrary (He would say) ``Be ye worshippers of Him Who is truly the Cherisher of all: For ye have taught the Book and ye have studied it earnestly."\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor would he instruct you to take angels and prophets for Lords and patrons. What! would he bid you to unbelief after ye have bowed your will (To Allah in Islam)?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
Behold! Allah took the covenant of the prophets, saying: ``I give you a Book and Wisdom; then comes to you a messenger, confirming what is with you; do ye believe in him and render him help." Allah said: ``Do ye agree, and take this my Covenant as binding on you?" They said: ``We agree." He said: ``Then bear witness, and I am with you among the witnesses."\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
If any turn back after this, they are perverted transgressors.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Do they seek for other than the Religion of Allah?-while all creatures in the heavens and on earth have, willing or unwilling, bowed to His Will (Accepted Islam), and to Him shall they all be brought back.\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say: ``We believe in Allah, and in what has been revealed to us and what was revealed to Abraham, Isma'il, Isaac, Jacob, and the Tribes, and in (the Books) given to Moses, Jesus, and the prophets, from their Lord: We make no distinction between one and another among them, and to Allah do we bow our will (in Islam)."\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
If anyone desires a religion other than Islam (submission to Allah), never will it be accepted of him; and in the Hereafter He will be in the ranks of those who have lost (All spiritual good).\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah Guide those who reject Faith after they accepted it and bore witness that the Messenger was true and that Clear Signs had come unto them? but Allah guides not a people unjust.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
Of such the reward is that on them (rests) the curse of Allah, of His angels, and of all mankind;-\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
In that will they dwell; nor will their penalty be lightened, nor respite be (their lot);-\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except for those that repent (Even) after that, and make amends; for verily Allah is Oft-Forgiving, Most Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
But those who reject Faith after they accepted it, and then go on adding to their defiance of Faith,- never will their repentance be accepted; for they are those who have (of set purpose) gone astray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
As to those who reject Faith, and die rejecting,- never would be accepted from any such as much gold as the earth contains, though they should offer it for ransom. For such is (in store) a penalty grievous, and they will find no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
By no means shall ye attain righteousness unless ye give (freely) of that which ye love; and whatever ye give, of a truth Allah knoweth it well.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel, except what Israel Made unlawful for itself, before the Law (of Moses) was revealed. Say: ``Bring ye the Law and study it, if ye be men of truth."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
If any, after this, invent a lie and attribute it to Allah, they are indeed unjust wrong-doers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say: ``Allah speaketh the Truth: follow the religion of Abraham, the sane in faith; he was not of the Pagans."\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
The first House (of worship) appointed for men was that at Bakka: Full of blessing and of guidance for all kinds of beings:\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are Signs Manifest; (for example), the Station of Abraham; whoever enters it attains security; Pilgrimage thereto is a duty men owe to Allah,- those who can afford the journey; but if any deny faith, Allah stands not in need of any of His creatures.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: ``O People of the Book! Why reject ye the Signs of Allah, when Allah is Himself witness to all ye do?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: ``O ye People of the Book! Why obstruct ye those who believe, from the path of Allah, Seeking to make it crooked, while ye were yourselves witnesses (to Allah's Covenant)? but Allah is not unmindful of all that ye do."\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O ye who believe! If ye listen to a faction among the People of the Book, they would (indeed) render you apostates after ye have believed!\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how would ye deny Faith while unto you are rehearsed the Signs of Allah, and among you Lives the Messenger? Whoever holds firmly to Allah will be shown a way that is straight.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O ye who believe! Fear Allah as He should be feared, and die not except in a state of Islam.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast, all together, by the rope which Allah (stretches out for you), and be not divided among yourselves; and remember with gratitude Allah's favour on you; for ye were enemies and He joined your hearts in love, so that by His Grace, ye became brethren; and ye were on the brink of the pit of Fire, and He saved you from it. Thus doth Allah make His Signs clear to you: That ye may be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
Let there arise out of you a band of people inviting to all that is good, enjoining what is right, and forbidding what is wrong: They are the ones to attain felicity.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
Be not like those who are divided amongst themselves and fall into disputations after receiving Clear Signs: For them is a dreadful penalty,-\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day when some faces will be (lit up with) white, and some faces will be (in the gloom of) black: To those whose faces will be black, (will be said): ``Did ye reject Faith after accepting it? Taste then the penalty for rejecting Faith."\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
But those whose faces will be (lit with) white,- they will be in (the light of) Allah's mercy: therein to dwell (for ever).\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the Signs of Allah: We rehearse them to thee in Truth: And Allah means no injustice to any of His creatures.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
To Allah belongs all that is in the heavens and on earth: To Him do all questions go back (for decision).\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
Ye are the best of peoples, evolved for mankind, enjoining what is right, forbidding what is wrong, and believing in Allah. If only the People of the Book had faith, it were best for them: among them are some who have faith, but most of them are perverted transgressors.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will do you no harm, barring a trifling annoyance; if they come out to fight you, they will show you their backs, and no help shall they get.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
Shame is pitched over them (Like a tent) wherever they are found, except when under a covenant (of protection) from Allah and from men; they draw on themselves wrath from Allah, and pitched over them is (the tent of) destitution. This because they rejected the Signs of Allah, and slew the prophets in defiance of right; this because they rebelled and transgressed beyond bounds.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
Not all of them are alike: Of the People of the Book are a portion that stand (For the right): They rehearse the Signs of Allah all night long, and they prostrate themselves in adoration.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and the Last Day; they enjoin what is right, and forbid what is wrong; and they hasten (in emulation) in (all) good works: They are in the ranks of the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
Of the good that they do, nothing will be rejected of them; for Allah knoweth well those that do right.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Those who reject Faith,- neither their possessions nor their (numerous) progeny will avail them aught against Allah: They will be companions of the Fire,-dwelling therein (for ever).\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
What they spend in the life of this (material) world May be likened to a wind which brings a nipping frost: It strikes and destroys the harvest of men who have wronged their own souls: it is not Allah that hath wronged them, but they wrong themselves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O ye who believe! Take not into your intimacy those outside your ranks: They will not fail to corrupt you. They only desire your ruin: Rank hatred has already appeared from their mouths: What their hearts conceal is far worse. We have made plain to you the Signs, if ye have wisdom.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Ah! ye are those who love them, but they love you not,- though ye believe in the whole of the Book. When they meet you, they say, ``We believe": But when they are alone, they bite off the very tips of their fingers at you in their rage. Say: ``Perish in your rage; Allah knoweth well all the secrets of the heart."\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If aught that is good befalls you, it grieves them; but if some misfortune overtakes you, they rejoice at it. But if ye are constant and do right, not the least harm will their cunning do to you; for Allah Compasseth round about all that they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
Remember that morning Thou didst leave Thy household (early) to post the faithful at their stations for battle: And Allah heareth and knoweth all things:\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
Remember two of your parties Meditated cowardice; but Allah was their protector, and in Allah should the faithful (Ever) put their trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
Allah had helped you at Badr, when ye were a contemptible little force; then fear Allah; thus May ye show your gratitude.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
Remember thou saidst to the Faithful: ``Is it not enough for you that Allah should help you with three thousand angels (Specially) sent down?\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
``Yea, - if ye remain firm, and act aright, even if the enemy should rush here on you in hot haste, your Lord would help you with five thousand angels Making a terrific onslaught.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah made it but a message of hope for you, and an assurance to your hearts: (in any case) there is no help except from Allah. The Exalted, the Wise:\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He might cut off a fringe of the Unbelievers or expose them to infamy, and they should then be turned back, frustrated of their purpose.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
Not for thee, (but for Allah), is the decision: Whether He turn in mercy to them, or punish them; for they are indeed wrong-doers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
To Allah belongeth all that is in the heavens and on earth. He forgiveth whom He pleaseth and punisheth whom He pleaseth; but Allah is Oft-Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O ye who believe! Devour not usury, doubled and multiplied; but fear Allah; that ye may (really) prosper.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
Fear the Fire, which is repaired for those who reject Faith:\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Messenger; that ye may obtain mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
Be quick in the race for forgiveness from your Lord, and for a Garden whose width is that (of the whole) of the heavens and of the earth, prepared for the righteous,-\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who spend (freely), whether in prosperity, or in adversity; who restrain anger, and pardon (all) men;- for Allah loves those who do good;-\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, having done something to be ashamed of, or wronged their own souls, earnestly bring Allah to mind, and ask for forgiveness for their sins,- and who can forgive sins except Allah?- and are never obstinate in persisting knowingly in (the wrong) they have done.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
For such the reward is forgiveness from their Lord, and Gardens with rivers flowing underneath,- an eternal dwelling: How excellent a recompense for those who work (and strive)!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Many were the Ways of Life that have passed away before you: travel through the earth, and see what was the end of those who rejected Truth.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
Here is a plain statement to men, a guidance and instruction to those who fear Allah!\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
So lose not heart, nor fall into despair: For ye must gain mastery if ye are true in Faith.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound hath touched you, be sure a similar wound hath touched the others. Such days (of varying fortunes) We give to men and men by turns: that Allah may know those that believe, and that He may take to Himself from your ranks Martyr-witnesses (to Truth). And Allah loveth not those that do wrong.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
Allah's object also is to purge those that are true in Faith and to deprive of blessing Those that resist Faith.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Did ye think that ye would enter Heaven without Allah testing those of you who fought hard (In His Cause) and remained steadfast?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
Ye did indeed wish for death before ye met him: Now ye have seen him with your own eyes, (And ye flinch!)\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is no more than a messenger: many Were the messenger that passed away before him. If he died or were slain, will ye then Turn back on your heels? If any did turn back on his heels, not the least harm will he do to Allah; but Allah (on the other hand) will swiftly reward those who (serve Him) with gratitude.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
Nor can a soul die except by Allah's leave, the term being fixed as by writing. If any do desire a reward in this life, We shall give it to him; and if any do desire a reward in the Hereafter, We shall give it to him. And swiftly shall We reward those that (serve us with) gratitude.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
How many of the prophets fought (in Allah's way), and with them (fought) Large bands of godly men? but they never lost heart if they met with disaster in Allah's way, nor did they weaken (in will) nor give in. And Allah Loves those who are firm and steadfast.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
All that they said was: ``Our Lord! Forgive us our sins and anything We may have done that transgressed our duty: Establish our feet firmly, and help us against those that resist Faith."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
And Allah gave them a reward in this world, and the excellent reward of the Hereafter. For Allah Loveth those who do good.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O ye who believe! If ye obey the Unbelievers, they will drive you back on your heels, and ye will turn back (from Faith) to your own loss.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
Nay, Allah is your protector, and He is the best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
Soon shall We cast terror into the hearts of the Unbelievers, for that they joined companions with Allah, for which He had sent no authority: their abode will be the Fire: And evil is the home of the wrong-doers!\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
Allah did indeed fulfil His promise to you when ye with His permission Were about to annihilate your enemy,-until ye flinched and fell to disputing about the order, and disobeyed it after He brought you in sight (of the booty) which ye covet. Among you are some that hanker after this world and some that desire the Hereafter. Then did He divert you from your foes in order to test you but He forgave you: For Allah is full of grace to those who believe.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
Behold! ye were climbing up the high ground, without even casting a side glance at any one, and the Messenger in your rear was calling you back. There did Allah give you one distress after another by way of requital, to teach you not to grieve for (the booty) that had escaped you and for (the ill) that had befallen you. For Allah is well aware of all that ye do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
After (the excitement) of the distress, He sent down calm on a band of you overcome with slumber, while another band was stirred to anxiety by their own feelings, Moved by wrong suspicions of Allah-suspicions due to ignorance. They said: ``What affair is this of ours?" Say thou: ``Indeed, this affair is wholly Allah's." They hide in their minds what they dare not reveal to thee. They say (to themselves): ``If we had had anything to do with this affair, We should not have been in the slaughter here." Say: ``Even if you had remained in your homes, those for whom death was decreed would certainly have gone forth to the place of their death"; but (all this was) that Allah might test what is in your breasts and purge what is in your hearts. For Allah knoweth well the secrets of your hearts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned back on the day the two hosts Met,-it was Satan who caused them to fail, because of some (evil) they had done. But Allah Has blotted out (their fault): For Allah is Oft-Forgiving, Most Forbearing.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O ye who believe! Be not like the Unbelievers, who say of their brethren, when they are travelling through the Earth or engaged in fighting: ``If they had stayed with us, they would not have died, or been slain." This that Allah may make it a cause of sighs and regrets in their hearts. It is Allah that gives Life and Death, and Allah sees well all that ye do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
And if ye are slain, or die, in the way of Allah, forgiveness and mercy from Allah are far better than all they could amass.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
And if ye die, or are slain, Lo! it is unto Allah that ye are brought together.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
It is part of the Mercy of Allah that thou dost deal gently with them Wert thou severe or harsh-hearted, they would have broken away from about thee: so pass over (Their faults), and ask for (Allah's) forgiveness for them; and consult them in affairs (of moment). Then, when thou hast Taken a decision put thy trust in Allah. For Allah loves those who put their trust (in Him).\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah helps you, none can overcome you: If He forsakes you, who is there, after that, that can help you? in Allah, then, Let believers put their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
No prophet could (ever) be false to his trust. If any person is so false, He shall, on the Day of Judgment, restore what he misappropriated; then shall every soul receive its due,- whatever it earned,- and none shall be dealt with unjustly.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is the man who follows the good pleasure of Allah Like the man who draws on himself the wrath of Allah, and whose abode is in Hell?- A woeful refuge!\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in varying gardens in the sight of Allah, and Allah sees well all that they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Allah did confer a great favour on the believers when He sent among them a messenger from among themselves, rehearsing unto them the Signs of Allah, sanctifying them, and instructing them in Scripture and Wisdom, while, before that, they had been in manifest error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
What! When a single disaster smites you, although ye smote (your enemies) with one twice as great, do ye say?- ``Whence is this?" Say (to them): ``It is from yourselves: For Allah hath power over all things."\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
What ye suffered on the day the two armies Met, was with the leave of Allah, in order that He might test the believers,-\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And the Hypocrites also. These were told: ``Come, fight in the way of Allah, or (at least) drive (The foe from your city)." They said: ``Had we known how to fight, we should certainly have followed you." They were that day nearer to Unbelief than to Faith, saying with their lips what was not in their hearts but Allah hath full knowledge of all they conceal.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
(They are) the ones that say, (of their brethren slain), while they themselves sit (at ease): ``If only they had listened to us they would not have been slain." Say: ``Avert death from your own selves, if ye speak the truth."\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Think not of those who are slain in Allah's way as dead. Nay, they live, finding their sustenance in the presence of their Lord;\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
They rejoice in the bounty provided by Allah: And with regard to those left behind, who have not yet joined them (in their bliss), the (Martyrs) glory in the fact that on them is no fear, nor have they (cause to) grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They glory in the Grace and the bounty from Allah, and in the fact that Allah suffereth not the reward of the Faithful to be lost (in the least).\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Of those who answered the call of Allah and the Messenger, even after being wounded, those who do right and refrain from wrong have a great reward;-\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Men said to them: ``A great army is gathering against you": And frightened them: But it (only) increased their Faith: They said: ``For us Allah sufficeth, and He is the best disposer of affairs."\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
And they returned with Grace and bounty from Allah: no harm ever touched them: For they followed the good pleasure of Allah: And Allah is the Lord of bounties unbounded.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is only the Evil One that suggests to you the fear of his votaries: Be ye not afraid of them, but fear Me, if ye have Faith.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
Let not those grieve thee who rush headlong into Unbelief: Not the least harm will they do to Allah: Allah's plan is that He will give them no portion in the Hereafter, but a severe punishment.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who purchase Unbelief at the price of faith,- not the least harm will they do to Allah, but they will have a grievous punishment.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
Let not the Unbelievers think that our respite to them is good for themselves: We grant them respite that they may grow in their iniquity: But they will have a shameful punishment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not leave the believers in the state in which ye are now, until He separates what is evil from what is good nor will He disclose to you the secrets of the Unseen. But He chooses of His Messengers (For the purpose) whom He pleases. So believe in Allah. And His messengers: And if ye believe and do right, ye have a reward without measure.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who covetously withhold of the gifts which Allah Hath given them of His Grace, think that it is good for them: Nay, it will be the worse for them: soon shall the things which they covetously withheld be tied to their necks Like a twisted collar, on the Day of Judgment. To Allah belongs the heritage of the heavens and the earth; and Allah is well-acquainted with all that ye do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Allah hath heard the taunt of those who say: ``Truly, Allah is indigent and we are rich!"- We shall certainly record their word and (their act) of slaying the prophets in defiance of right, and We shall say: ``Taste ye the penalty of the Scorching Fire!\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
``This is because of the (unrighteous deeds) which your hands sent on before ye: For Allah never harms those who serve Him."\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
They (also) said: ``Allah took our promise not to believe in an messenger unless He showed us a sacrifice consumed by Fire (From heaven)." Say: ``There came to you messengers before me, with clear Signs and even with what ye ask for: why then did ye slay them, if ye speak the truth?"\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
Then if they reject thee, so were rejected messengers before thee, who came with Clear Signs, Books of dark prophecies, and the Book of Enlightenment.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul shall have a taste of death: And only on the Day of Judgment shall you be paid your full recompense. Only he who is saved far from the Fire and admitted to the Garden will have attained the object (of Life): For the life of this world is but goods and chattels of deception.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
Ye shall certainly be tried and tested in your possessions and in your personal selves; and ye shall certainly Hear much that will grieve you, from those who received the Book before you and from those who worship many gods. But if ye persevere patiently, and guard against evil,-then that will be a determining factor in all affairs.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And remember Allah took a covenant from the People of the Book, to make it known and clear to mankind, and not to hide it; but they threw it away behind their backs, and purchased with it some miserable gain! And vile was the bargain they made!\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Think not that those who exult in what they have brought about, and love to be praised for what they have not done,- think escape the penalty. For them is a penalty Grievous indeed.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
To Allah belongeth the dominion of the heavens and the earth; and Allah hath power over all things.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Behold! in the creation of the heavens and the earth, and the alternation of night and day,- there are indeed Signs for men of understanding,-\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Men who celebrate the praises of Allah, standing, sitting, and lying down on their sides, and contemplate the (wonders of) creation in the heavens and the earth, (With the thought): ``Our Lord! not for naught Hast Thou created (all) this! Glory to Thee! Give us salvation from the penalty of the Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
``Our Lord! any whom Thou dost admit to the Fire, Truly Thou coverest with shame, and never will wrong-doers Find any helpers!\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
``Our Lord! we have heard the call of one calling (Us) to Faith, 'Believe ye in the Lord,' and we have believed. Our Lord! Forgive us our sins, blot out from us our iniquities, and take to Thyself our souls in the company of the righteous.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
``Our Lord! Grant us what Thou didst promise unto us through Thine messengers, and save us from shame on the Day of Judgment: For Thou never breakest Thy promise."\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And their Lord hath accepted of them, and answered them: ``Never will I suffer to be lost the work of any of you, be he male or female: Ye are members, one of another: Those who have left their homes, or been driven out therefrom, or suffered harm in My Cause, or fought or been slain,- verily, I will blot out from them their iniquities, and admit them into Gardens with rivers flowing beneath;- A reward from the presence of Allah, and from His presence is the best of rewards."\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let not the strutting about of the Unbelievers through the land deceive thee:\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
Little is it for enjoyment: Their ultimate abode is Hell: what an evil bed (To lie on)!\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
On the other hand, for those who fear their Lord, are Gardens, with rivers flowing beneath; therein are they to dwell (for ever),- a gift from the presence of Allah; and that which is in the presence of Allah is the best (bliss) for the righteous.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And there are, certainly, among the People of the Book, those who believe in Allah, in the revelation to you, and in the revelation to them, bowing in humility to Allah: They will not sell the Signs of Allah for a miserable gain! For them is a reward with their Lord, and Allah is swift in account.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O ye who believe! Persevere in patience and constancy; vie in such perseverance; strengthen each other; and fear Allah; that ye may prosper.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind! reverence your Guardian-Lord, who created you from a single person, created, of like nature, His mate, and from them twain scattered (like seeds) countless men and women;- reverence Allah, through whom ye demand your mutual (rights), and (reverence) the wombs (That bore you): for Allah ever watches over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
To orphans restore their property (When they reach their age), nor substitute (your) worthless things for (their) good ones; and devour not their substance (by mixing it up) with your own. For this is indeed a great sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
If ye fear that ye shall not be able to deal justly with the orphans, Marry women of your choice, Two or three or four; but if ye fear that ye shall not be able to deal justly (with them), then only one, or (a captive) that your right hands possess, that will be more suitable, to prevent you from doing injustice.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give the women (on marriage) their dower as a free gift; but if they, of their own good pleasure, remit any part of it to you, Take it and enjoy it with right good cheer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
To those weak of understanding Make not over your property, which Allah hath made a means of support for you, but feed and clothe them therewith, and speak to them words of kindness and justice.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
Make trial of orphans until they reach the age of marriage; if then ye find sound judgment in them, release their property to them; but consume it not wastefully, nor in haste against their growing up. If the guardian is well-off, Let him claim no remuneration, but if he is poor, let him have for himself what is just and reasonable. When ye release their property to them, take witnesses in their presence: But all-sufficient is Allah in taking account.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
From what is left by parents and those nearest related there is a share for men and a share for women, whether the property be small or large,-a determinate share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
But if at the time of division other relatives, or orphans or poor, are present, feed them out of the (property), and speak to them words of kindness and justice.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
Let those (disposing of an estate) have the same fear in their minds as they would have for their own if they had left a helpless family behind: Let them fear Allah, and speak words of appropriate (comfort).\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Those who unjustly eat up the property of orphans, eat up a Fire into their own bodies: They will soon be enduring a Blazing Fire!\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah (thus) directs you as regards your Children's (Inheritance): to the male, a portion equal to that of two females: if only daughters, two or more, their share is two-thirds of the inheritance; if only one, her share is a half. For parents, a sixth share of the inheritance to each, if the deceased left children; if no children, and the parents are the (only) heirs, the mother has a third; if the deceased Left brothers (or sisters) the mother has a sixth. (The distribution in all cases ('s) after the payment of legacies and debts. Ye know not whether your parents or your children are nearest to you in benefit. These are settled portions ordained by Allah; and Allah is All-knowing, Al-wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
In what your wives leave, your share is a half, if they leave no child; but if they leave a child, ye get a fourth; after payment of legacies and debts. In what ye leave, their share is a fourth, if ye leave no child; but if ye leave a child, they get an eighth; after payment of legacies and debts. If the man or woman whose inheritance is in question, has left neither ascendants nor descendants, but has left a brother or a sister, each one of the two gets a sixth; but if more than two, they share in a third; after payment of legacies and debts; so that no loss is caused (to any one). Thus is it ordained by Allah; and Allah is All-knowing, Most Forbearing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
Those are limits set by Allah: those who obey Allah and His Messenger will be admitted to Gardens with rivers flowing beneath, to abide therein (for ever) and that will be the supreme achievement.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
But those who disobey Allah and His Messenger and transgress His limits will be admitted to a Fire, to abide therein: And they shall have a humiliating punishment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
If any of your women are guilty of lewdness, Take the evidence of four (Reliable) witnesses from amongst you against them; and if they testify, confine them to houses until death do claim them, or Allah ordain for them some (other) way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
If two men among you are guilty of lewdness, punish them both. If they repent and amend, Leave them alone; for Allah is Oft-returning, Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
Allah accept the repentance of those who do evil in ignorance and repent soon afterwards; to them will Allah turn in mercy: For Allah is full of knowledge and wisdom.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
Of no effect is the repentance of those who continue to do evil, until death faces one of them, and he says, ``Now have I repented indeed;" nor of those who die rejecting Faith: for them have We prepared a punishment most grievous.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O ye who believe! Ye are forbidden to inherit women against their will. Nor should ye treat them with harshness, that ye may Take away part of the dower ye have given them,-except where they have been guilty of open lewdness; on the contrary live with them on a footing of kindness and equity. If ye take a dislike to them it may be that ye dislike a thing, and Allah brings about through it a great deal of good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
But if ye decide to take one wife in place of another, even if ye had given the latter a whole treasure for dower, Take not the least bit of it back: Would ye take it by slander and manifest wrong?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how could ye take it when ye have gone in unto each other, and they have Taken from you a solemn covenant?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And marry not women whom your fathers married,- except what is past: It was shameful and odious,- an abominable custom indeed.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Prohibited to you (For marriage) are:- Your mothers, daughters, sisters; father's sisters, Mother's sisters; brother's daughters, sister's daughters; foster-mothers (Who gave you suck), foster-sisters; your wives' mothers; your step-daughters under your guardianship, born of your wives to whom ye have gone in,- no prohibition if ye have not gone in;- (Those who have been) wives of your sons proceeding from your loins; and two sisters in wedlock at one and the same time, except for what is past; for Allah is Oft-forgiving, Most Merciful;-\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
Also (prohibited are) women already married, except those whom your right hands possess: Thus hath Allah ordained (Prohibitions) against you: Except for these, all others are lawful, provided ye seek (them in marriage) with gifts from your property,- desiring chastity, not lust, seeing that ye derive benefit from them, give them their dowers (at least) as prescribed; but if, after a dower is prescribed, agree Mutually (to vary it), there is no blame on you, and Allah is All-knowing, All-wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
If any of you have not the means wherewith to wed free believing women, they may wed believing girls from among those whom your right hands possess: And Allah hath full knowledge about your faith. Ye are one from another: Wed them with the leave of their owners, and give them their dowers, according to what is reasonable: They should be chaste, not lustful, nor taking paramours: when they are taken in wedlock, if they fall into shame, their punishment is half that for free women. This (permission) is for those among you who fear sin; but it is better for you that ye practise self-restraint. And Allah is Oft-forgiving, Most Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah doth wish to make clear to you and to show you the ordinances of those before you; and (He doth wish to) turn to you (In Mercy): And Allah is All-knowing, All-wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
Allah doth wish to Turn to you, but the wish of those who follow their lusts is that ye should turn away (from Him),- far, far away.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah doth wish to lighten your (difficulties): For man was created Weak (in flesh).\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O ye who believe! Eat not up your property among yourselves in vanities: But let there be amongst you Traffic and trade by mutual good-will: Nor kill (or destroy) yourselves: for verily Allah hath been to you Most Merciful!\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
If any do that in rancour and injustice,- soon shall We cast them into the Fire: And easy it is for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If ye (but) eschew the most heinous of the things which ye are forbidden to do, We shall expel out of you all the evil in you, and admit you to a gate of great honour.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And in no wise covet those things in which Allah Hath bestowed His gifts More freely on some of you than on others: To men is allotted what they earn, and to women what they earn: But ask Allah of His bounty. For Allah hath full knowledge of all things.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
To (benefit) every one, We have appointed shares and heirs to property left by parents and relatives. To those, also, to whom your right hand was pledged, give their due portion. For truly Allah is witness to all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the protectors and maintainers of women, because Allah has given the one more (strength) than the other, and because they support them from their means. Therefore the righteous women are devoutly obedient, and guard in (the husband's) absence what Allah would have them guard. As to those women on whose part ye fear disloyalty and ill-conduct, admonish them (first), (Next), refuse to share their beds, (And last) beat them (lightly); but if they return to obedience, seek not against them Means (of annoyance): For Allah is Most High, great (above you all).\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If ye fear a breach between them twain, appoint (two) arbiters, one from his family, and the other from hers; if they wish for peace, Allah will cause their reconciliation: For Allah hath full knowledge, and is acquainted with all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Serve Allah, and join not any partners with Him; and do good- to parents, kinsfolk, orphans, those in need, neighbours who are near, neighbours who are strangers, the companion by your side, the wayfarer (ye meet), and what your right hands possess: For Allah loveth not the arrogant, the vainglorious;-\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
(Nor) those who are niggardly or enjoin niggardliness on others, or hide the bounties which Allah hath bestowed on them; for We have prepared, for those who resist Faith, a punishment that steeps them in contempt;-\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
Not those who spend of their substance, to be seen of men, but have no faith in Allah and the Last Day: If any take the Evil One for their intimate, what a dreadful intimate he is!\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what burden Were it on them if they had faith in Allah and in the Last Day, and they spent out of what Allah hath given them for sustenance? For Allah hath full knowledge of them.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Allah is never unjust in the least degree: If there is any good (done), He doubleth it, and giveth from His own presence a great reward.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How then if We brought from each people a witness, and We brought thee as a witness against these people!\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that day those who reject Faith and disobey the messenger will wish that the earth Were made one with them: But never will they hide a single fact from Allah!\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O ye who believe! Approach not prayers with a mind befogged, until ye can understand all that ye say,- nor in a state of ceremonial impurity (Except when travelling on the road), until after washing your whole body. If ye are ill, or on a journey, or one of you cometh from offices of nature, or ye have been in contact with women, and ye find no water, then take for yourselves clean sand or earth, and rub therewith your faces and hands. For Allah doth blot out sins and forgive again and again.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Hast thou not turned Thy vision to those who were given a portion of the Book? they traffic in error, and wish that ye should lose the right path.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
But Allah hath full knowledge of your enemies: Allah is enough for a protector, and Allah is enough for a Helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Of the Jews there are those who displace words from their (right) places, and say: ``We hear and we disobey"; and ``Hear what is not Heard"; and ``Ra'ina"; with a twist of their tongues and a slander to Faith. If only they had said: ``What hear and we obey"; and ``Do hear"; and ``Do look at us"; it would have been better for them, and more proper; but Allah hath cursed them for their Unbelief; and but few of them will believe.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O ye People of the Book! believe in what We have (now) revealed, confirming what was (already) with you, before We change the face and fame of some (of you) beyond all recognition, and turn them hindwards, or curse them as We cursed the Sabbath-breakers, for the decision of Allah Must be carried out.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Allah forgiveth not that partners should be set up with Him; but He forgiveth anything else, to whom He pleaseth; to set up partners with Allah is to devise a sin Most heinous indeed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Hast thou not turned Thy vision to those who claim sanctity for themselves? Nay-but Allah Doth sanctify whom He pleaseth. But never will they fail to receive justice in the least little thing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Behold! how they invent a lie against Allah! but that by itself is a manifest sin!\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Hast thou not turned Thy vision to those who were given a portion of the Book? they believe in sorcery and Evil, and say to the Unbelievers that they are better guided in the (right) way Than the believers!\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
They are (men) whom Allah hath cursed: And those whom Allah Hath cursed, thou wilt find, have no one to help.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Have they a share in dominion or power? Behold, they give not a farthing to their fellow-men?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy mankind for what Allah hath given them of his bounty? but We had already given the people of Abraham the Book and Wisdom, and conferred upon them a great kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
Some of them believed, and some of them averted their faces from him: And enough is Hell for a burning fire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Those who reject our Signs, We shall soon cast into the Fire: as often as their skins are roasted through, We shall change them for fresh skins, that they may taste the penalty: for Allah is Exalted in Power, Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
But those who believe and do deeds of righteousness, We shall soon admit to Gardens, with rivers flowing beneath,- their eternal home: Therein shall they have companions pure and holy: We shall admit them to shades, cool and ever deepening.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Allah doth command you to render back your Trusts to those to whom they are due; And when ye judge between man and man, that ye judge with justice: Verily how excellent is the teaching which He giveth you! For Allah is He Who heareth and seeth all things.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O ye who believe! Obey Allah, and obey the Messenger, and those charged with authority among you. If ye differ in anything among yourselves, refer it to Allah and His Messenger, if ye do believe in Allah and the Last Day: That is best, and most suitable for final determination.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Hast thou not turned Thy vision to those who declare that they believe in the revelations that have come to thee and to those before thee? Their (real) wish is to resort together for judgment (in their disputes) to the Evil One, though they were ordered to reject him. But Satan's wish is to lead them astray far away (from the right).\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
When it is said to them: ``Come to what Allah hath revealed, and to the Messenger": Thou seest the Hypocrites avert their faces from thee in disgust.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How then, when they are seized by misfortune, because of the deeds which they hands have sent forth? Then their come to thee, swearing by Allah: ``We meant no more than good-will and conciliation!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
Those men,-Allah knows what is in their hearts; so keep clear of them, but admonish them, and speak to them a word to reach their very souls.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We sent not a messenger, but to be obeyed, in accordance with the will of Allah. If they had only, when they were unjust to themselves, come unto thee and asked Allah's forgiveness, and the Messenger had asked forgiveness for them, they would have found Allah indeed Oft-returning, Most Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by the Lord, they can have no (real) Faith, until they make thee judge in all disputes between them, and find in their souls no resistance against Thy decisions, but accept them with the fullest conviction.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
If We had ordered them to sacrifice their lives or to leave their homes, very few of them would have done it: But if they had done what they were (actually) told, it would have been best for them, and would have gone farthest to strengthen their (faith);\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And We should then have given them from our presence a great reward;\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And We should have shown them the Straight Way.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
All who obey Allah and the messenger are in the company of those on whom is the Grace of Allah,- of the prophets (who teach), the sincere (lovers of Truth), the witnesses (who testify), and the Righteous (who do good): Ah! what a beautiful fellowship!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
Such is the bounty from Allah: And sufficient is it that Allah knoweth all.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O ye who believe! Take your precautions, and either go forth in parties or go forth all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
There are certainly among you men who would tarry behind: If a misfortune befalls you, they say: ``Allah did favour us in that we were not present among them."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But if good fortune comes to you from Allah, they would be sure to say - as if there had never been Ties of affection between you and them - ``Oh! I wish I had been with them; a fine thing should I then have made of it!"\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let those fight in the cause of Allah Who sell the life of this world for the hereafter. To him who fighteth in the cause of Allah,- whether he is slain or gets victory - Soon shall We give him a reward of great (value).\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And why should ye not fight in the cause of Allah and of those who, being weak, are ill-treated (and oppressed)?- Men, women, and children, whose cry is: ``Our Lord! Rescue us from this town, whose people are oppressors; and raise for us from Thee one who will protect; and raise for us from Thee one who will help!"\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe fight in the cause of Allah, and those who reject Faith Fight in the cause of Evil: So fight ye against the friends of Satan: feeble indeed is the cunning of Satan.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Hast thou not turned Thy vision to those who were told to hold back their hands (from fight) but establish regular prayers and spend in regular charity? When (at length) the order for fighting was issued to them, behold! a section of them feared men as - or even more than - they should have feared Allah: They said: ``Our Lord! Why hast Thou ordered us to fight? Wouldst Thou not Grant us respite to our (natural) term, near (enough)?" Say: ``Short is the enjoyment of this world: the Hereafter is the best for those who do right: Never will ye be dealt with unjustly in the very least!\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
``Wherever ye are, death will find you out, even if ye are in towers built up strong and high!" If some good befalls them, they say, ``This is from Allah"; but if evil, they say, ``This is from thee" (O Prophet). Say: ``All things are from Allah." But what hath come to these people, that they fail to understand a single fact?\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good, (O man!) happens to thee, is from Allah; but whatever evil happens to thee, is from thy (own) soul. and We have sent thee as a messenger to (instruct) mankind. And enough is Allah for a witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
He who obeys the Messenger, obeys Allah: But if any turn away, We have not sent thee to watch over their (evil deeds).\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They have ``Obedience" on their lips; but when they leave thee, a section of them Meditate all night on things very different from what thou tellest them. But Allah records their nightly (plots): So keep clear of them, and put thy trust in Allah, and enough is Allah as a disposer of affairs.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Do they not consider the Qur'an (with care)? Had it been from other Than Allah, they would surely have found therein Much discrepancy.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When there comes to them some matter touching (Public) safety or fear, they divulge it. If they had only referred it to the Messenger, or to those charged with authority among them, the proper investigators would have Tested it from them (direct). Were it not for the Grace and Mercy of Allah unto you, all but a few of you would have fallen into the clutches of Satan.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Then fight in Allah's cause - Thou art held responsible only for thyself - and rouse the believers. It may be that Allah will restrain the fury of the Unbelievers; for Allah is the strongest in might and in punishment.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoever recommends and helps a good cause becomes a partner therein: And whoever recommends and helps an evil cause, shares in its burden: And Allah hath power over all things.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When a (courteous) greeting is offered you, meet it with a greeting still more courteous, or (at least) of equal courtesy. Allah takes careful account of all things.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! There is no god but He: of a surety He will gather you together against the Day of Judgment, about which there is no doubt. And whose word can be truer than Allah's?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
Why should ye be divided into two parties about the Hypocrites? Allah hath upset them for their (evil) deeds. Would ye guide those whom Allah hath thrown out of the Way? For those whom Allah hath thrown out of the Way, never shalt thou find the Way.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They but wish that ye should reject Faith, as they do, and thus be on the same footing (as they): But take not friends from their ranks until they flee in the way of Allah (From what is forbidden). But if they turn renegades, seize them and slay them wherever ye find them; and (in any case) take no friends or helpers from their ranks;-\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who join a group between whom and you there is a treaty (of peace), or those who approach you with hearts restraining them from fighting you as well as fighting their own people. If Allah had pleased, He could have given them power over you, and they would have fought you: Therefore if they withdraw from you but fight you not, and (instead) send you (Guarantees of) peace, then Allah Hath opened no way for you (to war against them).\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
Others you will find that wish to gain your confidence as well as that of their people: Every time they are sent back to temptation, they succumb thereto: if they withdraw not from you nor give you (guarantees) of peace besides restraining their hands, seize them and slay them wherever ye get them: In their case We have provided you with a clear argument against them.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
Never should a believer kill a believer; but (If it so happens) by mistake, (Compensation is due): If one (so) kills a believer, it is ordained that he should free a believing slave, and pay compensation to the deceased's family, unless they remit it freely. If the deceased belonged to a people at war with you, and he was a believer, the freeing of a believing slave (Is enough). If he belonged to a people with whom ye have treaty of Mutual alliance, compensation should be paid to his family, and a believing slave be freed. For those who find this beyond their means, (is prescribed) a fast for two months running: by way of repentance to Allah: for Allah hath all knowledge and all wisdom.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
If a man kills a believer intentionally, his recompense is Hell, to abide therein (For ever): And the wrath and the curse of Allah are upon him, and a dreadful penalty is prepared for him.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O ye who believe! When ye go abroad in the cause of Allah, investigate carefully, and say not to any one who offers you a salutation: ``Thou art none of a believer!" Coveting the perishable goods of this life: with Allah are profits and spoils abundant. Even thus were ye yourselves before, till Allah conferred on you His favours: Therefore carefully investigate. For Allah is well aware of all that ye do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are those believers who sit (at home) and receive no hurt, and those who strive and fight in the cause of Allah with their goods and their persons. Allah hath granted a grade higher to those who strive and fight with their goods and persons than to those who sit (at home). Unto all (in Faith) Hath Allah promised good: But those who strive and fight Hath He distinguished above those who sit (at home) by a special reward,-\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Ranks specially bestowed by Him, and Forgiveness and Mercy. For Allah is Oft-forgiving, Most Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
When angels take the souls of those who die in sin against their souls, they say: ``In what (plight) Were ye?" They reply: ``Weak and oppressed Were we in the earth." They say: ``Was not the earth of Allah spacious enough for you to move yourselves away (From evil)?" Such men will find their abode in Hell,- What an evil refuge! -\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except those who are (really) weak and oppressed - men, women, and children - who have no means in their power, nor (a guide-post) to their way.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
For these, there is hope that Allah will forgive: For Allah doth blot out (sins) and forgive again and again.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
He who forsakes his home in the cause of Allah, finds in the earth Many a refuge, wide and spacious: Should he die as a refugee from home for Allah and His Messenger, His reward becomes due and sure with Allah: And Allah is Oft-forgiving, Most Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
When ye travel through the earth, there is no blame on you if ye shorten your prayers, for fear the Unbelievers May attack you: For the Unbelievers are unto you open enemies.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
When thou (O Messenger) art with them, and standest to lead them in prayer, Let one party of them stand up (in prayer) with thee, Taking their arms with them: When they finish their prostrations, let them Take their position in the rear. And let the other party come up which hath not yet prayed - and let them pray with thee, Taking all precaution, and bearing arms: the Unbelievers wish, if ye were negligent of your arms and your baggage, to assault you in a single rush. But there is no blame on you if ye put away your arms because of the inconvenience of rain or because ye are ill; but take (every) precaution for yourselves. For the Unbelievers Allah hath prepared a humiliating punishment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When ye pass (Congregational) prayers, celebrate Allah's praises, standing, sitting down, or lying down on your sides; but when ye are free from danger, set up Regular Prayers: For such prayers are enjoined on believers at stated times.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And slacken not in following up the enemy: If ye are suffering hardships, they are suffering similar hardships; but ye have Hope from Allah, while they have none. And Allah is full of knowledge and wisdom.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
We have sent down to thee the Book in truth, that thou mightest judge between men, as guided by Allah: so be not (used) as an advocate by those who betray their trust;\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
But seek the forgiveness of Allah; for Allah is Oft-forgiving, Most Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
Contend not on behalf of such as betray their own souls; for Allah loveth not one given to perfidy and crime:\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They may hide (Their crimes) from men, but they cannot hide (Them) from Allah, seeing that He is in their midst when they plot by night, in words that He cannot approve: And Allah Doth compass round all that they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Ah! These are the sort of men on whose behalf ye may contend in this world; but who will contend with Allah on their behalf on the Day of Judgment, or who will carry their affairs through?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
If any one does evil or wrongs his own soul but afterwards seeks Allah's forgiveness, he will find Allah Oft-forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And if any one earns sin. he earns it against His own soul: for Allah is full of knowledge and wisdom.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
But if any one earns a fault or a sin and throws it on to one that is innocent, He carries (on himself) (Both) a falsehood and a flagrant sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
But for the Grace of Allah to thee and his Mercy, a party of them would certainly have plotted to lead thee astray. But (in fact) they will only Lead their own souls astray, and to thee they can do no harm in the least. For Allah hath sent down to thee the Book and wisdom and taught thee what thou Knewest not (before): And great is the Grace of Allah unto thee.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
In most of their secret talks there is no good: But if one exhorts to a deed of charity or justice or conciliation between men, (Secrecy is permissible): To him who does this, seeking the good pleasure of Allah, We shall soon give a reward of the highest (value).\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
If anyone contends with the Messenger even after guidance has been plainly conveyed to him, and follows a path other than that becoming to men of Faith, We shall leave him in the path he has chosen, and land him in Hell,- what an evil refuge!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Allah forgiveth not (The sin of) joining other gods with Him; but He forgiveth whom He pleaseth other sins than this: one who joins other gods with Allah, Hath strayed far, far away (from the right).\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
(The Pagans), leaving Him, call but upon female deities: They call but upon satan the persistent rebel!\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Allah did curse him, but he said: ``I will take of Thy servants a portion Marked off;\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
``I will mislead them, and I will create in them false desires; I will order them to slit the ears of cattle, and to deface the (fair) nature created by Allah." Whoever, forsaking Allah, takes satan for a friend, hath of a surety suffered a loss that is manifest.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
Satan makes them promises, and creates in them false desires; but satan's promises are nothing but deception.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
They (his dupes) will have their dwelling in Hell, and from it they will find no way of escape.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But those who believe and do deeds of righteousness,- we shall soon admit them to gardens, with rivers flowing beneath,-to dwell therein for ever. Allah's promise is the truth, and whose word can be truer than Allah's?\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
Not your desires, nor those of the People of the Book (can prevail): whoever works evil, will be requited accordingly. Nor will he find, besides Allah, any protector or helper.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
If any do deeds of righteousness,- be they male or female - and have faith, they will enter Heaven, and not the least injustice will be done to them.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
Who can be better in religion than one who submits his whole self to Allah, does good, and follows the way of Abraham the true in Faith? For Allah did take Abraham for a friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
But to Allah belong all things in the heavens and on earth: And He it is that Encompasseth all things.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They ask thy instruction concerning the women say: Allah doth instruct you about them: And (remember) what hath been rehearsed unto you in the Book, concerning the orphans of women to whom ye give not the portions prescribed, and yet whom ye desire to marry, as also concerning the children who are weak and oppressed: that ye stand firm for justice to orphans. There is not a good deed which ye do, but Allah is well-acquainted therewith.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a wife fears cruelty or desertion on her husband's part, there is no blame on them if they arrange an amicable settlement between themselves; and such settlement is best; even though men's souls are swayed by greed. But if ye do good and practise self-restraint, Allah is well-acquainted with all that ye do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
Ye are never able to be fair and just as between women, even if it is your ardent desire: But turn not away (from a woman) altogether, so as to leave her (as it were) hanging (in the air). If ye come to a friendly understanding, and practise self-restraint, Allah is Oft-forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they disagree (and must part), Allah will provide abundance for all from His all-reaching bounty: for Allah is He that careth for all and is Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
To Allah belong all things in the heavens and on earth. Verily we have directed the People of the Book before you, and you (o Muslims) to fear Allah. But if ye deny Him, lo! unto Allah belong all things in the heavens and on earth, and Allah is free of all wants, worthy of all praise.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
Yea, unto Allah belong all things in the heavens and on earth, and enough is Allah to carry through all affairs.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If it were His will, He could destroy you, o mankind, and create another race; for He hath power this to do.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
If any one desires a reward in this life, in Allah's (gift) is the reward (both) of this life and of the hereafter: for Allah is He that heareth and seeth (all things).\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O ye who believe! stand out firmly for justice, as witnesses to Allah, even as against yourselves, or your parents, or your kin, and whether it be (against) rich or poor: for Allah can best protect both. Follow not the lusts (of your hearts), lest ye swerve, and if ye distort (justice) or decline to do justice, verily Allah is well-acquainted with all that ye do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O ye who believe! Believe in Allah and His Messenger, and the scripture which He hath sent to His Messenger and the scripture which He sent to those before (him). Any who denieth Allah, His angels, His Books, His Messengers, and the Day of Judgment, hath gone far, far astray.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Those who believe, then reject faith, then believe (again) and (again) reject faith, and go on increasing in unbelief,- Allah will not forgive them nor guide them nor guide them on the way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
To the Hypocrites give the glad tidings that there is for them (but) a grievous penalty;-\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Yea, to those who take for friends unbelievers rather than believers: is it honour they seek among them? Nay,- all honour is with Allah.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
Already has He sent you Word in the Book, that when ye hear the signs of Allah held in defiance and ridicule, ye are not to sit with them unless they turn to a different theme: if ye did, ye would be like them. For Allah will collect the hypocrites and those who defy faith - all in Hell:-\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
(These are) the ones who wait and watch about you: if ye do gain a victory from Allah, they say: ``Were we not with you?"- but if the unbelievers gain a success, they say (to them): ``Did we not gain an advantage over you, and did we not guard you from the believers?" but Allah will judge betwixt you on the Day of Judgment. And never will Allah grant to the unbelievers a way (to triumphs) over the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
The Hypocrites - they think they are over-reaching Allah, but He will over-reach them: When they stand up to prayer, they stand without earnestness, to be seen of men, but little do they hold Allah in remembrance;\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
(They are) distracted in mind even in the midst of it,- being (sincerely) for neither one group nor for another whom Allah leaves straying,- never wilt thou find for him the way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O ye who believe! Take not for friends unbelievers rather than believers: Do ye wish to offer Allah an open proof against yourselves?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
The Hypocrites will be in the lowest depths of the Fire: no helper wilt thou find for them;-\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except for those who repent, mend (their lives) hold fast to Allah, and purify their religion as in Allah's sight: if so they will be (numbered) with the believers. And soon will Allah grant to the believers a reward of immense value.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What can Allah gain by your punishment, if ye are grateful and ye believe? Nay, it is Allah that recogniseth (all good), and knoweth all things.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah loveth not that evil should be noised abroad in public speech, except where injustice hath been done; for Allah is He who heareth and knoweth all things.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
Whether ye publish a good deed or conceal it or cover evil with pardon, verily Allah doth blot out (sins) and hath power (in the judgment of values).\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Those who deny Allah and His messengers, and (those who) wish to separate Allah from His messengers, saying: ``We believe in some but reject others": And (those who) wish to take a course midway,-\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
They are in truth (equally) unbelievers; and we have prepared for unbelievers a humiliating punishment.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
To those who believe in Allah and His messengers and make no distinction between any of the messengers, we shall soon give their (due) rewards: for Allah is Oft-forgiving, Most Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The people of the Book ask thee to cause a book to descend to them from heaven: Indeed they asked Moses for an even greater (miracle), for they said: ``Show us Allah in public," but they were dazed for their presumption, with thunder and lightning. Yet they worshipped the calf even after clear signs had come to them; even so we forgave them; and gave Moses manifest proofs of authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And for their covenant we raised over them (the towering height) of Mount (Sinai); and (on another occasion) we said: ``Enter the gate with humility"; and (once again) we commanded them: ``Transgress not in the matter of the sabbath." And we took from them a solemn covenant.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
(They have incurred divine displeasure): In that they broke their covenant; that they rejected the signs of Allah; that they slew the Messengers in defiance of right; that they said, ``Our hearts are the wrappings (which preserve Allah's Word; We need no more)";- Nay, Allah hath set the seal on their hearts for their blasphemy, and little is it they believe;-\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
That they rejected Faith; that they uttered against Mary a grave false charge;\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
That they said (in boast), ``We killed Christ Jesus the son of Mary, the Messenger of Allah";- but they killed him not, nor crucified him, but so it was made to appear to them, and those who differ therein are full of doubts, with no (certain) knowledge, but only conjecture to follow, for of a surety they killed him not:-\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
Nay, Allah raised him up unto Himself; and Allah is Exalted in Power, Wise;-\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
And there is none of the People of the Book but must believe in him before his death; and on the Day of Judgment he will be a witness against them;-\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
For the iniquity of the Jews We made unlawful for them certain (foods) good and wholesome which had been lawful for them;- in that they hindered many from Allah's Way;-\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
That they took usury, though they were forbidden; and that they devoured men's substance wrongfully;- we have prepared for those among them who reject faith a grievous punishment.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those among them who are well-grounded in knowledge, and the believers, believe in what hath been revealed to thee and what was revealed before thee: And (especially) those who establish regular prayer and practise regular charity and believe in Allah and in the Last Day: To them shall We soon give a great reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
We have sent thee inspiration, as We sent it to Noah and the Messengers after him: we sent inspiration to Abraham, Isma'il, Isaac, Jacob and the Tribes, to Jesus, Job, Jonah, Aaron, and solomon, and to David We gave the Psalms.\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
Of some messengers We have already told thee the story; of others We have not;- and to Moses Allah spoke direct;-\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers who gave good news as well as warning, that mankind, after (the coming) of the messengers, should have no plea against Allah: For Allah is Exalted in Power, Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah beareth witness that what He hath sent unto thee He hath sent from His (own) knowledge, and the angels bear witness: But enough is Allah for a witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Those who reject Faith and keep off (men) from the way of Allah, have verily strayed far, far away from the Path.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Those who reject Faith and do wrong,- Allah will not forgive them nor guide them to any way-\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the way of Hell, to dwell therein for ever. And this to Allah is easy.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O Mankind! The Messenger hath come to you in truth from Allah: believe in him: It is best for you. But if ye reject Faith, to Allah belong all things in the heavens and on earth: And Allah is All-knowing, All-wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People of the Book! Commit no excesses in your religion: Nor say of Allah aught but the truth. Christ Jesus the son of Mary was (no more than) a messenger of Allah, and His Word, which He bestowed on Mary, and a spirit proceeding from Him: so believe in Allah and His messengers. Say not ``Trinity": desist: it will be better for you: for Allah is one Allah: Glory be to Him: (far exalted is He) above having a son. To Him belong all things in the heavens and on earth. And enough is Allah as a Disposer of affairs.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
Christ disdaineth nor to serve and worship Allah, nor do the angels, those nearest (to Allah): those who disdain His worship and are arrogant,-He will gather them all together unto Himself to (answer).\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
But to those who believe and do deeds of righteousness, He will give their (due) rewards,- and more, out of His bounty: But those who are disdainful and arrogant, He will punish with a grievous penalty; Nor will they find, besides Allah, any to protect or help them.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind! verily there hath come to you a convincing proof from your Lord: For We have sent unto you a light (that is) manifest.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
Then those who believe in Allah, and hold fast to Him,- soon will He admit them to mercy and grace from Himself, and guide them to Himself by a straight way.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask thee for a legal decision. Say: Allah directs (thus) about those who leave no descendants or ascendants as heirs. If it is a man that dies, leaving a sister but no child, she shall have half the inheritance: If (such a deceased was) a woman, who left no child, Her brother takes her inheritance: If there are two sisters, they shall have two-thirds of the inheritance (between them): if there are brothers and sisters, (they share), the male having twice the share of the female. Thus doth Allah make clear to you (His law), lest ye err. And Allah hath knowledge of all things.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O ye who believe! fulfil (all) obligations. Lawful unto you (for food) are all four-footed animals, with the exceptions named: But animals of the chase are forbidden while ye are in the sacred precincts or in pilgrim garb: for Allah doth command according to His will and plan.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O ye who believe! Violate not the sanctity of the symbols of Allah, nor of the sacred month, nor of the animals brought for sacrifice, nor the garlands that mark out such animals, nor the people resorting to the sacred house, seeking of the bounty and good pleasure of their Lord. But when ye are clear of the sacred precincts and of pilgrim garb, ye may hunt and let not the hatred of some people in (once) shutting you out of the Sacred Mosque lead you to transgression (and hostility on your part). Help ye one another in righteousness and piety, but help ye not one another in sin and rancour: fear Allah: for Allah is strict in punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden to you (for food) are: dead meat, blood, the flesh of swine, and that on which hath been invoked the name of other than Allah; that which hath been killed by strangling, or by a violent blow, or by a headlong fall, or by being gored to death; that which hath been (partly) eaten by a wild animal; unless ye are able to slaughter it (in due form); that which is sacrificed on stone (altars); (forbidden) also is the division (of meat) by raffling with arrows: that is impiety. This day have those who reject faith given up all hope of your religion: yet fear them not but fear Me. This day have I perfected your religion for you, completed My favour upon you, and have chosen for you Islam as your religion. But if any is forced by hunger, with no inclination to transgression, Allah is indeed Oft-forgiving, Most Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask thee what is lawful to them (as food). Say: lawful unto you are (all) things good and pure: and what ye have taught your trained hunting animals (to catch) in the manner directed to you by Allah: eat what they catch for you, but pronounce the name of Allah over it: and fear Allah; for Allah is swift in taking account.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
This day are (all) things good and pure made lawful unto you. The food of the People of the Book is lawful unto you and yours is lawful unto them. (Lawful unto you in marriage) are (not only) chaste women who are believers, but chaste women among the People of the Book, revealed before your time,- when ye give them their due dowers, and desire chastity, not lewdness, nor secret intrigues if any one rejects faith, fruitless is his work, and in the Hereafter he will be in the ranks of those who have lost (all spiritual good).\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O ye who believe! when ye prepare for prayer, wash your faces, and your hands (and arms) to the elbows; Rub your heads (with water); and (wash) your feet to the ankles. If ye are in a state of ceremonial impurity, bathe your whole body. But if ye are ill, or on a journey, or one of you cometh from offices of nature, or ye have been in contact with women, and ye find no water, then take for yourselves clean sand or earth, and rub therewith your faces and hands, Allah doth not wish to place you in a difficulty, but to make you clean, and to complete his favour to you, that ye may be grateful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And call in remembrance the favour of Allah unto you, and His covenant, which He ratified with you, when ye said: ``We hear and we obey": And fear Allah, for Allah knoweth well the secrets of your hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O ye who believe! stand out firmly for Allah, as witnesses to fair dealing, and let not the hatred of others to you make you swerve to wrong and depart from justice. Be just: that is next to piety: and fear Allah. For Allah is well-acquainted with all that ye do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
To those who believe and do deeds of righteousness hath Allah promised forgiveness and a great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
Those who reject faith and deny our signs will be companions of Hell-fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O ye who believe! Call in remembrance the favour of Allah unto you when certain men formed the design to stretch out their hands against you, but (Allah) held back their hands from you: so fear Allah. And on Allah let believers put (all) their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Allah did aforetime take a covenant from the Children of Israel, and we appointed twelve captains among them. And Allah said: ``I am with you: if ye (but) establish regular prayers, practise regular charity, believe in my messengers, honour and assist them, and loan to Allah a beautiful loan, verily I will wipe out from you your evils, and admit you to gardens with rivers flowing beneath; but if any of you, after this, resisteth faith, he hath truly wandered from the path or rectitude."\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
But because of their breach of their covenant, We cursed them, and made their hearts grow hard; they change the words from their (right) places and forget a good part of the message that was sent them, nor wilt thou cease to find them- barring a few - ever bent on (new) deceits: but forgive them, and overlook (their misdeeds): for Allah loveth those who are kind.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
From those, too, who call themselves Christians, We did take a covenant, but they forgot a good part of the message that was sent them: so we estranged them, with enmity and hatred between the one and the other, to the day of judgment. And soon will Allah show them what it is they have done.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O people of the Book! There hath come to you our Messenger, revealing to you much that ye used to hide in the Book, and passing over much (that is now unnecessary): There hath come to you from Allah a (new) light and a perspicuous Book, -\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
Wherewith Allah guideth all who seek His good pleasure to ways of peace and safety, and leadeth them out of darkness, by His will, unto the light,- guideth them to a path that is straight.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
In blasphemy indeed are those that say that Allah is Christ the son of Mary. Say: ``Who then hath the least power against Allah, if His will were to destroy Christ the son of Mary, his mother, and all every - one that is on the earth? For to Allah belongeth the dominion of the heavens and the earth, and all that is between. He createth what He pleaseth. For Allah hath power over all things."\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
(Both) the Jews and the Christians say: ``We are sons of Allah, and his beloved." Say: ``Why then doth He punish you for your sins? Nay, ye are but men,- of the men he hath created: He forgiveth whom He pleaseth, and He punisheth whom He pleaseth: and to Allah belongeth the dominion of the heavens and the earth, and all that is between: and unto Him is the final goal (of all)"\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People of the Book! Now hath come unto you, making (things) clear unto you, Our Messenger, after the break in (the series of) our messengers, lest ye should say: ``There came unto us no bringer of glad tidings and no warner (from evil)": But now hath come unto you a bringer of glad tidings and a warner (from evil). And Allah hath power over all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
Remember Moses said to his people: ``O my people! Call in remembrance the favour of Allah unto you, when He produced prophets among you, made you kings, and gave you what He had not given to any other among the peoples.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
``O my people! Enter the holy land which Allah hath assigned unto you, and turn not back ignominiously, for then will ye be overthrown, to your own ruin."\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said: ``O Moses! In this land are a people of exceeding strength: Never shall we enter it until they leave it: if (once) they leave, then shall we enter."\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
(But) among (their) Allah-fearing men were two on whom Allah had bestowed His grace: They said: ``Assault them at the (proper) Gate: when once ye are in, victory will be yours; But on Allah put your trust if ye have faith."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: ``O Moses! while they remain there, never shall we be able to enter, to the end of time. Go thou, and thy Lord, and fight ye two, while we sit here (and watch)."\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He said: ``O my Lord! I have power only over myself and my brother: so separate us from this rebellious people!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
Allah said: ``Therefore will the land be out of their reach for forty years: In distraction will they wander through the land: But sorrow thou not over these rebellious people.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
Recite to them the truth of the story of the two sons of Adam. Behold! they each presented a sacrifice (to Allah): It was accepted from one, but not from the other. Said the latter: ``Be sure I will slay thee." ``Surely," said the former, ``Allah doth accept of the sacrifice of those who are righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
``If thou dost stretch thy hand against me, to slay me, it is not for me to stretch my hand against thee to slay thee: for I do fear Allah, the cherisher of the worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
``For me, I intend to let thee draw on thyself my sin as well as thine, for thou wilt be among the companions of the fire, and that is the reward of those who do wrong."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
The (selfish) soul of the other led him to the murder of his brother: he murdered him, and became (himself) one of the lost ones.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a raven, who scratched the ground, to show him how to hide the shame of his brother. ``Woe is me!" said he; ``Was I not even able to be as this raven, and to hide the shame of my brother?" then he became full of regrets-\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
On that account: We ordained for the Children of Israel that if any one slew a person - unless it be for murder or for spreading mischief in the land - it would be as if he slew the whole people: and if any one saved a life, it would be as if he saved the life of the whole people. Then although there came to them Our messengers with clear signs, yet, even after that, many of them continued to commit excesses in the land.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The punishment of those who wage war against Allah and His Messenger, and strive with might and main for mischief through the land is: execution, or crucifixion, or the cutting off of hands and feet from opposite sides, or exile from the land: that is their disgrace in this world, and a heavy punishment is theirs in the Hereafter;\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except for those who repent before they fall into your power: in that case, know that Allah is Oft-forgiving, Most Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O ye who believe! Do your duty to Allah, seek the means of approach unto Him, and strive with might and main in his cause: that ye may prosper.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
As to those who reject Faith,- if they had everything on earth, and twice repeated, to give as ransom for the penalty of the Day of Judgment, it would never be accepted of them, theirs would be a grievous penalty.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
Their wish will be to get out of the Fire, but never will they get out therefrom: their penalty will be one that endures.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
As to the thief, Male or female, cut off his or her hands: a punishment by way of example, from Allah, for their crime: and Allah is Exalted in power.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But if the thief repents after his crime, and amends his conduct, Allah turneth to him in forgiveness; for Allah is Oft-forgiving, Most Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Knowest thou not that to Allah (alone) belongeth the dominion of the heavens and the earth? He punisheth whom He pleaseth, and He forgiveth whom He pleaseth: and Allah hath power over all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger! let not those grieve thee, who race each other into unbelief: (whether it be) among those who say ``We believe" with their lips but whose hearts have no faith; or it be among the Jews,- men who will listen to any lie,- will listen even to others who have never so much as come to thee. They change the words from their (right) times and places: they say, ``If ye are given this, take it, but if not, beware!" If any one's trial is intended by Allah, thou hast no authority in the least for him against Allah. For such - it is not Allah's will to purify their hearts. For them there is disgrace in this world, and in the Hereafter a heavy punishment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
(They are fond of) listening to falsehood, of devouring anything forbidden. If they do come to thee, either judge between them, or decline to interfere. If thou decline, they cannot hurt thee in the least. If thou judge, judge in equity between them. For Allah loveth those who judge in equity.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
But why do they come to thee for decision, when they have (their own) law before them?- therein is the (plain) command of Allah; yet even after that, they would turn away. For they are not (really) People of Faith.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
It was We who revealed the law (to Moses): therein was guidance and light. By its standard have been judged the Jews, by the prophets who bowed (as in Islam) to Allah's will, by the rabbis and the doctors of law: for to them was entrusted the protection of Allah's book, and they were witnesses thereto: therefore fear not men, but fear me, and sell not my signs for a miserable price. If any do fail to judge by (the light of) what Allah hath revealed, they are (no better than) Unbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
We ordained therein for them: ``Life for life, eye for eye, nose or nose, ear for ear, tooth for tooth, and wounds equal for equal." But if any one remits the retaliation by way of charity, it is an act of atonement for himself. And if any fail to judge by (the light of) what Allah hath revealed, they are (No better than) wrong-doers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And in their footsteps We sent Jesus the son of Mary, confirming the Law that had come before him: We sent him the Gospel: therein was guidance and light, and confirmation of the Law that had come before him: a guidance and an admonition to those who fear Allah.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Let the people of the Gospel judge by what Allah hath revealed therein. If any do fail to judge by (the light of) what Allah hath revealed, they are (no better than) those who rebel.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
To thee We sent the Scripture in truth, confirming the scripture that came before it, and guarding it in safety: so judge between them by what Allah hath revealed, and follow not their vain desires, diverging from the Truth that hath come to thee. To each among you have we prescribed a law and an open way. If Allah had so willed, He would have made you a single people, but (His plan is) to test you in what He hath given you: so strive as in a race in all virtues. The goal of you all is to Allah; it is He that will show you the truth of the matters in which ye dispute;\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And this (He commands): Judge thou between them by what Allah hath revealed, and follow not their vain desires, but beware of them lest they beguile thee from any of that (teaching) which Allah hath sent down to thee. And if they turn away, be assured that for some of their crime it is Allah's purpose to punish them. And truly most men are rebellious.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Do they then seek after a judgment of (the days of) ignorance? But who, for a people whose faith is assured, can give better judgment than Allah?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O ye who believe! take not the Jews and the Christians for your friends and protectors: They are but friends and protectors to each other. And he amongst you that turns to them (for friendship) is of them. Verily Allah guideth not a people unjust.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
Those in whose hearts is a disease - thou seest how eagerly they run about amongst them, saying: ``We do fear lest a change of fortune bring us disaster." Ah! perhaps Allah will give (thee) victory, or a decision according to His will. Then will they repent of the thoughts which they secretly harboured in their hearts.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And those who believe will say: ``Are these the men who swore their strongest oaths by Allah, that they were with you?" All that they do will be in vain, and they will fall into (nothing but) ruin.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O ye who believe! if any from among you turn back from his Faith, soon will Allah produce a people whom He will love as they will love Him,- lowly with the believers, mighty against the rejecters, fighting in the way of Allah, and never afraid of the reproaches of such as find fault. That is the grace of Allah, which He will bestow on whom He pleaseth. And Allah encompasseth all, and He knoweth all things.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your (real) friends are (no less than) Allah, His Messenger, and the (fellowship of) believers,- those who establish regular prayers and regular charity, and they bow down humbly (in worship).\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
As to those who turn (for friendship) to Allah, His Messenger, and the (fellowship of) believers,- it is the fellowship of Allah that must certainly triumph.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O ye who believe! take not for friends and protectors those who take your religion for a mockery or sport,- whether among those who received the Scripture before you, or among those who reject Faith; but fear ye Allah, if ye have faith (indeed).\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
When ye proclaim your call to prayer they take it (but) as mockery and sport; that is because they are a people without understanding.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: ``O people of the Book! Do ye disapprove of us for no other reason than that we believe in Allah, and the revelation that hath come to us and that which came before (us), and (perhaps) that most of you are rebellious and disobedient?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say: ``Shall I point out to you something much worse than this, (as judged) by the treatment it received from Allah? those who incurred the curse of Allah and His wrath, those of whom some He transformed into apes and swine, those who worshipped evil;- these are (many times) worse in rank, and far more astray from the even path!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come to thee, they say: ``We believe": but in fact they enter with a mind against Faith, and they go out with the same but Allah knoweth fully all that they hide.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
Many of them dost thou see, racing each other in sin and rancour, and their eating of things forbidden. Evil indeed are the things that they do.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do not the rabbis and the doctors of Law forbid them from their (habit of) uttering sinful words and eating things forbidden? Evil indeed are their works.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: ``Allah's hand is tied up." Be their hands tied up and be they accursed for the (blasphemy) they utter. Nay, both His hands are widely outstretched: He giveth and spendeth (of His bounty) as He pleaseth. But the revelation that cometh to thee from Allah increaseth in most of them their obstinate rebellion and blasphemy. Amongst them we have placed enmity and hatred till the Day of Judgment. Every time they kindle the fire of war, Allah doth extinguish it; but they (ever) strive to do mischief on earth. And Allah loveth not those who do mischief.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
If only the People of the Book had believed and been righteous, We should indeed have blotted out their iniquities and admitted them to gardens of bliss.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
If only they had stood fast by the Law, the Gospel, and all the revelation that was sent to them from their Lord, they would have enjoyed happiness from every side. There is from among them a party on the right course: but many of them follow a course that is evil.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger! proclaim the (message) which hath been sent to thee from thy Lord. If thou didst not, thou wouldst not have fulfilled and proclaimed His mission. And Allah will defend thee from men (who mean mischief). For Allah guideth not those who reject Faith.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say: ``O People of the Book! ye have no ground to stand upon unless ye stand fast by the Law, the Gospel, and all the revelation that has come to you from your Lord." It is the revelation that cometh to thee from thy Lord, that increaseth in most of them their obstinate rebellion and blasphemy. But sorrow thou not over (these) people without Faith.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Those who believe (in the Qur'an), those who follow the Jewish (scriptures), and the Sabians and the Christians,- any who believe in Allah and the Last Day, and work righteousness,- on them shall be no fear, nor shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We took the covenant of the Children of Israel and sent them messengers, every time, there came to them a messenger with what they themselves desired not - some (of these) they called impostors, and some they (go so far as to) slay.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
They thought there would be no trial (or punishment); so they became blind and deaf; yet Allah (in mercy) turned to them; yet again many of them became blind and deaf. But Allah sees well all that they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
They do blaspheme who say: ``Allah is Christ the son of Mary." But said Christ: ``O Children of Israel! worship Allah, my Lord and your Lord." Whoever joins other gods with Allah,- Allah will forbid him the garden, and the Fire will be his abode. There will for the wrong-doers be no one to help.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They do blaspheme who say: Allah is one of three in a Trinity: for there is no god except One Allah. If they desist not from their word (of blasphemy), verily a grievous penalty will befall the blasphemers among them.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Why turn they not to Allah, and seek His forgiveness? For Allah is Oft-forgiving, Most Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
Christ the son of Mary was no more than a messenger; many were the messengers that passed away before him. His mother was a woman of truth. They had both to eat their (daily) food. See how Allah doth make His signs clear to them; yet see in what ways they are deluded away from the truth!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: ``Will ye worship, besides Allah, something which hath no power either to harm or benefit you? But Allah,- He it is that heareth and knoweth all things."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: ``O people of the Book! exceed not in your religion the bounds (of what is proper), trespassing beyond the truth, nor follow the vain desires of people who went wrong in times gone by,- who misled many, and strayed (themselves) from the even way.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Curses were pronounced on those among the Children of Israel who rejected Faith, by the tongue of David and of Jesus the son of Mary: because they disobeyed and persisted in excesses.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
Nor did they (usually) forbid one another the iniquities which they committed: evil indeed were the deeds which they did.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
Thou seest many of them turning in friendship to the Unbelievers. Evil indeed are (the works) which their souls have sent forward before them (with the result), that Allah's wrath is on them, and in torment will they abide.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
If only they had believed in Allah, in the Prophet, and in what hath been revealed to him, never would they have taken them for friends and protectors, but most of them are rebellious wrong-doers.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Strongest among men in enmity to the believers wilt thou find the Jews and Pagans; and nearest among them in love to the believers wilt thou find those who say, ``We are Christians": because amongst these are men devoted to learning and men who have renounced the world, and they are not arrogant.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they listen to the revelation received by the Messenger, thou wilt see their eyes overflowing with tears, for they recognise the truth: they pray: ``Our Lord! we believe; write us down among the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
``What cause can we have not to believe in Allah and the truth which has come to us, seeing that we long for our Lord to admit us to the company of the righteous?"\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
And for this their prayer hath Allah rewarded them with gardens, with rivers flowing underneath,- their eternal home. Such is the recompense of those who do good.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who reject Faith and belie our Signs,- they shall be companions of Hell-fire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O ye who believe! make not unlawful the good things which Allah hath made lawful for you, but commit no excess: for Allah loveth not those given to excess.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
Eat of the things which Allah hath provided for you, lawful and good; but fear Allah, in Whom ye believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not call you to account for what is futile in your oaths, but He will call you to account for your deliberate oaths: for expiation, feed ten indigent persons, on a scale of the average for the food of your families; or clothe them; or give a slave his freedom. If that is beyond your means, fast for three days. That is the expiation for the oaths ye have sworn. But keep to your oaths. Thus doth Allah make clear to you His signs, that ye may be grateful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O ye who believe! Intoxicants and gambling, (dedication of) stones, and (divination by) arrows, are an abomination,- of Satan's handwork: eschew such (abomination), that ye may prosper.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan's plan is (but) to excite enmity and hatred between you, with intoxicants and gambling, and hinder you from the remembrance of Allah, and from prayer: will ye not then abstain?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey Allah, and obey the Messenger, and beware (of evil): if ye do turn back, know ye that it is Our Messenger's duty to proclaim (the message) in the clearest manner.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
On those who believe and do deeds of righteousness there is no blame for what they ate (in the past), when they guard themselves from evil, and believe, and do deeds of righteousness,- (or) again, guard themselves from evil and believe,- (or) again, guard themselves from evil and do good. For Allah loveth those who do good.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O ye who believe! Allah doth but make a trial of you in a little matter of game well within reach of game well within reach of your hands and your lances, that He may test who feareth him unseen: any who transgress thereafter, will have a grievous penalty.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O ye who believe! Kill not game while in the sacred precincts or in pilgrim garb. If any of you doth so intentionally, the compensation is an offering, brought to the Ka'ba, of a domestic animal equivalent to the one he killed, as adjudged by two just men among you; or by way of atonement, the feeding of the indigent; or its equivalent in fasts: that he may taste of the penalty of his deed. Allah forgives what is past: for repetition Allah will exact from him the penalty. For Allah is Exalted, and Lord of Retribution.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Lawful to you is the pursuit of water-game and its use for food,- for the benefit of yourselves and those who travel; but forbidden is the pursuit of land-game;- as long as ye are in the sacred precincts or in pilgrim garb. And fear Allah, to Whom ye shall be gathered back.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah made the Ka'ba, the Sacred House, an asylum of security for men, as also the Sacred Months, the animals for offerings, and the garlands that mark them: That ye may know that Allah hath knowledge of what is in the heavens and on earth and that Allah is well acquainted with all things.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know ye that Allah is strict in punishment and that Allah is Oft-forgiving, Most Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The Messenger's duty is but to proclaim (the message). But Allah knoweth all that ye reveal and ye conceal.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: ``Not equal are things that are bad and things that are good, even though the abundance of the bad may dazzle thee; so fear Allah, O ye that understand; that (so) ye may prosper."\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O ye who believe! Ask not questions about things which, if made plain to you, may cause you trouble. But if ye ask about things when the Qur'an is being revealed, they will be made plain to you, Allah will forgive those: for Allah is Oft-forgiving, Most Forbearing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
Some people before you did ask such questions, and on that account lost their faith.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
It was not Allah who instituted (superstitions like those of) a slit-ear she-camel, or a she-camel let loose for free pasture, or idol sacrifices for twin-births in animals, or stallion-camels freed from work: It is blasphemers who invent a lie against Allah; but most of them lack wisdom.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
When it is said to them: ``Come to what Allah hath revealed; come to the Messenger": They say: ``Enough for us are the ways we found our fathers following." what! even though their fathers were void of knowledge and guidance?\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O ye who believe! Guard your own souls: If ye follow (right) guidance, no hurt can come to you from those who stray. the goal of you all is to Allah: it is He that will show you the truth of all that ye do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O ye who believe! When death approaches any of you, (take) witnesses among yourselves when making bequests,- two just men of your own (brotherhood) or others from outside if ye are journeying through the earth, and the chance of death befalls you (thus). If ye doubt (their truth), detain them both after prayer, and let them both swear by Allah: ``We wish not in this for any worldly gain, even though the (beneficiary) be our near relation: we shall hide not the evidence before Allah: if we do, then behold! the sin be upon us!"\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
But if it gets known that these two were guilty of the sin (of perjury), let two others stand forth in their places,- nearest in kin from among those who claim a lawful right: let them swear by Allah: ``We affirm that our witness is truer than that of those two, and that we have not trespassed (beyond the truth): if we did, behold! the wrong be upon us!"\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That is most suitable: that they may give the evidence in its true nature and shape, or else they would fear that other oaths would be taken after their oaths. But fear Allah, and listen (to His counsel): for Allah guideth not a rebellious people:\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
One day will Allah gather the messengers together, and ask: ``What was the response ye received (from men to your teaching)?" They will say: ``We have no knowledge: it is Thou Who knowest in full all that is hidden."\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
Then will Allah say: ``O Jesus the son of Mary! Recount My favour to thee and to thy mother. Behold! I strengthened thee with the holy spirit, so that thou didst speak to the people in childhood and in maturity. Behold! I taught thee the Book and Wisdom, the Law and the Gospel and behold! thou makest out of clay, as it were, the figure of a bird, by My leave, and thou breathest into it and it becometh a bird by My leave, and thou healest those born blind, and the lepers, by My leave. And behold! thou bringest forth the dead by My leave. And behold! I did restrain the Children of Israel from (violence to) thee when thou didst show them the clear Signs, and the unbelievers among them said: 'This is nothing but evident magic.'\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
``And behold! I inspired the disciples to have faith in Me and Mine Messenger: they said, 'We have faith, and do thou bear witness that we bow to Allah as Muslims'".\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
Behold! the disciples, said: ``O Jesus the son of Mary! can thy Lord send down to us a table set (with viands) from heaven?" Said Jesus: ``Fear Allah, if ye have faith."\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said: ``We only wish to eat thereof and satisfy our hearts, and to know that thou hast indeed told us the truth; and that we ourselves may be witnesses to the miracle."\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Said Jesus the son of Mary: ``O Allah our Lord! Send us from heaven a table set (with viands), that there may be for us - for the first and the last of us - a solemn festival and a sign from thee; and provide for our sustenance, for thou art the best Sustainer (of our needs)."\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: ``I will send it down unto you: But if any of you after that resisteth faith, I will punish him with a penalty such as I have not inflicted on any one among all the peoples."\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And behold! Allah will say: ``O Jesus the son of Mary! Didst thou say unto men, worship me and my mother as gods in derogation of Allah'?" He will say: ``Glory to Thee! never could I say what I had no right (to say). Had I said such a thing, thou wouldst indeed have known it. Thou knowest what is in my heart, Thou I know not what is in Thine. For Thou knowest in full all that is hidden.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
``Never said I to them aught except what Thou didst command me to say, to wit, 'worship Allah, my Lord and your Lord'; and I was a witness over them whilst I dwelt amongst them; when Thou didst take me up Thou wast the Watcher over them, and Thou art a witness to all things.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
``If Thou dost punish them, they are Thy servant: If Thou dost forgive them, Thou art the Exalted in power, the Wise."\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say: ``This is a day on which the truthful will profit from their truth: theirs are gardens, with rivers flowing beneath,- their eternal Home: Allah well-pleased with them, and they with Allah: That is the great salvation, (the fulfilment of all desires).\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah doth belong the dominion of the heavens and the earth, and all that is therein, and it is He Who hath power over all things.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen Praise be Allah, Who created the heavens and the earth, and made the darkness and the light. Yet those who reject Faith hold (others) as equal, with their Guardian-Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is created you from clay, and then decreed a stated term (for you). And there is in His presence another determined term; yet ye doubt within yourselves!\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He is Allah in the heavens and on earth. He knoweth what ye hide, and what ye reveal, and He knoweth the (recompense) which ye earn (by your deeds).\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
But never did a single one of the signs of their Lord reach them, but they turned away therefrom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
And now they reject the truth when it reaches them: but soon shall they learn the reality of what they used to mock at.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
See they not how many of those before them We did destroy?- generations We had established on the earth, in strength such as We have not given to you - for whom We poured out rain from the skies in abundance, and gave (fertile) streams flowing beneath their (feet): yet for their sins We destroyed them, and raised in their wake fresh generations (to succeed them).\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
If We had sent unto thee a written (message) on parchment, so that they could touch it with their hands, the Unbelievers would have been sure to say: ``This is nothing but obvious magic!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
They say: ``Why is not an angel sent down to him?" If we did send down an angel, the matter would be settled at once, and no respite would be granted them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
If We had made it an angel, We should have sent him as a man, and We should certainly have caused them confusion in a matter which they have already covered with confusion.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
Mocked were (many) messengers before thee; but their scoffers were hemmed in by the thing that they mocked.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say: ``Travel through the earth and see what was the end of those who rejected Truth."\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say: ``To whom belongeth all that is in the heavens and on earth?" Say: ``To Allah. He hath inscribed for Himself (the rule of) Mercy. That He will gather you together for the Day of Judgment, there is no doubt whatever. It is they who have lost their own souls, that will not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
To him belongeth all that dwelleth (or lurketh) in the night and the day. For he is the one who heareth and knoweth all things."\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: ``Shall I take for my protector any other than Allah, the Maker of the heavens and the earth? And He it is that feedeth but is not fed." Say: ``Nay! but I am commanded to be the first of those who bow to Allah (in Islam), and be not thou of the company of those who join gods with Allah."\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: ``I would, if I disobeyed my Lord, indeed have fear of the penalty of a Mighty Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
``On that day, if the penalty is averted from any, it is due to Allah's mercy; And that would be (Salvation), the obvious fulfilment of all desire.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
``If Allah touch thee with affliction, none can remove it but He; if He touch thee with happiness, He hath power over all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
``He is the irresistible, (watching) from above over His worshippers; and He is the Wise, acquainted with all things."\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say: ``What thing is most weighty in evidence?" Say: ``Allah is witness between me and you; This Qur'an hath been revealed to me by inspiration, that I may warn you and all whom it reaches. Can ye possibly bear witness that besides Allah there is another Allah?" Say: ``Nay! I cannot bear witness!" Say: ``But in truth He is the one Allah, and I truly am innocent of (your blasphemy of) joining others with Him."\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Book know this as they know their own sons. Those who have lost their own souls refuse therefore to believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
Who doth more wrong than he who inventeth a lie against Allah or rejecteth His signs? But verily the wrong-doers never shall prosper.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
One day shall We gather them all together: We shall say to those who ascribed partners (to Us): ``Where are the partners whom ye (invented and) talked about?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
There will then be (left) no subterfuge for them but to say: ``By Allah our Lord, we were not those who joined gods with Allah."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Behold! how they lie against their own souls! But the (lie) which they invented will leave them in the lurch.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
Of them there are some who (pretend to) listen to thee; but We have thrown veils on their hearts, So they understand it not, and deafness in their ears; if they saw every one of the signs, not they will believe in them; in so much that when they come to thee, they (but) dispute with thee; the Unbelievers say: ``These are nothing but tales of the ancients."\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
Others they keep away from it, and themselves they keep away; but they only destroy their own souls, and they perceive it not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If thou couldst but see when they are confronted with the Fire! They will say: ``Would that we were but sent back! Then would we not reject the signs of our Lord, but would be amongst those who believe!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Yea, in their own (eyes) will become manifest what before they concealed. But if they were returned, they would certainly relapse to the things they were forbidden, for they are indeed liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they (sometimes) say: ``There is nothing except our life on this earth, and never shall we be raised up again."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If thou couldst but see when they are confronted with their Lord! He will say: ``Is not this the truth?" They will say: ``Yea, by our Lord!" He will say: ``Taste ye then the penalty, because ye rejected Faith."\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Lost indeed are they who treat it as a falsehood that they must meet Allah,- until on a sudden the hour is on them, and they say: ``Ah! woe unto us that we took no thought of it"; for they bear their burdens on their backs, and evil indeed are the burdens that they bear?\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
What is the life of this world but play and amusement? But best is the home in the hereafter, for those who are righteous. Will ye not then understand?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know indeed the grief which their words do cause thee: It is not thee they reject: it is the signs of Allah, which the wicked contemn.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Rejected were the messengers before thee: with patience and constancy they bore their rejection and their wrongs, until Our aid did reach them: there is none that can alter the words (and decrees) of Allah. Already hast thou received some account of those messengers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
If their spurning is hard on thy mind, yet if thou wert able to seek a tunnel in the ground or a ladder to the skies and bring them a sign,- (what good?). If it were Allah's will, He could gather them together unto true guidance: so be not thou amongst those who are swayed by ignorance (and impatience)!\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Those who listen (in truth), be sure, will accept: as to the dead, Allah will raise them up; then will they be turned unto Him.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
They say: ``Why is not a sign sent down to him from his Lord?" Say: ``Allah hath certainly power to send down a sign: but most of them understand not.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is not an animal (that lives) on the earth, nor a being that flies on its wings, but (forms part of) communities like you. Nothing have we omitted from the Book, and they (all) shall be gathered to their Lord in the end.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who reject our signs are deaf and dumb,- in the midst of darkness profound: whom Allah willeth, He leaveth to wander: whom He willeth, He placeth on the way that is straight.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: ``Think ye to yourselves, if there come upon you the wrath of Allah, or the Hour (that ye dread), would ye then call upon other than Allah?- (reply) if ye are truthful!\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
``Nay,- On Him would ye call, and if it be His will, He would remove (the distress) which occasioned your call upon Him, and ye would forget (the false gods) which ye join with Him!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
Before thee We sent (messengers) to many nations, and We afflicted the nations with suffering and adversity, that they might learn humility.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
When the suffering reached them from us, why then did they not learn humility? On the contrary their hearts became hardened, and Satan made their (sinful) acts seem alluring to them.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
But when they forgot the warning they had received, We opened to them the gates of all (good) things, until, in the midst of their enjoyment of Our gifts, on a sudden, We called them to account, when lo! they were plunged in despair!\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
Of the wrong-doers the last remnant was cut off. Praise be to Allah, the Cherisher of the worlds.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say: ``Think ye, if Allah took away your hearing and your sight, and sealed up your hearts, who - a god other than Allah - could restore them to you?" See how We explain the signs by various (symbols); yet they turn aside.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: ``Think ye, if the punishment of Allah comes to you, whether suddenly or openly, will any be destroyed except those who do wrong?\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We send the messengers only to give good news and to warn: so those who believe and mend (their lives),- upon them shall be no fear, nor shall they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who reject our signs,- them shall punishment touch, for that they ceased not from transgressing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say: ``I tell you not that with me are the treasures of Allah, nor do I know what is hidden, nor do I tell you I am an angel. I but follow what is revealed to me." Say: ``can the blind be held equal to the seeing?" Will ye then consider not?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
Give this warning to those in whose (hearts) is the fear that they will be brought (to judgment) before their Lord: except for Him they will have no protector nor intercessor: that they may guard (against evil).\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
Send not away those who call on their Lord morning and evening, seeking His face. In naught art thou accountable for them, and in naught are they accountable for thee, that thou shouldst turn them away, and thus be (one) of the unjust.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Thus did We try some of them by comparison with others, that they should say: ``Is it these then that Allah hath favoured from amongst us?" Doth not Allah know best those who are grateful?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
When those come to thee who believe in Our signs, Say: ``Peace be on you: Your Lord hath inscribed for Himself (the rule of) mercy: verily, if any of you did evil in ignorance, and thereafter repented, and amend (his conduct), lo! He is Oft-forgiving, Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
Thus do We explain the signs in detail: that the way of the sinners may be shown up.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say: ``I am forbidden to worship those - others than Allah - whom ye call upon." Say: ``I will not follow your wain desires: If I did, I would stray from the path, and be not of the company of those who receive guidance."\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: ``For me, I (work) on a clear sign from my Lord, but ye reject Him. What ye would see hastened, is not in my power. The command rests with none but Allah: He declares the truth, and He is the best of judges."\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: ``If what ye would see hastened were in my power, the matter would be settled at once between you and me. But Allah knoweth best those who do wrong."\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
With Him are the keys of the unseen, the treasures that none knoweth but He. He knoweth whatever there is on the earth and in the sea. Not a leaf doth fall but with His knowledge: there is not a grain in the darkness (or depths) of the earth, nor anything fresh or dry (green or withered), but is (inscribed) in a record clear (to those who can read).\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He who doth take your souls by night, and hath knowledge of all that ye have done by day: by day doth He raise you up again; that a term appointed be fulfilled; In the end unto Him will be your return; then will He show you the truth of all that ye did.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the irresistible, (watching) from above over His worshippers, and He sets guardians over you. At length, when death approaches one of you, Our angels take his soul, and they never fail in their duty.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then are men returned unto Allah, their protector, the (only) reality: Is not His the command? and He is the swiftest in taking account.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say: ``Who is it that delivereth you from the dark recesses of land and sea, when ye call upon Him in humility and silent terror: 'If He only delivers us from these (dangers), (we vow) we shall truly show our gratitude'?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say ``It is Allah that delivereth you from these and all (other) distresses: and yet ye worship false gods!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: ``He hath power to send calamities on you, from above and below, or to cover you with confusion in party strife, giving you a taste of mutual vengeance - each from the other." See how We explain the signs by various (symbols); that they may understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
But thy people reject this, though it is the truth. Say: ``Not mine is the responsibility for arranging your affairs;\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every message is a limit of time, and soon shall ye know it."\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
When thou seest men engaged in vain discourse about Our signs, turn away from them unless they turn to a different theme. If Satan ever makes thee forget, then after recollection, sit not thou in the company of those who do wrong.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
On their account no responsibility falls on the righteous, but (their duty) is to remind them, that they may (learn to) fear Allah.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
Leave alone those who take their religion to be mere play and amusement, and are deceived by the life of this world. But proclaim (to them) this (truth): that every soul delivers itself to ruin by its own acts: it will find for itself no protector or intercessor except Allah: if it offered every ransom, (or reparation), none will be accepted: such is (the end of) those who deliver themselves to ruin by their own acts: they will have for drink (only) boiling water, and for punishment, one most grievous: for they persisted in rejecting Allah.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say: ``Shall we indeed call on others besides Allah,- things that can do us neither good nor harm,- and turn on our heels after receiving guidance from Allah? - like one whom the evil ones have made into a fool, wandering bewildered through the earth, his friends calling, come to us', (vainly) guiding him to the path." Say: ``Allah's guidance is the (only) guidance, and we have been directed to submit ourselves to the Lord of the worlds;-\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
``To establish regular prayers and to fear Allah: for it is to Him that we shall be gathered together."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It is He who created the heavens and the earth in true (proportions): the day He saith, ``Be," behold! it is. His word is the truth. His will be the dominion the day the trumpet will be blown. He knoweth the unseen as well as that which is open. For He is the Wise, well acquainted (with all things).\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
Lo! Abraham said to his father Azar: ``Takest thou idols for gods? For I see thee and thy people in manifest error."\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
So also did We show Abraham the power and the laws of the heavens and the earth, that he might (with understanding) have certitude.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When the night covered him over, He saw a star: He said: ``This is my Lord." But when it set, He said: ``I love not those that set."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
When he saw the moon rising in splendour, he said: ``This is my Lord." But when the moon set, He said: ``unless my Lord guide me, I shall surely be among those who go astray."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
When he saw the sun rising in splendour, he said: ``This is my Lord; this is the greatest (of all)." But when the sun set, he said: ``O my people! I am indeed free from your (guilt) of giving partners to Allah.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
``For me, I have set my face, firmly and truly, towards Him Who created the heavens and the earth, and never shall I give partners to Allah."\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His people disputed with him. He said: ``(Come) ye to dispute with me, about Allah, when He (Himself) hath guided me? I fear not (the beings) ye associate with Allah: Unless my Lord willeth, (nothing can happen). My Lord comprehendeth in His knowledge all things. Will ye not (yourselves) be admonished?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
``How should I fear (the beings) ye associate with Allah, when ye fear not to give partners to Allah without any warrant having been given to you? Which of (us) two parties hath more right to security? (tell me) if ye know.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
``It is those who believe and confuse not their beliefs with wrong - that are (truly) in security, for they are on (right) guidance."\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
That was the reasoning about Us, which We gave to Abraham (to use) against his people: We raise whom We will, degree after degree: for thy Lord is full of wisdom and knowledge.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
We gave him Isaac and Jacob: all (three) guided: and before him, We guided Noah, and among his progeny, David, Solomon, Job, Joseph, Moses, and Aaron: thus do We reward those who do good:\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zakariya and John, and Jesus and Elias: all in the ranks of the righteous:\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Isma'il and Elisha, and Jonas, and Lot: and to all We gave favour above the nations:\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
(To them) and to their fathers, and progeny and brethren: We chose them, and we guided them to a straight way.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
This is the guidance of Allah: He giveth that guidance to whom He pleaseth, of His worshippers. If they were to join other gods with Him, all that they did would be vain for them.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
These were the men to whom We gave the Book, and authority, and prophethood: if these (their descendants) reject them, Behold! We shall entrust their charge to a new people who reject them not.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those were the (prophets) who received Allah's guidance: Copy the guidance they received; Say: ``No reward for this do I ask of you: This is no less than a message for the nations."\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
No just estimate of Allah do they make when they say: ``Nothing doth Allah send down to man (by way of revelation)" Say: ``Who then sent down the Book which Moses brought?- a light and guidance to man: But ye make it into (separate) sheets for show, while ye conceal much (of its contents): therein were ye taught that which ye knew not- neither ye nor your fathers." Say: ``Allah (sent it down)": Then leave them to plunge in vain discourse and trifling.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a Book which We have sent down, bringing blessings, and confirming (the revelations) which came before it: that thou mayest warn the mother of cities and all around her. Those who believe in the Hereafter believe in this (Book), and they are constant in guarding their prayers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who can be more wicked than one who inventeth a lie against Allah, or saith, ``I have received inspiration," when he hath received none, or (again) who saith, ``I can reveal the like of what Allah hath revealed"? If thou couldst but see how the wicked (do fare) in the flood of confusion at death! - the angels stretch forth their hands, (saying),"Yield up your souls: this day shall ye receive your reward,- a penalty of shame, for that ye used to tell lies against Allah, and scornfully to reject of His signs!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
``And behold! ye come to us bare and alone as We created you for the first time: ye have left behind you all (the favours) which We bestowed on you: We see not with you your intercessors whom ye thought to be partners in your affairs: so now all relations between you have been cut off, and your (pet) fancies have left you in the lurch!"\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
It is Allah Who causeth the seed-grain and the date-stone to split and sprout. He causeth the living to issue from the dead, and He is the one to cause the dead to issue from the living. That is Allah: then how are ye deluded away from the truth?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
He it is that cleaveth the day-break (from the dark): He makes the night for rest and tranquillity, and the sun and moon for the reckoning (of time): Such is the judgment and ordering of (Him), the Exalted in Power, the Omniscient.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He Who maketh the stars (as beacons) for you, that ye may guide yourselves, with their help, through the dark spaces of land and sea: We detail Our signs for people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He Who hath produced you from a single person: here is a place of sojourn and a place of departure: We detail Our signs for people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
It is He Who sendeth down rain from the skies: with it We produce vegetation of all kinds: from some We produce green (crops), out of which We produce grain, heaped up (at harvest); out of the date-palm and its sheaths (or spathes) (come) clusters of dates hanging low and near: and (then there are) gardens of grapes, and olives, and pomegranates, each similar (in kind) yet different (in variety): when they begin to bear fruit, feast your eyes with the fruit and the ripeness thereof. Behold! in these things there are signs for people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet they make the Jinns equals with Allah, though Allah did create the Jinns; and they falsely, having no knowledge, attribute to Him sons and daughters. Praise and glory be to Him! (for He is) above what they attribute to Him!\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
To Him is due the primal origin of the heavens and the earth: How can He have a son when He hath no consort? He created all things, and He hath full knowledge of all things.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
That is Allah, your Lord! there is no god but He, the Creator of all things: then worship ye Him: and He hath power to dispose of all affairs.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No vision can grasp Him, but His grasp is over all vision: He is above all comprehension, yet is acquainted with all things.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
``Now have come to you, from your Lord, proofs (to open your eyes): if any will see, it will be for (the good of) his own soul; if any will be blind, it will be to his own (harm): I am not (here) to watch over your doings."\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
Thus do we explain the signs by various (symbols): that they may say, ``Thou hast taught (us) diligently," and that We may make the matter clear to those who know.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow what thou art taught by inspiration from thy Lord: there is no god but He: and turn aside from those who join gods with Allah.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
If it had been Allah's plan, they would not have taken false gods: but We made thee not one to watch over their doings, nor art thou set over them to dispose of their affairs.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Revile not ye those whom they call upon besides Allah, lest they out of spite revile Allah in their ignorance. Thus have We made alluring to each people its own doings. In the end will they return to their Lord, and We shall then tell them the truth of all that they did.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
They swear their strongest oaths by Allah, that if a (special) sign came to them, by it they would believe. Say: ``Certainly (all) signs are in the power of Allah: but what will make you (Muslims) realise that (even) if (special) signs came, they will not believe."?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
We (too) shall turn to (confusion) their hearts and their eyes, even as they refused to believe in this in the first instance: We shall leave them in their trespasses, to wander in distraction.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
Even if We did send unto them angels, and the dead did speak unto them, and We gathered together all things before their very eyes, they are not the ones to believe, unless it is in Allah's plan. But most of them ignore (the truth).\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
Likewise did We make for every Messenger an enemy,- evil ones among men and jinns, inspiring each other with flowery discourses by way of deception. If thy Lord had so planned, they would not have done it: so leave them and their inventions alone.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
To such (deceit) let the hearts of those incline, who have no faith in the hereafter: let them delight in it, and let them earn from it what they may.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
Say: ``Shall I seek for judge other than Allah? - when He it is Who hath sent unto you the Book, explained in detail." They know full well, to whom We have given the Book, that it hath been sent down from thy Lord in truth. Never be then of those who doubt.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
The word of thy Lord doth find its fulfilment in truth and in justice: None can change His words: for He is the one who heareth and knoweth all.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
Wert thou to follow the common run of those on earth, they will lead thee away from the way of Allah. They follow nothing but conjecture: they do nothing but lie.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Thy Lord knoweth best who strayeth from His way: He knoweth best who they are that receive His guidance.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat of (meats) on which Allah's name hath been pronounced, if ye have faith in His signs.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
Why should ye not eat of (meats) on which Allah's name hath been pronounced, when He hath explained to you in detail what is forbidden to you - except under compulsion of necessity? But many do mislead (men) by their appetites unchecked by knowledge. Thy Lord knoweth best those who transgress.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
Eschew all sin, open or secret: those who earn sin will get due recompense for their ``earnings."\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
Eat not of (meats) on which Allah's name hath not been pronounced: That would be impiety. But the evil ones ever inspire their friends to contend with you if ye were to obey them, ye would indeed be Pagans.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Can he who was dead, to whom We gave life, and a light whereby he can walk amongst men, be like him who is in the depths of darkness, from which he can never come out? Thus to those without faith their own deeds seem pleasing.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
Thus have We placed leaders in every town, its wicked men, to plot (and burrow) therein: but they only plot against their own souls, and they perceive it not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
When there comes to them a sign (from Allah), They say: ``We shall not believe until we receive one (exactly) like those received by Allah's messengers." Allah knoweth best where (and how) to carry out His mission. Soon will the wicked be overtaken by humiliation before Allah, and a severe punishment, for all their plots.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
Those whom Allah (in His plan) willeth to guide,- He openeth their breast to Islam; those whom He willeth to leave straying,- He maketh their breast close and constricted, as if they had to climb up to the skies: thus doth Allah (heap) the penalty on those who refuse to believe.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
This is the way of thy Lord, leading straight: We have detailed the signs for those who receive admonition.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them will be a home of peace in the presence of their Lord: He will be their friend, because they practised (righteousness).\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
One day will He gather them all together, (and say): ``O ye assembly of Jinns! Much (toll) did ye take of men." Their friends amongst men will say: ``Our Lord! we made profit from each other: but (alas!) we reached our term - which thou didst appoint for us." He will say: ``The Fire be your dwelling-place: you will dwell therein for ever, except as Allah willeth." for thy Lord is full of wisdom and knowledge.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
Thus do we make the wrong-doers turn to each other, because of what they earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
``O ye assembly of Jinns and men! came there not unto you messengers from amongst you, setting forth unto you My signs, and warning you of the meeting of this Day of yours?" They will say: ``We bear witness against ourselves." It was the life of this world that deceived them. So against themselves will they bear witness that they rejected Faith.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
(The messengers were sent) thus, for thy Lord would not destroy for their wrong-doing men's habitations whilst their occupants were unwarned.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
To all are degrees (or ranks) according to their deeds: for thy Lord is not unmindful of anything that they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Thy Lord is self-sufficient, full of Mercy: if it were His will, He could destroy you, and in your place appoint whom He will as your successors, even as He raised you up from the posterity of other people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
All that hath been promised unto you will come to pass: nor can ye frustrate it (in the least bit).\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say: ``O my people! Do whatever ye can: I will do (my part): soon will ye know who it is whose end will be (best) in the Hereafter: certain it is that the wrong-doers will not prosper."\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
Out of what Allah hath produced in abundance in tilth and in cattle, they assigned Him a share: they say, according to their fancies: ``This is for Allah, and this" - for our ``partners"! but the share of their" partners ``reacheth not Allah, whilst the share of Allah reacheth their ``partners"! evil (and unjust) is their assignment!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
Even so, in the eyes of most of the pagans, their ``partners" made alluring the slaughter of their children, in order to lead them to their own destruction, and cause confusion in their religion. If Allah had willed, they would not have done so: But leave alone them and their inventions.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they say that such and such cattle and crops are taboo, and none should eat of them except those whom - so they say - We wish; further, there are cattle forbidden to yoke or burden, and cattle on which, (at slaughter), the name of Allah is not pronounced; - inventions against Allah's name: soon will He requite them for their inventions.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
They say: ``What is in the wombs of such and such cattle is specially reserved (for food) for our men, and forbidden to our women; but if it is still-born, then all have share therein. For their (false) attribution (of superstitions to Allah), He will soon punish them: for He is full of wisdom and knowledge.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Lost are those who slay their children, from folly, without knowledge, and forbid food which Allah hath provided for them, inventing (lies) against Allah. They have indeed gone astray and heeded no guidance.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
It is He Who produceth gardens, with trellises and without, and dates, and tilth with produce of all kinds, and olives and pomegranates, similar (in kind) and different (in variety): eat of their fruit in their season, but render the dues that are proper on the day that the harvest is gathered. But waste not by excess: for Allah loveth not the wasters.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
Of the cattle are some for burden and some for meat: eat what Allah hath provided for you, and follow not the footsteps of Satan: for he is to you and avowed enemy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
(Take) eight (head of cattle) in (four) pairs: of sheep a pair, and of goats a pair; say, hath He forbidden the two males, or the two females, or (the young) which the wombs of the two females enclose? Tell me with knowledge if ye are truthful:\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
Of camels a pair, and oxen a pair; say, hath He forbidden the two males, or the two females, or (the young) which the wombs of the two females enclose? - Were ye present when Allah ordered you such a thing? But who doth more wrong than one who invents a lie against Allah, to lead astray men without knowledge? For Allah guideth not people who do wrong.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say: ``I find not in the message received by me by inspiration any (meat) forbidden to be eaten by one who wishes to eat it, unless it be dead meat, or blood poured forth, or the flesh of swine,- for it is an abomination - or, what is impious, (meat) on which a name has been invoked, other than Allah's". But (even so), if a person is forced by necessity, without wilful disobedience, nor transgressing due limits,- thy Lord is Oft-forgiving, Most Merciful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
For those who followed the Jewish Law, We forbade every (animal) with undivided hoof, and We forbade them that fat of the ox and the sheep, except what adheres to their backs or their entrails, or is mixed up with a bone: this in recompense for their wilful disobedience: for We are true (in Our ordinances).\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
If they accuse thee of falsehood, say: ``Your Lord is full of mercy all-embracing; but from people in guilt never will His wrath be turned back.\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Those who give partners (to Allah) will say: ``If Allah had wished, we should not have given partners to Him nor would our fathers; nor should we have had any taboos." So did their ancestors argue falsely, until they tasted of Our wrath. Say: ``Have ye any (certain) knowledge? If so, produce it before us. Ye follow nothing but conjecture: ye do nothing but lie."\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say: ``With Allah is the argument that reaches home: if it had been His will, He could indeed have guided you all."\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: ``Bring forward your witnesses to prove that Allah did forbid so and so." If they bring such witnesses, be not thou amongst them: Nor follow thou the vain desires of such as treat our signs as falsehoods, and such as believe not in the Hereafter: for they hold others as equal with their Guardian-Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say: ``Come, I will rehearse what Allah hath (really) prohibited you from": Join not anything as equal with Him; be good to your parents; kill not your children on a plea of want;- We provide sustenance for you and for them;- come not nigh to shameful deeds. Whether open or secret; take not life, which Allah hath made sacred, except by way of justice and law: thus doth He command you, that ye may learn wisdom.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And come not nigh to the orphan's property, except to improve it, until he attain the age of full strength; give measure and weight with (full) justice;- no burden do We place on any soul, but that which it can bear;- whenever ye speak, speak justly, even if a near relative is concerned; and fulfil the covenant of Allah: thus doth He command you, that ye may remember.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
Verily, this is My way, leading straight: follow it: follow not (other) paths: they will scatter you about from His (great) path: thus doth He command you. that ye may be righteous.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Moreover, We gave Moses the Book, completing (Our favour) to those who would do right, and explaining all things in detail,- and a guide and a mercy, that they might believe in the meeting with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this is a Book which We have revealed as a blessing: so follow it and be righteous, that ye may receive mercy:\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest ye should say: ``The Book was sent down to two Peoples before us, and for our part, we remained unacquainted with all that they learned by assiduous study:"\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest ye should say: ``If the Book had only been sent down to us, we should have followed its guidance better than they." Now then hath come unto you a clear (sign) from your Lord,- and a guide and a mercy: then who could do more wrong than one who rejecteth Allah's signs, and turneth away therefrom? In good time shall We requite those who turn away from Our signs, with a dreadful penalty, for their turning away.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Are they waiting to see if the angels come to them, or thy Lord (Himself), or certain of the signs of thy Lord! the day that certain of the signs of thy Lord do come, no good will it do to a soul to believe in them then if it believed not before nor earned righteousness through its faith. Say: ``Wait ye: we too are waiting."\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
As for those who divide their religion and break up into sects, thou hast no part in them in the least: their affair is with Allah: He will in the end tell them the truth of all that they did.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
He that doeth good shall have ten times as much to his credit: He that doeth evil shall only be recompensed according to his evil: no wrong shall be done unto (any of) them.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say: ``Verily, my Lord hath guided me to a way that is straight,- a religion of right,- the path (trod) by Abraham the true in Faith, and he (certainly) joined not gods with Allah."\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: ``Truly, my prayer and my service of sacrifice, my life and my death, are (all) for Allah, the Cherisher of the Worlds:\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
No partner hath He: this am I commanded, and I am the first of those who bow to His will.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: ``Shall I seek for (my) Cherisher other than Allah, when He is the Cherisher of all things (that exist)? Every soul draws the meed of its acts on none but itself: no bearer of burdens can bear the burden of another. Your goal in the end is towards Allah: He will tell you the truth of the things wherein ye disputed."\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
It is He Who hath made you (His) agents, inheritors of the earth: He hath raised you in ranks, some above others: that He may try you in the gifts He hath given you: for thy Lord is quick in punishment: yet He is indeed Oft-forgiving, Most Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif, Lam, Mim, Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
A Book revealed unto thee,- So let thy heart be oppressed no more by any difficulty on that account,- that with it thou mightest warn (the erring) and teach the Believers).\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow (O men!) the revelation given unto you from your Lord, and follow not, as friends or protectors, other than Him. Little it is ye remember of admonition.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many towns have We destroyed (for their sins)? Our punishment took them on a sudden by night or while they slept for their afternoon rest.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
When (thus) Our punishment took them, no cry did they utter but this: ``Indeed we did wrong."\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then shall we question those to whom Our message was sent and those by whom We sent it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
And verily, We shall recount their whole story with knowledge, for We were never absent (at any time or place).\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
The balance that day will be true (to nicety): those whose scale (of good) will be heavy, will prosper:\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
Those whose scale will be light, will be their souls in perdition, for that they wrongfully treated Our signs.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
It is We Who have placed you with authority on earth, and provided you therein with means for the fulfilment of your life: small are the thanks that ye give!\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
It is We Who created you and gave you shape; then We bade the angels prostrate to Adam, and they prostrate; not so Iblis; He refused to be of those who prostrate.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
(Allah) said: ``What prevented thee from prostrating when I commanded thee?" He said: ``I am better than he: Thou didst create me from fire, and him from clay."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
(Allah) said: ``Get thee down from this: it is not for thee to be arrogant here: get out, for thou art of the meanest (of creatures)."\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
He said: ``Give me respite till the day they are raised up."\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
(Allah) said: ``Be thou among those who have respite."\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
He said: ``Because thou hast thrown me out of the way, lo! I will lie in wait for them on thy straight way:\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
``Then will I assault them from before them and behind them, from their right and their left: Nor wilt thou find, in most of them, gratitude (for thy mercies)."\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
(Allah) said: ``Get out from this, disgraced and expelled. If any of them follow thee,- Hell will I fill with you all.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
``O Adam! dwell thou and thy wife in the Garden, and enjoy (its good things) as ye wish: but approach not this tree, or ye run into harm and transgression."\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then began Satan to whisper suggestions to them, bringing openly before their minds all their shame that was hidden from them (before): he said: ``Your Lord only forbade you this tree, lest ye should become angels or such beings as live for ever."\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore to them both, that he was their sincere adviser.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So by deceit he brought about their fall: when they tasted of the tree, their shame became manifest to them, and they began to sew together the leaves of the garden over their bodies. And their Lord called unto them: ``Did I not forbid you that tree, and tell you that Satan was an avowed enemy unto you?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said: ``Our Lord! We have wronged our own souls: If thou forgive us not and bestow not upon us Thy Mercy, we shall certainly be lost."\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
(Allah) said: ``Get ye down. With enmity between yourselves. On earth will be your dwelling-place and your means of livelihood,- for a time."\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said: ``Therein shall ye live, and therein shall ye die; but from it shall ye be taken out (at last)."\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O ye Children of Adam! We have bestowed raiment upon you to cover your shame, as well as to be an adornment to you. But the raiment of righteousness,- that is the best. Such are among the Signs of Allah, that they may receive admonition!\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O ye Children of Adam! Let not Satan seduce you, in the same manner as He got your parents out of the Garden, stripping them of their raiment, to expose their shame: for he and his tribe watch you from a position where ye cannot see them: We made the evil ones friends (only) to those without faith.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
When they do aught that is shameful, they say: ``We found our fathers doing so"; and ``Allah commanded us thus": Say: ``Nay, Allah never commands what is shameful: do ye say of Allah what ye know not?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say: ``My Lord hath commanded justice; and that ye set your whole selves (to Him) at every time and place of prayer, and call upon Him, making your devotion sincere as in His sight: such as He created you in the beginning, so shall ye return."\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
Some He hath guided: Others have (by their choice) deserved the loss of their way; in that they took the evil ones, in preference to Allah, for their friends and protectors, and think that they receive guidance.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! wear your beautiful apparel at every time and place of prayer: eat and drink: But waste not by excess, for Allah loveth not the wasters.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say: Who hath forbidden the beautiful (gifts) of Allah, which He hath produced for His servants, and the things, clean and pure, (which He hath provided) for sustenance? Say: They are, in the life of this world, for those who believe, (and) purely for them on the Day of Judgment. Thus do We explain the signs in detail for those who understand.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say: the things that my Lord hath indeed forbidden are: shameful deeds, whether open or secret; sins and trespasses against truth or reason; assigning of partners to Allah, for which He hath given no authority; and saying things about Allah of which ye have no knowledge.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
To every people is a term appointed: when their term is reached, not an hour can they cause delay, nor (an hour) can they advance (it in anticipation).\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O ye Children of Adam! whenever there come to you messengers from amongst you, rehearsing My signs unto you,- those who are righteous and mend (their lives),- on them shall be no fear nor shall they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But those who reject Our signs and treat them with arrogance,- they are companions of the Fire, to dwell therein (for ever).\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who is more unjust than one who invents a lie against Allah or rejects His Signs? For such, their portion appointed must reach them from the Book (of decrees): until, when our messengers (of death) arrive and take their souls, they say: ``Where are the things that ye used to invoke besides Allah?" They will reply, ``They have left us in the lurch," And they will bear witness against themselves, that they had rejected Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
He will say: ``Enter ye in the company of the peoples who passed away before you - men and jinns, - into the Fire." Every time a new people enters, it curses its sister-people (that went before), until they follow each other, all into the Fire. Saith the last about the first: ``Our Lord! it is these that misled us: so give them a double penalty in the Fire." He will say: ``Doubled for all": but this ye do not understand.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
Then the first will say to the last: ``See then! No advantage have ye over us; so taste ye of the penalty for all that ye did!"\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
To those who reject Our signs and treat them with arrogance, no opening will there be of the gates of heaven, nor will they enter the garden, until the camel can pass through the eye of the needle: Such is Our reward for those in sin.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
For them there is Hell, as a couch (below) and folds and folds of covering above: such is Our requital of those who do wrong.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
But those who believe and work righteousness,- no burden do We place on any soul, but that which it can bear,- they will be Companions of the Garden, therein to dwell (for ever).\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We shall remove from their hearts any lurking sense of injury;- beneath them will be rivers flowing;- and they shall say: ``Praise be to Allah, who hath guided us to this (felicity): never could we have found guidance, had it not been for the guidance of Allah: indeed it was the truth, that the messengers of our Lord brought unto us." And they shall hear the cry: ``Behold! the garden before you! Ye have been made its inheritors, for your deeds (of righteousness)."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
The Companions of the Garden will call out to the Companions of the Fire: ``We have indeed found the promises of our Lord to us true: Have you also found Your Lord's promises true?" They shall say, ``Yes"; but a crier shall proclaim between them: ``The curse of Allah is on the wrong-doers;-\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
``Those who would hinder (men) from the path of Allah and would seek in it something crooked: they were those who denied the Hereafter."\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
Between them shall be a veil, and on the heights will be men who would know every one by his marks: they will call out to the Companions of the Garden, ``peace on you": they will not have entered, but they will have an assurance (thereof).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
When their eyes shall be turned towards the Companions of the Fire, they will say: ``Our Lord! send us not to the company of the wrong-doers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
The men on the heights will call to certain men whom they will know from their marks, saying: ``Of what profit to you were your hoards and your arrogant ways?\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
``Behold! are these not the men whom you swore that Allah with His Mercy would never bless? Enter ye the Garden: no fear shall be on you, nor shall ye grieve."\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
The Companions of the Fire will call to the Companions of the Garden: ``Pour down to us water or anything that Allah doth provide for your sustenance." They will say: ``Both these things hath Allah forbidden to those who rejected Him."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
``Such as took their religion to be mere amusement and play, and were deceived by the life of the world." That day shall We forget them as they forgot the meeting of this day of theirs, and as they were wont to reject Our signs.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
For We had certainly sent unto them a Book, based on knowledge, which We explained in detail,- a guide and a mercy to all who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Do they just wait for the final fulfilment of the event? On the day the event is finally fulfilled, those who disregarded it before will say: ``The messengers of our Lord did indeed bring true (tidings). Have we no intercessors now to intercede on our behalf? Or could we be sent back? then should we behave differently from our behaviour in the past." In fact they will have lost their souls, and the things they invented will leave them in the lurch.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Your Guardian-Lord is Allah, Who created the heavens and the earth in six days, and is firmly established on the throne (of authority): He draweth the night as a veil o'er the day, each seeking the other in rapid succession: He created the sun, the moon, and the stars, (all) governed by laws under His command. Is it not His to create and to govern? Blessed be Allah, the Cherisher and Sustainer of the worlds!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Call on your Lord with humility and in private: for Allah loveth not those who trespass beyond bounds.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
Do no mischief on the earth, after it hath been set in order, but call on Him with fear and longing (in your hearts): for the Mercy of Allah is (always) near to those who do good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
It is He Who sendeth the winds like heralds of glad tidings, going before His mercy: when they have carried the heavy-laden clouds, We drive them to a land that is dead, make rain to descend thereon, and produce every kind of harvest therewith: thus shall We raise up the dead: perchance ye may remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
From the land that is clean and good, by the will of its Cherisher, springs up produce, (rich) after its kind: but from the land that is bad, springs up nothing but that which is niggardly: thus do we explain the signs by various (symbols) to those who are grateful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
We sent Noah to his people. He said: ``O my people! worship Allah! ye have no other god but Him. I fear for you the punishment of a dreadful day!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The leaders of his people said: ``Ah! we see thee evidently wandering (in mind)."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
He said: ``O my people! No wandering is there in my (mind): on the contrary I am a messenger from the Lord and Cherisher of the worlds!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
``I but fulfil towards you the duties of my Lord's mission: Sincere is my advice to you, and I know from Allah something that ye know not.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
``Do ye wonder that there hath come to you a message from your Lord, through a man of your own people, to warn you,- so that ye may fear Allah and haply receive His Mercy?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they rejected him, and We delivered him, and those with him, in the Ark: but We overwhelmed in the flood those who rejected Our signs. They were indeed a blind people!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
To the 'Ad people, (We sent) Hud, one of their (own) brethren: He said: O my people! worship Allah! ye have no other god but Him will ye not fear (Allah)?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The leaders of the Unbelievers among his people said: ``Ah! we see thou art an imbecile!" and ``We think thou art a liar!"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said: ``O my people! I am no imbecile, but (I am) a messenger from the Lord and Cherisher of the worlds!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
``I but fulfil towards you the duties of my Lord's mission: I am to you a sincere and trustworthy adviser.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
``Do ye wonder that there hath come to you a message from your Lord through a man of your own people, to warn you? call in remembrance that He made you inheritors after the people of Noah, and gave you a stature tall among the nations. Call in remembrance the benefits (ye have received) from Allah: that so ye may prosper."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: ``Comest thou to us, that we may worship Allah alone, and give up the cult of our fathers? bring us what thou threatenest us with, if so be that thou tellest the truth!"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
He said: ``Punishment and wrath have already come upon you from your Lord: dispute ye with me over names which ye have devised - ye and your fathers,- without authority from Allah? then wait: I am amongst you, also waiting."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
We saved him and those who adhered to him. By Our mercy, and We cut off the roots of those who rejected Our signs and did not believe.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
To the Thamud people (We sent) Salih, one of their own brethren: He said: ``O my people! worship Allah: ye have no other god but Him. Now hath come unto you a clear (Sign) from your Lord! This she-camel of Allah is a Sign unto you: So leave her to graze in Allah's earth, and let her come to no harm, or ye shall be seized with a grievous punishment.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
``And remember how He made you inheritors after the 'Ad people and gave you habitations in the land: ye build for yourselves palaces and castles in (open) plains, and carve out homes in the mountains; so bring to remembrance the benefits (ye have received) from Allah, and refrain from evil and mischief on the earth."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The leaders of the arrogant party among his people said to those who were reckoned powerless - those among them who believed: ``know ye indeed that Salih is a messenger from his Lord?" They said: ``We do indeed believe in the revelation which hath been sent through him."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
The Arrogant party said: ``For our part, we reject what ye believe in."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
Then they ham-strung the she-camel, and insolently defied the order of their Lord, saying: ``O Salih! bring about thy threats, if thou art a messenger (of Allah)!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake took them unawares, and they lay prostrate in their homes in the morning!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
So Salih left them, saying: ``O my people! I did indeed convey to you the message for which I was sent by my Lord: I gave you good counsel, but ye love not good counsellors!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
We also (sent) Lut: He said to his people: ``Do ye commit lewdness such as no people in creation (ever) committed before you?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
``For ye practise your lusts on men in preference to women: ye are indeed a people transgressing beyond bounds."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And his people gave no answer but this: they said, ``Drive them out of your city: these are indeed men who want to be clean and pure!"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
But we saved him and his family, except his wife: she was of those who legged behind.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And we rained down on them a shower (of brimstone): Then see what was the end of those who indulged in sin and crime!\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
To the Madyan people We sent Shu'aib, one of their own brethren: he said: ``O my people! worship Allah; Ye have no other god but Him. Now hath come unto you a clear (Sign) from your Lord! Give just measure and weight, nor withhold from the people the things that are their due; and do no mischief on the earth after it has been set in order: that will be best for you, if ye have Faith.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
``And squat not on every road, breathing threats, hindering from the path of Allah those who believe in Him, and seeking in it something crooked; But remember how ye were little, and He gave you increase. And hold in your mind's eye what was the end of those who did mischief.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
``And if there is a party among you who believes in the message with which I have been sent, and a party which does not believe, hold yourselves in patience until Allah doth decide between us: for He is the best to decide.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The leaders, the arrogant party among his people, said: ``O Shu'aib! we shall certainly drive thee out of our city - (thee) and those who believe with thee; or else ye (thou and they) shall have to return to our ways and religion." He said: ``What! even though we do detest (them)?\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
``We should indeed invent a lie against Allah, if we returned to your ways after Allah hath rescued us therefrom; nor could we by any manner of means return thereto unless it be as in the will and plan of Allah, Our Lord. Our Lord can reach out to the utmost recesses of things by His knowledge. In the Allah is our trust. our Lord! decide Thou between us and our people in truth, for Thou art the best to decide."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
The leaders, the unbelievers among his people, said: ``If ye follow Shu'aib, be sure then ye are ruined!"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
But the earthquake took them unawares, and they lay prostrate in their homes before the morning!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
The men who reject Shu'aib became as if they had never been in the homes where they had flourished: the men who rejected Shu'aib - it was they who were ruined!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
So Shu'aib left them, saying: ``O my people! I did indeed convey to you the messages for which I was sent by my Lord: I gave you good counsel, but how shall I lament over a people who refuse to believe!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
Whenever We sent a prophet to a town, We took up its people in suffering and adversity, in order that they might learn humility.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed their suffering into prosperity, until they grew and multiplied, and began to say: ``Our fathers (too) were touched by suffering and affluence"... Behold! We called them to account of a sudden, while they realised not (their peril).\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
If the people of the towns had but believed and feared Allah, We should indeed have opened out to them (All kinds of) blessings from heaven and earth; but they rejected (the truth), and We brought them to book for their misdeeds.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Did the people of the towns feel secure against the coming of Our wrath by night while they were asleep?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or else did they feel secure against its coming in broad daylight while they played about (care-free)?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Did they then feel secure against the plan of Allah?- but no one can feel secure from the Plan of Allah, except those (doomed) to ruin!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
To those who inherit the earth in succession to its (previous) possessors, is it not a guiding, (lesson) that, if We so willed, We could punish them (too) for their sins, and seal up their hearts so that they could not hear?\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Such were the towns whose story We (thus) relate unto thee: There came indeed to them their messengers with clear (signs): But they would not believe what they had rejected before. Thus doth Allah seal up the hearts of those who reject faith.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
Most of them We found not men (true) to their covenant: but most of them We found rebellious and disobedient.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then after them We sent Moses with Our signs to Pharaoh and his chiefs, but they wrongfully rejected them: So see what was the end of those who made mischief.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
Moses said: ``O Pharaoh! I am a messenger from the Lord of the worlds,-\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
One for whom it is right to say nothing but truth about Allah. Now have I come unto you (people), from your Lord, with a clear (Sign): So let the Children of Israel depart along with me."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
(Pharaoh) said: ``If indeed thou hast come with a Sign, show it forth,- if thou tellest the truth."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
Then (Moses) threw his rod, and behold! it was a serpent, plain (for all to see)!\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew out his hand, and behold! it was white to all beholders!\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
Said the Chiefs of the people of Pharaoh: ``This is indeed a sorcerer well-versed.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
``His plan is to get you out of your land: then what is it ye counsel?"\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said: ``Keep him and his brother in suspense (for a while); and send to the cities men to collect-\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
And bring up to thee all (our) sorcerers well-versed."\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
So there came the sorcerers to Pharaoh: They said, ``of course we shall have a (suitable) reward if we win!"\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said: ``Yea, (and more),- for ye shall in that case be (raised to posts) nearest (to my person)."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: ``O Moses! wilt thou throw (first), or shall we have the (first) throw?"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
Said Moses: ``Throw ye (first)." So when they threw, they bewitched the eyes of the people, and struck terror into them: for they showed a great (feat of) magic.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
We put it into Moses's mind by inspiration: ``Throw (now) thy rod": and behold! it swallows up straight away all the falsehoods which they fake!\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus truth was confirmed, and all that they did was made of no effect.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
So the (great ones) were vanquished there and then, and were made to look small.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
But the sorcerers fell down prostrate in adoration.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
Saying: ``We believe in the Lord of the Worlds,-\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
``The Lord of Moses and Aaron."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Said Pharaoh: ``Believe ye in Him before I give you permission? Surely this is a trick which ye have planned in the city to drive out its people: but soon shall ye know (the consequences).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
``Be sure I will cut off your hands and your feet on apposite sides, and I will cause you all to die on the cross."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said: ``For us, We are but sent back unto our Lord:\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
``But thou dost wreak thy vengeance on us simply because we believed in the Signs of our Lord when they reached us! Our Lord! pour out on us patience and constancy, and take our souls unto thee as Muslims (who bow to thy will)!\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
Said the chiefs of Pharaoh's people: ``Wilt thou leave Moses and his people, to spread mischief in the land, and to abandon thee and thy gods?" He said: ``Their male children will we slay; (only) their females will we save alive; and we have over them (power) irresistible."\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Said Moses to his people: ``Pray for help from Allah, and (wait) in patience and constancy: for the earth is Allah's, to give as a heritage to such of His servants as He pleaseth; and the end is (best) for the righteous.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said: ``We have had (nothing but) trouble, both before and after thou camest to us." He said: ``It may be that your Lord will destroy your enemy and make you inheritors in the earth; that so He may try you by your deeds."\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
We punished the people of Pharaoh with years (of droughts) and shortness of crops; that they might receive admonition.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But when good (times) came, they said, ``This is due to us;" When gripped by calamity, they ascribed it to evil omens connected with Moses and those with him! Behold! in truth the omens of evil are theirs in Allah's sight, but most of them do not understand!\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
They said (to Moses): ``Whatever be the Signs thou bringest, to work therewith thy sorcery on us, we shall never believe in thee.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent (plagues) on them: Wholesale death, Locusts, Lice, Frogs, And Blood: Signs openly self-explained: but they were steeped in arrogance,- a people given to sin.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
Every time the penalty fell on them, they said: ``O Moses! on your behalf call on thy Lord in virtue of his promise to thee: If thou wilt remove the penalty from us, we shall truly believe in thee, and we shall send away the Children of Israel with thee."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But every time We removed the penalty from them according to a fixed term which they had to fulfil,- Behold! they broke their word!\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We exacted retribution from them: We drowned them in the sea, because they rejected Our Signs and failed to take warning from them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made a people, considered weak (and of no account), inheritors of lands in both east and west, - lands whereon We sent down Our blessings. The fair promise of thy Lord was fulfilled for the Children of Israel, because they had patience and constancy, and We levelled to the ground the great works and fine buildings which Pharaoh and his people erected (with such pride).\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
We took the Children of Israel (with safety) across the sea. They came upon a people devoted entirely to some idols they had. They said: ``O Moses! fashion for us a god like unto the gods they have." He said: ``Surely ye are a people without knowledge.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
``As to these folk,- the cult they are in is (but) a fragment of a ruin, and vain is the (worship) which they practise."\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said: ``Shall I seek for you a god other than the (true) Allah, when it is Allah Who hath endowed you with gifts above the nations?"\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And remember We rescued you from Pharaoh's people, who afflicted you with the worst of penalties, who slew your male children and saved alive your females: in that was a momentous trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
We appointed for Moses thirty nights, and completed (the period) with ten (more): thus was completed the term (of communion) with his Lord, forty nights. And Moses had charged his brother Aaron (before he went up): ``Act for me amongst my people: Do right, and follow not the way of those who do mischief."\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
When Moses came to the place appointed by Us, and his Lord addressed him, He said: ``O my Lord! show (Thyself) to me, that I may look upon thee." Allah said: ``By no means canst thou see Me (direct); But look upon the mount; if it abide in its place, then shalt thou see Me." When his Lord manifested His glory on the Mount, He made it as dust. And Moses fell down in a swoon. When he recovered his senses he said: ``Glory be to Thee! to Thee I turn in repentance, and I am the first to believe."\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
(Allah) said: ``O Moses! I have chosen thee above (other) men, by the mission I (have given thee) and the words I (have spoken to thee): take then the (revelation) which I give thee, and be of those who give thanks."\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We ordained laws for him in the tablets in all matters, both commanding and explaining all things, (and said): ``Take and hold these with firmness, and enjoin thy people to hold fast by the best in the precepts: soon shall I show you the homes of the wicked,- (How they lie desolate)."\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
Those who behave arrogantly on the earth in defiance of right - them will I turn away from My signs: Even if they see all the signs, they will not believe in them; and if they see the way of right conduct, they will not adopt it as the way; but if they see the way of error, that is the way they will adopt. For they have rejected our signs, and failed to take warning from them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who reject Our signs and the meeting in the Hereafter,- vain are their deeds: Can they expect to be rewarded except as they have wrought?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
The people of Moses made, in his absence, out of their ornaments, the image of calf, (for worship): it seemed to low: did they not see that it could neither speak to them, nor show them the way? They took it for worship and they did wrong.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
When they repented, and saw that they had erred, they said: ``If our Lord have not mercy upon us and forgive us, we shall indeed be of those who perish."\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
When Moses came back to his people, angry and grieved, he said: ``Evil it is that ye have done in my place in my absence: did ye make haste to bring on the judgment of your Lord?" He put down the tablets, seized his brother by (the hair of) his head, and dragged him to him. Aaron said: ``Son of my mother! the people did indeed reckon me as naught, and went near to slaying me! Make not the enemies rejoice over my misfortune, nor count thou me amongst the people of sin."\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
Moses prayed: ``O my Lord! forgive me and my brother! admit us to Thy mercy! for Thou art the Most Merciful of those who show mercy!"\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Those who took the calf (for worship) will indeed be overwhelmed with wrath from their Lord, and with shame in this life: thus do We recompense those who invent (falsehoods).\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
But those who do wrong but repent thereafter and (truly) believe,- verily thy Lord is thereafter Oft-Forgiving, Most Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
When the anger of Moses was appeased, he took up the tablets: in the writing thereon was guidance and Mercy for such as fear their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moses chose seventy of his people for Our place of meeting: when they were seized with violent quaking, he prayed: ``O my Lord! if it had been Thy will Thou couldst have destroyed, long before, both them and me: wouldst Thou destroy us for the deeds of the foolish ones among us? this is no more than Thy trial: by it Thou causest whom Thou wilt to stray, and Thou leadest whom Thou wilt into the right path. Thou art our Protector: so forgive us and give us Thy mercy; for Thou art the best of those who forgive.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
``And ordain for us that which is good, in this life and in the Hereafter: for we have turned unto Thee." He said: ``With My punishment I visit whom I will; but My mercy extendeth to all things. That (mercy) I shall ordain for those who do right, and practise regular charity, and those who believe in Our signs;-\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
``Those who follow the messenger, the unlettered Prophet, whom they find mentioned in their own (scriptures),- in the law and the Gospel;- for he commands them what is just and forbids them what is evil; he allows them as lawful what is good (and pure) and prohibits them from what is bad (and impure); He releases them from their heavy burdens and from the yokes that are upon them. So it is those who believe in him, honour him, help him, and follow the light which is sent down with him,- it is they who will prosper."\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say: ``O men! I am sent unto you all, as the Messenger of Allah, to Whom belongeth the dominion of the heavens and the earth: there is no god but He: it is He That giveth both life and death. So believe in Allah and His Messenger, the Unlettered Prophet, who believeth in Allah and His words: follow him that (so) ye may be guided."\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
Of the people of Moses there is a section who guide and do justice in the light of truth.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
We divided them into twelve tribes or nations. We directed Moses by inspiration, when his (thirsty) people asked him for water: ``Strike the rock with thy staff": out of it there gushed forth twelve springs: Each group knew its own place for water. We gave them the shade of clouds, and sent down to them manna and quails, (saying): ``Eat of the good things We have provided for you": (but they rebelled); to Us they did no harm, but they harmed their own souls.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And remember it was said to them: ``Dwell in this town and eat therein as ye wish, but say the word of humility and enter the gate in a posture of humility: We shall forgive you your faults; We shall increase (the portion of) those who do good."\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But the transgressors among them changed the word from that which had been given them so we sent on them a plague from heaven. For that they repeatedly transgressed.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
Ask them concerning the town standing close by the sea. Behold! they transgressed in the matter of the Sabbath. For on the day of their Sabbath their fish did come to them, openly holding up their heads, but on the day they had no Sabbath, they came not: thus did We make a trial of them, for they were given to transgression.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
When some of them said: ``Why do ye preach to a people whom Allah will destroy or visit with a terrible punishment?"- said the preachers:" To discharge our duty to your Lord, and perchance they may fear Him."\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
When they disregarded the warnings that had been given them, We rescued those who forbade Evil; but We visited the wrong-doers with a grievous punishment because they were given to transgression.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
When in their insolence they transgressed (all) prohibitions, We said to them: ``Be ye apes, despised and rejected."\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
Behold! thy Lord did declare that He would send against them, to the Day of Judgment, those who would afflict them with grievous penalty. Thy Lord is quick in retribution, but He is also Oft-forgiving, Most Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
We broke them up into sections on this earth. There are among them some that are the righteous, and some that are the opposite. We have tried them with both prosperity and adversity: In order that they might turn (to us).\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
After them succeeded an (evil) generation: They inherited the Book, but they chose (for themselves) the vanities of this world, saying (for excuse): ``(Everything) will be forgiven us." (Even so), if similar vanities came their way, they would (again) seize them. Was not the covenant of the Book taken from them, that they would not ascribe to Allah anything but the truth? and they study what is in the Book. But best for the righteous is the home in the Hereafter. Will ye not understand?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
As to those who hold fast by the Book and establish regular prayer,- never shall We suffer the reward of the righteous to perish.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
When We shook the Mount over them, as if it had been a canopy, and they thought it was going to fall on them (We said): ``Hold firmly to what We have given you, and bring (ever) to remembrance what is therein; perchance ye may fear Allah."\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
When thy Lord drew forth from the Children of Adam - from their loins - their descendants, and made them testify concerning themselves, (saying): ``Am I not your Lord (who cherishes and sustains you)?"- They said: ``Yea! We do testify!" (This), lest ye should say on the Day of Judgment: ``Of this we were never mindful":\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or lest ye should say: ``Our fathers before us may have taken false gods, but we are (their) descendants after them: wilt Thou then destroy us because of the deeds of men who were futile?"\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
Thus do We explain the signs in detail; and perchance they may turn (unto Us).\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
Relate to them the story of the man to whom We sent Our signs, but he passed them by: so Satan followed him up, and he went astray.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
If it had been Our will, We should have elevated him with Our signs; but he inclined to the earth, and followed his own vain desires. His similitude is that of a dog: if you attack him, he lolls out his tongue, or if you leave him alone, he (still) lolls out his tongue. That is the similitude of those who reject Our signs; So relate the story; perchance they may reflect.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil as an example are people who reject Our signs and wrong their own souls.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whom Allah doth guide,- he is on the right path: whom He rejects from His guidance,- such are the persons who perish.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
Many are the Jinns and men we have made for Hell: They have hearts wherewith they understand not, eyes wherewith they see not, and ears wherewith they hear not. They are like cattle,- nay more misguided: for they are heedless (of warning).\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
The most beautiful names belong to Allah: so call on him by them; but shun such men as use profanity in his names: for what they do, they will soon be requited.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
Of those We have created are people who direct (others) with truth. And dispense justice therewith.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
Those who reject Our signs, We shall gradually visit with punishment, in ways they perceive not;\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
Respite will I grant unto them: for My scheme is strong (and unfailing).\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Do they not reflect? Their companion is not seized with madness: he is but a perspicuous warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Do they see nothing in the government of the heavens and the earth and all that Allah hath created? (Do they not see) that it may well be that their terms is nigh drawing to an end? In what message after this will they then believe?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
To such as Allah rejects from His guidance, there can be no guide: He will leave them in their trespasses, wandering in distraction.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask thee about the (final) Hour - when will be its appointed time? Say: ``The knowledge thereof is with my Lord (alone): None but He can reveal as to when it will occur. Heavy were its burden through the heavens and the earth. Only, all of a sudden will it come to you." They ask thee as if thou Wert eager in search thereof: Say: ``The knowledge thereof is with Allah (alone), but most men know not."\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say: ``I have no power over any good or harm to myself except as Allah willeth. If I had knowledge of the unseen, I should have multiplied all good, and no evil should have touched me: I am but a warner, and a bringer of glad tidings to those who have faith."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He Who created you from a single person, and made his mate of like nature, in order that he might dwell with her (in love). When they are united, she bears a light burden and carries it about (unnoticed). When she grows heavy, they both pray to Allah their Lord, (saying): ``If Thou givest us a goodly child, we vow we shall (ever) be grateful."\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He giveth them a goodly child, they ascribe to others a share in the gift they have received: but Allah is exalted high above the partners they ascribe to Him.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they indeed ascribe to Him as partners things that can create nothing, but are themselves created?\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
No aid can they give them, nor can they aid themselves!\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
If ye call them to guidance, they will not obey: For you it is the same whether ye call them or ye hold your peace!\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Verily those whom ye call upon besides Allah are servants like unto you: Call upon them, and let them listen to your prayer, if ye are (indeed) truthful!\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet to walk with? Or hands to lay hold with? Or eyes to see with? Or ears to hear with? Say: ``Call your 'god-partners', scheme (your worst) against me, and give me no respite!\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
``For my Protector is Allah, Who revealed the Book (from time to time), and He will choose and befriend the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
``But those ye call upon besides Him, are unable to help you, and indeed to help themselves."\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
If thou callest them to guidance, they hear not. Thou wilt see them looking at thee, but they see not.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Hold to forgiveness; command what is right; But turn away from the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
If a suggestion from Satan assail thy (mind), seek refuge with Allah; for He heareth and knoweth (all things).\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Those who fear Allah, when a thought of evil from Satan assaults them, bring Allah to remembrance, when lo! they see (aright)!\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
But their brethren (the evil ones) plunge them deeper into error, and never relax (their efforts).\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
If thou bring them not a revelation, they say: ``Why hast thou not got it together?" Say: ``I but follow what is revealed to me from my Lord: this is (nothing but) lights from your Lord, and Guidance, and mercy, for any who have faith."\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
When the Qur'an is read, listen to it with attention, and hold your peace: that ye may receive Mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And do thou (O reader!) Bring thy Lord to remembrance in thy (very) soul, with humility and in reverence, without loudness in words, in the mornings and evenings; and be not thou of those who are unheedful.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Those who are near to thy Lord, disdain not to do Him worship: They celebrate His praises, and prostrate before Him.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask thee concerning (things taken as) spoils of war. Say: ``(such) spoils are at the disposal of Allah and the Messenger: So fear Allah, and keep straight the relations between yourselves: Obey Allah and His Messenger, if ye do believe."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
For, Believers are those who, when Allah is mentioned, feel a tremor in their hearts, and when they hear His signs rehearsed, find their faith strengthened, and put (all) their trust in their Lord;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Who establish regular prayers and spend (freely) out of the gifts We have given them for sustenance:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
Such in truth are the believers: they have grades of dignity with their Lord, and forgiveness, and generous sustenance:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
Just as thy Lord ordered thee out of thy house in truth, even though a party among the Believers disliked it,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with thee concerning the truth after it was made manifest, as if they were being driven to death and they (actually) saw it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
Behold! Allah promised you one of the two (enemy) parties, that it should be yours: Ye wished that the one unarmed should be yours, but Allah willed to justify the Truth according to His words and to cut off the roots of the Unbelievers;-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
That He might justify Truth and prove Falsehood false, distasteful though it be to those in guilt.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
Remember ye implored the assistance of your Lord, and He answered you: ``I will assist you with a thousand of the angels, ranks on ranks."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah made it but a message of hope, and an assurance to your hearts: (in any case) there is no help except from Allah: and Allah is Exalted in Power, Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
Remember He covered you with a sort of drowsiness, to give you calm as from Himself, and he caused rain to descend on you from heaven, to clean you therewith, to remove from you the stain of Satan, to strengthen your hearts, and to plant your feet firmly therewith.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
Remember thy Lord inspired the angels (with the message): ``I am with you: give firmness to the Believers: I will instil terror into the hearts of the Unbelievers: smite ye above their necks and smite all their finger-tips off them."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This because they contended against Allah and His Messenger: If any contend against Allah and His Messenger, Allah is strict in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
Thus (will it be said): ``Taste ye then of the (punishment): for those who resist Allah, is the penalty of the Fire."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O ye who believe! when ye meet the Unbelievers in hostile array, never turn your backs to them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
If any do turn his back to them on such a day - unless it be in a stratagem of war, or to retreat to a troop (of his own)- he draws on himself the wrath of Allah, and his abode is Hell,- an evil refuge (indeed)!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
It is not ye who slew them; it was Allah: when thou threwest (a handful of dust), it was not thy act, but Allah's: in order that He might test the Believers by a gracious trial from Himself: for Allah is He Who heareth and knoweth (all things).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
That, and also because Allah is He Who makes feeble the plans and stratagem of the Unbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
(O Unbelievers!) if ye prayed for victory and judgment, now hath the judgment come to you: if ye desist (from wrong), it will be best for you: if ye return (to the attack), so shall We. Not the least good will your forces be to you even if they were multiplied: for verily Allah is with those who believe!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O ye who believe! Obey Allah and His Messenger, and turn not away from him when ye hear (him speak).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
Nor be like those who say, ``We hear," but listen not:\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
For the worst of beasts in the sight of Allah are the deaf and the dumb,- those who understand not.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
If Allah had found in them any good. He would indeed have made them listen: (As it is), if He had made them listen, they would but have turned back and declined (Faith).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O ye who believe! give your response to Allah and His Messenger, when He calleth you to that which will give you life; and know that Allah cometh in between a man and his heart, and that it is He to Whom ye shall (all) be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear tumult or oppression, which affecteth not in particular (only) those of you who do wrong: and know that Allah is strict in punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
Call to mind when ye were a small (band), despised through the land, and afraid that men might despoil and kidnap you; But He provided a safe asylum for you, strengthened you with His aid, and gave you Good things for sustenance: that ye might be grateful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O ye that believe! betray not the trust of Allah and the Messenger, nor misappropriate knowingly things entrusted to you.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know ye that your possessions and your progeny are but a trial; and that it is Allah with Whom lies your highest reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O ye who believe! if ye fear Allah, He will grant you a criterion (to judge between right and wrong), remove from you (all) evil (that may afflict) you, and forgive you: for Allah is the Lord of grace unbounded.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
Remember how the Unbelievers plotted against thee, to keep thee in bonds, or slay thee, or get thee out (of thy home). They plot and plan, and Allah too plans; but the best of planners is Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
When Our Signs are rehearsed to them, they say: ``We have heard this (before): if we wished, we could say (words) like these: these are nothing but tales of the ancients."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
Remember how they said: ``O Allah if this is indeed the Truth from Thee, rain down on us a shower of stones form the sky, or send us a grievous penalty."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But Allah was not going to send them a penalty whilst thou wast amongst them; nor was He going to send it whilst they could ask for pardon.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
But what plea have they that Allah should not punish them, when they keep out (men) from the sacred Mosque - and they are not its guardians? No men can be its guardians except the righteous; but most of them do not understand.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their prayer at the House (of Allah) is nothing but whistling and clapping of hands: (Its only answer can be), ``Taste ye the penalty because ye blasphemed."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
The Unbelievers spend their wealth to hinder (man) from the path of Allah, and so will they continue to spend; but in the end they will have (only) regrets and sighs; at length they will be overcome: and the Unbelievers will be gathered together to Hell;-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
In order that Allah may separate the impure from the pure, put the impure, one on another, heap them together, and cast them into Hell. They will be the ones to have lost.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to the Unbelievers, if (now) they desist (from Unbelief), their past would be forgiven them; but if they persist, the punishment of those before them is already (a matter of warning for them).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them on until there is no more tumult or oppression, and there prevail justice and faith in Allah altogether and everywhere; but if they cease, verily Allah doth see all that they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
If they refuse, be sure that Allah is your Protector - the best to protect and the best to help.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that out of all the booty that ye may acquire (in war), a fifth share is assigned to Allah,- and to the Messenger, and to near relatives, orphans, the needy, and the wayfarer,- if ye do believe in Allah and in the revelation We sent down to Our servant on the Day of Testing,- the Day of the meeting of the two forces. For Allah hath power over all things.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
Remember ye were on the hither side of the valley, and they on the farther side, and the caravan on lower ground than ye. Even if ye had made a mutual appointment to meet, ye would certainly have failed in the appointment: But (thus ye met), that Allah might accomplish a matter already enacted; that those who died might die after a clear Sign (had been given), and those who lived might live after a Clear Sign (had been given). And verily Allah is He Who heareth and knoweth (all things).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
Remember in thy dream Allah showed them to thee as few: if He had shown them to thee as many, ye would surely have been discouraged, and ye would surely have disputed in (your) decision; but Allah saved (you): for He knoweth well the (secrets) of (all) hearts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
And remember when ye met, He showed them to you as few in your eyes, and He made you appear as contemptible in their eyes: that Allah might accomplish a matter already enacted. For to Allah do all questions go back (for decision).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O ye who believe! When ye meet a force, be firm, and call Allah in remembrance much (and often); that ye may prosper:\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Messenger; and fall into no disputes, lest ye lose heart and your power depart; and be patient and persevering: For Allah is with those who patiently persevere:\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And be not like those who started from their homes insolently and to be seen of men, and to hinder (men) from the path of Allah: For Allah compasseth round about all that they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
Remember Satan made their (sinful) acts seem alluring to them, and said: ``No one among men can overcome you this day, while I am near to you": But when the two forces came in sight of each other, he turned on his heels, and said: ``Lo! I am clear of you; lo! I see what ye see not; Lo! I fear Allah: for Allah is strict in punishment."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
Lo! the hypocrites say, and those in whose hearts is a disease: ``These people,- their religion has misled them." But if any trust in Allah, behold! Allah is Exalted in might, Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
If thou couldst see, when the angels take the souls of the Unbelievers (at death), (How) they smite their faces and their backs, (saying): ``Taste the penalty of the blazing Fire-\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
``Because of (the deeds) which your (own) hands sent forth; for Allah is never unjust to His servants:\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
``(Deeds) after the manner of the people of Pharaoh and of those before them: They rejected the Signs of Allah, and Allah punished them for their crimes: for Allah is Strong, and Strict in punishment:\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
``Because Allah will never change the grace which He hath bestowed on a people until they change what is in their (own) souls: and verily Allah is He Who heareth and knoweth (all things)."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
(Deeds) after the manner of the people of Pharaoh and those before them": They treated as false the Signs of their Lord: so We destroyed them for their crimes, and We drowned the people of Pharaoh: for they were all oppressors and wrong-doers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
For the worst of beasts in the sight of Allah are those who reject Him: They will not believe.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
They are those with whom thou didst make a covenant, but they break their covenant every time, and they have not the fear (of Allah).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
If ye gain the mastery over them in war, disperse, with them, those who follow them, that they may remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If thou fearest treachery from any group, throw back (their covenant) to them, (so as to be) on equal terms: for Allah loveth not the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
Let not the unbelievers think that they can get the better (of the godly): they will never frustrate (them).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
Against them make ready your strength to the utmost of your power, including steeds of war, to strike terror into (the hearts of) the enemies, of Allah and your enemies, and others besides, whom ye may not know, but whom Allah doth know. Whatever ye shall spend in the cause of Allah, shall be repaid unto you, and ye shall not be treated unjustly.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
But if the enemy incline towards peace, do thou (also) incline towards peace, and trust in Allah: for He is One that heareth and knoweth (all things).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
Should they intend to deceive thee,- verily Allah sufficeth thee: He it is That hath strengthened thee with His aid and with (the company of) the Believers;\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And (moreover) He hath put affection between their hearts: not if thou hadst spent all that is in the earth, couldst thou have produced that affection, but Allah hath done it: for He is Exalted in might, Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet! sufficient unto thee is Allah,- (unto thee) and unto those who follow thee among the Believers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet! rouse the Believers to the fight. If there are twenty amongst you, patient and persevering, they will vanquish two hundred: if a hundred, they will vanquish a thousand of the Unbelievers: for these are a people without understanding.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
For the present, Allah hath lightened your (task), for He knoweth that there is a weak spot in you: But (even so), if there are a hundred of you, patient and persevering, they will vanquish two hundred, and if a thousand, they will vanquish two thousand, with the leave of Allah: for Allah is with those who patiently persevere.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not fitting for a prophet that he should have prisoners of war until he hath thoroughly subdued the land. Ye look for the temporal goods of this world; but Allah looketh to the Hereafter: And Allah is Exalted in might, Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had it not been for a previous ordainment from Allah, a severe penalty would have reached you for the (ransom) that ye took.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
But (now) enjoy what ye took in war, lawful and good: but fear Allah: for Allah is Oft-forgiving, Most Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! say to those who are captives in your hands: ``If Allah findeth any good in your hearts, He will give you something better than what has been taken from you, and He will forgive you: for Allah is Oft-forgiving, Most Merciful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they have treacherous designs against thee, (O Messenger!), they have already been in treason against Allah, and so hath He given (thee) power over them. And Allah so He Who hath (full) knowledge and wisdom.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Those who believed, and adopted exile, and fought for the Faith, with their property and their persons, in the cause of Allah, as well as those who gave (them) asylum and aid,- these are (all) friends and protectors, one of another. As to those who believed but came not into exile, ye owe no duty of protection to them until they come into exile; but if they seek your aid in religion, it is your duty to help them, except against a people with whom ye have a treaty of mutual alliance. And (remember) Allah seeth all that ye do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
The Unbelievers are protectors, one of another: Unless ye do this, (protect each other), there would be tumult and oppression on earth, and great mischief.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
Those who believe, and adopt exile, and fight for the Faith, in the cause of Allah as well as those who give (them) asylum and aid,- these are (all) in very truth the Believers: for them is the forgiveness of sins and a provision most generous.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who accept Faith subsequently, and adopt exile, and fight for the Faith in your company,- they are of you. But kindred by blood have prior rights against each other in the Book of Allah. Verily Allah is well-acquainted with all things.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen A (declaration) of immunity from Allah and His Messenger, to those of the Pagans with whom ye have contracted mutual alliances:-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
Go ye, then, for four months, backwards and forwards, (as ye will), throughout the land, but know ye that ye cannot frustrate Allah (by your falsehood) but that Allah will cover with shame those who reject Him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And an announcement from Allah and His Messenger, to the people (assembled) on the day of the Great Pilgrimage,- that Allah and His Messenger dissolve (treaty) obligations with the Pagans. If then, ye repent, it were best for you; but if ye turn away, know ye that ye cannot frustrate Allah. And proclaim a grievous penalty to those who reject Faith.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
(But the treaties are) not dissolved with those Pagans with whom ye have entered into alliance and who have not subsequently failed you in aught, nor aided any one against you. So fulfil your engagements with them to the end of their term: for Allah loveth the righteous.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
But when the forbidden months are past, then fight and slay the Pagans wherever ye find them, an seize them, beleaguer them, and lie in wait for them in every stratagem (of war); but if they repent, and establish regular prayers and practise regular charity, then open the way for them: for Allah is Oft-forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
If one amongst the Pagans ask thee for asylum, grant it to him, so that he may hear the word of Allah; and then escort him to where he can be secure. That is because they are men without knowledge.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a league, before Allah and His Messenger, with the Pagans, except those with whom ye made a treaty near the sacred Mosque? As long as these stand true to you, stand ye true to them: for Allah doth love the righteous.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How (can there be such a league), seeing that if they get an advantage over you, they respect not in you the ties either of kinship or of covenant? With (fair words from) their mouths they entice you, but their hearts are averse from you; and most of them are rebellious and wicked.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
The Signs of Allah have they sold for a miserable price, and (many) have they hindered from His way: evil indeed are the deeds they have done.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
In a Believer they respect not the ties either of kinship or of covenant! It is they who have transgressed all bounds.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But (even so), if they repent, establish regular prayers, and practise regular charity,- they are your brethren in Faith: (thus) do We explain the Signs in detail, for those who understand.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they violate their oaths after their covenant, and taunt you for your Faith,- fight ye the chiefs of Unfaith: for their oaths are nothing to them: that thus they may be restrained.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will ye not fight people who violated their oaths, plotted to expel the Messenger, and took the aggressive by being the first (to assault) you? Do ye fear them? Nay, it is Allah Whom ye should more justly fear, if ye believe!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them, and Allah will punish them by your hands, cover them with shame, help you (to victory) over them, heal the breasts of Believers,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And still the indignation of their hearts. For Allah will turn (in mercy) to whom He will; and Allah is All-Knowing, All-Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Or think ye that ye shall be abandoned, as though Allah did not know those among you who strive with might and main, and take none for friends and protectors except Allah, His Messenger, and the (community of) Believers? But Allah is well-acquainted with (all) that ye do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for such as join gods with Allah, to visit or maintain the mosques of Allah while they witness against their own souls to infidelity. The works of such bear no fruit: In Fire shall they dwell.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
The mosques of Allah shall be visited and maintained by such as believe in Allah and the Last Day, establish regular prayers, and practise regular charity, and fear none (at all) except Allah. It is they who are expected to be on true guidance.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do ye make the giving of drink to pilgrims, or the maintenance of the Sacred Mosque, equal to (the pious service of) those who believe in Allah and the Last Day, and strive with might and main in the cause of Allah? They are not comparable in the sight of Allah: and Allah guides not those who do wrong.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believe, and suffer exile and strive with might and main, in Allah's cause, with their goods and their persons, have the highest rank in the sight of Allah: they are the people who will achieve (salvation).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord doth give them glad tidings of a Mercy from Himself, of His good pleasure, and of gardens for them, wherein are delights that endure:\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
They will dwell therein for ever. Verily in Allah's presence is a reward, the greatest (of all).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O ye who believe! take not for protectors your fathers and your brothers if they love infidelity above Faith: if any of you do so, they do wrong.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: If it be that your fathers, your sons, your brothers, your mates, or your kindred; the wealth that ye have gained; the commerce in which ye fear a decline: or the dwellings in which ye delight - are dearer to you than Allah, or His Messenger, or the striving in His cause;- then wait until Allah brings about His decision: and Allah guides not the rebellious.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Assuredly Allah did help you in many battle-fields and on the day of Hunain: Behold! your great numbers elated you, but they availed you naught: the land, for all that it is wide, did constrain you, and ye turned back in retreat.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
But Allah did pour His calm on the Messenger and on the Believers, and sent down forces which ye saw not: He punished the Unbelievers; thus doth He reward those without Faith.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Again will Allah, after this, turn (in mercy) to whom He will: for Allah is Oft-forgiving, Most Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O ye who believe! Truly the Pagans are unclean; so let them not, after this year of theirs, approach the Sacred Mosque. And if ye fear poverty, soon will Allah enrich you, if He wills, out of His bounty, for Allah is All-knowing, All-wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight those who believe not in Allah nor the Last Day, nor hold that forbidden which hath been forbidden by Allah and His Messenger, nor acknowledge the religion of Truth, (even if they are) of the People of the Book, until they pay the Jizya with willing submission, and feel themselves subdued.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews call 'Uzair a son of Allah, and the Christians call Christ the son of Allah. That is a saying from their mouth; (in this) they but imitate what the unbelievers of old used to say. Allah's curse be on them: how they are deluded away from the Truth!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They take their priests and their anchorites to be their lords in derogation of Allah, and (they take as their Lord) Christ the son of Mary; yet they were commanded to worship but One Allah: there is no god but He. Praise and glory to Him: (Far is He) from having the partners they associate (with Him).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
Fain would they extinguish Allah's light with their mouths, but Allah will not allow but that His light should be perfected, even though the Unbelievers may detest (it).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He Who hath sent His Messenger with guidance and the Religion of Truth, to proclaim it over all religion, even though the Pagans may detest (it).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O ye who believe! there are indeed many among the priests and anchorites, who in Falsehood devour the substance of men and hinder (them) from the way of Allah. And there are those who bury gold and silver and spend it not in the way of Allah: announce unto them a most grievous penalty-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On the Day when heat will be produced out of that (wealth) in the fire of Hell, and with it will be branded their foreheads, their flanks, and their backs, their flanks, and their backs.- ``This is the (treasure) which ye buried for yourselves: taste ye, then, the (treasures) ye buried!"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
The number of months in the sight of Allah is twelve (in a year)- so ordained by Him the day He created the heavens and the earth; of them four are sacred: that is the straight usage. So wrong not yourselves therein, and fight the Pagans all together as they fight you all together. But know that Allah is with those who restrain themselves.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
Verily the transposing (of a prohibited month) is an addition to Unbelief: the Unbelievers are led to wrong thereby: for they make it lawful one year, and forbidden another year, in order to adjust the number of months forbidden by Allah and make such forbidden ones lawful. The evil of their course seems pleasing to them. But Allah guideth not those who reject Faith.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O ye who believe! what is the matter with you, that, when ye are asked to go forth in the cause of Allah, ye cling heavily to the earth? Do ye prefer the life of this world to the Hereafter? But little is the comfort of this life, as compared with the Hereafter.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
Unless ye go forth, He will punish you with a grievous penalty, and put others in your place; but Him ye would not harm in the least. For Allah hath power over all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If ye help not (your leader), (it is no matter): for Allah did indeed help him, when the Unbelievers drove him out: he had no more than one companion; they two were in the cave, and he said to his companion, ``Have no fear, for Allah is with us": then Allah sent down His peace upon him, and strengthened him with forces which ye saw not, and humbled to the depths the word of the Unbelievers. But the word of Allah is exalted to the heights: for Allah is Exalted in might, Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Go ye forth, (whether equipped) lightly or heavily, and strive and struggle, with your goods and your persons, in the cause of Allah. That is best for you, if ye (but) knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
If there had been immediate gain (in sight), and the journey easy, they would (all) without doubt have followed thee, but the distance was long, (and weighed) on them. They would indeed swear by Allah, ``If we only could, we should certainly have come out with you": They would destroy their own souls; for Allah doth know that they are certainly lying.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
Allah give thee grace! why didst thou grant them until those who told the truth were seen by thee in a clear light, and thou hadst proved the liars?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day ask thee for no exemption from fighting with their goods and persons. And Allah knoweth well those who do their duty.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
Only those ask thee for exemption who believe not in Allah and the Last Day, and whose hearts are in doubt, so that they are tossed in their doubts to and fro.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
If they had intended to come out, they would certainly have made some preparation therefor; but Allah was averse to their being sent forth; so He made them lag behind, and they were told, ``Sit ye among those who sit (inactive)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
If they had come out with you, they would not have added to your (strength) but only (made for) disorder, hurrying to and fro in your midst and sowing sedition among you, and there would have been some among you who would have listened to them. But Allah knoweth well those who do wrong.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Indeed they had plotted sedition before, and upset matters for thee, until,- the Truth arrived, and the Decree of Allah became manifest much to their disgust.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
Among them is (many) a man who says: ``Grant me exemption and draw me not into trial." Have they not fallen into trial already? and indeed Hell surrounds the Unbelievers (on all sides).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalls thee, it grieves them; but if a misfortune befalls thee, they say, ``We took indeed our precautions beforehand," and they turn away rejoicing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: ``Nothing will happen to us except what Allah has decreed for us: He is our protector": and on Allah let the Believers put their trust.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: ``Can you expect for us (any fate) other than one of two glorious things- (Martyrdom or victory)? But we can expect for you either that Allah will send his punishment from Himself, or by our hands. So wait (expectant); we too will wait with you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: ``Spend (for the cause) willingly or unwillingly: not from you will it be accepted: for ye are indeed a people rebellious and wicked."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
The only reasons why their contributions are not accepted are: that they reject Allah and His Messenger; that they come to prayer without earnestness; and that they offer contributions unwillingly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
Let not their wealth nor their (following in) sons dazzle thee: in reality Allah's plan is to punish them with these things in this life, and that their souls may perish in their (very) denial of Allah.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by Allah that they are indeed of you; but they are not of you: yet they are afraid (to appear in their true colours).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they could find a place to flee to, or caves, or a place of concealment, they would turn straightaway thereto, with an obstinate rush.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And among them are men who slander thee in the matter of (the distribution of) the alms: if they are given part thereof, they are pleased, but if not, behold! they are indignant!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
If only they had been content with what Allah and His Messenger gave them, and had said, ``Sufficient unto us is Allah! Allah and His Messenger will soon give us of His bounty: to Allah do we turn our hopes!" (that would have been the right course).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
Alms are for the poor and the needy, and those employed to administer the (funds); for those whose hearts have been (recently) reconciled (to Truth); for those in bondage and in debt; in the cause of Allah; and for the wayfarer: (thus is it) ordained by Allah, and Allah is full of knowledge and wisdom.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
Among them are men who molest the Prophet and say, ``He is (all) ear." Say, ``He listens to what is best for you: he believes in Allah, has faith in the Believers, and is a Mercy to those of you who believe." But those who molest the Messenger will have a grievous penalty.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
To you they swear by Allah. In order to please you: But it is more fitting that they should please Allah and His Messenger, if they are Believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Know they not that for those who oppose Allah and His Messenger, is the Fire of Hell?- wherein they shall dwell. That is the supreme disgrace.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The Hypocrites are afraid lest a Sura should be sent down about them, showing them what is (really passing) in their hearts. Say: ``Mock ye! But verily Allah will bring to light all that ye fear (should be revealed).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
If thou dost question them, they declare (with emphasis): ``We were only talking idly and in play." Say: ``Was it at Allah, and His Signs, and His Messenger, that ye were mocking?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make ye no excuses: ye have rejected Faith after ye had accepted it. If We pardon some of you, We will punish others amongst you, for that they are in sin.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The Hypocrites, men and women, (have an understanding) with each other: They enjoin evil, and forbid what is just, and are close with their hands. They have forgotten Allah; so He hath forgotten them. Verily the Hypocrites are rebellious and perverse.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah hath promised the Hypocrites men and women, and the rejecters, of Faith, the fire of Hell: Therein shall they dwell: Sufficient is it for them: for them is the curse of Allah, and an enduring punishment,-\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
As in the case of those before you: they were mightier than you in power, and more flourishing in wealth and children. They had their enjoyment of their portion: and ye have of yours, as did those before you; and ye indulge in idle talk as they did. They!- their work are fruitless in this world and in the Hereafter, and they will lose (all spiritual good).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Hath not the story reached them of those before them?- the People of Noah, and 'Ad, and Thamud; the People of Abraham, the men of Midian, and the cities overthrown. To them came their messengers with clear signs. It is not Allah Who wrongs them, but they wrong their own souls.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The Believers, men and women, are protectors one of another: they enjoin what is just, and forbid what is evil: they observe regular prayers, practise regular charity, and obey Allah and His Messenger. On them will Allah pour His mercy: for Allah is Exalted in power, Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah hath promised to Believers, men and women, gardens under which rivers flow, to dwell therein, and beautiful mansions in gardens of everlasting bliss. But the greatest bliss is the good pleasure of Allah: that is the supreme felicity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! strive hard against the unbelievers and the Hypocrites, and be firm against them. Their abode is Hell,- an evil refuge indeed.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing (evil), but indeed they uttered blasphemy, and they did it after accepting Islam; and they meditated a plot which they were unable to carry out: this revenge of theirs was (their) only return for the bounty with which Allah and His Messenger had enriched them! If they repent, it will be best for them; but if they turn back (to their evil ways), Allah will punish them with a grievous penalty in this life and in the Hereafter: They shall have none on earth to protect or help them.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
Amongst them are men who made a covenant with Allah, that if He bestowed on them of His bounty, they would give (largely) in charity, and be truly amongst those who are righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
But when He did bestow of His bounty, they became covetous, and turned back (from their covenant), averse (from its fulfilment).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He hath put as a consequence hypocrisy into their hearts, (to last) till the Day, whereon they shall meet Him: because they broke their covenant with Allah, and because they lied (again and again).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Know they not that Allah doth know their secret (thoughts) and their secret counsels, and that Allah knoweth well all things unseen?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who slander such of the believers as give themselves freely to (deeds of) charity, as well as such as can find nothing to give except the fruits of their labour,- and throw ridicule on them,- Allah will throw back their ridicule on them: and they shall have a grievous penalty.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Whether thou ask for their forgiveness, or not, (their sin is unforgivable): if thou ask seventy times for their forgiveness, Allah will not forgive them: because they have rejected Allah and His Messenger: and Allah guideth not those who are perversely rebellious.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left behind (in the Tabuk expedition) rejoiced in their inaction behind the back of the Messenger of Allah: they hated to strive and fight, with their goods and their persons, in the cause of Allah: they said, ``Go not forth in the heat." Say, ``The fire of Hell is fiercer in heat." If only they could understand!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Let them laugh a little: much will they weep: a recompense for the (evil) that they do.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If, then, Allah bring thee back to any of them, and they ask thy permission to come out (with thee), say: ``Never shall ye come out with me, nor fight an enemy with me: for ye preferred to sit inactive on the first occasion: Then sit ye (now) with those who lag behind."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
Nor do thou ever pray for any of them that dies, nor stand at his grave; for they rejected Allah and His Messenger, and died in a state of perverse rebellion.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
Nor let their wealth nor their (following in) sons dazzle thee: Allah's plan is to punish them with these things in this world, and that their souls may perish in their (very) denial of Allah.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
When a Sura comes down, enjoining them to believe in Allah and to strive and fight along with His Messenger, those with wealth and influence among them ask thee for exemption, and say: ``Leave us (behind): we would be with those who sit (at home)."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They prefer to be with (the women), who remain behind (at home): their hearts are sealed and so they understand not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger, and those who believe with him, strive and fight with their wealth and their persons: for them are (all) good things: and it is they who will prosper.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah hath prepared for them gardens under which rivers flow, to dwell therein: that is the supreme felicity.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And there were, among the desert Arabs (also), men who made excuses and came to claim exemption; and those who were false to Allah and His Messenger (merely) sat inactive. Soon will a grievous penalty seize the Unbelievers among them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no blame on those who are infirm, or ill, or who find no resources to spend (on the cause), if they are sincere (in duty) to Allah and His Messenger: no ground (of complaint) can there be against such as do right: and Allah is Oft-forgiving, Most Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor (is there blame) on those who came to thee to be provided with mounts, and when thou saidst, ``I can find no mounts for you," they turned back, their eyes streaming with tears of grief that they had no resources wherewith to provide the expenses.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The ground (of complaint) is against such as claim exemption while they are rich. They prefer to stay with the (women) who remain behind: Allah hath sealed their hearts; so they know not (What they miss).\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will present their excuses to you when ye return to them. Say thou: ``Present no excuses: we shall not believe you: Allah hath already informed us of the true state of matters concerning you: It is your actions that Allah and His Messenger will observe: in the end will ye be brought back to Him Who knoweth what is hidden and what is open: then will He show you the truth of all that ye did."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear to you by Allah, when ye return to them, that ye may leave them alone. So leave them alone: For they are an abomination, and Hell is their dwelling-place,-a fitting recompense for the (evil) that they did.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear unto you, that ye may be pleased with them but if ye are pleased with them, Allah is not pleased with those who disobey.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The Arabs of the desert are the worst in Unbelief and hypocrisy, and most fitted to be in ignorance of the command which Allah hath sent down to His Messenger: But Allah is All-knowing, All-Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
Some of the desert Arabs look upon their payments as a fine, and watch for disasters for you: on them be the disaster of evil: for Allah is He That heareth and knoweth (all things).\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
But some of the desert Arabs believe in Allah and the Last Day, and look on their payments as pious gifts bringing them nearer to Allah and obtaining the prayers of the Messenger. Aye, indeed they bring them nearer (to Him): soon will Allah admit them to His Mercy: for Allah is Oft-forgiving, Most Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
The vanguard (of Islam)- the first of those who forsook (their homes) and of those who gave them aid, and (also) those who follow them in (all) good deeds,- well-pleased is Allah with them, as are they with Him: for them hath He prepared gardens under which rivers flow, to dwell therein for ever: that is the supreme felicity.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
Certain of the desert Arabs round about you are hypocrites, as well as (desert Arabs) among the Medina folk: they are obstinate in hypocrisy: thou knowest them not: We know them: twice shall We punish them: and in addition shall they be sent to a grievous penalty.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
Others (there are who) have acknowledged their wrong-doings: they have mixed an act that was good with another that was evil. Perhaps Allah will turn unto them (in Mercy): for Allah is Oft-Forgiving, Most Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Of their goods, take alms, that so thou mightest purify and sanctify them; and pray on their behalf. Verily thy prayers are a source of security for them: And Allah is One Who heareth and knoweth.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Know they not that Allah doth accept repentance from His votaries and receives their gifts of charity, and that Allah is verily He, the Oft-Returning, Most Merciful?\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say: ``Work (righteousness): Soon will Allah observe your work, and His Messenger, and the Believers: Soon will ye be brought back to the knower of what is hidden and what is open: then will He show you the truth of all that ye did."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
There are (yet) others, held in suspense for the command of Allah, whether He will punish them, or turn in mercy to them: and Allah is All-Knowing, Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And there are those who put up a mosque by way of mischief and infidelity - to disunite the Believers - and in preparation for one who warred against Allah and His Messenger aforetime. They will indeed swear that their intention is nothing but good; But Allah doth declare that they are certainly liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand thou forth therein. There is a mosque whose foundation was laid from the first day on piety; it is more worthy of the standing forth (for prayer) therein. In it are men who love to be purified; and Allah loveth those who make themselves pure.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Which then is best? - he that layeth his foundation on piety to Allah and His good pleasure? - or he that layeth his foundation on an undermined sand-cliff ready to crumble to pieces? and it doth crumble to pieces with him, into the fire of Hell. And Allah guideth not people that do wrong.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The foundation of those who so build is never free from suspicion and shakiness in their hearts, until their hearts are cut to pieces. And Allah is All-Knowing, Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Allah hath purchased of the believers their persons and their goods; for theirs (in return) is the garden (of Paradise): they fight in His cause, and slay and are slain: a promise binding on Him in truth, through the Law, the Gospel, and the Qur'an: and who is more faithful to his covenant than Allah? then rejoice in the bargain which ye have concluded: that is the achievement supreme.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those that turn (to Allah) in repentance; that serve Him, and praise Him; that wander in devotion to the cause of Allah,: that bow down and prostrate themselves in prayer; that enjoin good and forbid evil; and observe the limit set by Allah;- (These do rejoice). So proclaim the glad tidings to the Believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not fitting, for the Prophet and those who believe, that they should pray for forgiveness for Pagans, even though they be of kin, after it is clear to them that they are companions of the Fire.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And Abraham prayed for his father's forgiveness only because of a promise he had made to him. But when it became clear to him that he was an enemy to Allah, he dissociated himself from him: for Abraham was most tender-hearted, forbearing.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
And Allah will not mislead a people after He hath guided them, in order that He may make clear to them what to fear (and avoid)- for Allah hath knowledge of all things.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Unto Allah belongeth the dominion of the heavens and the earth. He giveth life and He taketh it. Except for Him ye have no protector nor helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Allah turned with favour to the Prophet, the Muhajirs, and the Ansar,- who followed him in a time of distress, after that the hearts of a part of them had nearly swerved (from duty); but He turned to them (also): for He is unto them Most Kind, Most Merciful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
(He turned in mercy also) to the three who were left behind; (they felt guilty) to such a degree that the earth seemed constrained to them, for all its spaciousness, and their (very) souls seemed straitened to them,- and they perceived that there is no fleeing from Allah (and no refuge) but to Himself. Then He turned to them, that they might repent: for Allah is Oft-Returning, Most Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O ye who believe! Fear Allah and be with those who are true (in word and deed).\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It was not fitting for the people of Medina and the Bedouin Arabs of the neighbourhood, to refuse to follow Allah's Messenger, nor to prefer their own lives to his: because nothing could they suffer or do, but was reckoned to their credit as a deed of righteousness,- whether they suffered thirst, or fatigue, or hunger, in the cause of Allah, or trod paths to raise the ire of the Unbelievers, or received any injury whatever from an enemy: for Allah suffereth not the reward to be lost of those who do good;-\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor could they spend anything (for the cause) - small or great- nor cut across a valley, but the deed is inscribed to their credit: that Allah may requite their deed with the best (possible reward).\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
Nor should the Believers all go forth together: if a contingent from every expedition remained behind, they could devote themselves to studies in religion, and admonish the people when they return to them,- that thus they (may learn) to guard themselves (against evil).\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O ye who believe! fight the unbelievers who gird you about, and let them find firmness in you: and know that Allah is with those who fear Him.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
Whenever there cometh down a sura, some of them say: ``Which of you has had His faith increased by it?" Yea, those who believe,- their faith is increased and they do rejoice.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But those in whose hearts is a disease,- it will add doubt to their doubt, and they will die in a state of Unbelief.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
See they not that they are tried every year once or twice? Yet they turn not in repentance, and they take no heed.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
Whenever there cometh down a Sura, they look at each other, (saying), ``Doth anyone see you?" Then they turn aside: Allah hath turned their hearts (from the light); for they are a people that understand not.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Now hath come unto you a Messenger from amongst yourselves: it grieves him that ye should perish: ardently anxious is he over you: to the Believers is he most kind and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
But if they turn away, Say: ``Allah sufficeth me: there is no god but He: On Him is my trust,- He the Lord of the Throne (of Glory) Supreme!"\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen A. L. R. These are the ayats of the Book of Wisdom.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it a matter of wonderment to men that We have sent Our inspiration to a man from among themselves?- that he should warn mankind (of their danger), and give the good news to the Believers that they have before their Lord the lofty rank of truth. (But) say the Unbelievers: ``This is indeed an evident sorcerer!"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Verily your Lord is Allah, who created the heavens and the earth in six days, and is firmly established on the throne (of authority), regulating and governing all things. No intercessor (can plead with Him) except after His leave (hath been obtained). This is Allah your Lord; Him therefore serve ye: will ye not receive admonition?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him will be your return- of all of you. The promise of Allah is true and sure. It is He Who beginneth the process of creation, and repeateth it, that He may reward with justice those who believe and work righteousness; but those who reject Him will have draughts of boiling fluids, and a penalty grievous, because they did reject Him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He Who made the sun to be a shining glory and the moon to be a light (of beauty), and measured out stages for her; that ye might know the number of years and the count (of time). Nowise did Allah create this but in truth and righteousness. (Thus) doth He explain His Signs in detail, for those who understand.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Verily, in the alternation of the night and the day, and in all that Allah hath created, in the heavens and the earth, are signs for those who fear Him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Those who rest not their hope on their meeting with Us, but are pleased and satisfied with the life of the present, and those who heed not Our Signs,-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
Their abode is the Fire, because of the (evil) they earned.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Those who believe, and work righteousness,- their Lord will guide them because of their faith: beneath them will flow rivers in gardens of bliss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
(This will be) their cry therein: ``Glory to Thee, O Allah!" And ``Peace" will be their greeting therein! and the close of their cry will be: ``Praise be to Allah, the Cherisher and Sustainer of the worlds!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
If Allah were to hasten for men the ill (they have earned) as they would fain hasten on the good,- then would their respite be settled at once. But We leave those who rest not their hope on their meeting with Us, in their trespasses, wandering in distraction to and fro.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
When trouble toucheth a man, He crieth unto Us (in all postures)- lying down on his side, or sitting, or standing. But when We have solved his trouble, he passeth on his way as if he had never cried to Us for a trouble that touched him! thus do the deeds of transgressors seem fair in their eyes!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
Generations before you We destroyed when they did wrong: their messengers came to them with clear-signs, but they would not believe! thus do We requite those who sin!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We made you heirs in the land after them, to see how ye would behave!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
But when Our Clear Signs are rehearsed unto them, those who rest not their hope on their meeting with Us, Say: ``Bring us a reading other than this, or change this," Say: ``It is not for me, of my own accord, to change it: I follow naught but what is revealed unto me: if I were to disobey my Lord, I should myself fear the penalty of a Great Day (to come)."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say: ``If Allah had so willed, I should not have rehearsed it to you, nor would He have made it known to you. A whole life-time before this have I tarried amongst you: will ye not then understand?"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who doth more wrong than such as forge a lie against Allah, or deny His Signs? But never will prosper those who sin.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
They serve, besides Allah, things that hurt them not nor profit them, and they say: ``These are our intercessors with Allah." Say: ``Do ye indeed inform Allah of something He knows not, in the heavens or on earth?- Glory to Him! and far is He above the partners they ascribe (to Him)!"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind was but one nation, but differed (later). Had it not been for a word that went forth before from thy Lord, their differences would have been settled between them.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
They say: ``Why is not a sign sent down to him from his Lord?" Say: ``The Unseen is only for Allah (to know), then wait ye: I too will wait with you."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
When We make mankind taste of some mercy after adversity hath touched them, behold! they take to plotting against Our Signs! Say: ``Swifter to plan is Allah!" Verily, Our messengers record all the plots that ye make!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is Who enableth you to traverse through land and sea; so that ye even board ships;- they sail with them with a favourable wind, and they rejoice thereat; then comes a stormy wind and the waves come to them from all sides, and they think they are being overwhelmed: they cry unto Allah, sincerely offering (their) duty unto Him saying, ``If thou dost deliver us from this, we shall truly show our gratitude!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But when he delivereth them, behold! they transgress insolently through the earth in defiance of right! O mankind! your insolence is against your own souls,- an enjoyment of the life of the present: in the end, to Us is your return, and We shall show you the truth of all that ye did.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The likeness of the life of the present is as the rain which We send down from the skies: by its mingling arises the produce of the earth- which provides food for men and animals: (It grows) till the earth is clad with its golden ornaments and is decked out (in beauty): the people to whom it belongs think they have all powers of disposal over it: There reaches it Our command by night or by day, and We make it like a harvest clean-mown, as if it had not flourished only the day before! thus do We explain the Signs in detail for those who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
But Allah doth call to the Home of Peace: He doth guide whom He pleaseth to a way that is straight.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
To those who do right is a goodly (reward)- Yea, more (than in measure)! No darkness nor shame shall cover their faces! they are companions of the garden; they will abide therein (for aye)!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
But those who have earned evil will have a reward of like evil: ignominy will cover their (faces): No defender will they have from (the wrath of) Allah: Their faces will be covered, as it were, with pieces from the depth of the darkness of night: they are companions of the Fire: they will abide therein (for aye)!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
One day shall We gather them all together. Then shall We say to those who joined gods (with Us): ``To your place! ye and those ye joined as 'partners' We shall separate them, and their ``Partners" shall say: ``It was not us that ye worshipped!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
``Enough is Allah for a witness between us and you: we certainly knew nothing of your worship of us!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There will every soul prove (the fruits of) the deeds it sent before: they will be brought back to Allah their rightful Lord, and their invented falsehoods will leave them in the lurch.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say: ``Who is it that sustains you (in life) from the sky and from the earth? or who is it that has power over hearing and sight? And who is it that brings out the living from the dead and the dead from the living? and who is it that rules and regulates all affairs?" They will soon say, ``Allah". Say, ``will ye not then show piety (to Him)?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is Allah, your real Cherisher and Sustainer: apart from truth, what (remains) but error? How then are ye turned away?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus is the word of thy Lord proved true against those who rebel: Verily they will not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: ``Of your 'partners', can any originate creation and repeat it?" Say: ``It is Allah Who originates creation and repeats it: then how are ye deluded away (from the truth)?"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: ``Of your 'partners' is there any that can give any guidance towards truth?" Say: ``It is Allah Who gives guidance towards truth, is then He Who gives guidance to truth more worthy to be followed, or he who finds not guidance (himself) unless he is guided? what then is the matter with you? How judge ye?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
But most of them follow nothing but fancy: truly fancy can be of no avail against truth. Verily Allah is well aware of all that they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
This Qur'an is not such as can be produced by other than Allah; on the contrary it is a confirmation of (revelations) that went before it, and a fuller explanation of the Book - wherein there is no doubt - from the Lord of the worlds.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say, ``He forged it"? say: ``Bring then a Sura like unto it, and call (to your aid) anyone you can besides Allah, if it be ye speak the truth!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Nay, they charge with falsehood that whose knowledge they cannot compass, even before the elucidation thereof hath reached them: thus did those before them make charges of falsehood: but see what was the end of those who did wrong!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
Of them there are some who believe therein, and some who do not: and thy Lord knoweth best those who are out for mischief.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
If they charge thee with falsehood, say: ``My work to me, and yours to you! ye are free from responsibility for what I do, and I for what ye do!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
Among them are some who (pretend to) listen to thee: But canst thou make the deaf to hear,- even though they are without understanding?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them are some who look at thee: but canst thou guide the blind,- even though they will not see?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Verily Allah will not deal unjustly with man in aught: It is man that wrongs his own soul.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
One day He will gather them together: (It will be) as if they had tarried but an hour of a day: they will recognise each other: assuredly those will be lost who denied the meeting with Allah and refused to receive true guidance.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We show thee (realised in thy life-time) some part of what We promise them,- or We take thy soul (to Our Mercy) (Before that),- in any case, to Us is their return: ultimately Allah is witness, to all that they do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
To every people (was sent) a messenger: when their messenger comes (before them), the matter will be judged between them with justice, and they will not be wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
They say: ``When will this promise come to pass,- if ye speak the truth?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say: ``I have no power over any harm or profit to myself except as Allah willeth. To every people is a term appointed: when their term is reached, not an hour can they cause delay, nor (an hour) can they advance (it in anticipation)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: ``Do ye see,- if His punishment should come to you by night or by day,- what portion of it would the sinners wish to hasten?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
``Would ye then believe in it at last, when it actually cometh to pass? (It will then be said): 'Ah! now? and ye wanted (aforetime) to hasten it on!'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
``At length will be said to the wrong-doers: 'Taste ye the enduring punishment! ye get but the recompense of what ye earned!'"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
They seek to be informed by thee: ``Is that true?" Say: ``Aye! by my Lord! it is the very truth! and ye cannot frustrate it!"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
Every soul that hath sinned, if it possessed all that is on earth, would fain give it in ransom: They would declare (their) repentance when they see the penalty: but the judgment between them will be with justice, and no wrong will be done unto them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Is it not (the case) that to Allah belongeth whatever is in the heavens and on earth? Is it not (the case) that Allah's promise is assuredly true? Yet most of them understand not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
It is He Who giveth life and who taketh it, and to Him shall ye all be brought back.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind! there hath come to you a direction from your Lord and a healing for the (diseases) in your hearts,- and for those who believe, a guidance and a Mercy.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: ``In the bounty of Allah. And in His Mercy,- in that let them rejoice": that is better than the (wealth) they hoard.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say: ``See ye what things Allah hath sent down to you for sustenance? Yet ye hold forbidden some things thereof and (some things) lawful." Say: ``Hath Allah indeed permitted you, or do ye invent (things) to attribute to Allah?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what think those who invent lies against Allah, of the Day of Judgment? Verily Allah is full of bounty to mankind, but most of them are ungrateful.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
In whatever business thou mayest be, and whatever portion thou mayest be reciting from the Qur'an,- and whatever deed ye (mankind) may be doing,- We are witnesses thereof when ye are deeply engrossed therein. Nor is hidden from thy Lord (so much as) the weight of an atom on the earth or in heaven. And not the least and not the greatest of these things but are recorded in a clear record.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Behold! verily on the friends of Allah there is no fear, nor shall they grieve;\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believe and (constantly) guard against evil;-\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them are glad tidings, in the life of the present and in the Hereafter; no change can there be in the words of Allah. This is indeed the supreme felicity.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
Let not their speech grieve thee: for all power and honour belong to Allah: It is He Who heareth and knoweth (all things).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Behold! verily to Allah belong all creatures, in the heavens and on earth. What do they follow who worship as His ``partners" other than Allah? They follow nothing but fancy, and they do nothing but lie.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is That hath made you the night that ye may rest therein, and the day to make things visible (to you). Verily in this are signs for those who listen (to His Message).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: ``Allah hath begotten a son!" - Glory be to Him! He is self-sufficient! His are all things in the heavens and on earth! No warrant have ye for this! say ye about Allah what ye know not?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: ``Those who invent a lie against Allah will never prosper."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
A little enjoyment in this world!- and then, to Us will be their return, then shall We make them taste the severest penalty for their blasphemies.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
Relate to them the story of Noah. Behold! he said to his people: ``O my people, if it be hard on your (mind) that I should stay (with you) and commemorate the signs of Allah,- yet I put my trust in Allah. Get ye then an agreement about your plan and among your partners, so your plan be on to you dark and dubious. Then pass your sentence on me, and give me no respite.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
``But if ye turn back, (consider): no reward have I asked of you: my reward is only due from Allah, and I have been commanded to be of those who submit to Allah's will (in Islam)."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
They rejected Him, but We delivered him, and those with him, in the Ark, and We made them inherit (the earth), while We overwhelmed in the flood those who rejected Our Signs. Then see what was the end of those who were warned (but heeded not)!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then after him We sent (many) messengers to their peoples: they brought them Clear Signs, but they would not believe what they had already rejected beforehand. Thus do We seal the hearts of the transgressors.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then after them sent We Moses and Aaron to Pharaoh and his chiefs with Our Signs. But they were arrogant: they were a people in sin.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
When the Truth did come to them from Us, they said: ``This is indeed evident sorcery!"\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Said Moses: ``Say ye (this) about the truth when it hath (actually) reached you? Is sorcery (like) this? But sorcerers will not prosper."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: ``Hast thou come to us to turn us away from the ways we found our fathers following,- in order that thou and thy brother may have greatness in the land? But not we shall believe in you!"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
Said Pharaoh: ``Bring me every sorcerer well versed."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
When the sorcerers came, Moses said to them: ``Throw ye what ye (wish) to throw!"\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
When they had had their throw, Moses said: ``What ye have brought is sorcery: Allah will surely make it of no effect: for Allah prospereth not the work of those who make mischief.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
``And Allah by His words doth prove and establish His truth, however much the sinners may hate it!"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But none believed in Moses except some children of his people, because of the fear of Pharaoh and his chiefs, lest they should persecute them; and certainly Pharaoh was mighty on the earth and one who transgressed all bounds.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
Moses said: ``O my people! If ye do (really) believe in Allah, then in Him put your trust if ye submit (your will to His)."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said: ``In Allah do we put out trust. Our Lord! make us not a trial for those who practise oppression;\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
``And deliver us by Thy Mercy from those who reject (Thee)."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
We inspired Moses and his brother with this Message: ``Provide dwellings for your people in Egypt, make your dwellings into places of worship, and establish regular prayers: and give glad tidings to those who believe!"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
Moses prayed: ``Our Lord! Thou hast indeed bestowed on Pharaoh and his chiefs splendour and wealth in the life of the present, and so, Our Lord, they mislead (men) from Thy Path. Deface, our Lord, the features of their wealth, and send hardness to their hearts, so they will not believe until they see the grievous penalty."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
Allah said: ``Accepted is your prayer (O Moses and Aaron)! So stand ye straight, and follow not the path of those who know not."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
We took the Children of Israel across the sea: Pharaoh and his hosts followed them in insolence and spite. At length, when overwhelmed with the flood, he said: ``I believe that there is no god except Him Whom the Children of Israel believe in: I am of those who submit (to Allah in Islam)."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
(It was said to him): ``Ah now!- But a little while before, wast thou in rebellion!- and thou didst mischief (and violence)!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
``This day shall We save thee in the body, that thou mayest be a sign to those who come after thee! but verily, many among mankind are heedless of Our Signs!"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
We settled the Children of Israel in a beautiful dwelling-place, and provided for them sustenance of the best: it was after knowledge had been granted to them, that they fell into schisms. Verily Allah will judge between them as to the schisms amongst them, on the Day of Judgment.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
If thou wert in doubt as to what We have revealed unto thee, then ask those who have been reading the Book from before thee: the Truth hath indeed come to thee from thy Lord: so be in no wise of those in doubt.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
Nor be of those who reject the signs of Allah, or thou shalt be of those who perish.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Those against whom the word of thy Lord hath been verified would not believe-\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every Sign was brought unto them,- until they see (for themselves) the penalty grievous.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Why was there not a single township (among those We warned), which believed,- so its faith should have profited it,- except the people of Jonah? When they believed, We removed from them the penalty of ignominy in the life of the present, and permitted them to enjoy (their life) for a while.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
If it had been thy Lord's will, they would all have believed,- all who are on earth! wilt thou then compel mankind, against their will, to believe!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
No soul can believe, except by the will of Allah, and He will place doubt (or obscurity) on those who will not understand.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: ``Behold all that is in the heavens and on earth"; but neither Signs nor Warners profit those who believe not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Do they then expect (any thing) but (what happened in) the days of the men who passed away before them? Say: ``Wait ye then: for I, too, will wait with you."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
In the end We deliver Our messengers and those who believe: Thus is it fitting on Our part that We should deliver those who believe!\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say: ``O ye men! If ye are in doubt as to my religion, (behold!) I worship not what ye worship, other than Allah! But I worship Allah - Who will take your souls (at death): I am commanded to be (in the ranks) of the Believers,\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
``And further (thus): 'set thy face towards religion with true piety, and never in any wise be of the Unbelievers;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
``'Nor call on any, other than Allah;- Such will neither profit thee nor hurt thee: if thou dost, behold! thou shalt certainly be of those who do wrong.'"\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
If Allah do touch thee with hurt, there is none can remove it but He: if He do design some benefit for thee, there is none can keep back His favour: He causeth it to reach whomsoever of His servants He pleaseth. And He is the Oft-Forgiving, Most Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say: ``O ye men! Now Truth hath reached you from your Lord! those who receive guidance, do so for the good of their own souls; those who stray, do so to their own loss: and I am not (set) over you to arrange your affairs."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
Follow thou the inspiration sent unto thee, and be patient and constant, till Allah do decide: for He is the best to decide.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen A. L. R. (This is) a Book, with verses basic or fundamental (of established meaning), further explained in detail,- from One Who is Wise and Well-acquainted (with all things):\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
(It teacheth) that ye should worship none but Allah. (Say): ``Verily I am (sent) unto you from Him to warn and to bring glad tidings:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
``(And to preach thus), 'Seek ye the forgiveness of your Lord, and turn to Him in repentance; that He may grant you enjoyment, good (and true), for a term appointed, and bestow His abounding grace on all who abound in merit! But if ye turn away, then I fear for you the penalty of a great day:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
'To Allah is your return, and He hath power over all things.'"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Behold! they fold up their hearts, that they may lie hid from Him! Ah even when they cover themselves with their garments, He knoweth what they conceal, and what they reveal: for He knoweth well the (inmost secrets) of the hearts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
There is no moving creature on earth but its sustenance dependeth on Allah: He knoweth the time and place of its definite abode and its temporary deposit: All is in a clear Record.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
He it is Who created the heavens and the earth in six Days - and His Throne was over the waters - that He might try you, which of you is best in conduct. But if thou wert to say to them, ``Ye shall indeed be raised up after death", the Unbelievers would be sure to say, ``This is nothing but obvious sorcery!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
If We delay the penalty for them for a definite term, they are sure to say, ``What keeps it back?" Ah! On the day it (actually) reaches them, nothing will turn it away from them, and they will be completely encircled by that which they used to mock at!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
If We give man a taste of Mercy from Ourselves, and then withdraw it from him, behold! he is in despair and (falls into) blasphemy.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
But if We give him a taste of (Our) favours after adversity hath touched him, he is sure to say, ``All evil has departed from me:" Behold! he falls into exultation and pride.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Not so do those who show patience and constancy, and work righteousness; for them is forgiveness (of sins) and a great reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
Perchance thou mayest (feel the inclination) to give up a part of what is revealed unto thee, and thy heart feeleth straitened lest they say, ``Why is not a treasure sent down unto him, or why does not an angel come down with him?" But thou art there only to warn! It is Allah that arrangeth all affairs!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or they may say, ``He forged it," Say, ``Bring ye then ten suras forged, like unto it, and call (to your aid) whomsoever ye can, other than Allah!- If ye speak the truth!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
``If then they (your false gods) answer not your (call), know ye that this revelation is sent down (replete) with the knowledge of Allah, and that there is no god but He! will ye even then submit (to Islam)?"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Those who desire the life of the present and its glitter,- to them we shall pay (the price of) their deeds therein,- without diminution.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
They are those for whom there is nothing in the Hereafter but the Fire: vain are the designs they frame therein, and of no effect and the deeds that they do!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Can they be (like) those who accept a Clear (Sign) from their Lord, and whom a witness from Himself doth teach, as did the Book of Moses before it,- a guide and a mercy? They believe therein; but those of the Sects that reject it,- the Fire will be their promised meeting-place. Be not then in doubt thereon: for it is the truth from thy Lord: yet many among men do not believe!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
Who doth more wrong than those who invent a life against Allah? They will be turned back to the presence of their Lord, and the witnesses will say, ``These are the ones who lied against their Lord! Behold! the Curse of Allah is on those who do wrong!-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
``Those who would hinder (men) from the path of Allah and would seek in it something crooked: these were they who denied the Hereafter!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
They will in no wise frustrate (His design) on earth, nor have they protectors besides Allah! Their penalty will be doubled! They lost the power to hear, and they did not see!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
They are the ones who have lost their own souls: and the (fancies) they invented have left them in the lurch!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Without a doubt, these are the very ones who will lose most in the Hereafter!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
But those who believe and work righteousness, and humble themselves before their Lord,- They will be companions of the gardens, to dwell therein for aye!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
These two kinds (of men) may be compared to the blind and deaf, and those who can see and hear well. Are they equal when compared? Will ye not then take heed?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
We sent Noah to his people (with a mission): ``I have come to you with a Clear Warning:\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
``That ye serve none but Allah: Verily I do fear for you the penalty of a grievous day."\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
But the chiefs of the Unbelievers among his people said: ``We see (in) thee nothing but a man like ourselves: Nor do we see that any follow thee but the meanest among us, in judgment immature: Nor do we see in you (all) any merit above us: in fact we think ye are liars!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: ``O my people! See ye if (it be that) I have a Clear Sign from my Lord, and that He hath sent Mercy unto me from His own presence, but that the Mercy hath been obscured from your sight? shall we compel you to accept it when ye are averse to it?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
``And O my people! I ask you for no wealth in return: my reward is from none but Allah: But I will not drive away (in contempt) those who believe: for verily they are to meet their Lord, and ye I see are the ignorant ones!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
``And O my people! who would help me against Allah if I drove them away? Will ye not then take heed?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
``I tell you not that with me are the treasures of Allah, nor do I know what is hidden, nor claim I to be an angel. Nor yet do I say, of those whom your eyes do despise that Allah will not grant them (all) that is good: Allah knoweth best what is in their souls: I should, if I did, indeed be a wrong-doer."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: ``O Noah! thou hast disputed with us, and (much) hast thou prolonged the dispute with us: now bring upon us what thou threatenest us with, if thou speakest the truth!?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said: ``Truly, Allah will bring it on you if He wills,- and then, ye will not be able to frustrate it!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
``Of no profit will be my counsel to you, much as I desire to give you (good) counsel, if it be that Allah willeth to leave you astray: He is your Lord! and to Him will ye return!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or do they say, ``He has forged it"? Say: ``If I had forged it, on me were my sin! and I am free of the sins of which ye are guilty!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
It was revealed to Noah: ``None of thy people will believe except those who have believed already! So grieve no longer over their (evil) deeds.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
``But construct an Ark under Our eyes and Our inspiration, and address Me no (further) on behalf of those who are in sin: for they are about to be overwhelmed (in the Flood)."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
Forthwith he (starts) constructing the Ark: Every time that the chiefs of his people passed by him, they threw ridicule on him. He said: ``If ye ridicule us now, we (in our turn) can look down on you with ridicule likewise!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
``But soon will ye know who it is on whom will descend a penalty that will cover them with shame,- on whom will be unloosed a penalty lasting:"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
At length, behold! there came Our command, and the fountains of the earth gushed forth! We said: ``Embark therein, of each kind two, male and female, and your family - except those against whom the word has already gone forth,- and the Believers." but only a few believed with him.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
So he said: ``Embark ye on the Ark, In the name of Allah, whether it move or be at rest! For my Lord is, be sure, Oft-Forgiving, Most Merciful!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
So the Ark floated with them on the waves (towering) like mountains, and Noah called out to his son, who had separated himself (from the rest): ``O my son! embark with us, and be not with the unbelievers!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
The son replied: ``I will betake myself to some mountain: it will save me from the water." Noah said: ``This day nothing can save, from the command of Allah, any but those on whom He hath mercy! ``And the waves came between them, and the son was among those overwhelmed in the Flood.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
Then the word went forth: ``O earth! swallow up thy water, and O sky! Withhold (thy rain)!" and the water abated, and the matter was ended. The Ark rested on Mount Judi, and the word went forth: ``Away with those who do wrong!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah called upon his Lord, and said: ``O my Lord! surely my son is of my family! and Thy promise is true, and Thou art the justest of Judges!"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: ``O Noah! He is not of thy family: For his conduct is unrighteous. So ask not of Me that of which thou hast no knowledge! I give thee counsel, lest thou act like the ignorant!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
Noah said: ``O my Lord! I do seek refuge with Thee, lest I ask Thee for that of which I have no knowledge. And unless thou forgive me and have Mercy on me, I should indeed be lost!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
The word came: ``O Noah! Come down (from the Ark) with peace from Us, and blessing on thee and on some of the peoples (who will spring) from those with thee: but (there will be other) peoples to whom We shall grant their pleasures (for a time), but in the end will a grievous penalty reach them from Us."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
Such are some of the stories of the unseen, which We have revealed unto thee: before this, neither thou nor thy people knew them. So persevere patiently: for the End is for those who are righteous.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
To the 'Ad People (We sent) Hud, one of their own brethren. He said: ``O my people! worship Allah! ye have no other god but Him. (Your other gods) ye do nothing but invent!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
``O my people! I ask of you no reward for this (Message). My reward is from none but Him who created me: Will ye not then understand?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
``And O my people! Ask forgiveness of your Lord, and turn to Him (in repentance): He will send you the skies pouring abundant rain, and add strength to your strength: so turn ye not back in sin!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said: ``O Hud! No Clear (Sign) that hast thou brought us, and we are not the ones to desert our gods on thy word! Nor shall we believe in thee!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
``We say nothing but that (perhaps) some of our gods may have seized thee with imbecility." He said: ``I call Allah to witness, and do ye bear witness, that I am free from the sin of ascribing, to Him,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
``Other gods as partners! so scheme (your worst) against me, all of you, and give me no respite.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
``I put my trust in Allah, My Lord and your Lord! There is not a moving creature, but He hath grasp of its fore-lock. Verily, it is my Lord that is on a straight Path.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
``If ye turn away,- I (at least) have conveyed the Message with which I was sent to you. My Lord will make another people to succeed you, and you will not harm Him in the least. For my Lord hath care and watch over all things."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
So when Our decree issued, We saved Hud and those who believed with him, by (special) Grace from Ourselves: We saved them from a severe penalty.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
Such were the 'Ad People: they rejected the Signs of their Lord and Cherisher; disobeyed His messengers; And followed the command of every powerful, obstinate transgressor.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were pursued by a Curse in this life,- and on the Day of Judgment. Ah! Behold! for the 'Ad rejected their Lord and Cherisher! Ah! Behold! removed (from sight) were 'Ad the people of Hud!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
To the Thamud People (We sent) Salih, one of their own brethren. He said: ``O my people! Worship Allah: ye have no other god but Him. It is He Who hath produced you from the earth and settled you therein: then ask forgiveness of Him, and turn to Him (in repentance): for my Lord is (always) near, ready to answer."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: ``O Salih! thou hast been of us! a centre of our hopes hitherto! dost thou (now) forbid us the worship of what our fathers worshipped? But we are really in suspicious (disquieting) doubt as to that to which thou invitest us."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said: ``O my people! do ye see? if I have a Clear (Sign) from my Lord and He hath sent Mercy unto me from Himself,- who then can help me against Allah if I were to disobey Him? What then would ye add to my (portion) but perdition?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
``And O my people! This she-camel of Allah is a symbol to you: leave her to feed on Allah's (free) earth, and inflict no harm on her, or a swift penalty will seize you!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they did ham-string her. So he said: ``Enjoy yourselves in your homes for three days: (Then will be your ruin): (Behold) there a promise not to be belied!"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
When Our Decree issued, We saved Salih and those who believed with him, by (special) Grace from Ourselves - and from the Ignominy of that day. For thy Lord - He is the Strong One, and able to enforce His Will.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
The (mighty) Blast overtook the wrong-doers, and they lay prostrate in their homes before the morning,-\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never dwelt and flourished there. Ah! Behold! for the Thamud rejected their Lord and Cherisher! Ah! Behold! removed (from sight) were the Thamud!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
There came Our messengers to Abraham with glad tidings. They said, ``Peace!" He answered, ``Peace!" and hastened to entertain them with a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw their hands went not towards the (meal), he felt some mistrust of them, and conceived a fear of them. They said: ``Fear not: We have been sent against the people of Lut."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing (there), and she laughed: But we gave her glad tidings of Isaac, and after him, of Jacob.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said: ``Alas for me! shall I bear a child, seeing I am an old woman, and my husband here is an old man? That would indeed be a wonderful thing!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: ``Dost thou wonder at Allah's decree? The grace of Allah and His blessings on you, o ye people of the house! for He is indeed worthy of all praise, full of all glory!"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
When fear had passed from (the mind of) Abraham and the glad tidings had reached him, he began to plead with us for Lut's people.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
For Abraham was, without doubt, forbearing (of faults), compassionate, and given to look to Allah.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
O Abraham! Seek not this. The decree of thy Lord hath gone forth: for them there cometh a penalty that cannot be turned back!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
When Our messengers came to Lut, he was grieved on their account and felt himself powerless (to protect) them. He said: ``This is a distressful day."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came rushing towards him, and they had been long in the habit of practising abominations. He said: ``O my people! Here are my daughters: they are purer for you (if ye marry)! Now fear Allah, and cover me not with shame about my guests! Is there not among you a single right-minded man?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: ``Well dost thou know we have no need of thy daughters: indeed thou knowest quite well what we want!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: ``Would that I had power to suppress you or that I could betake myself to some powerful support."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
(The Messengers) said: ``O Lut! We are Messengers from thy Lord! By no means shall they reach thee! now travel with thy family while yet a part of the night remains, and let not any of you look back: but thy wife (will remain behind): To her will happen what happens to the people. Morning is their time appointed: Is not the morning nigh?"\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
When Our Decree issued, We turned (the cities) upside down, and rained down on them brimstones hard as baked clay, spread, layer on layer,-\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked as from thy Lord: Nor are they ever far from those who do wrong!\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
To the Madyan People (We sent) Shu'aib, one of their own brethren: he said: ``O my people! worship Allah: Ye have no other god but Him. And give not short measure or weight: I see you in prosperity, but I fear for you the penalty of a day that will compass (you) all round.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
``And O my people! give just measure and weight, nor withhold from the people the things that are their due: commit not evil in the land with intent to do mischief.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
``That which is left you by Allah is best for you, if ye (but) believed! but I am not set over you to keep watch!"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said: ``O Shu'aib! Does thy (religion of) prayer command thee that we leave off the worship which our fathers practised, or that we leave off doing what we like with our property? truly, thou art the one that forbeareth with faults and is right-minded!"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: ``O my people! see ye whether I have a Clear (Sign) from my Lord, and He hath given me sustenance (pure and) good as from Himself? I wish not, in opposition to you, to do that which I forbid you to do. I only desire (your) betterment to the best of my power; and my success (in my task) can only come from Allah. In Him I trust, and unto Him I look.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
``And O my people! let not my dissent (from you) cause you to sin, lest ye suffer a fate similar to that of the people of Noah or of Hud or of Salih, nor are the people of Lut far off from you!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
``But ask forgiveness of your Lord, and turn unto Him (in repentance): For my Lord is indeed full of mercy and loving-kindness."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: ``O Shu'aib! much of what thou sayest we do not understand! In fact among us we see that thou hast no strength! Were it not for thy family, we should certainly have stoned thee! for thou hast among us no great position!"\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: ``O my people! is then my family of more consideration with you than Allah? For ye cast Him away behind your backs (with contempt). But verily my Lord encompasseth on all sides all that ye do!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
``And O my people! Do whatever ye can: I will do (my part): Soon will ye know who it is on whom descends the penalty of ignominy; and who is a liar! and watch ye! for I too am watching with you!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
When Our decree issued, We saved Shu'aib and those who believed with him, by (special) mercy from Ourselves: But the (mighty) blast did seize the wrong-doers, and they lay prostrate in their homes by the morning,-\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As if they had never dwelt and flourished there! Ah! Behold! How the Madyan were removed (from sight) as were removed the Thamud!\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And we sent Moses, with Our Clear (Signs) and an authority manifest,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
Unto Pharaoh and his chiefs: but they followed the command of Pharaoh and the command of Pharaoh was no right (guide).\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will go before his people on the Day of Judgment, and lead them into the Fire (as cattle are led to water): But woeful indeed will be the place to which they are led!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
And they are followed by a curse in this (life) and on the Day of Judgment: and woeful is the gift which shall be given (unto them)!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
These are some of the stories of communities which We relate unto thee: of them some are standing, and some have been mown down (by the sickle of time).\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
It was not We that wronged them: They wronged their own souls: the deities, other than Allah, whom they invoked, profited them no whit when there issued the decree of thy Lord: Nor did they add aught (to their lot) but perdition!\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the chastisement of thy Lord when He chastises communities in the midst of their wrong: grievous, indeed, and severe is His chastisement.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
In that is a Sign for those who fear the penalty of the Hereafter: that is a Day for which mankind will be gathered together: that will be a Day of Testimony.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
Nor shall We delay it but for a term appointed.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
The day it arrives, no soul shall speak except by His leave: of those (gathered) some will be wretched and some will be blessed.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
Those who are wretched shall be in the Fire: There will be for them therein (nothing but) the heaving of sighs and sobs:\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
They will dwell therein for all the time that the heavens and the earth endure, except as thy Lord willeth: for thy Lord is the (sure) accomplisher of what He planneth.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And those who are blessed shall be in the Garden: They will dwell therein for all the time that the heavens and the earth endure, except as thy Lord willeth: a gift without break.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
Be not then in doubt as to what these men worship. They worship nothing but what their fathers worshipped before (them): but verily We shall pay them back (in full) their portion without (the least) abatement.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
We certainly gave the Book to Moses, but differences arose therein: had it not been that a word had gone forth before from thy Lord, the matter would have been decided between them, but they are in suspicious doubt concerning it.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And, of a surety, to all will your Lord pay back (in full the recompense) of their deeds: for He knoweth well all that they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
Therefore stand firm (in the straight Path) as thou art commanded,- thou and those who with thee turn (unto Allah); and transgress not (from the Path): for He seeth well all that ye do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And incline not to those who do wrong, or the Fire will seize you; and ye have no protectors other than Allah, nor shall ye be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And establish regular prayers at the two ends of the day and at the approaches of the night: For those things, that are good remove those that are evil: Be that the word of remembrance to those who remember (their Lord):\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be steadfast in patience; for verily Allah will not suffer the reward of the righteous to perish.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
Why were there not, among the generations before you, persons possessed of balanced good sense, prohibiting (men) from mischief in the earth - except a few among them whom We saved (from harm)? But the wrong-doers pursued the enjoyment of the good things of life which were given them, and persisted in sin.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
Nor would thy Lord be the One to destroy communities for a single wrong-doing, if its members were likely to mend.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
If thy Lord had so willed, He could have made mankind one people: but they will not cease to dispute.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except those on whom thy Lord hath bestowed His Mercy: and for this did He create them: and the Word of thy Lord shall be fulfilled: ``I will fill Hell with jinns and men all together."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
All that we relate to thee of the stories of the messengers,- with it We make firm thy heart: in them there cometh to thee the Truth, as well as an exhortation and a message of remembrance to those who believe.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
Say to those who do not believe: ``Do what ever ye can: We shall do our part;\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
``And wait ye! We too shall wait."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
To Allah do belong the unseen (secrets) of the heavens and the earth, and to Him goeth back every affair (for decision): then worship Him, and put thy trust in Him: and thy Lord is not unmindful of aught that ye do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen A. L. R. These are the symbols (or Verses) of the perspicuous Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
We have sent it down as an Arabic Qur'an, in order that ye may learn wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We do relate unto thee the most beautiful of stories, in that We reveal to thee this (portion of the) Qur'an: before this, thou too was among those who knew it not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
Behold! Joseph said to his father: ``O my father! I did see eleven stars and the sun and the moon: I saw them prostrate themselves to me!"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
Said (the father): ``My (dear) little son! relate not thy vision to thy brothers, lest they concoct a plot against thee: for Satan is to man an avowed enemy!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
``Thus will thy Lord choose thee and teach thee the interpretation of stories (and events) and perfect His favour to thee and to the posterity of Jacob - even as He perfected it to thy fathers Abraham and Isaac aforetime! for Allah is full of knowledge and wisdom."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Verily in Joseph and his brethren are signs (or symbols) for seekers (after Truth).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
They said: ``Truly Joseph and his brother are loved more by our father than we: But we are a goodly body! really our father is obviously wandering (in his mind)!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
``Slay ye Joseph or cast him out to some (unknown) land, that so the favour of your father may be given to you alone: (there will be time enough) for you to be righteous after that!"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
Said one of them: ``Slay not Joseph, but if ye must do something, throw him down to the bottom of the well: he will be picked up by some caravan of travellers."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: ``O our father! why dost thou not trust us with Joseph,- seeing we are indeed his sincere well-wishers?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
``Send him with us tomorrow to enjoy himself and play, and we shall take every care of him."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
(Jacob) said: ``Really it saddens me that ye should take him away: I fear lest the wolf should devour him while ye attend not to him."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: ``If the wolf were to devour him while we are (so large) a party, then should we indeed (first) have perished ourselves!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So they did take him away, and they all agreed to throw him down to the bottom of the well: and We put into his heart (this Message): 'Of a surety thou shalt (one day) tell them the truth of this their affair while they know (thee) not'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
Then they came to their father in the early part of the night, weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said: ``O our father! We went racing with one another, and left Joseph with our things; and the wolf devoured him.... But thou wilt never believe us even though we tell the truth."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
They stained his shirt with false blood. He said: ``Nay, but your minds have made up a tale (that may pass) with you, (for me) patience is most fitting: Against that which ye assert, it is Allah (alone) Whose help can be sought"..\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
Then there came a caravan of travellers: they sent their water-carrier (for water), and he let down his bucket (into the well)... He said: ``Ah there! Good news! Here is a (fine) young man!" So they concealed him as a treasure! But Allah knoweth well all that they do!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
The (Brethren) sold him for a miserable price, for a few dirhams counted out: in such low estimation did they hold him!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
The man in Egypt who bought him, said to his wife: ``Make his stay (among us) honourable: may be he will bring us much good, or we shall adopt him as a son." Thus did We establish Joseph in the land, that We might teach him the interpretation of stories (and events). And Allah hath full power and control over His affairs; but most among mankind know it not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
When Joseph attained His full manhood, We gave him power and knowledge: thus do We reward those who do right.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
But she in whose house he was, sought to seduce him from his (true) self: she fastened the doors, and said: ``Now come, thou (dear one)!" He said: ``Allah forbid! truly (thy husband) is my lord! he made my sojourn agreeable! truly to no good come those who do wrong!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And (with passion) did she desire him, and he would have desired her, but that he saw the evidence of his Lord: thus (did We order) that We might turn away from him (all) evil and shameful deeds: for he was one of Our servants, sincere and purified.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
So they both raced each other to the door, and she tore his shirt from the back: they both found her lord near the door. She said: ``What is the (fitting) punishment for one who formed an evil design against thy wife, but prison or a grievous chastisement?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He said: ``It was she that sought to seduce me - from my (true) self." And one of her household saw (this) and bore witness, (thus):- ``If it be that his shirt is rent from the front, then is her tale true, and he is a liar!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
``But if it be that his shirt is torn from the back, then is she the liar, and he is telling the truth!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when he saw his shirt,- that it was torn at the back,- (her husband) said: ``Behold! It is a snare of you women! truly, mighty is your snare!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
``O Joseph, pass this over! (O wife), ask forgiveness for thy sin, for truly thou hast been at fault!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
Ladies said in the City: ``The wife of the (great) 'Aziz is seeking to seduce her slave from his (true) self: Truly hath he inspired her with violent love: we see she is evidently going astray."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
When she heard of their malicious talk, she sent for them and prepared a banquet for them: she gave each of them a knife: and she said (to Joseph), ``Come out before them." When they saw him, they did extol him, and (in their amazement) cut their hands: they said, ``Allah preserve us! no mortal is this! this is none other than a noble angel!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: ``There before you is the man about whom ye did blame me! I did seek to seduce him from his (true) self but he did firmly save himself guiltless!.... and now, if he doth not my bidding, he shall certainly be cast into prison, and (what is more) be of the company of the vilest!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said: ``O my Lord! the prison is more to my liking than that to which they invite me: Unless Thou turn away their snare from me, I should (in my youthful folly) feel inclined towards them and join the ranks of the ignorant."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord hearkened to him (in his prayer), and turned away from him their snare: Verily He heareth and knoweth (all things).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it occurred to the men, after they had seen the signs, (that it was best) to imprison him for a time.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
Now with him there came into the prison two young men. Said one of them: ``I see myself (in a dream) pressing wine." said the other: ``I see myself (in a dream) carrying bread on my head, and birds are eating, thereof." ``Tell us" (they said) ``The truth and meaning thereof: for we see thou art one that doth good (to all)."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: ``Before any food comes (in due course) to feed either of you, I will surely reveal to you the truth and meaning of this ere it befall you: that is part of the (duty) which my Lord hath taught me. I have (I assure you) abandoned the ways of a people that believe not in Allah and that (even) deny the Hereafter.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
``And I follow the ways of my fathers,- Abraham, Isaac, and Jacob; and never could we attribute any partners whatever to Allah: that (comes) of the grace of Allah to us and to mankind: yet most men are not grateful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
``O my two companions of the prison! (I ask you): are many lords differing among themselves better, or the One Allah, Supreme and Irresistible?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
``If not Him, ye worship nothing but names which ye have named,- ye and your fathers,- for which Allah hath sent down no authority: the command is for none but Allah: He hath commanded that ye worship none but Him: that is the right religion, but most men understand not...\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
``O my two companions of the prison! As to one of you, he will pour out the wine for his lord to drink: as for the other, he will hang from the cross, and the birds will eat from off his head. (so) hath been decreed that matter whereof ye twain do enquire"...\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And of the two, to that one whom he consider about to be saved, he said: ``Mention me to thy lord." But Satan made him forget to mention him to his lord: and (Joseph) lingered in prison a few (more) years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
The king (of Egypt) said: ``I do see (in a vision) seven fat kine, whom seven lean ones devour, and seven green ears of corn, and seven (others) withered. O ye chiefs! Expound to me my vision if it be that ye can interpret visions."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: ``A confused medley of dreams: and we are not skilled in the interpretation of dreams."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
But the man who had been released, one of the two (who had been in prison) and who now bethought him after (so long) a space of time, said: ``I will tell you the truth of its interpretation: send ye me (therefore)."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
``O Joseph!" (he said) ``O man of truth! Expound to us (the dream) of seven fat kine whom seven lean ones devour, and of seven green ears of corn and (seven) others withered: that I may return to the people, and that they may understand."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
(Joseph) said: ``For seven years shall ye diligently sow as is your wont: and the harvests that ye reap, ye shall leave them in the ear,- except a little, of which ye shall eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
``Then will come after that (period) seven dreadful (years), which will devour what ye shall have laid by in advance for them,- (all) except a little which ye shall have (specially) guarded.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
``Then will come after that (period) a year in which the people will have abundant water, and in which they will press (wine and oil)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
So the king said: ``Bring ye him unto me." But when the messenger came to him, (Joseph) said: ``Go thou back to thy lord, and ask him, 'What is the state of mind of the ladies who cut their hands'? For my Lord is certainly well aware of their snare."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
(The king) said (to the ladies): ``What was your affair when ye did seek to seduce Joseph from his (true) self?" The ladies said: ``Allah preserve us! no evil know we against him!" Said the 'Aziz's wife: ``Now is the truth manifest (to all): it was I who sought to seduce him from his (true) self: He is indeed of those who are (ever) true (and virtuous).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
``This (say I), in order that He may know that I have never been false to him in his absence, and that Allah will never guide the snare of the false ones.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
``Nor do I absolve my own self (of blame): the (human) soul is certainly prone to evil, unless my Lord do bestow His Mercy: but surely my Lord is Oft-forgiving, Most Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
So the king said: ``Bring him unto me; I will take him specially to serve about my own person." Therefore when he had spoken to him, he said: ``Be assured this day, thou art, before our own presence, with rank firmly established, and fidelity fully proved!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
(Joseph) said: ``Set me over the store-houses of the land: I will indeed guard them, as one that knows (their importance)."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus did We give established power to Joseph in the land, to take possession therein as, when, or where he pleased. We bestow of our Mercy on whom We please, and We suffer not, to be lost, the reward of those who do good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
But verily the reward of the Hereafter is the best, for those who believe, and are constant in righteousness.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
Then came Joseph's brethren: they entered his presence, and he knew them, but they knew him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had furnished them forth with provisions (suitable) for them, he said: ``Bring unto me a brother ye have, of the same father as yourselves, (but a different mother): see ye not that I pay out full measure, and that I do provide the best hospitality?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
``Now if ye bring him not to me, ye shall have no measure (of corn) from me, nor shall ye (even) come near me."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: ``We shall certainly seek to get our wish about him from his father: Indeed we shall do it."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And (Joseph) told his servants to put their stock-in-trade (with which they had bartered) into their saddle-bags, so they should know it only when they returned to their people, in order that they might come back.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
Now when they returned to their father, they said: ``O our father! No more measure of grain shall we get (unless we take our brother): So send our brother with us, that we may get our measure; and we will indeed take every care of him."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said: ``Shall I trust you with him with any result other than when I trusted you with his brother aforetime? But Allah is the best to take care (of him), and He is the Most Merciful of those who show mercy!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
Then when they opened their baggage, they found their stock-in-trade had been returned to them. They said: ``O our father! What (more) can we desire? this our stock-in-trade has been returned to us: so we shall get (more) food for our family; We shall take care of our brother; and add (at the same time) a full camel's load (of grain to our provisions). This is but a small quantity.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
(Jacob) said: ``Never will I send him with you until ye swear a solemn oath to me, in Allah's name, that ye will be sure to bring him back to me unless ye are yourselves hemmed in (and made powerless). And when they had sworn their solemn oath, he said: ``Over all that we say, be Allah the witness and guardian!"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
Further he said: ``O my sons! enter not all by one gate: enter ye by different gates. Not that I can profit you aught against Allah (with my advice): None can command except Allah: On Him do I put my trust: and let all that trust put their trust on Him."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered in the manner their father had enjoined, it did not profit them in the least against (the plan of) Allah: It was but a necessity of Jacob's soul, which he discharged. For he was, by our instruction, full of knowledge (and experience): but most men know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
Now when they came into Joseph's presence, he received his (full) brother to stay with him. He said (to him): ``Behold! I am thy (own) brother; so grieve not at aught of their doings."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
At length when he had furnished them forth with provisions (suitable) for them, he put the drinking cup into his brother's saddle-bag. Then shouted out a crier: ``O ye (in) the caravan! behold! ye are thieves, without doubt!"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They said, turning towards them: ``What is it that ye miss?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said: ``We miss the great beaker of the king; for him who produces it, is (the reward of) a camel load; I will be bound by it."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
(The brothers) said: ``By Allah! well ye know that we came not to make mischief in the land, and we are no thieves!"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
(The Egyptians) said: ``What then shall be the penalty of this, if ye are (proved) to have lied?"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said: ``The penalty should be that he in whose saddle-bag it is found, should be held (as bondman) to atone for the (crime). Thus it is we punish the wrong-doers!"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he began (the search) with their baggage, before (he came to) the baggage of his brother: at length he brought it out of his brother's baggage. Thus did We plan for Joseph. He could not take his brother by the law of the king except that Allah willed it (so). We raise to degrees (of wisdom) whom We please: but over all endued with knowledge is one, the All-Knowing.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said: ``If he steals, there was a brother of his who did steal before (him)." But these things did Joseph keep locked in his heart, revealing not the secrets to them. He (simply) said (to himself): ``Ye are the worse situated; and Allah knoweth best the truth of what ye assert!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: ``O exalted one! Behold! he has a father, aged and venerable, (who will grieve for him); so take one of us in his place; for we see that thou art (gracious) in doing good."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said: ``Allah forbid that we take other than him with whom we found our property: indeed (if we did so), we should be acting wrongfully.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
Now when they saw no hope of his (yielding), they held a conference in private. The leader among them said: ``Know ye not that your father did take an oath from you in Allah's name, and how, before this, ye did fail in your duty with Joseph? Therefore will I not leave this land until my father permits me, or Allah commands me; and He is the best to command.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
``Turn ye back to your father, and say, 'O our father! behold! thy son committed theft! we bear witness only to what we know, and we could not well guard against the unseen!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
``'Ask at the town where we have been and the caravan in which we returned, and (you will find) we are indeed telling the truth.'"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
Jacob said: ``Nay, but ye have yourselves contrived a story (good enough) for you. So patience is most fitting (for me). Maybe Allah will bring them (back) all to me (in the end). For He is indeed full of knowledge and wisdom."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them, and said: ``How great is my grief for Joseph!" And his eyes became white with sorrow, and he fell into silent melancholy.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: ``By Allah! (never) wilt thou cease to remember Joseph until thou reach the last extremity of illness, or until thou die!"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: ``I only complain of my distraction and anguish to Allah, and I know from Allah that which ye know not...\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
``O my sons! go ye and enquire about Joseph and his brother, and never give up hope of Allah's Soothing Mercy: truly no one despairs of Allah's Soothing Mercy, except those who have no faith."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
Then, when they came (back) into (Joseph's) presence they said: ``O exalted one! distress has seized us and our family: we have (now) brought but scanty capital: so pay us full measure, (we pray thee), and treat it as charity to us: for Allah doth reward the charitable."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said: ``Know ye how ye dealt with Joseph and his brother, not knowing (what ye were doing)?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: ``Art thou indeed Joseph?" He said, ``I am Joseph, and this is my brother: Allah has indeed been gracious to us (all): behold, he that is righteous and patient,- never will Allah suffer the reward to be lost, of those who do right."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: ``By Allah! indeed has Allah preferred thee above us, and we certainly have been guilty of sin!"\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said: ``This day let no reproach be (cast) on you: Allah will forgive you, and He is the Most Merciful of those who show mercy!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
``Go with this my shirt, and cast it over the face of my father: he will come to see (clearly). Then come ye (here) to me together with all your family."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
When the caravan left (Egypt), their father said: ``I do indeed scent the presence of Joseph: Nay, think me not a dotard."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said: ``By Allah! truly thou art in thine old wandering mind."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then when the bearer of the good news came, He cast (the shirt) over his face, and he forthwith regained clear sight. He said: ``Did I not say to you, 'I know from Allah that which ye know not?'"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: ``O our father! ask for us forgiveness for our sins, for we were truly at fault."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: ``Soon will I ask my Lord for forgiveness for you: for he is indeed Oft-Forgiving, Most Merciful."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
Then when they entered the presence of Joseph, he provided a home for his parents with himself, and said: ``Enter ye Egypt (all) in safety if it please Allah."\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he raised his parents high on the throne (of dignity), and they fell down in prostration, (all) before him. He said: ``O my father! this is the fulfilment of my vision of old! Allah hath made it come true! He was indeed good to me when He took me out of prison and brought you (all here) out of the desert, (even) after Satan had sown enmity between me and my brothers. Verily my Lord understandeth best the mysteries of all that He planneth to do, for verily He is full of knowledge and wisdom.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
``O my Lord! Thou hast indeed bestowed on me some power, and taught me something of the interpretation of dreams and events,- O Thou Creator of the heavens and the earth! Thou art my Protector in this world and in the Hereafter. Take Thou my soul (at death) as one submitting to Thy will (as a Muslim), and unite me with the righteous."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
Such is one of the stories of what happened unseen, which We reveal by inspiration unto thee; nor wast thou (present) with them then when they concerted their plans together in the process of weaving their plots.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
Yet no faith will the greater part of mankind have, however ardently thou dost desire it.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
And no reward dost thou ask of them for this: it is no less than a message for all creatures.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many Signs in the heavens and the earth do they pass by? Yet they turn (their faces) away from them!\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah without associating (other as partners) with Him!\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they then feel secure from the coming against them of the covering veil of the wrath of Allah,- or of the coming against them of the (final) Hour all of a sudden while they perceive not?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say thou: ``This is my way: I do invite unto Allah,- on evidence clear as the seeing with one's eyes,- I and whoever follows me. Glory to Allah! and never will I join gods with Allah!"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
Nor did We send before thee (as messengers) any but men, whom we did inspire,- (men) living in human habitations. Do they not travel through the earth, and see what was the end of those before them? But the home of the hereafter is best, for those who do right. Will ye not then understand?\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
(Respite will be granted) until, when the messengers give up hope (of their people) and (come to) think that they were treated as liars, there reaches them Our help, and those whom We will are delivered into safety. But never will be warded off our punishment from those who are in sin.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
There is, in their stories, instruction for men endued with understanding. It is not a tale invented, but a confirmation of what went before it,- a detailed exposition of all things, and a guide and a mercy to any such as believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen A. L. M. R. These are the signs (or verses) of the Book: that which hath been revealed unto thee from thy Lord is the Truth; but most men believe not.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
Allah is He Who raised the heavens without any pillars that ye can see; is firmly established on the throne (of authority); He has subjected the sun and the moon (to his Law)! Each one runs (its course) for a term appointed. He doth regulate all affairs, explaining the signs in detail, that ye may believe with certainty in the meeting with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He who spread out the earth, and set thereon mountains standing firm and (flowing) rivers: and fruit of every kind He made in pairs, two and two: He draweth the night as a veil o'er the Day. Behold, verily in these things there are signs for those who consider!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the earth are tracts (diverse though) neighbouring, and gardens of vines and fields sown with corn, and palm trees - growing out of single roots or otherwise: watered with the same water, yet some of them We make more excellent than others to eat. Behold, verily in these things there are signs for those who understand!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
If thou dost marvel (at their want of faith), strange is their saying: ``When we are (actually) dust, shall we indeed then be in a creation renewed?" They are those who deny their Lord! They are those round whose necks will be yokes (of servitude): they will be Companions of the Fire, to dwell therein (for aye)!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They ask thee to hasten on the evil in preference to the good: Yet have come to pass, before them, (many) exemplary punishments! But verily thy Lord is full of forgiveness for mankind for their wrong-doing, and verily thy Lord is (also) strict in punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
And the Unbelievers say: ``Why is not a sign sent down to him from his Lord?" But thou art truly a warner, and to every people a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah doth know what every female (womb) doth bear, by how much the wombs fall short (of their time or number) or do exceed. Every single thing is before His sight, in (due) proportion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
He knoweth the unseen and that which is open: He is the Great, the Most High.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is the same (to Him) whether any of you conceal his speech or declare it openly; whether he lie hid by night or walk forth freely by day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For each (such person) there are (angels) in succession, before and behind him: They guard him by command of Allah. Allah does not change a people's lot unless they change what is in their hearts. But when (once) Allah willeth a people's punishment, there can be no turning it back, nor will they find, besides Him, any to protect.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He Who doth show you the lightning, by way both of fear and of hope: It is He Who doth raise up the clouds, heavy with (fertilising) rain!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
Nay, thunder repeateth His praises, and so do the angels, with awe: He flingeth the loud-voiced thunder-bolts, and therewith He striketh whomsoever He will.. yet these (are the men) who (dare to) dispute about Allah, with the strength of His power (supreme)!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
For Him (alone) is prayer in Truth: any others that they call upon besides Him hear them no more than if they were to stretch forth their hands for water to reach their mouths but it reaches them not: for the prayer of those without Faith is nothing but (futile) wandering (in the mind).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
Whatever beings there are in the heavens and the earth do prostrate themselves to Allah (Acknowledging subjection),- with good-will or in spite of themselves: so do their shadows in the morning and evenings.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say: ``Who is the Lord and Sustainer of the heavens and the earth?" Say: ``(It is) Allah." Say: ``Do ye then take (for worship) protectors other than Him, such as have no power either for good or for harm to themselves?" Say: ``Are the blind equal with those who see? Or the depths of darkness equal with light?" Or do they assign to Allah partners who have created (anything) as He has created, so that the creation seemed to them similar? Say: ``Allah is the Creator of all things: He is the One, the Supreme and Irresistible."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down water from the skies, and the channels flow, each according to its measure: But the torrent bears away to foam that mounts up to the surface. Even so, from that (ore) which they heat in the fire, to make ornaments or utensils therewith, there is a scum likewise. Thus doth Allah (by parables) show forth Truth and Vanity. For the scum disappears like forth cast out; while that which is for the good of mankind remains on the earth. Thus doth Allah set forth parables.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who respond to their Lord, are (all) good things. But those who respond not to Him,- Even if they had all that is in the heavens and on earth, and as much more, (in vain) would they offer it for ransom. For them will the reckoning be terrible: their abode will be Hell,- what a bed of misery!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Is then one who doth know that that which hath been revealed unto thee from thy Lord is the Truth, like one who is blind? It is those who are endued with understanding that receive admonition;-\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfil the covenant of Allah and fail not in their plighted word;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
Those who join together those things which Allah hath commanded to be joined, hold their Lord in awe, and fear the terrible reckoning;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
Those who patiently persevere, seeking the countenance of their Lord; Establish regular prayers; spend, out of (the gifts) We have bestowed for their sustenance, secretly and openly; and turn off Evil with good: for such there is the final attainment of the (eternal) home,-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Gardens of perpetual bliss: they shall enter there, as well as the righteous among their fathers, their spouses, and their offspring: and angels shall enter unto them from every gate (with the salutation):\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
``Peace unto you for that ye persevered in patience! Now how excellent is the final home!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
But those who break the Covenant of Allah, after having plighted their word thereto, and cut asunder those things which Allah has commanded to be joined, and work mischief in the land;- on them is the curse; for them is the terrible home!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah doth enlarge, or grant by (strict) measure, the sustenance (which He giveth) to whomso He pleaseth. (The wordly) rejoice in the life of this world: But the life of this world is but little comfort in the Hereafter.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
The Unbelievers say: ``Why is not a sign sent down to him from his Lord?" Say: ``Truly Allah leaveth, to stray, whom He will; But He guideth to Himself those who turn to Him in penitence,-\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
``Those who believe, and whose hearts find satisfaction in the remembrance of Allah: for without doubt in the remembrance of Allah do hearts find satisfaction.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
``For those who believe and work righteousness, is (every) blessedness, and a beautiful place of (final) return."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus have we sent thee amongst a People before whom (long since) have (other) Peoples (gone and) passed away; in order that thou mightest rehearse unto them what We send down unto thee by inspiration; yet do they reject (Him), the Most Gracious! Say: ``He is my Lord! There is no god but He! On Him is my trust, and to Him do I turn!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
If there were a Qur'an with which mountains were moved, or the earth were cloven asunder, or the dead were made to speak, (this would be the one!) But, truly, the command is with Allah in all things! Do not the Believers know, that, had Allah (so) willed, He could have guided all mankind (to the right)? But the Unbelievers,- never will disaster cease to seize them for their (ill) deeds, or to settle close to their homes, until the promise of Allah come to pass, for, verily, Allah will not fail in His promise.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
Mocked were (many) messengers before thee: but I granted respite to the unbelievers, and finally I punished them: Then how (terrible) was my requital!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is then He who standeth over every soul (and knoweth) all that it doth, (like any others)? And yet they ascribe partners to Allah. Say: ``But name them! is it that ye will inform Him of something he knoweth not on earth, or is it (just) a show of words?" Nay! to those who believe not, their pretence seems pleasing, but they are kept back (thereby) from the path. And those whom Allah leaves to stray, no one can guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is a penalty in the life of this world, but harder, truly, is the penalty of the Hereafter: and defender have they none against Allah.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The parable of the Garden which the righteous are promised!- beneath it flow rivers: perpetual is the enjoyment thereof and the shade therein: such is the end of the Righteous; and the end of Unbelievers in the Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those to whom We have given the Book rejoice at what hath been revealed unto thee: but there are among the clans those who reject a part thereof. Say: ``I am commanded to worship Allah, and not to join partners with Him. Unto Him do I call, and unto Him is my return."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
Thus have We revealed it to be a judgment of authority in Arabic. Wert thou to follow their (vain) desires after the knowledge which hath reached thee, then wouldst thou find neither protector nor defender against Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
We did send messengers before thee, and appointed for them wives and children: and it was never the part of a messenger to bring a sign except as Allah permitted (or commanded). For each period is a Book (revealed).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah doth blot out or confirm what He pleaseth: with Him is the Mother of the Book.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We shall show thee (within thy life-time) part of what we promised them or take to ourselves thy soul (before it is all accomplished),- thy duty is to make (the Message) reach them: it is our part to call them to account.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
See they not that We gradually reduce the land (in their control) from its outlying borders? (Where) Allah commands, there is none to put back His Command: and He is swift in calling to account.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those before them did (also) devise plots; but in all things the master-planning is Allah's He knoweth the doings of every soul: and soon will the Unbelievers know who gets home in the end.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
The Unbelievers say: ``No messenger art thou." Say: ``Enough for a witness between me and you is Allah, and such as have knowledge of the Book."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen A. L. R. A Book which We have revealed unto thee, in order that thou mightest lead mankind out of the depths of darkness into light - by the leave of their Lord - to the Way of (Him) the Exalted in power, worthy of all praise!-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Of Allah, to Whom do belong all things in the heavens and on earth! But alas for the Unbelievers for a terrible penalty (their Unfaith will bring them)!-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who love the life of this world more than the Hereafter, who hinder (men) from the Path of Allah and seek therein something crooked: they are astray by a long distance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
We sent not a messenger except (to teach) in the language of his (own) people, in order to make (things) clear to them. Now Allah leaves straying those whom He pleases and guides whom He pleases: and He is Exalted in power, full of Wisdom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
We sent Moses with Our signs (and the command). ``Bring out thy people from the depths of darkness into light, and teach them to remember the Days of Allah." Verily in this there are Signs for such as are firmly patient and constant,- grateful and appreciative.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
Remember! Moses said to his people: ``Call to mind the favour of Allah to you when He delivered you from the people of Pharaoh: they set you hard tasks and punishments, slaughtered your sons, and let your women-folk live: therein was a tremendous trial from your Lord."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And remember! your Lord caused to be declared (publicly): ``If ye are grateful, I will add more (favours) unto you; But if ye show ingratitude, truly My punishment is terrible indeed."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said: ``If ye show ingratitude, ye and all on earth together, yet is Allah free of all wants, worthy of all praise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has not the story reached you, (O people!), of those who (went) before you? - of the people of Noah, and 'Ad, and Thamud? - And of those who (came) after them? None knows them but Allah. To them came messengers with Clear (Signs); but they put their hands up to their mouths, and said: ``We do deny (the mission) on which ye have been sent, and we are really in suspicious (disquieting) doubt as to that to which ye invite us."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their messengers said: ``Is there a doubt about Allah, The Creator of the heavens and the earth? It is He Who invites you, in order that He may forgive you your sins and give you respite for a term appointed!" They said: ``Ah! ye are no more than human, like ourselves! Ye wish to turn us away from the (gods) our fathers used to worship: then bring us some clear authority."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their messengers said to them: ``True, we are human like yourselves, but Allah doth grant His grace to such of his servants as He pleases. It is not for us to bring you an authority except as Allah permits. And on Allah let all men of faith put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
``No reason have we why we should not put our trust on Allah. Indeed He Has guided us to the Ways we (follow). We shall certainly bear with patience all the hurt you may cause us. For those who put their trust should put their trust on Allah."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And the Unbelievers said to their messengers: ``Be sure we shall drive you out of our land, or ye shall return to our religion." But their Lord inspired (this Message) to them: ``Verily We shall cause the wrong-doers to perish!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
``And verily We shall cause you to abide in the land, and succeed them. This for such as fear the Time when they shall stand before My tribunal,- such as fear the punishment denounced."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
But they sought victory and decision (there and then), and frustration was the lot of every powerful obstinate transgressor.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
In front of such a one is Hell, and he is given, for drink, boiling fetid water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
In gulps will he sip it, but never will he be near swallowing it down his throat: death will come to him from every quarter, yet will he not die: and in front of him will be a chastisement unrelenting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The parable of those who reject their Lord is that their works are as ashes, on which the wind blows furiously on a tempestuous day: No power have they over aught that they have earned: that is the straying far, far (from the goal).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Seest thou not that Allah created the heavens and the earth in Truth? If He so will, He can remove you and put (in your place) a new creation?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
Nor is that for Allah any great matter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
They will all be marshalled before Allah together: then will the weak say to those who were arrogant, ``For us, we but followed you; can ye then avail us to all against the wrath of Allah?" They will reply, ``If we had received the Guidance of Allah, we should have given it to you: to us it makes no difference (now) whether we rage, or bear (these torments) with patience: for ourselves there is no way of escape."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan will say when the matter is decided: ``It was Allah Who gave you a promise of Truth: I too promised, but I failed in my promise to you. I had no authority over you except to call you but ye listened to me: then reproach not me, but reproach your own souls. I cannot listen to your cries, nor can ye listen to mine. I reject your former act in associating me with Allah. For wrong-doers there must be a grievous penalty."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
But those who believe and work righteousness will be admitted to gardens beneath which rivers flow,- to dwell therein for aye with the leave of their Lord. Their greeting therein will be: ``Peace!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Seest thou not how Allah sets forth a parable? - A goodly word like a goodly tree, whose root is firmly fixed, and its branches (reach) to the heavens,- of its Lord. So Allah sets forth parables for men, in order that they may receive admonition.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
It brings forth its fruit at all times, by the leave of its Lord. So Allah sets forth parables for men, in order that they may receive admonition.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the parable of an evil Word is that of an evil tree: It is torn up by the root from the surface of the earth: it has no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah will establish in strength those who believe, with the word that stands firm, in this world and in the Hereafter; but Allah will leave, to stray, those who do wrong: Allah doeth what He willeth.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Hast thou not turned thy vision to those who have changed the favour of Allah. Into blasphemy and caused their people to descend to the House of Perdition?-\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Into Hell? They will burn therein,- an evil place to stay in!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up (idols) as equal to Allah, to mislead (men) from the Path! Say: ``Enjoy (your brief power)! But verily ye are making straightway for Hell!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Speak to my servants who have believed, that they may establish regular prayers, and spend (in charity) out of the sustenance we have given them, secretly and openly, before the coming of a Day in which there will be neither mutual bargaining nor befriending.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
It is Allah Who hath created the heavens and the earth and sendeth down rain from the skies, and with it bringeth out fruits wherewith to feed you; it is He Who hath made the ships subject to you, that they may sail through the sea by His command; and the rivers (also) hath He made subject to you.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He hath made subject to you the sun and the moon, both diligently pursuing their courses; and the night and the day hath he (also) made subject to you.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He giveth you of all that ye ask for. But if ye count the favours of Allah, never will ye be able to number them. Verily, man is given up to injustice and ingratitude.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
Remember Abraham said: ``O my Lord! make this city one of peace and security: and preserve me and my sons from worshipping idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
``O my Lord! they have indeed led astray many among mankind; He then who follows my (ways) is of me, and he that disobeys me,- but Thou art indeed Oft-forgiving, Most Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
``O our Lord! I have made some of my offspring to dwell in a valley without cultivation, by Thy Sacred House; in order, O our Lord, that they may establish regular Prayer: so fill the hearts of some among men with love towards them, and feed them with fruits: so that they may give thanks.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
``O our Lord! truly Thou dost know what we conceal and what we reveal: for nothing whatever is hidden from Allah, whether on earth or in heaven.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
``Praise be to Allah, Who hath granted unto me in old age Isma'il and Isaac: for truly my Lord is He, the Hearer of Prayer!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
O my Lord! make me one who establishes regular Prayer, and also (raise such) among my offspring O our Lord! and accept Thou my Prayer.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
``O our Lord! cover (us) with Thy Forgiveness - me, my parents, and (all) Believers, on the Day that the Reckoning will be established!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Think not that Allah doth not heed the deeds of those who do wrong. He but giveth them respite against a Day when the eyes will fixedly stare in horror,-\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
They running forward with necks outstretched, their heads uplifted, their gaze returning not towards them, and their hearts a (gaping) void!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
So warn mankind of the Day when the Wrath will reach them: then will the wrong-doers say: ``Our Lord! respite us (if only) for a short term: we will answer Thy call, and follow the messengers!" ``What! were ye not wont to swear aforetime that ye should suffer no decline?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
``And ye dwelt in the dwellings of men who wronged their own souls; ye were clearly shown how We dealt with them; and We put forth (many) parables in your behoof!"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
Mighty indeed were the plots which they made, but their plots were (well) within the sight of Allah, even though they were such as to shake the hills!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
Never think that Allah would fail his messengers in His promise: for Allah is Exalted in power, - the Lord of Retribution.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
One day the earth will be changed to a different earth, and so will be the heavens, and (men) will be marshalled forth, before Allah, the One, the Irresistible;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And thou wilt see the sinners that day bound together in fetters;-\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their garments of liquid pitch, and their faces covered with Fire;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That Allah may requite each soul according to its deserts; and verily Allah is swift in calling to account.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
Here is a Message for mankind: Let them take warning therefrom, and let them know that He is (no other than) One Allah: let men of understanding take heed.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen A. L. R. These are the Ayats of Revelation,- of a Qur'an that makes things clear.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Again and again will those who disbelieve, wish that they had bowed (to Allah's will) in Islam.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them alone, to enjoy (the good things of this life) and to please themselves: let (false) hope amuse them: soon will knowledge (undeceive them).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
Never did We destroy a population that had not a term decreed and assigned beforehand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
Neither can a people anticipate its term, nor delay it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
They say: ``O thou to whom the Message is being revealed! truly thou art mad (or possessed)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
``Why bringest thou not angels to us if it be that thou hast the Truth?"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We send not the angels down except for just cause: if they came (to the ungodly), behold! no respite would they have!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
We have, without doubt, sent down the Message; and We will assuredly guard it (from corruption).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
We did send messengers before thee amongst the religious sects of old:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
But never came a messenger to them but they mocked him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Even so do we let it creep into the hearts of the sinners -\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
That they should not believe in the (Message); but the ways of the ancients have passed away.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
Even if We opened out to them a gate from heaven, and they were to continue (all day) ascending therein,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would only say: ``Our eyes have been intoxicated: Nay, we have been bewitched by sorcery."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
It is We Who have set out the zodiacal signs in the heavens, and made them fair-seeming to (all) beholders;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And (moreover) We have guarded them from every cursed devil:\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
But any that gains a hearing by stealth, is pursued by a flaming fire, bright (to see).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth We have spread out (like a carpet); set thereon mountains firm and immovable; and produced therein all kinds of things in due balance.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And We have provided therein means of subsistence,- for you and for those for whose sustenance ye are not responsible.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing but its (sources and) treasures (inexhaustible) are with Us; but We only send down thereof in due and ascertainable measures.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We send the fecundating winds, then cause the rain to descend from the sky, therewith providing you with water (in abundance), though ye are not the guardians of its stores.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And verily, it is We Who give life, and Who give death: it is We Who remain inheritors (after all else passes away).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
To Us are known those of you who hasten forward, and those who lag behind.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
Assuredly it is thy Lord Who will gather them together: for He is perfect in Wisdom and Knowledge.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
We created man from sounding clay, from mud moulded into shape;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the Jinn race, We had created before, from the fire of a scorching wind.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
Behold! thy Lord said to the angels: ``I am about to create man, from sounding clay from mud moulded into shape;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
``When I have fashioned him (in due proportion) and breathed into him of My spirit, fall ye down in obeisance unto him."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels prostrated themselves, all of them together:\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Not so Iblis: he refused to be among those who prostrated themselves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
(Allah) said: ``O Iblis! what is your reason for not being among those who prostrated themselves?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
(Iblis) said: ``I am not one to prostrate myself to man, whom Thou didst create from sounding clay, from mud moulded into shape."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
(Allah) said: ``Then get thee out from here; for thou art rejected, accursed.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
``And the curse shall be on thee till the day of Judgment."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
(Iblis) said: ``O my Lord! give me then respite till the Day the (dead) are raised."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
(Allah) said: ``Respite is granted thee\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
``Till the Day of the Time appointed."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
(Iblis) said: ``O my Lord! because Thou hast put me in the wrong, I will make (wrong) fair-seeming to them on the earth, and I will put them all in the wrong,-\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
``Except Thy servants among them, sincere and purified (by Thy Grace)."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
(Allah) said: ``This (way of My sincere servants) is indeed a way that leads straight to Me.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
``For over My servants no authority shalt thou have, except such as put themselves in the wrong and follow thee."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And verily, Hell is the promised abode for them all!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
To it are seven gates: for each of those gates is a (special) class (of sinners) assigned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
The righteous (will be) amid gardens and fountains (of clear-flowing water).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
(Their greeting will be): ``Enter ye here in peace and security."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We shall remove from their hearts any lurking sense of injury: (they will be) brothers (joyfully) facing each other on thrones (of dignity).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
There no sense of fatigue shall touch them, nor shall they (ever) be asked to leave.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Tell My servants that I am indeed the Oft-forgiving, Most Merciful;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that My Penalty will be indeed the most grievous Penalty.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
Tell them about the guests of Abraham.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered his presence and said, ``Peace!" He said, ``We feel afraid of you!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said: ``Fear not! We give thee glad tidings of a son endowed with wisdom."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said: ``Do ye give me glad tidings that old age has seized me? Of what, then, is your good news?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said: ``We give thee glad tidings in truth: be not then in despair!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said: ``And who despairs of the mercy of his Lord, but such as go astray?"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
Abraham said: ``What then is the business on which ye (have come), O ye messengers (of Allah)?"\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said: ``We have been sent to a people (deep) in sin,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
``Excepting the adherents of Lut: them we are certainly (charged) to save (from harm),- All -\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
``Except his wife, who, We have ascertained, will be among those who will lag behind."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
At length when the messengers arrived among the adherents of Lut,\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said: ``Ye appear to be uncommon folk."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: ``Yea, we have come to thee to accomplish that of which they doubt.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
``We have brought to thee that which is inevitably due, and assuredly we tell the truth.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
``Then travel by night with thy household, when a portion of the night (yet remains), and do thou bring up the rear: let no one amongst you look back, but pass on whither ye are ordered."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We made known this decree to him, that the last remnants of those (sinners) should be cut off by the morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
The inhabitants of the city came in (mad) joy (at news of the young men).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
Lut said: ``These are my guests: disgrace me not:\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
``But fear Allah, and shame me not."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said: ``Did we not forbid thee (to speak) for all and sundry?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said: ``There are my daughters (to marry), if ye must act (so)."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
Verily, by thy life (O Prophet), in their wild intoxication, they wander in distraction, to and fro.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
But the (mighty) Blast overtook them before morning,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We turned (the cities) upside down, and rained down on them brimstones hard as baked clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Behold! in this are Signs for those who by tokens do understand.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And the (cities were) right on the high-road.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Behold! in this is a sign for those who believed.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the Companions of the Wood were also wrong-doers;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So We exacted retribution from them. They were both on an open highway, plain to see.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
The Companions of the Rocky Tract also rejected the messengers:\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
We sent them Our Signs, but they persisted in turning away from them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
Out of the mountains did they hew (their) edifices, (feeling themselves) secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the (mighty) Blast seized them of a morning,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
And of no avail to them was all that they did (with such art and care)!\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We created not the heavens, the earth, and all between them, but for just ends. And the Hour is surely coming (when this will be manifest). So overlook (any human faults) with gracious forgiveness.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
For verily it is thy Lord who is the Master-Creator, knowing all things.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And We have bestowed upon thee the Seven Oft-repeated (verses) and the Grand Qur'an.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Strain not thine eyes. (Wistfully) at what We have bestowed on certain classes of them, nor grieve over them: but lower thy wing (in gentleness) to the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say: ``I am indeed he that warneth openly and without ambiguity,"-\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
(Of just such wrath) as We sent down on those who divided (Scripture into arbitrary parts),-\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
(So also on such) as have made Qur'an into shreds (as they please).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
Therefore, by the Lord, We will, of a surety, call them to account,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
For all their deeds.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Therefore expound openly what thou art commanded, and turn away from those who join false gods with Allah.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
For sufficient are We unto thee against those who scoff,-\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Those who adopt, with Allah, another god: but soon will they come to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
We do indeed know how thy heart is distressed at what they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
But celebrate the praises of thy Lord, and be of those who prostrate themselves in adoration.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And serve thy Lord until there come unto thee the Hour that is Certain.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen (Inevitable) cometh (to pass) the Command of Allah: seek ye not then to hasten it: Glory to Him, and far is He above having the partners they ascribe unto Him!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He doth send down His angels with inspiration of His Command, to such of His servants as He pleaseth, (saying): ``Warn (Man) that there is no god but I: so do your duty unto Me."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He has created the heavens and the earth for just ends: Far is He above having the partners they ascribe to Him!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He has created man from a sperm-drop; and behold this same (man) becomes an open disputer!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And cattle He has created for you (men): from them ye derive warmth, and numerous benefits, and of their (meat) ye eat.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And ye have a sense of pride and beauty in them as ye drive them home in the evening, and as ye lead them forth to pasture in the morning.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they carry your heavy loads to lands that ye could not (otherwise) reach except with souls distressed: for your Lord is indeed Most Kind, Most Merciful,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And (He has created) horses, mules, and donkeys, for you to ride and use for show; and He has created (other) things of which ye have no knowledge.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And unto Allah leads straight the Way, but there are ways that turn aside: if Allah had willed, He could have guided all of you.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He who sends down rain from the sky: from it ye drink, and out of it (grows) the vegetation on which ye feed your cattle.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
With it He produces for you corn, olives, date-palms, grapes and every kind of fruit: verily in this is a sign for those who give thought.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
He has made subject to you the Night and the Day; the sun and the moon; and the stars are in subjection by His Command: verily in this are Signs for men who are wise.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And the things on this earth which He has multiplied in varying colours (and qualities): verily in this is a sign for men who celebrate the praises of Allah (in gratitude).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
It is He Who has made the sea subject, that ye may eat thereof flesh that is fresh and tender, and that ye may extract therefrom ornaments to wear; and thou seest the ships therein that plough the waves, that ye may seek (thus) of the bounty of Allah and that ye may be grateful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He has set up on the earth mountains standing firm, lest it should shake with you; and rivers and roads; that ye may guide yourselves;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And marks and sign-posts; and by the stars (men) guide themselves.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is then He Who creates like one that creates not? Will ye not receive admonition?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
If ye would count up the favours of Allah, never would ye be able to number them: for Allah is Oft-Forgiving, Most Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah doth know what ye conceal, and what ye reveal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those whom they invoke besides Allah create nothing and are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
(They are things) dead, lifeless: nor do they know when they will be raised up.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your Allah is one Allah: as to those who believe not in the Hereafter, their hearts refuse to know, and they are arrogant.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Undoubtedly Allah doth know what they conceal, and what they reveal: verily He loveth not the arrogant.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
When it is said to them, ``What is it that your Lord has revealed?" they say, ``Tales of the ancients!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
Let them bear, on the Day of Judgment, their own burdens in full, and also (something) of the burdens of those without knowledge, whom they misled. Alas, how grievous the burdens they will bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them did also plot (against Allah's Way): but Allah took their structures from their foundations, and the roof fell down on them from above; and the Wrath seized them from directions they did not perceive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then, on the Day of Judgment, He will cover them with shame, and say: ``Where are My 'partners' concerning whom ye used to dispute (with the godly)?" Those endued with knowledge will say: ``This Day, indeed, are the Unbelievers covered with shame and misery,-\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
``(Namely) those whose lives the angels take in a state of wrong-doing to their own souls." Then would they offer submission (with the pretence), ``We did no evil (knowingly)." (The angels will reply), ``Nay, but verily Allah knoweth all that ye did;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
``So enter the gates of Hell, to dwell therein. Thus evil indeed is the abode of the arrogant."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
To the righteous (when) it is said, ``What is it that your Lord has revealed?" they say, ``All that is good." To those who do good, there is good in this world, and the Home of the Hereafter is even better and excellent indeed is the Home of the righteous,-\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Gardens of Eternity which they will enter: beneath them flow (pleasant) rivers: they will have therein all that they wish: thus doth Allah reward the righteous,-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
(Namely) those whose lives the angels take in a state of purity, saying (to them), ``Peace be on you; enter ye the Garden, because of (the good) which ye did (in the world)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Do the (ungodly) wait until the angels come to them, or there comes the Command of thy Lord (for their doom)? So did those who went before them. But Allah wronged them not: nay, they wronged their own souls.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
But the evil results of their deeds overtook them, and that very (Wrath) at which they had scoffed hemmed them in.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
The worshippers of false gods say: ``If Allah had so willed, we should not have worshipped aught but Him - neither we nor our fathers,- nor should we have prescribed prohibitions other than His." So did those who went before them. But what is the mission of messengers but to preach the Clear Message?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
For We assuredly sent amongst every People a messenger, (with the Command), ``Serve Allah, and eschew Evil": of the People were some whom Allah guided, and some on whom error became inevitably (established). So travel through the earth, and see what was the end of those who denied (the Truth).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
If thou art anxious for their guidance, yet Allah guideth not such as He leaves to stray, and there is none to help them.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
They swear their strongest oaths by Allah, that Allah will not raise up those who die: Nay, but it is a promise (binding) on Him in truth: but most among mankind realise it not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
(They must be raised up), in order that He may manifest to them the truth of that wherein they differ, and that the rejecters of Truth may realise that they had indeed (surrendered to) Falsehood.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
For to anything which We have willed, We but say the word, ``Be", and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
To those who leave their homes in the cause of Allah, after suffering oppression,- We will assuredly give a goodly home in this world; but truly the reward of the Hereafter will be greater. If they only realised (this)!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
(They are) those who persevere in patience, and put their trust on their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And before thee also the messengers We sent were but men, to whom We granted inspiration: if ye realise this not, ask of those who possess the Message.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
(We sent them) with Clear Signs and Books of dark prophecies; and We have sent down unto thee (also) the Message; that thou mayest explain clearly to men what is sent for them, and that they may give thought.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do then those who devise evil (plots) feel secure that Allah will not cause the earth to swallow them up, or that the Wrath will not seize them from directions they little perceive?-\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He may not call them to account in the midst of their goings to and fro, without a chance of their frustrating Him?-\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He may not call them to account by a process of slow wastage - for thy Lord is indeed full of kindness and mercy.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Do they not look at Allah's creation, (even) among (inanimate) things,- How their (very) shadows turn round, from the right and the left, prostrating themselves to Allah, and that in the humblest manner?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And to Allah doth obeisance all that is in the heavens and on earth, whether moving (living) creatures or the angels: for none are arrogant (before their Lord).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They all revere their Lord, high above them, and they do all that they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
Allah has said: ``Take not (for worship) two gods: for He is just One Allah: then fear Me (and Me alone)."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs whatever is in the heavens and on earth, and to Him is duty due always: then will ye fear other than Allah?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And ye have no good thing but is from Allah: and moreover, when ye are touched by distress, unto Him ye cry with groans;\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Yet, when He removes the distress from you, behold! some of you turn to other gods to join with their Lord-\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
(As if) to show their ingratitude for the favours we have bestowed on them! then enjoy (your brief day): but soon will ye know (your folly)!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they (even) assign, to things they do not know, a portion out of that which We have bestowed for their sustenance! By Allah, ye shall certainly be called to account for your false inventions.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign daughters for Allah! - Glory be to Him! - and for themselves (sons,- the issue) they desire!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
When news is brought to one of them, of (the birth of) a female (child), his face darkens, and he is filled with inward grief!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
With shame does he hide himself from his people, because of the bad news he has had! Shall he retain it on (sufferance and) contempt, or bury it in the dust? Ah! what an evil (choice) they decide on?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
To those who believe not in the Hereafter, applies the similitude of evil: to Allah applies the highest similitude: for He is the Exalted in Power, full of Wisdom.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
If Allah were to punish men for their wrong-doing, He would not leave, on the (earth), a single living creature: but He gives them respite for a stated Term: When their Term expires, they would not be able to delay (the punishment) for a single hour, just as they would not be able to anticipate it (for a single hour).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They attribute to Allah what they hate (for themselves), and their tongues assert the falsehood that all good things are for themselves: without doubt for them is the Fire, and they will be the first to be hastened on into it!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We (also) sent (Our messengers) to Peoples before thee; but Satan made, (to the wicked), their own acts seem alluring: He is also their patron today, but they shall have a most grievous penalty.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We sent down the Book to thee for the express purpose, that thou shouldst make clear to them those things in which they differ, and that it should be a guide and a mercy to those who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah sends down rain from the skies, and gives therewith life to the earth after its death: verily in this is a Sign for those who listen.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And verily in cattle (too) will ye find an instructive sign. From what is within their bodies between excretions and blood, We produce, for your drink, milk, pure and agreeable to those who drink it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruit of the date-palm and the vine, ye get out wholesome drink and food: behold, in this also is a sign for those who are wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And thy Lord taught the Bee to build its cells in hills, on trees, and in (men's) habitations;\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then to eat of all the produce (of the earth), and find with skill the spacious paths of its Lord: there issues from within their bodies a drink of varying colours, wherein is healing for men: verily in this is a Sign for those who give thought.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
It is Allah who creates you and takes your souls at death; and of you there are some who are sent back to a feeble age, so that they know nothing after having known (much): for Allah is All-Knowing, All-Powerful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
Allah has bestowed His gifts of sustenance more freely on some of you than on others: those more favoured are not going to throw back their gifts to those whom their right hands possess, so as to be equal in that respect. Will they then deny the favours of Allah?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has made for you mates (and companions) of your own nature, and made for you, out of them, sons and daughters and grandchildren, and provided for you sustenance of the best: will they then believe in vain things, and be ungrateful for Allah's favours?-\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And worship others than Allah,- such as have no power of providing them, for sustenance, with anything in heavens or earth, and cannot possibly have such power?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
Invent not similitudes for Allah: for Allah knoweth, and ye know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah sets forth the Parable (of two men: one) a slave under the dominion of another; He has no power of any sort; and (the other) a man on whom We have bestowed goodly favours from Ourselves, and he spends thereof (freely), privately and publicly: are the two equal? (By no means;) praise be to Allah. But most of them understand not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
Allah sets forth (another) Parable of two men: one of them dumb, with no power of any sort; a wearisome burden is he to his master; whichever way be directs him, he brings no good: is such a man equal with one who commands Justice, and is on a Straight Way?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
To Allah belongeth the Mystery of the heavens and the earth. And the Decision of the Hour (of Judgment) is as the twingkling of an eye, or even quicker: for Allah hath power over all things.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
It is He Who brought you forth from the wombs of your mothers when ye knew nothing; and He gave you hearing and sight and intelligence and affections: that ye may give thanks (to Allah).\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Do they not look at the birds, held poised in the midst of (the air and) the sky? Nothing holds them up but (the power of) Allah. Verily in this are signs for those who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
It is Allah Who made your habitations homes of rest and quiet for you; and made for you, out of the skins of animals, (tents for) dwellings, which ye find so light (and handy) when ye travel and when ye stop (in your travels); and out of their wool, and their soft fibres (between wool and hair), and their hair, rich stuff and articles of convenience (to serve you) for a time.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
It is Allah Who made out of the things He created, some things to give you shade; of the hills He made some for your shelter; He made you garments to protect you from heat, and coats of mail to protect you from your (mutual) violence. Thus does He complete His favours on you, that ye may bow to His Will (in Islam).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
But if they turn away, thy duty is only to preach the clear Message.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognise the favours of Allah; then they deny them; and most of them are (creatures) ungrateful.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
One Day We shall raise from all Peoples a Witness: then will no excuse be accepted from Unbelievers, nor will they receive any favours.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
When the wrong-doers (actually) see the Penalty, then will it in no way be mitigated, nor will they then receive respite.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
When those who gave partners to Allah will see their ``partners", they will say: ``Our Lord! these are our 'partners,' those whom we used to invoke besides Thee." But they will throw back their word at them (and say): ``Indeed ye are liars!"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
That Day shall they (openly) show (their) submission to Allah; and all their inventions shall leave them in the lurch.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who reject Allah and hinder (men) from the Path of Allah - for them will We add Penalty to Penalty; for that they used to spread mischief.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
One day We shall raise from all Peoples a witness against them, from amongst themselves: and We shall bring thee as a witness against these (thy people): and We have sent down to thee the Book explaining all things, a Guide, a Mercy, and Glad Tidings to Muslims.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Allah commands justice, the doing of good, and liberality to kith and kin, and He forbids all shameful deeds, and injustice and rebellion: He instructs you, that ye may receive admonition.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
Fulfil the Covenant of Allah when ye have entered into it, and break not your oaths after ye have confirmed them; indeed ye have made Allah your surety; for Allah knoweth all that ye do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And be not like a woman who breaks into untwisted strands the yarn which she has spun, after it has become strong. Nor take your oaths to practise deception between yourselves, lest one party should be more numerous than another: for Allah will test you by this; and on the Day of Judgment He will certainly make clear to you (the truth of) that wherein ye disagree.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
If Allah so willed, He could make you all one people: But He leaves straying whom He pleases, and He guides whom He pleases: but ye shall certainly be called to account for all your actions.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And take not your oaths, to practise deception between yourselves, with the result that someone's foot may slip after it was firmly planted, and ye may have to taste the evil (consequences) of having hindered (men) from the Path of Allah, and a Mighty Wrath descend on you.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
Nor sell the covenant of Allah for a miserable price: for with Allah is (a prize) far better for you, if ye only knew.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
What is with you must vanish: what is with Allah will endure. And We will certainly bestow, on those who patiently persevere, their reward according to the best of their actions.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever works righteousness, man or woman, and has Faith, verily, to him will We give a new Life, a life that is good and pure and We will bestow on such their reward according to the best of their actions.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
When thou dost read the Qur'an, seek Allah's protection from Satan the rejected one.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
No authority has he over those who believe and put their trust in their Lord.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His authority is over those only, who take him as patron and who join partners with Allah.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
When We substitute one revelation for another,- and Allah knows best what He reveals (in stages),- they say, ``Thou art but a forger": but most of them understand not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say, the Holy Spirit has brought the revelation from thy Lord in Truth, in order to strengthen those who believe, and as a Guide and Glad Tidings to Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
We know indeed that they say, ``It is a man that teaches him." The tongue of him they wickedly point to is notably foreign, while this is Arabic, pure and clear.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Those who believe not in the Signs of Allah,- Allah will not guide them, and theirs will be a grievous Penalty.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
It is those who believe not in the Signs of Allah, that forge falsehood: it is they who lie!\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Any one who, after accepting faith in Allah, utters Unbelief,- except under compulsion, his heart remaining firm in Faith - but such as open their breast to Unbelief, on them is Wrath from Allah, and theirs will be a dreadful Penalty.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
This because they love the life of this world better than the Hereafter: and Allah will not guide those who reject Faith.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
Those are they whose hearts, ears, and eyes Allah has sealed up, and they take no heed.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
Without doubt, in the Hereafter they will perish.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
But verily thy Lord,- to those who leave their homes after trials and persecutions,- and who thereafter strive and fight for the faith and patiently persevere,- Thy Lord, after all this is oft-forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
One Day every soul will come up struggling for itself, and every soul will be recompensed (fully) for all its actions, and none will be unjustly dealt with.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
Allah sets forth a Parable: a city enjoying security and quiet, abundantly supplied with sustenance from every place: Yet was it ungrateful for the favours of Allah: so Allah made it taste of hunger and terror (in extremes) (closing in on it) like a garment (from every side), because of the (evil) which (its people) wrought.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And there came to them a Messenger from among themselves, but they falsely rejected him; so the Wrath seized them even in the midst of their iniquities.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of the sustenance which Allah has provided for you, lawful and good; and be grateful for the favours of Allah, if it is He Whom ye serve.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He has only forbidden you dead meat, and blood, and the flesh of swine, and any (food) over which the name of other than Allah has been invoked. But if one is forced by necessity, without wilful disobedience, nor transgressing due limits,- then Allah is Oft-Forgiving, Most Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
But say not - for any false thing that your tongues may put forth,- ``This is lawful, and this is forbidden," so as to ascribe false things to Allah. For those who ascribe false things to Allah, will never prosper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
(In such falsehood) is but a paltry profit; but they will have a most grievous Penalty.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
To the Jews We prohibited such things as We have mentioned to thee before: We did them no wrong, but they were used to doing wrong to themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
But verily thy Lord,- to those who do wrong in ignorance, but who thereafter repent and make amends,- thy Lord, after all this, is Oft-Forgiving, Most Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Abraham was indeed a model, devoutly obedient to Allah, (and) true in Faith, and he joined not gods with Allah:\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
He showed his gratitude for the favours of Allah, who chose him, and guided him to a Straight Way.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him Good in this world, and he will be, in the Hereafter, in the ranks of the Righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
So We have taught thee the inspired (Message), ``Follow the ways of Abraham the True in Faith, and he joined not gods with Allah."\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was only made (strict) for those who disagreed (as to its observance); But Allah will judge between them on the Day of Judgment, as to their differences.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Invite (all) to the Way of thy Lord with wisdom and beautiful preaching; and argue with them in ways that are best and most gracious: for thy Lord knoweth best, who have strayed from His Path, and who receive guidance.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if ye do catch them out, catch them out no worse than they catch you out: But if ye show patience, that is indeed the best (course) for those who are patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And do thou be patient, for thy patience is but from Allah; nor grieve over them: and distress not thyself because of their plots.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
For Allah is with those who restrain themselves, and those who do good.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glory to (Allah) Who did take His servant for a Journey by night from the Sacred Mosque to the farthest Mosque, whose precincts We did bless,- in order that We might show him some of Our Signs: for He is the One Who heareth and seeth (all things).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
We gave Moses the Book, and made it a Guide to the Children of Israel, (commanding): ``Take not other than Me as Disposer of (your) affairs."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
O ye that are sprung from those whom We carried (in the Ark) with Noah! Verily he was a devotee most grateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We gave (Clear) Warning to the Children of Israel in the Book, that twice would they do mischief on the earth and be elated with mighty arrogance (and twice would they be punished)!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
When the first of the warnings came to pass, We sent against you Our servants given to terrible warfare: They entered the very inmost parts of your homes; and it was a warning (completely) fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then did We grant you the Return as against them: We gave you increase in resources and sons, and made you the more numerous in man-power.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
If ye did well, ye did well for yourselves; if ye did evil, (ye did it) against yourselves. So when the second of the warnings came to pass, (We permitted your enemies) to disfigure your faces, and to enter your Temple as they had entered it before, and to visit with destruction all that fell into their power.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
It may be that your Lord may (yet) show Mercy unto you; but if ye revert (to your sins), We shall revert (to Our punishments): And we have made Hell a prison for those who reject (all Faith).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Verily this Qur'an doth guide to that which is most right (or stable), and giveth the Glad Tidings to the Believers who work deeds of righteousness, that they shall have a magnificent reward;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And to those who believe not in the Hereafter, (it announceth) that We have prepared for them a Penalty Grievous (indeed).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
The prayer that man should make for good, he maketh for evil; for man is given to hasty (deeds).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
We have made the Night and the Day as two (of Our) Signs: the Sign of the Night have We obscured, while the Sign of the Day We have made to enlighten you; that ye may seek bounty from your Lord, and that ye may know the number and count of the years: all things have We explained in detail.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
Every man's fate We have fastened on his own neck: On the Day of Judgment We shall bring out for him a scroll, which he will see spread open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
(It will be said to him:) ``Read thine (own) record: Sufficient is thy soul this day to make out an account against thee."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Who receiveth guidance, receiveth it for his own benefit: who goeth astray doth so to his own loss: No bearer of burdens can bear the burden of another: nor would We visit with Our Wrath until We had sent an messenger (to give warning).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
When We decide to destroy a population, We (first) send a definite order to those among them who are given the good things of this life and yet transgress; so that the word is proved true against them: then (it is) We destroy them utterly.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many generations have We destroyed after Noah? and enough is thy Lord to note and see the sins of His servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
If any do wish for the transitory things (of this life), We readily grant them - such things as We will, to such person as We will: in the end have We provided Hell for them: they will burn therein, disgraced and rejected.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
Those who do wish for the (things of) the Hereafter, and strive therefor with all due striving, and have Faith,- they are the ones whose striving is acceptable (to Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
Of the bounties of thy Lord We bestow freely on all- These as well as those: The bounties of thy Lord are not closed (to anyone).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
See how We have bestowed more on some than on others; but verily the Hereafter is more in rank and gradation and more in excellence.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Take not with Allah another object of worship; or thou (O man!) wilt sit in disgrace and destitution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
Thy Lord hath decreed that ye worship none but Him, and that ye be kind to parents. Whether one or both of them attain old age in thy life, say not to them a word of contempt, nor repel them, but address them in terms of honour.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And, out of kindness, lower to them the wing of humility, and say: ``My Lord! bestow on them thy Mercy even as they cherished me in childhood."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knoweth best what is in your hearts: If ye do deeds of righteousness, verily He is Most Forgiving to those who turn to Him again and again (in true penitence).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And render to the kindred their due rights, as (also) to those in want, and to the wayfarer: But squander not (your wealth) in the manner of a spendthrift.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Verily spendthrifts are brothers of the Evil Ones; and the Evil One is to his Lord (himself) ungrateful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And even if thou hast to turn away from them in pursuit of the Mercy from thy Lord which thou dost expect, yet speak to them a word of easy kindness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
Make not thy hand tied (like a niggard's) to thy neck, nor stretch it forth to its utmost reach, so that thou become blameworthy and destitute.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Verily thy Lord doth provide sustenance in abundance for whom He pleaseth, and He provideth in a just measure. For He doth know and regard all His servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
Kill not your children for fear of want: We shall provide sustenance for them as well as for you. Verily the killing of them is a great sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
Nor come nigh to adultery: for it is a shameful (deed) and an evil, opening the road (to other evils).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
Nor take life - which Allah has made sacred - except for just cause. And if anyone is slain wrongfully, we have given his heir authority (to demand qisas or to forgive): but let him not exceed bounds in the matter of taking life; for he is helped (by the Law).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
Come not nigh to the orphan's property except to improve it, until he attains the age of full strength; and fulfil (every) engagement, for (every) engagement will be enquired into (on the Day of Reckoning).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
Give full measure when ye measure, and weigh with a balance that is straight: that is the most fitting and the most advantageous in the final determination.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And pursue not that of which thou hast no knowledge; for every act of hearing, or of seeing or of (feeling in) the heart will be enquired into (on the Day of Reckoning).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
Nor walk on the earth with insolence: for thou canst not rend the earth asunder, nor reach the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
Of all such things the evil is hateful in the sight of thy Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
These are among the (precepts of) wisdom, which thy Lord has revealed to thee. Take not, with Allah, another object of worship, lest thou shouldst be thrown into Hell, blameworthy and rejected.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Has then your Lord (O Pagans!) preferred for you sons, and taken for Himself daughters among the angels? Truly ye utter a most dreadful saying!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
We have explained (things) in various (ways) in this Qur'an, in order that they may receive admonition, but it only increases their flight (from the Truth)!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say: If there had been (other) gods with Him, as they say,- behold, they would certainly have sought out a way to the Lord of the Throne!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Glory to Him! He is high above all that they say!- Exalted and Great (beyond measure)!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth, and all beings therein, declare His glory: there is not a thing but celebrates His praise; And yet ye understand not how they declare His glory! Verily He is Oft-Forbear, Most Forgiving!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
When thou dost recite the Qur'an, We put, between thee and those who believe not in the Hereafter, a veil invisible:\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We put coverings over their hearts (and minds) lest they should understand the Qur'an, and deafness into their ears: when thou dost commemorate thy Lord and Him alone in the Qur'an, they turn on their backs, fleeing (from the Truth).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know best why it is they listen, when they listen to thee; and when they meet in private conference, behold, the wicked say, ``Ye follow none other than a man bewitched!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See what similes they strike for thee: but they have gone astray, and never can they find a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
They say: ``What! when we are reduced to bones and dust, should we really be raised up (to be) a new creation?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say: ``(Nay!) be ye stones or iron,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
``Or created matter which, in your minds, is hardest (to be raised up),- (Yet shall ye be raised up)!" then will they say: ``Who will cause us to return?" Say: ``He who created you first!" Then will they wag their heads towards thee, and say, ``When will that be?" Say, ``May be it will be quite soon!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
``It will be on a Day when He will call you, and ye will answer (His call) with (words of) His praise, and ye will think that ye tarried but a little while!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Say to My servants that they should (only) say those things that are best: for Satan doth sow dissensions among them: For Satan is to man an avowed enemy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
It is your Lord that knoweth you best: If He please, He granteth you mercy, or if He please, punishment: We have not sent thee to be a disposer of their affairs for them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And it is your Lord that knoweth best all beings that are in the heavens and on earth: We did bestow on some prophets more (and other) gifts than on others: and We gave to David (the gift of) the Psalms.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say: ``Call on those - besides Him - whom ye fancy: they have neither the power to remove your troubles from you nor to change them."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they call upon do desire (for themselves) means of access to their Lord, - even those who are nearest: they hope for His Mercy and fear His Wrath: for the Wrath of thy Lord is something to take heed of.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
There is not a population but We shall destroy it before the Day of Judgment or punish it with a dreadful Penalty: that is written in the (eternal) Record.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And We refrain from sending the signs, only because the men of former generations treated them as false: We sent the she-camel to the Thamud to open their eyes, but they treated her wrongfully: We only send the Signs by way of terror (and warning from evil).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
Behold! We told thee that thy Lord doth encompass mankind round about: We granted the vision which We showed thee, but as a trial for men,- as also the Cursed Tree (mentioned) in the Qur'an: We put terror (and warning) into them, but it only increases their inordinate transgression!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
Behold! We said to the angels: ``Bow down unto Adam": They bowed down except Iblis: He said, ``Shall I bow down to one whom Thou didst create from clay?"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said: ``Seest Thou? this is the one whom Thou hast honoured above me! If Thou wilt but respite me to the Day of Judgment, I will surely bring his descendants under my sway - all but a few!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
(Allah) said: ``Go thy way; if any of them follow thee, verily Hell will be the recompense of you (all)- an ample recompense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
``Lead to destruction those whom thou canst among them, with thy (seductive) voice; make assaults on them with thy cavalry and thy infantry; mutually share with them wealth and children; and make promises to them." But Satan promises them nothing but deceit.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
``As for My servants, no authority shalt thou have over them:" Enough is thy Lord for a Disposer of affairs.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He That maketh the Ship go smoothly for you through the sea, in order that ye may seek of his Bounty. For he is unto you most Merciful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
When distress seizes you at sea, those that ye call upon - besides Himself - leave you in the lurch! but when He brings you back safe to land, ye turn away (from Him). Most ungrateful is man!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do ye then feel secure that He will not cause you to be swallowed up beneath the earth when ye are on land, or that He will not send against you a violent tornado (with showers of stones) so that ye shall find no one to carry out your affairs for you?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do ye feel secure that He will not send you back a second time to sea and send against you a heavy gale to drown you because of your ingratitude, so that ye find no helper. Therein against Us?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
We have honoured the sons of Adam; provided them with transport on land and sea; given them for sustenance things good and pure; and conferred on them special favours, above a great part of our creation.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
One day We shall call together all human beings with their (respective) Imams: those who are given their record in their right hand will read it (with pleasure), and they will not be dealt with unjustly in the least.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
But those who were blind in this world, will be blind in the hereafter, and most astray from the Path.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
And their purpose was to tempt thee away from that which We had revealed unto thee, to substitute in our name something quite different; (in that case), behold! they would certainly have made thee (their) friend!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And had We not given thee strength, thou wouldst nearly have inclined to them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
In that case We should have made thee taste an equal portion (of punishment) in this life, and an equal portion in death: and moreover thou wouldst have found none to help thee against Us!\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
Their purpose was to scare thee off the land, in order to expel thee; but in that case they would not have stayed (therein) after thee, except for a little while.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
(This was Our) way with the messengers We sent before thee: thou wilt find no change in Our ways.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish regular prayers - at the sun's decline till the darkness of the night, and the morning prayer and reading: for the prayer and reading in the morning carry their testimony.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And pray in the small watches of the morning: (it would be) an additional prayer (or spiritual profit) for thee: soon will thy Lord raise thee to a Station of Praise and Glory!\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
Say: ``O my Lord! Let my entry be by the Gate of Truth and Honour, and likewise my exit by the Gate of Truth and Honour; and grant me from Thy Presence an authority to aid (me)."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say: ``Truth has (now) arrived, and Falsehood perished: for Falsehood is (by its nature) bound to perish."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
We send down (stage by stage) in the Qur'an that which is a healing and a mercy to those who believe: to the unjust it causes nothing but loss after loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
Yet when We bestow Our favours on man, he turns away and becomes remote on his side (instead of coming to Us), and when evil seizes him he gives himself up to despair!\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say: ``Everyone acts according to his own disposition: But your Lord knows best who it is that is best guided on the Way."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They ask thee concerning the Spirit (of inspiration). Say: ``The Spirit (cometh) by command of my Lord: of knowledge it is only a little that is communicated to you, (O men!)"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
If it were Our Will, We could take away that which We have sent thee by inspiration: then wouldst thou find none to plead thy affair in that matter as against Us,-\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except for Mercy from thy Lord: for his bounty is to thee (indeed) great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: ``If the whole of mankind and Jinns were to gather together to produce the like of this Qur'an, they could not produce the like thereof, even if they backed up each other with help and support.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And We have explained to man, in this Qur'an, every kind of similitude: yet the greater part of men refuse (to receive it) except with ingratitude!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
They say: ``We shall not believe in thee, until thou cause a spring to gush forth for us from the earth,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
``Or (until) thou have a garden of date trees and vines, and cause rivers to gush forth in their midst, carrying abundant water;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
``Or thou cause the sky to fall in pieces, as thou sayest (will happen), against us; or thou bring Allah and the angels before (us) face to face:\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
``Or thou have a house adorned with gold, or thou mount a ladder right into the skies. No, we shall not even believe in thy mounting until thou send down to us a book that we could read." Say: ``Glory to my Lord! Am I aught but a man,- a messenger?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
What kept men back from belief when Guidance came to them, was nothing but this: they said, ``Has Allah sent a man (like us) to be (His) Messenger?"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say, ``If there were settled, on earth, angels walking about in peace and quiet, We should certainly have sent them down from the heavens an angel for a messenger."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: ``Enough is Allah for a witness between me and you: for He is well acquainted with His servants, and He sees (all things).\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
It is he whom Allah guides, that is on true Guidance; but he whom He leaves astray - for such wilt thou find no protector besides Him. On the Day of Judgment We shall gather, them together, prone on their faces, blind, dumb, and deaf: their abode will be Hell: every time it shows abatement, We shall increase from them the fierceness of the Fire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their recompense, because they rejected Our signs, and said, ``When we are reduced to bones and broken dust, should we really be raised up (to be) a new Creation?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
See they not that Allah, Who created the heavens and the earth, has power to create the like of them (anew)? Only He has decreed a term appointed, of which there is no doubt. But the unjust refuse (to receive it) except with ingratitude.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say: ``If ye had control of the Treasures of the Mercy of my Lord, behold, ye would keep them back, for fear of spending them: for man is (every) niggardly!"\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
To Moses We did give Nine Clear Signs: As the Children of Israel: when he came to them, Pharaoh said to him: ``O Moses! I consider thee, indeed, to have been worked upon by sorcery!\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
Moses said, ``Thou knowest well that these things have been sent down by none but the Lord of the heavens and the earth as eye-opening evidence: and I consider thee indeed, O Pharaoh, to be one doomed to destruction!"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
So he resolved to remove them from the face of the earth: but We did drown him and all who were with him.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said thereafter to the Children of Israel, ``Dwell securely in the land (of promise)": but when the second of the warnings came to pass, We gathered you together in a mingled crowd.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
We sent down the (Qur'an) in Truth, and in Truth has it descended: and We sent thee but to give Glad Tidings and to warn (sinners).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
(It is) a Qur'an which We have divided (into parts from time to time), in order that thou mightest recite it to men at intervals: We have revealed it by stages.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say: ``Whether ye believe in it or not, it is true that those who were given knowledge beforehand, when it is recited to them, fall down on their faces in humble prostration,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
``And they say: 'Glory to our Lord! Truly has the promise of our Lord been fulfilled!'"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
They fall down on their faces in tears, and it increases their (earnest) humility.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say: ``Call upon Allah, or call upon Rahman: by whatever name ye call upon Him, (it is well): for to Him belong the Most Beautiful Names. Neither speak thy Prayer aloud, nor speak it in a low tone, but seek a middle course between."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
Say: ``Praise be to Allah, who begets no son, and has no partner in (His) dominion: Nor (needs) He any to protect Him from humiliation: yea, magnify Him for His greatness and glory!"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise be to Allah, Who hath sent to His Servant the Book, and hath allowed therein no Crookedness:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
(He hath made it) Straight (and Clear) in order that He may warn (the godless) of a terrible Punishment from Him, and that He may give Glad Tidings to the Believers who work righteous deeds, that they shall have a goodly Reward,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
Wherein they shall remain for ever:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
Further, that He may warn those (also) who say, ``Allah hath begotten a son":\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
No knowledge have they of such a thing, nor had their fathers. It is a grievous thing that issues from their mouths as a saying what they say is nothing but falsehood!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Thou wouldst only, perchance, fret thyself to death, following after them, in grief, if they believe not in this Message.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
That which is on earth we have made but as a glittering show for the earth, in order that We may test them - as to which of them are best in conduct.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
Verily what is on earth we shall make but as dust and dry soil (without growth or herbage).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Or dost thou reflect that the Companions of the Cave and of the Inscription were wonders among Our Sign?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
Behold, the youths betook themselves to the Cave: they said, ``Our Lord! bestow on us Mercy from Thyself, and dispose of our affair for us in the right way!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Then We draw (a veil) over their ears, for a number of years, in the Cave, (so that they heard not):\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Then We roused them, in order to test which of the two parties was best at calculating the term of years they had tarried!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We relate to thee their story in truth: they were youths who believed in their Lord, and We advanced them in guidance:\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
We gave strength to their hearts: Behold, they stood up and said: ``Our Lord is the Lord of the heavens and of the earth: never shall we call upon any god other than Him: if we did, we should indeed have uttered an enormity!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
``These our people have taken for worship gods other than Him: why do they not bring forward an authority clear (and convincing) for what they do? Who doth more wrong than such as invent a falsehood against Allah?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
``When ye turn away from them and the things they worship other than Allah, betake yourselves to the Cave: Your Lord will shower His mercies on you and disposes of your affair towards comfort and ease."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
Thou wouldst have seen the sun, when it rose, declining to the right from their Cave, and when it set, turning away from them to the left, while they lay in the open space in the midst of the Cave. Such are among the Signs of Allah: He whom Allah, guides is rightly guided; but he whom Allah leaves to stray,- for him wilt thou find no protector to lead him to the Right Way.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
Thou wouldst have deemed them awake, whilst they were asleep, and We turned them on their right and on their left sides: their dog stretching forth his two fore-legs on the threshold: if thou hadst come up on to them, thou wouldst have certainly turned back from them in flight, and wouldst certainly have been filled with terror of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
Such (being their state), we raised them up (from sleep), that they might question each other. Said one of them, ``How long have ye stayed (here)?" They said, ``We have stayed (perhaps) a day, or part of a day." (At length) they (all) said, ``Allah (alone) knows best how long ye have stayed here.... Now send ye then one of you with this money of yours to the town: let him find out which is the best food (to be had) and bring some to you, that (ye may) satisfy your hunger therewith: And let him behave with care and courtesy, and let him not inform any one about you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
``For if they should come upon you, they would stone you or force you to return to their cult, and in that case ye would never attain prosperity."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
Thus did We make their case known to the people, that they might know that the promise of Allah is true, and that there can be no doubt about the Hour of Judgment. Behold, they dispute among themselves as to their affair. (Some) said, ``Construct a building over them": Their Lord knows best about them: those who prevailed over their affair said, ``Let us surely build a place of worship over them."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
(Some) say they were three, the dog being the fourth among them; (others) say they were five, the dog being the sixth,- doubtfully guessing at the unknown; (yet others) say they were seven, the dog being the eighth. Say thou: ``My Lord knoweth best their number; It is but few that know their (real case)." Enter not, therefore, into controversies concerning them, except on a matter that is clear, nor consult any of them about (the affair of) the Sleepers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
Nor say of anything, ``I shall be sure to do so and so tomorrow"-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Without adding, ``So please Allah!" and call thy Lord to mind when thou forgettest, and say, ``I hope that my Lord will guide me ever closer (even) than this to the right road."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
So they stayed in their Cave three hundred years, and (some) add nine (more)\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: ``Allah knows best how long they stayed: with Him is (the knowledge of) the secrets of the heavens and the earth: how clearly He sees, how finely He hears (everything)! They have no protector other than Him; nor does He share His Command with any person whatsoever.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite (and teach) what has been revealed to thee of the Book of thy Lord: none can change His Words, and none wilt thou find as a refuge other than Him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And keep thy soul content with those who call on their Lord morning and evening, seeking His Face; and let not thine eyes pass beyond them, seeking the pomp and glitter of this Life; no obey any whose heart We have permitted to neglect the remembrance of Us, one who follows his own desires, whose case has gone beyond all bounds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
Say, ``The truth is from your Lord": Let him who will believe, and let him who will, reject (it): for the wrong-doers We have prepared a Fire whose (smoke and flames), like the walls and roof of a tent, will hem them in: if they implore relief they will be granted water like melted brass, that will scald their faces, how dreadful the drink! How uncomfortable a couch to recline on!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
As to those who believe and work righteousness, verily We shall not suffer to perish the reward of any who do a (single) righteous deed.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
For them will be Gardens of Eternity; beneath them rivers will flow; they will be adorned therein with bracelets of gold, and they will wear green garments of fine silk and heavy brocade: They will recline therein on raised thrones. How good the recompense! How beautiful a couch to recline on!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
Set forth to them the parable of two men: for one of them We provided two gardens of grape-vines and surrounded them with date palms; in between the two We placed corn-fields.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of those gardens brought forth its produce, and failed not in the least therein: in the midst of them We caused a river to flow.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
(Abundant) was the produce this man had: he said to his companion, in the course of a mutual argument: ``more wealth have I than you, and more honour and power in (my following of) men."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
He went into his garden in a state (of mind) unjust to his soul: He said, ``I deem not that this will ever perish,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
``Nor do I deem that the Hour (of Judgment) will (ever) come: Even if I am brought back to my Lord, I shall surely find (there) something better in exchange."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion said to him, in the course of the argument with him: ``Dost thou deny Him Who created thee out of dust, then out of a sperm-drop, then fashioned thee into a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
``But (I think) for my part that He is Allah, My Lord, and none shall I associate with my Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
``Why didst thou not, as thou wentest into thy garden, say: 'Allah's will (be done)! There is no power but with Allah!' If thou dost see me less than thee in wealth and sons,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
``It may be that my Lord will give me something better than thy garden, and that He will send on thy garden thunderbolts (by way of reckoning) from heaven, making it (but) slippery sand!-\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
``Or the water of the garden will run off underground so that thou wilt never be able to find it."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
So his fruits (and enjoyment) were encompassed (with ruin), and he remained twisting and turning his hands over what he had spent on his property, which had (now) tumbled to pieces to its very foundations, and he could only say, ``Woe is me! Would I had never ascribed partners to my Lord and Cherisher!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
Nor had he numbers to help him against Allah, nor was he able to deliver himself.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
There, the (only) protection comes from Allah, the True One. He is the Best to reward, and the Best to give success.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
Set forth to them the similitude of the life of this world: It is like the rain which we send down from the skies: the earth's vegetation absorbs it, but soon it becomes dry stubble, which the winds do scatter: it is (only) Allah who prevails over all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and sons are allurements of the life of this world: But the things that endure, good deeds, are best in the sight of thy Lord, as rewards, and best as (the foundation for) hopes.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
One Day We shall remove the mountains, and thou wilt see the earth as a level stretch, and We shall gather them, all together, nor shall We leave out any one of them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they will be marshalled before thy Lord in ranks, (with the announcement), ``Now have ye come to Us (bare) as We created you first: aye, ye thought We shall not fulfil the appointment made to you to meet (Us)!":\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book (of Deeds) will be placed (before you); and thou wilt see the sinful in great terror because of what is (recorded) therein; they will say, ``Ah! woe to us! what a Book is this! It leaves out nothing small or great, but takes account thereof!" They will find all that they did, placed before them: And not one will thy Lord treat with injustice.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
Behold! We said to the angels, ``Bow down to Adam": They bowed down except Iblis. He was one of the Jinns, and he broke the Command of his Lord. Will ye then take him and his progeny as protectors rather than Me? And they are enemies to you! Evil would be the exchange for the wrong-doers!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I called them not to witness the creation of the heavens and the earth, nor (even) their own creation: nor is it for helpers such as Me to take as lead (men) astray!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
One Day He will say, ``Call on those whom ye thought to be My partners," and they will call on them, but they will not listen to them; and We shall make for them a place of common perdition.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the Sinful shall see the fire and apprehend that they have to fall therein: no means will they find to turn away therefrom.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
We have explained in detail in this Qur'an, for the benefit of mankind, every kind of similitude: but man is, in most things, contentious.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And what is there to keep back men from believing, now that Guidance has come to them, nor from praying for forgiveness from their Lord, but that (they ask that) the ways of the ancients be repeated with them, or the Wrath be brought to them face to face?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
We only send the messengers to give Glad Tidings and to give warnings: But the unbelievers dispute with vain argument, in order therewith to weaken the truth, and they treat My Signs as a jest, as also the fact that they are warned!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who doth more wrong than one who is reminded of the Signs of his Lord, but turns away from them, forgetting the (deeds) which his hands have sent forth? Verily We have set veils over their hearts lest they should understand this, and over their ears, deafness, if thou callest them to guidance, even then will they never accept guidance.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
But your Lord is Most forgiving, full of Mercy. If He were to call them (at once) to account for what they have earned, then surely He would have hastened their punishment: but they have their appointed time, beyond which they will find no refuge.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
Such were the populations we destroyed when they committed iniquities; but we fixed an appointed time for their destruction.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
Behold, Moses said to his attendant, ``I will not give up until I reach the junction of the two seas or (until) I spend years and years in travel."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they reached the Junction, they forgot (about) their Fish, which took its course through the sea (straight) as in a tunnel.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
When they had passed on (some distance), Moses said to his attendant: ``Bring us our early meal; truly we have suffered much fatigue at this (stage of) our journey."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He replied: ``Sawest thou (what happened) when we betook ourselves to the rock? I did indeed forget (about) the Fish: none but Satan made me forget to tell (you) about it: it took its course through the sea in a marvellous way!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
Moses said: ``That was what we were seeking after:" So they went back on their footsteps, following (the path they had come).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
So they found one of Our servants, on whom We had bestowed Mercy from Ourselves and whom We had taught knowledge from Our own Presence.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him: ``May I follow thee, on the footing that thou teach me something of the (Higher) Truth which thou hast been taught?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
(The other) said: ``Verily thou wilt not be able to have patience with me!"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
``And how canst thou have patience about things about which thy understanding is not complete?"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
Moses said: ``Thou wilt find me, if Allah so will, (truly) patient: nor shall I disobey thee in aught."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
The other said: ``If then thou wouldst follow me, ask me no questions about anything until I myself speak to thee concerning it."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they both proceeded: until, when they were in the boat, he scuttled it. Said Moses: ``Hast thou scuttled it in order to drown those in it? Truly a strange thing hast thou done!"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He answered: ``Did I not tell thee that thou canst have no patience with me?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
Moses said: ``Rebuke me not for forgetting, nor grieve me by raising difficulties in my case."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then they proceeded: until, when they met a young man, he slew him. Moses said: ``Hast thou slain an innocent person who had slain none? Truly a foul (unheard of) thing hast thou done!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He answered: ``Did I not tell thee that thou canst have no patience with me?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
(Moses) said: ``If ever I ask thee about anything after this, keep me not in thy company: then wouldst thou have received (full) excuse from my side."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
Then they proceeded: until, when they came to the inhabitants of a town, they asked them for food, but they refused them hospitality. They found there a wall on the point of falling down, but he set it up straight. (Moses) said: ``If thou hadst wished, surely thou couldst have exacted some recompense for it!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He answered: ``This is the parting between me and thee: now will I tell thee the interpretation of (those things) over which thou wast unable to hold patience.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
``As for the boat, it belonged to certain men in dire want: they plied on the water: I but wished to render it unserviceable, for there was after them a certain king who seized on every boat by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
``As for the youth, his parents were people of Faith, and we feared that he would grieve them by obstinate rebellion and ingratitude (to Allah and man).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
``So we desired that their Lord would give them in exchange (a son) better in purity (of conduct) and closer in affection.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
``As for the wall, it belonged to two youths, orphans, in the Town; there was, beneath it, a buried treasure, to which they were entitled: their father had been a righteous man: So thy Lord desired that they should attain their age of full strength and get out their treasure - a mercy (and favour) from thy Lord. I did it not of my own accord. Such is the interpretation of (those things) over which thou wast unable to hold patience."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
They ask thee concerning Zul-qarnain. Say, ``I will rehearse to you something of his story."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Verily We established his power on earth, and We gave him the ways and the means to all ends.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
One (such) way he followed,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until, when he reached the setting of the sun, he found it set in a spring of murky water: Near it he found a People: We said: ``O Zul-qarnain! (thou hast authority,) either to punish them, or to treat them with kindness."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: ``Whoever doth wrong, him shall we punish; then shall he be sent back to his Lord; and He will punish him with a punishment unheard-of (before).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
``But whoever believes, and works righteousness,- he shall have a goodly reward, and easy will be his task as We order it by our Command."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then followed he (another) way,\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until, when he came to the rising of the sun, he found it rising on a people for whom We had provided no covering protection against the sun.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
(He left them) as they were: We completely understood what was before him.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then followed he (another) way,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he reached (a tract) between two mountains, he found, beneath them, a people who scarcely understood a word.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said: ``O Zul-qarnain! the Gog and Magog (People) do great mischief on earth: shall we then render thee tribute in order that thou mightest erect a barrier between us and them?\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said: ``(The power) in which my Lord has established me is better (than tribute): Help me therefore with strength (and labour): I will erect a strong barrier between you and them:\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
``Bring me blocks of iron." At length, when he had filled up the space between the two steep mountain-sides, He said, ``Blow (with your bellows)" Then, when he had made it (red) as fire, he said: ``Bring me, that I may pour over it, molten lead."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
Thus were they made powerless to scale it or to dig through it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said: ``This is a mercy from my Lord: But when the promise of my Lord comes to pass, He will make it into dust; and the promise of my Lord is true."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
On that day We shall leave them to surge like waves on one another: the trumpet will be blown, and We shall collect them all together.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And We shall present Hell that day for Unbelievers to see, all spread out,-\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
(Unbelievers) whose eyes had been under a veil from remembrance of Me, and who had been unable even to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do the Unbelievers think that they can take My servants as protectors besides Me? Verily We have prepared Hell for the Unbelievers for (their) entertainment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say: ``Shall we tell you of those who lose most in respect of their deeds?-\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
``Those whose efforts have been wasted in this life, while they thought that they were acquiring good by their works?"\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
They are those who deny the Signs of their Lord and the fact of their having to meet Him (in the Hereafter): vain will be their works, nor shall We, on the Day of Judgment, give them any weight.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That is their reward, Hell, because they rejected Faith, and took My Signs and My Messengers by way of jest.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
As to those who believe and work righteous deeds, they have, for their entertainment, the Gardens of Paradise,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
Wherein they shall dwell (for aye): no change will they wish for from them.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say: ``If the ocean were ink (wherewith to write out) the words of my Lord, sooner would the ocean be exhausted than would the words of my Lord, even if we added another ocean like it, for its aid."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say: ``I am but a man like yourselves, (but) the inspiration has come to me, that your Allah is one Allah: whoever expects to meet his Lord, let him work righteousness, and, in the worship of his Lord, admit no one as partner.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf. Ha. Ya. 'Ain. Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
(This is) a recital of the Mercy of thy Lord to His servant Zakariya.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
Behold! he cried to his Lord in secret,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
Praying: ``O my Lord! infirm indeed are my bones, and the hair of my head doth glisten with grey: but never am I unblest, O my Lord, in my prayer to Thee!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
``Now I fear (what) my relatives (and colleagues) (will do) after me: but my wife is barren: so give me an heir as from Thyself,-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
``(One that) will (truly) represent me, and represent the posterity of Jacob; and make him, O my Lord! one with whom Thou art well-pleased!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
(His prayer was answered): ``O Zakariya! We give thee good news of a son: His name shall be Yahya: on none by that name have We conferred distinction before."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: ``O my Lord! How shall I have a son, when my wife is barren and I have grown quite decrepit from old age?"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He said: ``So (it will be) thy Lord saith, 'that is easy for Me: I did indeed create thee before, when thou hadst been nothing!'"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
(Zakariya) said: ``O my Lord! give me a Sign." ``Thy Sign," was the answer, ``Shall be that thou shalt speak to no man for three nights, although thou art not dumb."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
So Zakariya came out to his people from him chamber: He told them by signs to celebrate Allah's praises in the morning and in the evening.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
(To his son came the command): ``O Yahya! take hold of the Book with might": and We gave him Wisdom even as a youth,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And piety (for all creatures) as from Us, and purity: He was devout,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And kind to his parents, and he was not overbearing or rebellious.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
So Peace on him the day he was born, the day that he dies, and the day that he will be raised up to life (again)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
Relate in the Book (the story of) Mary, when she withdrew from her family to a place in the East.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
She placed a screen (to screen herself) from them; then We sent her our angel, and he appeared before her as a man in all respects.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said: ``I seek refuge from thee to (Allah) Most Gracious: (come not near) if thou dost fear Allah."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said: ``Nay, I am only a messenger from thy Lord, (to announce) to thee the gift of a holy son.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said: ``How shall I have a son, seeing that no man has touched me, and I am not unchaste?"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said: ``So (it will be): Thy Lord saith, 'that is easy for Me: and (We wish) to appoint him as a Sign unto men and a Mercy from Us': It is a matter (so) decreed."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and she retired with him to a remote place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the pains of childbirth drove her to the trunk of a palm-tree: She cried (in her anguish): ``Ah! would that I had died before this! would that I had been a thing forgotten and out of sight!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
But (a voice) cried to her from beneath the (palm-tree): ``Grieve not! for thy Lord hath provided a rivulet beneath thee;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
``And shake towards thyself the trunk of the palm-tree: It will let fall fresh ripe dates upon thee.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
``So eat and drink and cool (thine) eye. And if thou dost see any man, say, 'I have vowed a fast to (Allah) Most Gracious, and this day will I enter into not talk with any human being'"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
At length she brought the (babe) to her people, carrying him (in her arms). They said: ``O Mary! truly an amazing thing hast thou brought!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
``O sister of Aaron! Thy father was not a man of evil, nor thy mother a woman unchaste!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
But she pointed to the babe. They said: ``How can we talk to one who is a child in the cradle?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He said: ``I am indeed a servant of Allah: He hath given me revelation and made me a prophet;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
``And He hath made me blessed wheresoever I be, and hath enjoined on me Prayer and Charity as long as I live;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
``(He) hath made me kind to my mother, and not overbearing or miserable;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
``So peace is on me the day I was born, the day that I die, and the day that I shall be raised up to life (again)"!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such (was) Jesus the son of Mary: (it is) a statement of truth, about which they (vainly) dispute.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It is not befitting to (the majesty of) Allah that He should beget a son. Glory be to Him! when He determines a matter, He only says to it, ``Be", and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
Verily Allah is my Lord and your Lord: Him therefore serve ye: this is a Way that is straight.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
But the sects differ among themselves: and woe to the unbelievers because of the (coming) Judgment of a Momentous Day!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How plainly will they see and hear, the Day that they will appear before Us! but the unjust today are in error manifest!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
But warn them of the Day of Distress, when the matter will be determined: for (behold,) they are negligent and they do not believe!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
It is We Who will inherit the earth, and all beings thereon: to Us will they all be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
(Also mention in the Book (the story of) Abraham: He was a man of Truth, a prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
Behold, he said to his father: ``O my father! why worship that which heareth not and seeth not, and can profit thee nothing?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
``O my father! to me hath come knowledge which hath not reached thee: so follow me: I will guide thee to a way that is even and straight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
``O my father! serve not Satan: for Satan is a rebel against (Allah) Most Gracious.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
``O my father! I fear lest a Penalty afflict thee from (Allah) Most Gracious, so that thou become to Satan a friend."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
(The father) replied: ``Dost thou hate my gods, O Abraham? If thou forbear not, I will indeed stone thee: Now get away from me for a good long while!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
Abraham said: ``Peace be on thee: I will pray to my Lord for thy forgiveness: for He is to me Most Gracious.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
``And I will turn away from you (all) and from those whom ye invoke besides Allah: I will call on my Lord: perhaps, by my prayer to my Lord, I shall be not unblest."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
When he had turned away from them and from those whom they worshipped besides Allah, We bestowed on him Isaac and Jacob, and each one of them We made a prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We bestowed of Our Mercy on them, and We granted them lofty honour on the tongue of truth.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
Also mention in the Book (the story of) Moses: for he was specially chosen, and he was a messenger (and) a prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And we called him from the right side of Mount (Sinai), and made him draw near to Us, for mystic (converse).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And, out of Our Mercy, We gave him his brother Aaron, (also) a prophet.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
Also mention in the Book (the story of) Isma'il: He was (strictly) true to what he promised, and he was a messenger (and) a prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
He used to enjoin on his people Prayer and Charity, and he was most acceptable in the sight of his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
Also mention in the Book the case of Idris: He was a man of truth (and sincerity), (and) a prophet:\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to a lofty station.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
Those were some of the prophets on whom Allah did bestow His Grace,- of the posterity of Adam, and of those who We carried (in the Ark) with Noah, and of the posterity of Abraham and Israel of those whom We guided and chose. Whenever the Signs of (Allah) Most Gracious were rehearsed to them, they would fall down in prostrate adoration and in tears.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
But after them there followed a posterity who missed prayers and followed after lusts soon, then, will they face Destruction,-\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except those who repent and believe, and work righteousness: for these will enter the Garden and will not be wronged in the least,-\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Gardens of Eternity, those which (Allah) Most Gracious has promised to His servants in the Unseen: for His promise must (necessarily) come to pass.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They will not there hear any vain discourse, but only salutations of Peace: And they will have therein their sustenance, morning and evening.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Garden which We give as an inheritance to those of Our servants who guard against Evil.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
(The angels say:) ``We descend not but by command of thy Lord: to Him belongeth what is before us and what is behind us, and what is between: and thy Lord never doth forget,-\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
``Lord of the heavens and of the earth, and of all that is between them; so worship Him, and be constant and patient in His worship: knowest thou of any who is worthy of the same Name as He?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
Man says: ``What! When I am dead, shall I then be raised up alive?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
But does not man call to mind that We created him before out of nothing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
So, by thy Lord, without doubt, We shall gather them together, and (also) the Evil Ones (with them); then shall We bring them forth on their knees round about Hell;\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then shall We certainly drag out from every sect all those who were worst in obstinate rebellion against (Allah) Most Gracious.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
And certainly We know best those who are most worthy of being burned therein.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
Not one of you but will pass over it: this is, with thy Lord, a Decree which must be accomplished.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
But We shall save those who guarded against evil, and We shall leave the wrong-doers therein, (humbled) to their knees.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
When Our Clear Signs are rehearsed to them, the Unbelievers say to those who believe, ``Which of the two sides is best in point of position? Which makes the best show in council?"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
But how many (countless) generations before them have we destroyed, who were even better in equipment and in glitter to the eye?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: ``If any men go astray, (Allah) Most Gracious extends (the rope) to them, until, when they see the warning of Allah (being fulfilled) - either in punishment or in (the approach of) the Hour,- they will at length realise who is worst in position, and (who) weakest in forces!\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
``And Allah doth advance in guidance those who seek guidance: and the things that endure, Good Deeds, are best in the sight of thy Lord, as rewards, and best in respect of (their) eventual return."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Hast thou then seen the (sort of) man who rejects Our Signs, yet says: ``I shall certainly be given wealth and children?"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he penetrated to the Unseen, or has he taken a contract with (Allah) Most Gracious?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
Nay! We shall record what he says, and We shall add and add to his punishment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
To Us shall return all that he talks of and he shall appear before Us bare and alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken (for worship) gods other than Allah, to give them power and glory!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Instead, they shall reject their worship, and become adversaries against them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Seest thou not that We have set the Evil Ones on against the unbelievers, to incite them with fury?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So make no haste against them, for We but count out to them a (limited) number (of days).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
The day We shall gather the righteous to (Allah) Most Gracious, like a band presented before a king for honours,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And We shall drive the sinners to Hell, like thirsty cattle driven down to water,-\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
None shall have the power of intercession, but such a one as has received permission (or promise) from (Allah) Most Gracious.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
They say: ``(Allah) Most Gracious has begotten a son!"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Indeed ye have put forth a thing most monstrous!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
At it the skies are ready to burst, the earth to split asunder, and the mountains to fall down in utter ruin,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That they should invoke a son for (Allah) Most Gracious.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
For it is not consonant with the majesty of (Allah) Most Gracious that He should beget a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
Not one of the beings in the heavens and the earth but must come to (Allah) Most Gracious as a servant.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He does take an account of them (all), and hath numbered them (all) exactly.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And everyone of them will come to Him singly on the Day of Judgment.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
On those who believe and work deeds of righteousness, will (Allah) Most Gracious bestow love.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
So have We made the (Qur'an) easy in thine own tongue, that with it thou mayest give Glad Tidings to the righteous, and warnings to people given to contention.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
But how many (countless) generations before them have We destroyed? Canst thou find a single one of them (now) or hear (so much as) a whisper of them?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta-Ha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down the Qur'an to thee to be (an occasion) for thy distress,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as an admonition to those who fear (Allah),-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from Him Who created the earth and the heavens on high.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
(Allah) Most Gracious is firmly established on the throne (of authority).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs what is in the heavens and on earth, and all between them, and all beneath the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
If thou pronounce the word aloud, (it is no matter): for verily He knoweth what is secret and what is yet more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah! there is no god but He! To Him belong the most Beautiful Names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Has the story of Moses reached thee?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
Behold, he saw a fire: So he said to his family, ``Tarry ye; I perceive a fire; perhaps I can bring you some burning brand therefrom, or find some guidance at the fire."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
But when he came to the fire, a voice was heard: ``O Moses!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
``Verily I am thy Lord! therefore (in My presence) put off thy shoes: thou art in the sacred valley Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
``I have chosen thee: listen, then, to the inspiration (sent to thee).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
``Verily, I am Allah: There is no god but I: So serve thou Me (only), and establish regular prayer for celebrating My praise.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
``Verily the Hour is coming - My design is to keep it hidden - for every soul to receive its reward by the measure of its Endeavour.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
``Therefore let not such as believe not therein but follow their own lusts, divert thee therefrom, lest thou perish!"..\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
``And what is that in the right hand, O Moses?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said, ``It is my rod: on it I lean; with it I beat down fodder for my flocks; and in it I find other uses."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
(Allah) said, ``Throw it, O Moses!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
He threw it, and behold! It was a snake, active in motion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
(Allah) said, ``Seize it, and fear not: We shall return it at once to its former condition"..\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
``Now draw thy hand close to thy side: It shall come forth white (and shining), without harm (or stain),- as another Sign,-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
``In order that We may show thee (two) of our Greater Signs.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
``Go thou to Pharaoh, for he has indeed transgressed all bounds."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
(Moses) said: ``O my Lord! expand me my breast;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
``Ease my task for me;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
``And remove the impediment from my speech,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
``So they may understand what I say:\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
``And give me a Minister from my family,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
``Aaron, my brother;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
``Add to my strength through him,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
``And make him share my task:\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
``That we may celebrate Thy praise without stint,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
``And remember Thee without stint:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
``For Thou art He that (ever) regardeth us."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
(Allah) said: ``Granted is thy prayer, O Moses!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
``And indeed We conferred a favour on thee another time (before).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
``Behold! We sent to thy mother, by inspiration, the message:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
``'Throw (the child) into the chest, and throw (the chest) into the river: the river will cast him up on the bank, and he will be taken up by one who is an enemy to Me and an enemy to him': But I cast (the garment of) love over thee from Me: and (this) in order that thou mayest be reared under Mine eye.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
``Behold! thy sister goeth forth and saith, 'shall I show you one who will nurse and rear the (child)?' So We brought thee back to thy mother, that her eye might be cooled and she should not grieve. Then thou didst slay a man, but We saved thee from trouble, and We tried thee in various ways. Then didst thou tarry a number of years with the people of Midian. Then didst thou come hither as ordained, O Moses!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
``And I have prepared thee for Myself (for service)"..\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
``Go, thou and thy brother, with My Signs, and slacken not, either of you, in keeping Me in remembrance.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
``Go, both of you, to Pharaoh, for he has indeed transgressed all bounds;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
``But speak to him mildly; perchance he may take warning or fear (Allah)."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They (Moses and Aaron) said: ``Our Lord! We fear lest he hasten with insolence against us, or lest he transgress all bounds."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said: ``Fear not: for I am with you: I hear and see (everything).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
``So go ye both to him, and say, 'Verily we are messengers sent by thy Lord: Send forth, therefore, the Children of Israel with us, and afflict them not: with a Sign, indeed, have we come from thy Lord! and peace to all who follow guidance!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
``'Verily it has been revealed to us that the Penalty (awaits) those who reject and turn away.'"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
(When this message was delivered), (Pharaoh) said: ``Who, then, O Moses, is the Lord of you two?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said: ``Our Lord is He Who gave to each (created) thing its form and nature, and further, gave (it) guidance."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
(Pharaoh) said: ``What then is the condition of previous generations?"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
He replied: ``The knowledge of that is with my Lord, duly recorded: my Lord never errs, nor forgets,-\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
``He Who has, made for you the earth like a carpet spread out; has enabled you to go about therein by roads (and channels); and has sent down water from the sky." With it have We produced diverse pairs of plants each separate from the others.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat (for yourselves) and pasture your cattle: verily, in this are Signs for men endued with understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
From the (earth) did We create you, and into it shall We return you, and from it shall We bring you out once again.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And We showed Pharaoh all Our Signs, but he did reject and refuse.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said: ``Hast thou come to drive us out of our land with thy magic, O Moses?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
``But we can surely produce magic to match thine! So make a tryst between us and thee, which we shall not fail to keep - neither we nor thou - in a place where both shall have even chances."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
Moses said: ``Your tryst is the Day of the Festival, and let the people be assembled when the sun is well up."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Pharaoh withdrew: He concerted his plan, and then came (back).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Moses said to him: Woe to you! Forge not ye a lie against Allah, lest He destroy you (at once) utterly by chastisement: the forger must suffer frustration!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
So they disputed, one with another, over their affair, but they kept their talk secret.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said: ``These two are certainly (expert) magicians: their object is to drive you out from your land with their magic, and to do away with your most cherished institutions.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
``Therefore concert your plan, and then assemble in (serried) ranks: He wins (all along) today who gains the upper hand."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said: ``O Moses! whether wilt thou that thou throw (first) or that we be the first to throw?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said, ``Nay, throw ye first!" Then behold their ropes and their rods-so it seemed to him on account of their magic - began to be in lively motion!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
So Moses conceived in his mind a (sort of) fear.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said: ``Fear not! for thou hast indeed the upper hand:\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
``Throw that which is in thy right hand: Quickly will it swallow up that which they have faked what they have faked is but a magician's trick: and the magician thrives not, (no matter) where he goes."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
So the magicians were thrown down to prostration: they said, ``We believe in the Lord of Aaron and Moses".\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
(Pharaoh) said: ``Believe ye in Him before I give you permission? Surely this must be your leader, who has taught you magic! be sure I will cut off your hands and feet on opposite sides, and I will have you crucified on trunks of palm-trees: so shall ye know for certain, which of us can give the more severe and the more lasting punishment!"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said: ``Never shall we regard thee as more than the Clear Signs that have come to us, or than Him Who created us! so decree whatever thou desirest to decree: for thou canst only decree (touching) the life of this world.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
``For us, we have believed in our Lord: may He forgive us our faults, and the magic to which thou didst compel us: for Allah is Best and Most Abiding."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Verily he who comes to his Lord as a sinner (at Judgment),- for him is Hell: therein shall he neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But such as come to Him as Believers who have worked righteous deeds,- for them are ranks exalted,-\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Gardens of Eternity, beneath which flow rivers: they will dwell therein for aye: such is the reward of those who purify themselves (from evil).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
We sent an inspiration to Moses: ``Travel by night with My servants, and strike a dry path for them through the sea, without fear of being overtaken (by Pharaoh) and without (any other) fear."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Then Pharaoh pursued them with his forces, but the waters completely overwhelmed them and covered them up.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
Pharaoh led his people astray instead of leading them aright.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O ye Children of Israel! We delivered you from your enemy, and We made a Covenant with you on the right side of Mount (Sinai), and We sent down to you Manna and quails:\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
(Saying): ``Eat of the good things We have provided for your sustenance, but commit no excess therein, lest My Wrath should justly descend on you: and those on whom descends My Wrath do perish indeed!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
``But, without doubt, I am (also) He that forgives again and again, to those who repent, believe, and do right, who,- in fine, are ready to receive true guidance."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
(When Moses was up on the Mount, Allah said:) ``What made thee hasten in advance of thy people, O Moses?"\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He replied: ``Behold, they are close on my footsteps: I hastened to thee, O my Lord, to please thee."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
(Allah) said: ``We have tested thy people in thy absence: the Samiri has led them astray."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
So Moses returned to his people in a state of indignation and sorrow. He said: ``O my people! did not your Lord make a handsome promise to you? Did then the promise seem to you long (in coming)? Or did ye desire that Wrath should descend from your Lord on you, and so ye broke your promise to me?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said: ``We broke not the promise to thee, as far as lay in our power: but we were made to carry the weight of the ornaments of the (whole) people, and we threw them (into the fire), and that was what the Samiri suggested.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
``Then he brought out (of the fire) before the (people) the image of a calf: It seemed to low: so they said: This is your god, and the god of Moses, but (Moses) has forgotten!"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Could they not see that it could not return them a word (for answer), and that it had no power either to harm them or to do them good?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
Aaron had already, before this said to them: ``O my people! ye are being tested in this: for verily your Lord is (Allah) Most Gracious; so follow me and obey my command."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They had said: ``We will not abandon this cult, but we will devote ourselves to it until Moses returns to us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
(Moses) said: ``O Aaron! what kept thee back, when thou sawest them going wrong,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
``From following me? Didst thou then disobey my order?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
(Aaron) replied: ``O son of my mother! Seize (me) not by my beard nor by (the hair of) my head! Truly I feared lest thou shouldst say, 'Thou has caused a division among the children of Israel, and thou didst not respect my word!'"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
(Moses) said: ``What then is thy case, O Samiri?"\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He replied: ``I saw what they saw not: so I took a handful (of dust) from the footprint of the Messenger, and threw it (into the calf): thus did my soul suggest to me."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
(Moses) said: ``Get thee gone! but thy (punishment) in this life will be that thou wilt say, 'touch me not'; and moreover (for a future penalty) thou hast a promise that will not fail: Now look at thy god, of whom thou hast become a devoted worshipper: We will certainly (melt) it in a blazing fire and scatter it broadcast in the sea!"\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
But the god of you all is the One Allah: there is no god but He: all things He comprehends in His knowledge.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus do We relate to thee some stories of what happened before: for We have sent thee a Message from Our own Presence.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
If any do turn away therefrom, verily they will bear a burden on the Day of judgment;\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
They will abide in this (state): and grievous will the burden be to them on that Day,-\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day when the Trumpet will be sounded: that Day, We shall gather the sinful, blear-eyed (with terror).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
In whispers will they consult each other: ``Yet tarried not longer than ten (Days);\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know best what they will say, when their leader most eminent in conduct will say: ``Ye tarried not longer than a day!"\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They ask thee concerning the Mountains: say, ``My Lord will uproot them and scatter them as dust;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
``He will leave them as plains smooth and level;\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
``Nothing crooked or curved wilt thou see in their place."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day will they follow the Caller (straight): no crookedness (can they show) him: all sounds shall humble themselves in the Presence of (Allah) Most Gracious: nothing shalt thou hear but the tramp of their feet (as they march).\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that Day shall no intercession avail except for those for whom permission has been granted by (Allah) Most Gracious and whose word is acceptable to Him.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows what (appears to His creatures as) before or after or behind them: but they shall not compass it with their knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
(All) faces shall be humbled before (Him) - the Living, the Self-Subsisting, Eternal: hopeless indeed will be the man that carries iniquity (on his back).\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
But he who works deeds of righteousness, and has faith, will have no fear of harm nor of any curtailment (of what is his due).\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
Thus have We sent this down - an arabic Qur'an - and explained therein in detail some of the warnings, in order that they may fear Allah, or that it may cause their remembrance (of Him).\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
High above all is Allah, the King, the Truth! Be not in haste with the Qur'an before its revelation to thee is completed, but say, ``O my Lord! advance me in knowledge."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
We had already, beforehand, taken the covenant of Adam, but he forgot: and We found on his part no firm resolve.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
When We said to the angels, ``Prostrate yourselves to Adam", they prostrated themselves, but not Iblis: he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said: ``O Adam! verily, this is an enemy to thee and thy wife: so let him not get you both out of the Garden, so that thou art landed in misery.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
``There is therein (enough provision) for thee not to go hungry nor to go naked,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
``Nor to suffer from thirst, nor from the sun's heat."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
But Satan whispered evil to him: he said, ``O Adam! shall I lead thee to the Tree of Eternity and to a kingdom that never decays?"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
In the result, they both ate of the tree, and so their nakedness appeared to them: they began to sew together, for their covering, leaves from the Garden: thus did Adam disobey his Lord, and allow himself to be seduced.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
But his Lord chose him (for His Grace): He turned to him, and gave him Guidance.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He said: ``Get ye down, both of you,- all together, from the Garden, with enmity one to another: but if, as is sure, there comes to you Guidance from Me, whosoever follows My Guidance, will not lose his way, nor fall into misery.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
``But whosoever turns away from My Message, verily for him is a life narrowed down, and We shall raise him up blind on the Day of Judgment."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say: ``O my Lord! why hast Thou raised me up blind, while I had sight (before)?"\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
(Allah) will say: ``Thus didst Thou, when Our Signs came unto thee, disregard them: so wilt thou, this day, be disregarded."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
And thus do We recompense him who transgresses beyond bounds and believes not in the Signs of his Lord: and the Penalty of the Hereafter is far more grievous and more enduring.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a warning to such men (to call to mind) how many generations before them We destroyed, in whose haunts they (now) move? Verily, in this are Signs for men endued with understanding.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
Had it not been for a Word that went forth before from thy Lord, (their punishment) must necessarily have come; but there is a Term appointed (for respite).\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
Therefore be patient with what they say, and celebrate (constantly) the praises of thy Lord, before the rising of the sun, and before its setting; yea, celebrate them for part of the hours of the night, and at the sides of the day: that thou mayest have (spiritual) joy.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
Nor strain thine eyes in longing for the things We have given for enjoyment to parties of them, the splendour of the life of this world, through which We test them: but the provision of thy Lord is better and more enduring.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
Enjoin prayer on thy people, and be constant therein. We ask thee not to provide sustenance: We provide it for thee. But the (fruit of) the Hereafter is for righteousness.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
They say: ``Why does he not bring us a sign from his Lord?" Has not a Clear Sign come to them of all that was in the former Books of revelation?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And if We had inflicted on them a penalty before this, they would have said: ``Our Lord! If only Thou hadst sent us a messenger, we should certainly have followed Thy Signs before we were humbled and put to shame."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say: ``Each one (of us) is waiting: wait ye, therefore, and soon shall ye know who it is that is on the straight and even way, and who it is that has received Guidance."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Closer and closer to mankind comes their Reckoning: yet they heed not and they turn away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Never comes (aught) to them of a renewed Message from their Lord, but they listen to it as in jest,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
Their hearts toying as with trifles. The wrong-doers conceal their private counsels, (saying), ``Is this (one) more than a man like yourselves? Will ye go to witchcraft with your eyes open?"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
Say: ``My Lord knoweth (every) word (spoken) in the heavens and on earth: He is the One that heareth and knoweth (all things)."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
``Nay," they say, ``(these are) medleys of dream! - Nay, He forged it! - Nay, He is (but) a poet! Let him then bring us a Sign like the ones that were sent to (Prophets) of old!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
(As to those) before them, not one of the populations which We destroyed believed: will these believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
Before thee, also, the messengers We sent were but men, to whom We granted inspiration: If ye realise this not, ask of those who possess the Message.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
Nor did We give them bodies that ate no food, nor were they exempt from death.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
In the end We fulfilled to them Our Promise, and We saved them and those whom We pleased, but We destroyed those who transgressed beyond bounds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
We have revealed for you (O men!) a book in which is a Message for you: will ye not then understand?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many were the populations We utterly destroyed because of their iniquities, setting up in their places other peoples?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Yet, when they felt Our Punishment (coming), behold, they (tried to) flee from it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
Flee not, but return to the good things of this life which were given you, and to your homes in order that ye may be called to account.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said: ``Ah! woe to us! We were indeed wrong-doers!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And that cry of theirs ceased not, till We made them as a field that is mown, as ashes silent and quenched.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
Not for (idle) sport did We create the heavens and the earth and all that is between!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
If it had been Our wish to take (just) a pastime, We should surely have taken it from the things nearest to Us, if We would do (such a thing)!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, We hurl the Truth against falsehood, and it knocks out its brain, and behold, falsehood doth perish! Ah! woe be to you for the (false) things ye ascribe (to Us).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belong all (creatures) in the heavens and on earth: Even those who are in His (very) Presence are not too proud to serve Him, nor are they (ever) weary (of His service):\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They celebrate His praises night and day, nor do they ever flag or intermit.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they taken (for worship) gods from the earth who can raise (the dead)?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
If there were, in the heavens and the earth, other gods besides Allah, there would have been confusion in both! but glory to Allah, the Lord of the Throne: (High is He) above what they attribute to Him!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He cannot be questioned for His acts, but they will be questioned (for theirs).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken for worship (other) gods besides him? Say, ``Bring your convincing proof: this is the Message of those with me and the Message of those before me." But most of them know not the Truth, and so turn away.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
Not a messenger did We send before thee without this inspiration sent by Us to him: that there is no god but I; therefore worship and serve Me.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say: ``(Allah) Most Gracious has begotten offspring." Glory to Him! they are (but) servants raised to honour.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They speak not before He speaks, and they act (in all things) by His Command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them, and what is behind them, and they offer no intercession except for those who are acceptable, and they stand in awe and reverence of His (Glory).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
If any of them should say, ``I am a god besides Him", such a one We should reward with Hell: thus do We reward those who do wrong.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Do not the Unbelievers see that the heavens and the earth were joined together (as one unit of creation), before we clove them asunder? We made from water every living thing. Will they not then believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have set on the earth mountains standing firm, lest it should shake with them, and We have made therein broad highways (between mountains) for them to pass through: that they may receive Guidance.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We have made the heavens as a canopy well guarded: yet do they turn away from the Signs which these things (point to)!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
It is He Who created the Night and the Day, and the sun and the moon: all (the celestial bodies) swim along, each in its rounded course.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
We granted not to any man before thee permanent life (here): if then thou shouldst die, would they live permanently?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul shall have a taste of death: and We test you by evil and by good by way of trial. to Us must ye return.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
When the Unbelievers see thee, they treat thee not except with ridicule. ``Is this," (they say), ``the one who talks of your gods?" and they blaspheme at the mention of (Allah) Most Gracious!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man is a creature of haste: soon (enough) will I show you My Signs; then ye will not ask Me to hasten them!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
They say: ``When will this promise come to pass, if ye are telling the truth?"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only the Unbelievers knew (the time) when they will not be able to ward off the fire from their faces, nor yet from their backs, and (when) no help can reach them!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Nay, it may come to them all of a sudden and confound them: no power will they have then to avert it, nor will they (then) get respite.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Mocked were (many) messenger before thee; But their scoffers were hemmed in by the thing that they mocked.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: ``Who can keep you safe by night and by day from (the Wrath of) (Allah) Most Gracious?" Yet they turn away from the mention of their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they gods that can guard them from Us? They have no power to aid themselves, nor can they be defended from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, We gave the good things of this life to these men and their fathers until the period grew long for them; See they not that We gradually reduce the land (in their control) from its outlying borders? Is it then they who will win?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say, ``I do but warn you according to revelation": But the deaf will not hear the call, (even) when they are warned!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
If but a breath of the Wrath of thy Lord do touch them, they will then say, ``Woe to us! we did wrong indeed!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
We shall set up scales of justice for the Day of Judgment, so that not a soul will be dealt with unjustly in the least, and if there be (no more than) the weight of a mustard seed, We will bring it (to account): and enough are We to take account.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
In the past We granted to Moses and Aaron the criterion (for judgment), and a Light and a Message for those who would do right,-\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord in their most secret thoughts, and who hold the Hour (of Judgment) in awe.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this is a blessed Message which We have sent down: will ye then reject it?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
We bestowed aforetime on Abraham his rectitude of conduct, and well were We acquainted with him.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
Behold! he said to his father and his people, ``What are these images, to which ye are (so assiduously) devoted?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said, ``We found our fathers worshipping them."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said, ``Indeed ye have been in manifest error - ye and your fathers."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said, ``Have you brought us the Truth, or are you one of those who jest?"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said, ``Nay, your Lord is the Lord of the heavens and the earth, He Who created them (from nothing): and I am a witness to this (Truth).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
``And by Allah, I have a plan for your idols - after ye go away and turn your backs"..\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he broke them to pieces, (all) but the biggest of them, that they might turn (and address themselves) to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said, ``Who has done this to our gods? He must indeed be some man of impiety!"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said, ``We heard a youth talk of them: He is called Abraham."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said, ``Then bring him before the eyes of the people, that they may bear witness."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said, ``Art thou the one that did this with our gods, O Abraham?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said: ``Nay, this was done by - this is their biggest one! ask them, if they can speak intelligently!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they turned to themselves and said, ``Surely ye are the ones in the wrong!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then were they confounded with shame: (they said), ``Thou knowest full well that these (idols) do not speak!"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
(Abraham) said, ``Do ye then worship, besides Allah, things that can neither be of any good to you nor do you harm?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
``Fie upon you, and upon the things that ye worship besides Allah! Have ye no sense?"..\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said, ``Burn him and protect your gods, If ye do (anything at all)!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said, ``O Fire! be thou cool, and (a means of) safety for Abraham!"\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
Then they sought a stratagem against him: but We made them the ones that lost most!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
But We delivered him and (his nephew) Lut (and directed them) to the land which We have blessed for the nations.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed on him Isaac and, as an additional gift, (a grandson), Jacob, and We made righteous men of every one (of them).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders, guiding (men) by Our Command, and We sent them inspiration to do good deeds, to establish regular prayers, and to practise regular charity; and they constantly served Us (and Us only).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And to Lut, too, We gave Judgment and Knowledge, and We saved him from the town which practised abominations: truly they were a people given to Evil, a rebellious people.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him to Our Mercy: for he was one of the Righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
(Remember) Noah, when he cried (to Us) aforetime: We listened to his (prayer) and delivered him and his family from great distress.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
We helped him against people who rejected Our Signs: truly they were a people given to Evil: so We drowned them (in the Flood) all together.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And remember David and Solomon, when they gave judgment in the matter of the field into which the sheep of certain people had strayed by night: We did witness their judgment.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
To Solomon We inspired the (right) understanding of the matter: to each (of them) We gave Judgment and Knowledge; it was Our power that made the hills and the birds celebrate Our praises, with David: it was We Who did (all these things).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
It was We Who taught him the making of coats of mail for your benefit, to guard you from each other's violence: will ye then be grateful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
(It was Our power that made) the violent (unruly) wind flow (tamely) for Solomon, to his order, to the land which We had blessed: for We do know all things.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the evil ones, were some who dived for him, and did other work besides; and it was We Who guarded them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And (remember) Job, when He cried to his Lord, ``Truly distress has seized me, but Thou art the Most Merciful of those that are merciful."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We listened to him: We removed the distress that was on him, and We restored his people to him, and doubled their number,- as a Grace from Ourselves, and a thing for commemoration, for all who serve Us.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And (remember) Isma'il, Idris, and Zul-kifl, all (men) of constancy and patience;\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
We admitted them to Our mercy: for they were of the righteous ones.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And remember Zun-nun, when he departed in wrath: He imagined that We had no power over him! But he cried through the deptHs of darkness, ``There is no god but thou: glory to thee: I was indeed wrong!"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We listened to him: and delivered him from distress: and thus do We deliver those who have faith.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And (remember) Zakariya, when he cried to his Lord: ``O my Lord! leave me not without offspring, though thou art the best of inheritors."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We listened to him: and We granted him Yahya: We cured his wife's (Barrenness) for him. These (three) were ever quick in emulation in good works; they used to call on Us with love and reverence, and humble themselves before Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And (remember) her who guarded her chastity: We breathed into her of Our spirit, and We made her and her son a sign for all peoples.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Verily, this brotherhood of yours is a single brotherhood, and I am your Lord and Cherisher: therefore serve Me (and no other).\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But (later generations) cut off their affair (of unity), one from another: (yet) will they all return to Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
Whoever works any act of righteousness and has faith,- His endeavour will not be rejected: We shall record it in his favour.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
But there is a ban on any population which We have destroyed: that they shall not return,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until the Gog and Magog (people) are let through (their barrier), and they swiftly swarm from every hill.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
Then will the true promise draw nigh (of fulfilment): then behold! the eyes of the Unbelievers will fixedly stare in horror: ``Ah! Woe to us! we were indeed heedless of this; nay, we truly did wrong!"\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Verily ye, (unbelievers), and the (false) gods that ye worship besides Allah, are (but) fuel for Hell! to it will ye (surely) come!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
If these had been gods, they would not have got there! but each one will abide therein.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
There, sobbing will be their lot, nor will they there hear (aught else).\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Those for whom the good (record) from Us has gone before, will be removed far therefrom.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
Not the slightest sound will they hear of Hell: what their souls desired, in that will they dwell.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The Great Terror will bring them no grief: but the angels will meet them (with mutual greetings): ``This is your Day,- (the Day) that ye were promised."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
The Day that We roll up the heavens like a scroll rolled up for books (completed),- even as We produced the first creation, so shall We produce a new one: a promise We have undertaken: truly shall We fulfil it.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
Before this We wrote in the Psalms, after the Message (given to Moses): My servants the righteous, shall inherit the earth."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Verily in this (Qur'an) is a Message for people who would (truly) worship Allah.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We sent thee not, but as a Mercy for all creatures.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: ``What has come to me by inspiration is that your Allah is One Allah: will ye therefore bow to His Will (in Islam)?"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they turn back, Say: ``I have proclaimed the Message to you all alike and in truth; but I know not whether that which ye are promised is near or far.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
``It is He Who knows what is open in speech and what ye hide (in your hearts).\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
``I know not but that it may be a trial for you, and a grant of (worldly) livelihood (to you) for a time."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
Say: ``O my Lord! judge Thou in truth!" ``Our Lord Most Gracious is the One Whose assistance should be sought against the blasphemies ye utter!"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind! fear your Lord! for the convulsion of the Hour (of Judgment) will be a thing terrible!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
The Day ye shall see it, every mother giving suck shall forget her suckling-babe, and every pregnant female shall drop her load (unformed): thou shalt see mankind as in a drunken riot, yet not drunk: but dreadful will be the Wrath of Allah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And yet among men there are such as dispute about Allah, without knowledge, and follow every evil one obstinate in rebellion!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
About the (Evil One) it is decreed that whoever turns to him for friendship, him will he lead astray, and he will guide him to the Penalty of the Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O mankind! if ye have a doubt about the Resurrection, (consider) that We created you out of dust, then out of sperm, then out of a leech-like clot, then out of a morsel of flesh, partly formed and partly unformed, in order that We may manifest (our power) to you; and We cause whom We will to rest in the wombs for an appointed term, then do We bring you out as babes, then (foster you) that ye may reach your age of full strength; and some of you are called to die, and some are sent back to the feeblest old age, so that they know nothing after having known (much), and (further), thou seest the earth barren and lifeless, but when We pour down rain on it, it is stirred (to life), it swells, and it puts forth every kind of beautiful growth (in pairs).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
This is so, because Allah is the Reality: it is He Who gives life to the dead, and it is He Who has power over all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And verily the Hour will come: there can be no doubt about it, or about (the fact) that Allah will raise up all who are in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
Yet there is among men such a one as disputes about Allah, without Knowledge, without Guidance, and without a Book of Enlightenment,-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
(Disdainfully) bending his side, in order to lead (men) astray from the Path of Allah: for him there is disgrace in this life, and on the Day of Judgment We shall make him taste the Penalty of burning (Fire).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
(It will be said): ``This is because of the deeds which thy hands sent forth, for verily Allah is not unjust to His servants.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
There are among men some who serve Allah, as it were, on the verge: if good befalls them, they are, therewith, well content; but if a trial comes to them, they turn on their faces: they lose both this world and the Hereafter: that is loss for all to see!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
They call on such deities, besides Allah, as can neither hurt nor profit them: that is straying far indeed (from the Way)!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
(Perhaps) they call on one whose hurt is nearer than his profit: evil, indeed, is the patron, and evil the companion (or help)!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Verily Allah will admit those who believe and work righteous deeds, to Gardens, beneath which rivers flow: for Allah carries out all that He plans.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
If any think that Allah will not help him (His Messenger) in this world and the Hereafter, let him stretch out a rope to the ceiling and cut (himself) off: then let him see whether his plan will remove that which enrages (him)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Thus have We sent down Clear Signs; and verily Allah doth guide whom He will!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Those who believe (in the Qur'an), those who follow the Jewish (scriptures), and the Sabians, Christians, Magians, and Polytheists,- Allah will judge between them on the Day of Judgment: for Allah is witness of all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Seest thou not that to Allah bow down in worship all things that are in the heavens and on earth,- the sun, the moon, the stars; the hills, the trees, the animals; and a great number among mankind? But a great number are (also) such as are fit for Punishment: and such as Allah shall disgrace,- None can raise to honour: for Allah carries out all that He wills.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These two antagonists dispute with each other about their Lord: But those who deny (their Lord),- for them will be cut out a garment of Fire: over their heads will be poured out boiling water.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
With it will be scalded what is within their bodies, as well as (their) skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
In addition there will be maces of iron (to punish) them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Every time they wish to get away therefrom, from anguish, they will be forced back therein, and (it will be said), ``Taste ye the Penalty of Burning!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Allah will admit those who believe and work righteous deeds, to Gardens beneath which rivers flow: they shall be adorned therein with bracelets of gold and pearls; and their garments there will be of silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
For they have been guided (in this life) to the purest of speeches; they have been guided to the Path of Him Who is Worthy of (all) Praise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
As to those who have rejected (Allah), and would keep back (men) from the Way of Allah, and from the Sacred Mosque, which We have made (open) to (all) men - equal is the dweller there and the visitor from the country - and any whose purpose therein is profanity or wrong-doing - them will We cause to taste of a most Grievous Penalty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
Behold! We gave the site, to Abraham, of the (Sacred) House, (saying): ``Associate not anything (in worship) with Me; and sanctify My House for those who compass it round, or stand up, or bow, or prostrate themselves (therein in prayer).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
``And proclaim the Pilgrimage among men: they will come to thee on foot and (mounted) on every kind of camel, lean on account of journeys through deep and distant mountain highways;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
``That they may witness the benefits (provided) for them, and celebrate the name of Allah, through the Days appointed, over the cattle which He has provided for them (for sacrifice): then eat ye thereof and feed the distressed ones in want.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
``Then let them complete the rites prescribed for them, perform their vows, and (again) circumambulate the Ancient House."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
Such (is the Pilgrimage): whoever honours the sacred rites of Allah, for him it is good in the Sight of his Lord. Lawful to you (for food in Pilgrimage) are cattle, except those mentioned to you (as exception): but shun the abomination of idols, and shun the word that is false,-\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Being true in faith to Allah, and never assigning partners to Him: if anyone assigns partners to Allah, is as if he had fallen from heaven and been snatched up by birds, or the wind had swooped (like a bird on its prey) and thrown him into a far-distant place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
Such (is his state): and whoever holds in honour the symbols of Allah, (in the sacrifice of animals), such (honour) should come truly from piety of heart.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In them ye have benefits for a term appointed: in the end their place of sacrifice is near the Ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
To every people did We appoint rites (of sacrifice), that they might celebrate the name of Allah over the sustenance He gave them from animals (fit for food). But your god is One God: submit then your wills to Him (in Islam): and give thou the good news to those who humble themselves,-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
To those whose hearts when Allah is mentioned, are filled with fear, who show patient perseverance over their afflictions, keep up regular prayer, and spend (in charity) out of what We have bestowed upon them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
The sacrificial camels we have made for you as among the symbols from Allah: in them is (much) good for you: then pronounce the name of Allah over them as they line up (for sacrifice): when they are down on their sides (after slaughter), eat ye thereof, and feed such as (beg not but) live in contentment, and such as beg with due humility: thus have We made animals subject to you, that ye may be grateful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
It is not their meat nor their blood, that reaches Allah: it is your piety that reaches Him: He has thus made them subject to you, that ye may glorify Allah for His Guidance to you and proclaim the good news to all who do right.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Verily Allah will defend (from ill) those who believe: verily, Allah loveth not any that is a traitor to faith, or show ingratitude.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
To those against whom war is made, permission is given (to fight), because they are wronged;- and verily, Allah is most powerful for their aid;-\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
(They are) those who have been expelled from their homes in defiance of right,- (for no cause) except that they say, ``our Lord is Allah". Did not Allah check one set of people by means of another, there would surely have been pulled down monasteries, churches, synagogues, and mosques, in which the name of Allah is commemorated in abundant measure. Allah will certainly aid those who aid his (cause);- for verily Allah is full of Strength, Exalted in Might, (able to enforce His Will).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
(They are) those who, if We establish them in the land, establish regular prayer and give regular charity, enjoin the right and forbid wrong: with Allah rests the end (and decision) of (all) affairs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they treat thy (mission) as false, so did the peoples before them (with their prophets),- the People of Noah, and 'Ad and Thamud;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
Those of Abraham and Lut;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the Companions of the Madyan People; and Moses was rejected (in the same way). But I granted respite to the Unbelievers, and (only) after that did I punish them: but how (terrible) was my rejection (of them)!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many populations have We destroyed, which were given to wrong-doing? They tumbled down on their roofs. And how many wells are lying idle and neglected, and castles lofty and well-built?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Do they not travel through the land, so that their hearts (and minds) may thus learn wisdom and their ears may thus learn to hear? Truly it is not their eyes that are blind, but their hearts which are in their breasts.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
Yet they ask thee to hasten on the Punishment! But Allah will not fail in His Promise. Verily a Day in the sight of thy Lord is like a thousand years of your reckoning.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And to how many populations did I give respite, which were given to wrong-doing? in the end I punished them. To me is the destination (of all).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say: ``O men! I am (sent) to you only to give a Clear Warning:\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
``Those who believe and work righteousness, for them is forgiveness and a sustenance most generous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
``But those who strive against Our Signs, to frustrate them,- they will be Companions of the Fire."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never did We send a messenger or a prophet before thee, but, when he framed a desire, Satan threw some (vanity) into his desire: but Allah will cancel anything (vain) that Satan throws in, and Allah will confirm (and establish) His Signs: for Allah is full of Knowledge and Wisdom:\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
That He may make the suggestions thrown in by Satan, but a trial for those in whose hearts is a disease and who are hardened of heart: verily the wrong-doers are in a schism far (from the Truth):\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And that those on whom knowledge has been bestowed may learn that the (Qur'an) is the Truth from thy Lord, and that they may believe therein, and their hearts may be made humbly (open) to it: for verily Allah is the Guide of those who believe, to the Straight Way.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
Those who reject Faith will not cease to be in doubt concerning (Revelation) until the Hour (of Judgment) comes suddenly upon them, or there comes to them the Penalty of a Day of Disaster.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
On that Day of Dominion will be that of Allah: He will judge between them: so those who believe and work righteous deeds will be in Gardens of Delight.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And for those who reject Faith and deny our Signs, there will be a humiliating Punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
Those who leave their homes in the cause of Allah, and are then slain or die,- On them will Allah bestow verily a goodly Provision: Truly Allah is He Who bestows the best provision.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
Verily He will admit them to a place with which they shall be well pleased: for Allah is All-Knowing, Most Forbearing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That (is so). And if one has retaliated to no greater extent than the injury he received, and is again set upon inordinately, Allah will help him: for Allah is One that blots out (sins) and forgives (again and again).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah merges night into day, and He merges day into night, and verily it is Allah Who hears and sees (all things).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah - He is the Reality; and those besides Him whom they invoke,- they are but vain Falsehood: verily Allah is He, Most High, Most Great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Seest thou not that Allah sends down rain from the sky, and forthwith the earth becomes clothed with green? for Allah is He Who understands the finest mysteries, and is well-acquainted (with them).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs all that is in the heavens and on earth: for verily Allah,- He is free of all wants, Worthy of all Praise.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Seest thou not that Allah has made subject to you (men) all that is on the earth, and the ships that sail through the sea by His Command? He withholds the sky (rain) from failing on the earth except by His leave: for Allah is Most Kind and Most Merciful to man.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
It is He Who gave you life, will cause you to die, and will again give you life: Truly man is a most ungrateful creature!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
To every People have We appointed rites and ceremonies which they must follow: let them not then dispute with thee on the matter, but do thou invite (them) to thy Lord: for thou art assuredly on the Right Way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
If they do wrangle with thee, say, ``Allah knows best what it is ye are doing."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
``Allah will judge between you on the Day of Judgment concerning the matters in which ye differ."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Knowest thou not that Allah knows all that is in heaven and on earth? Indeed it is all in a Record, and that is easy for Allah.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
Yet they worship, besides Allah, things for which no authority has been sent down to them, and of which they have (really) no knowledge: for those that do wrong there is no helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
When Our Clear Signs are rehearsed to them, thou wilt notice a denial on the faces of the Unbelievers! they nearly attack with violence those who rehearse Our Signs to them. Say, ``Shall I tell you of something (far) worse than these Signs? It is the Fire (of Hell)! Allah has promised it to the Unbelievers! and evil is that destination!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O men! Here is a parable set forth! listen to it! Those on whom, besides Allah, ye call, cannot create (even) a fly, if they all met together for the purpose! and if the fly should snatch away anything from them, they would have no power to release it from the fly. Feeble are those who petition and those whom they petition!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
No just estimate have they made of Allah: for Allah is He Who is strong and able to Carry out His Will.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses messengers from angels and from men for Allah is He Who hears and sees (all things).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is before them and what is behind them: and to Allah go back all questions (for decision).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O ye who believe! bow down, prostrate yourselves, and adore your Lord; and do good; that ye may prosper.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive in His cause as ye ought to strive, (with sincerity and under discipline). He has chosen you, and has imposed no difficulties on you in religion; it is the cult of your father Abraham. It is He Who has named you Muslims, both before and in this (Revelation); that the Messenger may be a witness for you, and ye be witnesses for mankind! So establish regular Prayer, give regular Charity, and hold fast to Allah! He is your Protector - the Best to protect and the Best to help!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen The believers must (eventually) win through,-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who humble themselves in their prayers;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
Who avoid vain talk;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
Who are active in deeds of charity;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
Who abstain from sex,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except with those joined to them in the marriage bond, or (the captives) whom their right hands possess,- for (in their case) they are free from blame,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But those whose desires exceed those limits are transgressors;-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
Those who faithfully observe their trusts and their covenants;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And who (strictly) guard their prayers;-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These will be the heirs,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who will inherit Paradise: they will dwell therein (for ever).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
Man We did create from a quintessence (of clay);\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Then We placed him as (a drop of) sperm in a place of rest, firmly fixed;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We made the sperm into a clot of congealed blood; then of that clot We made a (foetus) lump; then we made out of that lump bones and clothed the bones with flesh; then we developed out of it another creature. So blessed be Allah, the best to create!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
After that, at length ye will die\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Again, on the Day of Judgment, will ye be raised up.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And We have made, above you, seven tracts; and We are never unmindful of (our) Creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We send down water from the sky according to (due) measure, and We cause it to soak in the soil; and We certainly are able to drain it off (with ease).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
With it We grow for you gardens of date-palms and vines: in them have ye abundant fruits: and of them ye eat (and have enjoyment),-\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
Also a tree springing out of Mount Sinai, which produces oil, and relish for those who use it for food.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And in cattle (too) ye have an instructive example: from within their bodies We produce (milk) for you to drink; there are, in them, (besides), numerous (other) benefits for you; and of their (meat) ye eat;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them, as well as in ships, ye ride.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
(Further, We sent a long line of prophets for your instruction). We sent Noah to his people: He said, ``O my people! worship Allah! Ye have no other god but Him. Will ye not fear (Him)?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
The chiefs of the Unbelievers among his people said: ``He is no more than a man like yourselves: his wish is to assert his superiority over you: if Allah had wished (to send messengers), He could have sent down angels; never did we hear such a thing (as he says), among our ancestors of old."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
(And some said): ``He is only a man possessed: wait (and have patience) with him for a time."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
(Noah) said: ``O my Lord! help me: for that they accuse me of falsehood!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So We inspired him (with this message): ``Construct the Ark within Our sight and under Our guidance: then when comes Our Command, and the fountains of the earth gush forth, take thou on board pairs of every species, male and female, and thy family- except those of them against whom the Word has already gone forth: And address Me not in favour of the wrong-doers; for they shall be drowned (in the Flood).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when thou hast embarked on the Ark - thou and those with thee,- say: ``Praise be to Allah, Who has saved us from the people who do wrong."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say: ``O my Lord! enable me to disembark with thy blessing: for Thou art the Best to enable (us) to disembark."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Verily in this there are Signs (for men to understand); (thus) do We try (men).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then We raised after them another generation.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And We sent to them a messenger from among themselves, (saying), ``Worship Allah! ye have no other god but Him. Will ye not fear (Him)?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And the chiefs of his people, who disbelieved and denied the Meeting in the Hereafter, and on whom We had bestowed the good things of this life, said: ``He is no more than a man like yourselves: he eats of that of which ye eat, and drinks of what ye drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
``If ye obey a man like yourselves, behold, it is certain ye will be lost.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
``Does he promise that when ye die and become dust and bones, ye shall be brought forth (again)?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
``Far, very far is that which ye are promised!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
``There is nothing but our life in this world! We shall die and we live! But we shall never be raised up again!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
``He is only a man who invents a lie against Allah, but we are not the ones to believe in him!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
(The prophet) said: ``O my Lord! help me: for that they accuse me of falsehood."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
(Allah) said: ``In but a little while, they are sure to be sorry!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
Then the Blast overtook them with justice, and We made them as rubbish of dead leaves (floating on the stream of Time)! So away with the people who do wrong!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then We raised after them other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No people can hasten their term, nor can they delay (it).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then sent We our messengers in succession: every time there came to a people their messenger, they accused him of falsehood: so We made them follow each other (in punishment): We made them as a tale (that is told): So away with a people that will not believe!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron, with Our Signs and authority manifest,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
To Pharaoh and his Chiefs: But these behaved insolently: they were an arrogant people.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said: ``Shall we believe in two men like ourselves? And their people are subject to us!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they accused them of falsehood, and they became of those who were destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We gave Moses the Book, in order that they might receive guidance.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Mary and his mother as a Sign: We gave them both shelter on high ground, affording rest and security and furnished with springs.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O ye messengers! enjoy (all) things good and pure, and work righteousness: for I am well-acquainted with (all) that ye do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And verily this Brotherhood of yours is a single Brotherhood, and I am your Lord and Cherisher: therefore fear Me (and no other).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But people have cut off their affair (of unity), between them, into sects: each party rejoices in that which is with itself.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
But leave them in their confused ignorance for a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they think that because We have granted them abundance of wealth and sons,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We would hasten them on in every good? Nay, they do not understand.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Verily those who live in awe for fear of their Lord;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
Those who believe in the Signs of their Lord;\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
Those who join not (in worship) partners with their Lord;\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who dispense their charity with their hearts full of fear, because they will return to their Lord;-\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
It is these who hasten in every good work, and these who are foremost in them.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
On no soul do We place a burden greater than it can bear: before Us is a record which clearly shows the truth: they will never be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
But their hearts are in confused ignorance of this; and there are, besides that, deeds of theirs, which they will (continue) to do,-\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until, when We seize in Punishment those of them who received the good things of this world, behold, they will groan in supplication!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
(It will be said): ``Groan not in supplication this day: for ye shall certainly not be helped by Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
``My Signs used to be rehearsed to you, but ye used to turn back on your heels-\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
``In arrogance: talking nonsense about the (Qur'an), like one telling fables by night."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Do they not ponder over the Word (of Allah), or has anything (new) come to them that did not come to their fathers of old?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or do they not recognise their Messenger, that they deny him?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or do they say, ``He is possessed"? Nay, he has brought them the Truth, but most of them hate the Truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
If the Truth had been in accord with their desires, truly the heavens and the earth, and all beings therein would have been in confusion and corruption! Nay, We have sent them their admonition, but they turn away from their admonition.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or is it that thou askest them for some recompense? But the recompense of thy Lord is best: He is the Best of those who give sustenance.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
But verily thou callest them to the Straight Way;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And verily those who believe not in the Hereafter are deviating from that Way.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
If We had mercy on them and removed the distress which is on them, they would obstinately persist in their transgression, wandering in distraction to and fro.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
We inflicted Punishment on them, but they humbled not themselves to their Lord, nor do they submissively entreat (Him)!-\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until We open on them a gate leading to a severe Punishment: then Lo! they will be plunged in despair therein!\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He Who has created for you (the faculties of) hearing, sight, feeling and understanding: little thanks it is ye give!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And He has multiplied you through the earth, and to Him shall ye be gathered back.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
It is He Who gives life and death, and to Him (is due) the alternation of Night and Day: will ye not then understand?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
On the contrary they say things similar to what the ancients said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say: ``What! when we die and become dust and bones, could we really be raised up again?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
``Such things have been promised to us and to our fathers before! they are nothing but tales of the ancients!"\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: ``To whom belong the earth and all beings therein? (say) if ye know!"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say, ``To Allah!" say: ``Yet will ye not receive admonition?"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: ``Who is the Lord of the seven heavens, and the Lord of the Throne (of Glory) Supreme?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say, ``(They belong) to Allah." Say: ``Will ye not then be filled with awe?"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say: ``Who is it in whose hands is the governance of all things,- who protects (all), but is not protected (of any)? (say) if ye know."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say, ``(It belongs) to Allah." Say: ``Then how are ye deluded?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
We have sent them the Truth: but they indeed practise falsehood!\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
No son did Allah beget, nor is there any god along with Him: (if there were many gods), behold, each god would have taken away what he had created, and some would have lorded it over others! Glory to Allah! (He is free) from the (sort of) things they attribute to Him!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
He knows what is hidden and what is open: too high is He for the partners they attribute to Him!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say: ``O my Lord! if Thou wilt show me (in my lifetime) that which they are warned against,-\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
``Then, O my Lord! put me not amongst the people who do wrong!"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And We are certainly able to show thee (in fulfilment) that against which they are warned.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with that which is best: We are well acquainted with the things they say.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say ``O my Lord! I seek refuge with Thee from the suggestions of the Evil Ones.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
``And I seek refuge with Thee O my Lord! lest they should come near me."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
(In Falsehood will they be) Until, when death comes to one of them, he says: ``O my Lord! send me back (to life),-\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
``In order that I may work righteousness in the things I neglected." - ``By no means! It is but a word he says."- Before them is a Partition till the Day they are raised up.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
Then when the Trumpet is blown, there will be no more relationships between them that Day, nor will one ask after another!\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then those whose balance (of good deeds) is heavy,- they will attain salvation:\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
But those whose balance is light, will be those who have lost their souls, in Hell will they abide.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire will burn their faces, and they will therein grin, with their lips displaced.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
``Were not My Signs rehearsed to you, and ye did but treat them as falsehood?"\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: ``our Lord! Our misfortune overwhelmed us, and we became a people astray!\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
``Our Lord! bring us out of this: if ever we return (to Evil), then shall we be wrong-doers indeed!"\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He will say: ``Be ye driven into it (with ignominy)! And speak ye not to Me!\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
``A part of My servants there was, who used to pray 'our Lord! we believe; then do Thou forgive us, and have mercy upon us: For Thou art the Best of those who show mercy!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
``But ye treated them with ridicule, so much so that (ridicule of) them made you forget My Message while ye were laughing at them!\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
``I have rewarded them this Day for their patience and constancy: they are indeed the ones that have achieved Bliss..."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say: ``What number of years did ye stay on earth?"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say: ``We stayed a day or part of a day: but ask those who keep account."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: ``Ye stayed not but a little,- if ye had only known!\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
``Did ye then think that We had created you in jest, and that ye would not be brought back to Us (for account)?"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
Therefore exalted be Allah, the King, the Reality: there is no god but He, the Lord of the Throne of Honour!\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
If anyone invokes, besides Allah, Any other god, he has no authority therefor; and his reckoning will be only with his Lord! and verily the Unbelievers will fail to win through!\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
So say: ``O my Lord! grant Thou forgiveness and mercy for Thou art the Best of those who show mercy!"\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen A sura which We have sent down and which We have ordained in it have We sent down Clear Signs, in order that ye may receive admonition.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The woman and the man guilty of adultery or fornication,- flog each of them with a hundred stripes: Let not compassion move you in their case, in a matter prescribed by Allah, if ye believe in Allah and the Last Day: and let a party of the Believers witness their punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
Let no man guilty of adultery or fornication marry and but a woman similarly guilty, or an Unbeliever: nor let any but such a man or an Unbeliever marry such a woman: to the Believers such a thing is forbidden.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who launch a charge against chaste women, and produce not four witnesses (to support their allegations),- flog them with eighty stripes; and reject their evidence ever after: for such men are wicked transgressors;-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Unless they repent thereafter and mend (their conduct); for Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And for those who launch a charge against their spouses, and have (in support) no evidence but their own,- their solitary evidence (can be received) if they bear witness four times (with an oath) by Allah that they are solemnly telling the truth;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth (oath) (should be) that they solemnly invoke the curse of Allah on themselves if they tell a lie.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But it would avert the punishment from the wife, if she bears witness four times (with an oath) By Allah, that (her husband) is telling a lie;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth (oath) should be that she solemnly invokes the wrath of Allah on herself if (her accuser) is telling the truth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
If it were not for Allah's grace and mercy on you, and that Allah is Oft-Returning, full of Wisdom,- (Ye would be ruined indeed).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Those who brought forward the lie are a body among yourselves: think it not to be an evil to you; On the contrary it is good for you: to every man among them (will come the punishment) of the sin that he earned, and to him who took on himself the lead among them, will be a penalty grievous.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why did not the believers - men and women - when ye heard of the affair,- put the best construction on it in their own minds and say, ``This (charge) is an obvious lie"?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not bring four witnesses to prove it? When they have not brought the witnesses, such men, in the sight of Allah, (stand forth) themselves as liars!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Were it not for the grace and mercy of Allah on you, in this world and the Hereafter, a grievous penalty would have seized you in that ye rushed glibly into this affair.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
Behold, ye received it on your tongues, and said out of your mouths things of which ye had no knowledge; and ye thought it to be a light matter, while it was most serious in the sight of Allah.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why did ye not, when ye heard it, say? - ``It is not right of us to speak of this: Glory to Allah! this is a most serious slander!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah doth admonish you, that ye may never repeat such (conduct), if ye are (true) Believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah makes the Signs plain to you: for Allah is full of knowledge and wisdom.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Those who love (to see) scandal published broadcast among the Believers, will have a grievous Penalty in this life and in the Hereafter: Allah knows, and ye know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
Were it not for the grace and mercy of Allah on you, and that Allah is full of kindness and mercy, (ye would be ruined indeed).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O ye who believe! follow not Satan's footsteps: if any will follow the footsteps of Satan, he will (but) command what is shameful and wrong: and were it not for the grace and mercy of Allah on you, not one of you would ever have been pure: but Allah doth purify whom He pleases: and Allah is One Who hears and knows (all things).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
Let not those among you who are endued with grace and amplitude of means resolve by oath against helping their kinsmen, those in want, and those who have left their homes in Allah's cause: let them forgive and overlook, do you not wish that Allah should forgive you? For Allah is Oft-Forgiving, Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Those who slander chaste women, indiscreet but believing, are cursed in this life and in the Hereafter: for them is a grievous Penalty,-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day when their tongues, their hands, and their feet will bear witness against them as to their actions.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day Allah will pay them back (all) their just dues, and they will realise that Allah is the (very) Truth, that makes all things manifest.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Women impure are for men impure, and men impure for women impure and women of purity are for men of purity, and men of purity are for women of purity: these are not affected by what people say: for them there is forgiveness, and a provision honourable.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O ye who believe! enter not houses other than your own, until ye have asked permission and saluted those in them: that is best for you, in order that ye may heed (what is seemly).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
If ye find no one in the house, enter not until permission is given to you: if ye are asked to go back, go back: that makes for greater purity for yourselves: and Allah knows well all that ye do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
It is no fault on your part to enter houses not used for living in, which serve some (other) use for you: And Allah has knowledge of what ye reveal and what ye conceal.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Say to the believing men that they should lower their gaze and guard their modesty: that will make for greater purity for them: And Allah is well acquainted with all that they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And say to the believing women that they should lower their gaze and guard their modesty; that they should not display their beauty and ornaments except what (must ordinarily) appear thereof; that they should draw their veils over their bosoms and not display their beauty except to their husbands, their fathers, their husband's fathers, their sons, their husbands' sons, their brothers or their brothers' sons, or their sisters' sons, or their women, or the slaves whom their right hands possess, or male servants free of physical needs, or small children who have no sense of the shame of sex; and that they should not strike their feet in order to draw attention to their hidden ornaments. And O ye Believers! turn ye all together towards Allah, that ye may attain Bliss.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
Marry those among you who are single, or the virtuous ones among yourselves, male or female: if they are in poverty, Allah will give them means out of His grace: for Allah encompasseth all, and he knoweth all things.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
Let those who find not the wherewithal for marriage keep themselves chaste, until Allah gives them means out of His grace. And if any of your slaves ask for a deed in writing (to enable them to earn their freedom for a certain sum), give them such a deed if ye know any good in them: yea, give them something yourselves out of the means which Allah has given to you. But force not your maids to prostitution when they desire chastity, in order that ye may make a gain in the goods of this life. But if anyone compels them, yet, after such compulsion, is Allah, Oft-Forgiving, Most Merciful (to them),\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
We have already sent down to you verses making things clear, an illustration from (the story of) people who passed away before you, and an admonition for those who fear (Allah).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth. The Parable of His Light is as if there were a Niche and within it a Lamp: the Lamp enclosed in Glass: the glass as it were a brilliant star: Lit from a blessed Tree, an Olive, neither of the east nor of the west, whose oil is well-nigh luminous, though fire scarce touched it: Light upon Light! Allah doth guide whom He will to His Light: Allah doth set forth Parables for men: and Allah doth know all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
(Lit is such a Light) in houses, which Allah hath permitted to be raised to honour; for the celebration, in them, of His name: In them is He glorified in the mornings and in the evenings, (again and again),-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
By men whom neither traffic nor merchandise can divert from the Remembrance of Allah, nor from regular Prayer, nor from the practice of regular Charity: Their (only) fear is for the Day when hearts and eyes will be transformed (in a world wholly new),-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may reward them according to the best of their deeds, and add even more for them out of His Grace: for Allah doth provide for those whom He will, without measure.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
But the Unbelievers,- their deeds are like a mirage in sandy deserts, which the man parched with thirst mistakes for water; until when he comes up to it, he finds it to be nothing: But he finds Allah (ever) with him, and Allah will pay him his account: and Allah is swift in taking account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or (the Unbelievers' state) is like the depths of darkness in a vast deep ocean, overwhelmed with billow topped by billow, topped by (dark) clouds: depths of darkness, one above another: if a man stretches out his hands, he can hardly see it! for any to whom Allah giveth not light, there is no light!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Seest thou not that it is Allah Whose praises all beings in the heavens and on earth do celebrate, and the birds (of the air) with wings outspread? Each one knows its own (mode of) prayer and praise. And Allah knows well all that they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
Yea, to Allah belongs the dominion of the heavens and the earth; and to Allah is the final goal (of all).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Seest thou not that Allah makes the clouds move gently, then joins them together, then makes them into a heap? - then wilt thou see rain issue forth from their midst. And He sends down from the sky mountain masses (of clouds) wherein is hail: He strikes therewith whom He pleases and He turns it away from whom He pleases, the vivid flash of His lightning well-nigh blinds the sight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
It is Allah Who alternates the Night and the Day: verily in these things is an instructive example for those who have vision!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
And Allah has created every animal from water: of them there are some that creep on their bellies; some that walk on two legs; and some that walk on four. Allah creates what He wills for verily Allah has power over all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have indeed sent down signs that make things manifest: and Allah guides whom He wills to a way that is straight.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
They say, ``We believe in Allah and in the messenger, and we obey": but even after that, some of them turn away: they are not (really) Believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
When they are summoned to Allah and His messenger, in order that He may judge between them, behold some of them decline (to come).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if the right is on their side, they come to him with all submission.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is it that there is a disease in their hearts? or do they doubt, or are they in fear, that Allah and His Messenger will deal unjustly with them? Nay, it is they themselves who do wrong.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The answer of the Believers, when summoned to Allah and His Messenger, in order that He may judge between them, is no other than this: they say, ``We hear and we obey": it is such as these that will attain felicity.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
It is such as obey Allah and His Messenger, and fear Allah and do right, that will win (in the end),\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They swear their strongest oaths by Allah that, if only thou wouldst command them, they would leave (their homes). Say: ``Swear ye not; Obedience is (more) reasonable; verily, Allah is well acquainted with all that ye do."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: ``Obey Allah, and obey the Messenger: but if ye turn away, he is only responsible for the duty placed on him and ye for that placed on you. If ye obey him, ye shall be on right guidance. The Messenger's duty is only to preach the clear (Message).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised, to those among you who believe and work righteous deeds, that He will, of a surety, grant them in the land, inheritance (of power), as He granted it to those before them; that He will establish in authority their religion - the one which He has chosen for them; and that He will change (their state), after the fear in which they (lived), to one of security and peace: 'They will worship Me (alone) and not associate aught with Me. 'If any do reject Faith after this, they are rebellious and wicked.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
So establish regular Prayer and give regular Charity; and obey the Messenger; that ye may receive mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Never think thou that the Unbelievers are going to frustrate (Allah's Plan) on earth: their abode is the Fire,- and it is indeed an evil refuge!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O ye who believe! let those whom your right hands possess, and the (children) among you who have not come of age ask your permission (before they come to your presence), on three occasions: before morning prayer; the while ye doff your clothes for the noonday heat; and after the late-night prayer: these are your three times of undress: outside those times it is not wrong for you or for them to move about attending to each other: Thus does Allah make clear the Signs to you: for Allah is full of knowledge and wisdom.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
But when the children among you come of age, let them (also) ask for permission, as do those senior to them (in age): Thus does Allah make clear His Signs to you: for Allah is full of knowledge and wisdom.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
Such elderly women as are past the prospect of marriage,- there is no blame on them if they lay aside their (outer) garments, provided they make not a wanton display of their beauty: but it is best for them to be modest: and Allah is One Who sees and knows all things.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
It is no fault in the blind nor in one born lame, nor in one afflicted with illness, nor in yourselves, that ye should eat in your own houses, or those of your fathers, or your mothers, or your brothers, or your sisters, or your father's brothers or your father's sisters, or your mother's brothers, or your mother's sisters, or in houses of which the keys are in your possession, or in the house of a sincere friend of yours: there is no blame on you, whether ye eat in company or separately. But if ye enter houses, salute each other - a greeting of blessing and purity as from Allah. Thus does Allah make clear the signs to you: that ye may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
Only those are believers, who believe in Allah and His Messenger: when they are with him on a matter requiring collective action, they do not depart until they have asked for his leave; those who ask for thy leave are those who believe in Allah and His Messenger; so when they ask for thy leave, for some business of theirs, give leave to those of them whom thou wilt, and ask Allah for their forgiveness: for Allah is Oft-Forgiving, Most Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Deem not the summons of the Messenger among yourselves like the summons of one of you to another: Allah doth know those of you who slip away under shelter of some excuse: then let those beware who withstand the Messenger's order, lest some trial befall them, or a grievous penalty be inflicted on them.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Be quite sure that to Allah doth belong whatever is in the heavens and on earth. Well doth He know what ye are intent upon: and one day they will be brought back to Him, and He will tell them the truth of what they did: for Allah doth know all things.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed is He who sent down the criterion to His servant, that it may be an admonition to all creatures;-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to whom belongs the dominion of the heavens and the earth: no son has He begotten, nor has He a partner in His dominion: it is He who created all things, and ordered them in due proportions.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet have they taken, besides him, gods that can create nothing but are themselves created; that have no control of hurt or good to themselves; nor can they control death nor life nor resurrection.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
But the misbelievers say: ``Naught is this but a lie which he has forged, and others have helped him at it." In truth it is they who have put forward an iniquity and a falsehood.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say: ``Tales of the ancients, which he has caused to be written: and they are dictated before him morning and evening."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say: ``The (Qur'an) was sent down by Him who knows the mystery (that is) in the heavens and the earth: verily He is Oft-Forgiving, Most Merciful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say: ``What sort of a messenger is this, who eats food, and walks through the streets? Why has not an angel been sent down to him to give admonition with him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
``Or (Why) has not a treasure been bestowed on him, or why has he (not) a garden for enjoyment?" The wicked say: ``Ye follow none other than a man bewitched."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
See what kinds of comparisons they make for thee! But they have gone astray, and never a way will they be able to find!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed is He who, if that were His will, could give thee better (things) than those,- Gardens beneath which rivers flow; and He could give thee palaces (secure to dwell in).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Nay they deny the hour (of the judgment to come): but We have prepared a blazing fire for such as deny the hour:\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it sees them from a place far off, they will hear its fury and its ranging sigh.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are cast, bound together into a constricted place therein, they will plead for destruction there and then!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
``This day plead not for a single destruction: plead for destruction oft-repeated!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: ``Is that best, or the eternal garden, promised to the righteous? for them, that is a reward as well as a goal (of attainment).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
``For them there will be therein all that they wish for: they will dwell (there) for aye: A promise to be prayed for from thy Lord."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
The day He will gather them together as well as those whom they worship besides Allah, He will ask: ``Was it ye who let these My servants astray, or did they stray from the Path themselves?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say: ``Glory to Thee! not meet was it for us that we should take for protectors others besides Thee: But Thou didst bestow, on them and their fathers, good things (in life), until they forgot the Message: for they were a people (worthless and) lost."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
(Allah will say): ``Now have they proved you liars in what ye say: so ye cannot avert (your penalty) nor (get) help." And whoever among you does wrong, him shall We cause to taste of a grievous Penalty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And the messengers whom We sent before thee were all (men) who ate food and walked through the streets: We have made some of you as a trial for others: will ye have patience? for Allah is One Who sees (all things).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
Such as fear not the meeting with Us (for Judgment) say: ``Why are not the angels sent down to us, or (why) do we not see our Lord?" Indeed they have an arrogant conceit of themselves, and mighty is the insolence of their impiety!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
The Day they see the angels,- no joy will there be to the sinners that Day: The (angels) will say: ``There is a barrier forbidden (to you) altogether!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We shall turn to whatever deeds they did (in this life), and We shall make such deeds as floating dust scattered about.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The Companions of the Garden will be well, that Day, in their abode, and have the fairest of places for repose.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
The Day the heaven shall be rent asunder with clouds, and angels shall be sent down, descending (in ranks),-\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
That Day, the dominion as of right and truth, shall be (wholly) for (Allah) Most Merciful: it will be a Day of dire difficulty for the misbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
The Day that the wrong-doer will bite at his hands, he will say, ``Oh! would that I had taken a (straight) path with the Messenger!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
``Ah! woe is me! Would that I had never taken such a one for a friend!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
``He did lead me astray from the Message (of Allah) after it had come to me! Ah! the Evil One is but a traitor to man!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
Then the Messenger will say: ``O my Lord! Truly my people took this Qur'an for just foolish nonsense."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Thus have We made for every prophet an enemy among the sinners: but enough is thy Lord to guide and to help.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
Those who reject Faith say: ``Why is not the Qur'an revealed to him all at once? Thus (is it revealed), that We may strengthen thy heart thereby, and We have rehearsed it to thee in slow, well-arranged stages, gradually.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And no question do they bring to thee but We reveal to thee the truth and the best explanation (thereof).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be gathered to Hell (prone) on their faces,- they will be in an evil plight, and, as to Path, most astray.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
(Before this,) We sent Moses The Book, and appointed his brother Aaron with him as minister;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
And We command: ``Go ye both, to the people who have rejected our Signs:" And those (people) We destroyed with utter destruction.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Noah,- when they rejected the messengers, We drowned them, and We made them as a Sign for mankind; and We have prepared for (all) wrong-doers a grievous Penalty;-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
As also 'Ad and Thamud, and the Companions of the Rass, and many a generation between them.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
To each one We set forth Parables and examples; and each one We broke to utter annihilation (for their sins).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And the (Unbelievers) must indeed have passed by the town on which was rained a shower of evil: did they not then see it (with their own eyes)? But they fear not the Resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
When they see thee, they treat thee no otherwise than in mockery: ``Is this the one whom Allah has sent as a messenger?"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
``He indeed would well-nigh have misled us from our gods, had it not been that we were constant to them!" - Soon will they know, when they see the Penalty, who it is that is most misled in Path!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Seest thou such a one as taketh for his god his own passion (or impulse)? Couldst thou be a disposer of affairs for him?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or thinkest thou that most of them listen or understand? They are only like cattle;- nay, they are worse astray in Path.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Hast thou not turned thy vision to thy Lord?- How He doth prolong the shadow! If He willed, He could make it stationary! then do We make the sun its guide;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We draw it in towards Ourselves,- a contraction by easy stages.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And He it is Who makes the Night as a Robe for you, and Sleep as Repose, and makes the Day (as it were) a Resurrection.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And He it is Who sends the winds as heralds of glad tidings, going before His mercy, and We send down pure water from the sky,-\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That with it We may give life to a dead land, and slake the thirst of things We have created,- cattle and men in great numbers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And We have distributed the (water) amongst them, in order that they may celebrate (our) praises, but most men are averse (to aught) but (rank) ingratitude.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
Had it been Our Will, We could have sent a warner to every centre of population.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
Therefore listen not to the Unbelievers, but strive against them with the utmost strenuousness, with the (Qur'an).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
It is He Who has let free the two bodies of flowing water: One palatable and sweet, and the other salt and bitter; yet has He made a barrier between them, a partition that is forbidden to be passed.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
It is He Who has created man from water: then has He established relationships of lineage and marriage: for thy Lord has power (over all things).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
Yet do they worship, besides Allah, things that can neither profit them nor harm them: and the Misbeliever is a helper (of Evil), against his own Lord!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
But thee We only sent to give glad tidings and admonition.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: ``No reward do I ask of you for it but this: that each one who will may take a (straight) Path to his Lord."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And put thy trust in Him Who lives and dies not; and celebrate his praise; and enough is He to be acquainted with the faults of His servants;-\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
He Who created the heavens and the earth and all that is between, in six days, and is firmly established on the Throne (of Authority): Allah Most Gracious: ask thou, then, about Him of any acquainted (with such things).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
When it is said to them, ``Prostrate to (Allah) Most Gracious!", they say, ``And what is (Allah) Most Gracious? Shall we prostrate to that which thou commandest us?" And it increases their flight (from the Truth).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed is He Who made constellations in the skies, and placed therein a Lamp and a Moon giving light;\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He Who made the Night and the Day to follow each other: for such as have the will to celebrate His praises or to show their gratitude.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the servants of (Allah) Most Gracious are those who walk on the earth in humility, and when the ignorant address them, they say, ``Peace!";\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
Those who spend the night in adoration of their Lord prostrate and standing;\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
Those who say, ``Our Lord! avert from us the Wrath of Hell, for its Wrath is indeed an affliction grievous,-\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
``Evil indeed is it as an abode, and as a place to rest in";\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
Those who, when they spend, are not extravagant and not niggardly, but hold a just (balance) between those (extremes);\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
Those who invoke not, with Allah, any other god, nor slay such life as Allah has made sacred except for just cause, nor commit fornication; - and any that does this (not only) meets punishment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
(But) the Penalty on the Day of Judgment will be doubled to him, and he will dwell therein in ignominy,-\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Unless he repents, believes, and works righteous deeds, for Allah will change the evil of such persons into good, and Allah is Oft-Forgiving, Most Merciful,\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whoever repents and does good has truly turned to Allah with an (acceptable) conversion;-\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
Those who witness no falsehood, and, if they pass by futility, they pass by it with honourable (avoidance);\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
Those who, when they are admonished with the Signs of their Lord, droop not down at them as if they were deaf or blind;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who pray, ``Our Lord! Grant unto us wives and offspring who will be the comfort of our eyes, and give us (the grace) to lead the righteous."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those are the ones who will be rewarded with the highest place in heaven, because of their patient constancy: therein shall they be met with salutations and peace,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Dwelling therein;- how beautiful an abode and place of rest!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say (to the Rejecters): ``My Lord is not uneasy because of you if ye call not on Him: But ye have indeed rejected (Him), and soon will come the inevitable (punishment)!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta. Sin. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are verses of the Book that makes (things) clear.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
It may be thou frettest thy soul with grief, that they do not become Believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If (such) were Our Will, We could send down to them from the sky a Sign, to which they would bend their necks in humility.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
But there comes not to them a newly-revealed Message from (Allah) Most Gracious, but they turn away therefrom.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
They have indeed rejected (the Message): so they will know soon (enough) the truth of what they mocked at!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Do they not look at the earth,- how many noble things of all kinds We have produced therein?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Verily, in this is a Sign: but most of them do not believe.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And verily, thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
Behold, thy Lord called Moses: ``Go to the people of iniquity,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
``The people of the Pharaoh: will they not fear Allah?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: ``O my Lord! I do fear that they will charge me with falsehood:\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
``My breast will be straitened. And my speech may not go (smoothly): so send unto Aaron.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
``And (further), they have a charge of crime against me; and I fear they may slay me."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
Allah said: ``By no means! proceed then, both of you, with Our Signs; We are with you, and will listen (to your call).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
``So go forth, both of you, to Pharaoh, and say: 'We have been sent by the Lord and Cherisher of the worlds;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
``'Send thou with us the Children of Israel.'"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
(Pharaoh) said: ``Did we not cherish thee as a child among us, and didst thou not stay in our midst many years of thy life?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
``And thou didst a deed of thine which (thou knowest) thou didst, and thou art an ungrateful (wretch)!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Moses said: ``I did it then, when I was in error.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
``So I fled from you (all) when I feared you; but my Lord has (since) invested me with judgment (and wisdom) and appointed me as one of the messengers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
``And this is the favour with which thou dost reproach me,- that thou hast enslaved the Children of Israel!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said: ``And what is the 'Lord and Cherisher of the worlds'?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
(Moses) said: ``The Lord and Cherisher of the heavens and the earth, and all between,- if ye want to be quite sure."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
(Pharaoh) said to those around: ``Did ye not listen (to what he says)?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
(Moses) said: ``Your Lord and the Lord of your fathers from the beginning!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
(Pharaoh) said: ``Truly your messenger who has been sent to you is a veritable madman!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
(Moses) said: ``Lord of the East and the West, and all between! if ye only had sense!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
(Pharaoh) said: ``If thou dost put forward any god other than me, I will certainly put thee in prison!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
(Moses) said: ``Even if I showed you something clear (and) convincing?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
(Pharaoh) said: ``Show it then, if thou tellest the truth!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So (Moses) threw his rod, and behold, it was a serpent, plain (for all to see)!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew out his hand, and behold, it was white to all beholders!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
(Pharaoh) said to the Chiefs around him: ``This is indeed a sorcerer well-versed:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
``His plan is to get you out of your land by his sorcery; then what is it ye counsel?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: ``Keep him and his brother in suspense (for a while), and dispatch to the Cities heralds to collect-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
``And bring up to thee all (our) sorcerers well-versed."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the sorcerers were got together for the appointment of a day well-known,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And the people were told: ``Are ye (now) assembled?-\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
``That we may follow the sorcerers (in religion) if they win?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
So when the sorcerers arrived, they said to Pharaoh: ``Of course - shall we have a (suitable) reward if we win?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: ``Yea, (and more),- for ye shall in that case be (raised to posts) nearest (to my person)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them: ``Throw ye - that which ye are about to throw!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they threw their ropes and their rods, and said: ``By the might of Pharaoh, it is we who will certainly win!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses threw his rod, when, behold, it straightway swallows up all the falsehoods which they fake!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
Then did the sorcerers fall down, prostrate in adoration,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
Saying: ``We believe in the Lord of the Worlds,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
``The Lord of Moses and Aaron."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
Said (Pharaoh): ``Believe ye in Him before I give you permission? surely he is your leader, who has taught you sorcery! but soon shall ye know! Be sure I will cut off your hands and your feet on opposite sides, and I will cause you all to die on the cross!"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: ``No matter! for us, we shall but return to our Lord!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
``Only, our desire is that our Lord will forgive us our faults, that we may become foremost among the believers!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
By inspiration we told Moses: ``Travel by night with my servants; for surely ye shall be pursued."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent heralds to (all) the Cities,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
(Saying): ``These (Israelites) are but a small band,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
``And they are raging furiously against us;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
``But we are a multitude amply fore-warned."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So We expelled them from gardens, springs,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
Treasures, and every kind of honourable position;\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Thus it was, but We made the Children of Israel inheritors of such things.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
So they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two bodies saw each other, the people of Moses said: ``We are sure to be overtaken."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
(Moses) said: ``By no means! my Lord is with me! Soon will He guide me!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We told Moses by inspiration: ``Strike the sea with thy rod." So it divided, and each separate part became like the huge, firm mass of a mountain.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And We made the other party approach thither.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
We delivered Moses and all who were with him;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
But We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Verily in this is a Sign: but most of them do not believe.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And rehearse to them (something of) Abraham's story.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
Behold, he said to his father and his people: ``What worship ye?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said: ``We worship idols, and we remain constantly in attendance on them."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said: ``Do they listen to you when ye call (on them)?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
``Or do you good or harm?"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said: ``Nay, but we found our fathers doing thus (what we do)."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: ``Do ye then see whom ye have been worshipping,-\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
``Ye and your fathers before you?-\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
``For they are enemies to me; not so the Lord and Cherisher of the Worlds;\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
``Who created me, and it is He Who guides me;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
``Who gives me food and drink,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
``And when I am ill, it is He Who cures me;\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
``Who will cause me to die, and then to life (again);\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
``And who, I hope, will forgive me my faults on the day of Judgment.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
``O my Lord! bestow wisdom on me, and join me with the righteous;\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
``Grant me honourable mention on the tongue of truth among the latest (generations);\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
``Make me one of the inheritors of the Garden of Bliss;\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
``Forgive my father, for that he is among those astray;\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
``And let me not be in disgrace on the Day when (men) will be raised up;-\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
``The Day whereon neither wealth nor sons will avail,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
``But only he (will prosper) that brings to Allah a sound heart;\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
``To the righteous, the Garden will be brought near,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
``And to those straying in Evil, the Fire will be placed in full view;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
``And it shall be said to them: 'Where are the (gods) ye worshipped-\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
``'Besides Allah? Can they help you or help themselves?'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
``Then they will be thrown headlong into the (Fire),- they and those straying in Evil,\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
``And the whole hosts of Iblis together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
``They will say there in their mutual bickerings:\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
``'By Allah, we were truly in an error manifest,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
``'When we held you as equals with the Lord of the Worlds;\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
``'And our seducers were only those who were steeped in guilt.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
``'Now, then, we have none to intercede (for us),\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
``'Nor a single friend to feel (for us).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
``'Now if we only had a chance of return we shall truly be of those who believe!'"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Verily in this is a Sign but most of them do not believe.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Noah rejected the messengers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
Behold, their brother Noah said to them: ``Will ye not fear (Allah)?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
``I am to you a messenger worthy of all trust:\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
``So fear Allah, and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
``No reward do I ask of you for it: my reward is only from the Lord of the Worlds:\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
``So fear Allah, and obey me."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said: ``Shall we believe in thee when it is the meanest that follow thee?"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: ``And what do I know as to what they do?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
``Their account is only with my Lord, if ye could (but) understand.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
``I am not one to drive away those who believe.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
``I am sent only to warn plainly in public."\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: ``If thou desist not, O Noah! thou shalt be stoned (to death)."\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: ``O my Lord! truly my people have rejected me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
``Judge Thou, then, between me and them openly, and deliver me and those of the Believers who are with me."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
So We delivered him and those with him, in the Ark filled (with all creatures).\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Thereafter We drowned those who remained behind.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Verily in this is a Sign: but most of them do not believe.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
The 'Ad (people) rejected the messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
Behold, their brother Hud said to them: ``Will ye not fear (Allah)?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
``I am to you a messenger worthy of all trust:\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
``So fear Allah and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
``No reward do I ask of you for it: my reward is only from the Lord of the Worlds.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
``Do ye build a landmark on every high place to amuse yourselves?\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
``And do ye get for yourselves fine buildings in the hope of living therein (for ever)?\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
``And when ye exert your strong hand, do ye do it like men of absolute power?\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
``Now fear Allah, and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
``Yea, fear Him Who has bestowed on you freely all that ye know.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
``Freely has He bestowed on you cattle and sons,-\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
``And Gardens and Springs.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
``Truly I fear for you the Penalty of a Great Day."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said: ``It is the same to us whether thou admonish us or be not among (our) admonishers!\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
``This is no other than a customary device of the ancients,\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
``And we are not the ones to receive Pains and Penalties!"\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they rejected him, and We destroyed them. Verily in this is a Sign: but most of them do not believe.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
The Thamud (people) rejected the messengers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
Behold, their brother Salih said to them: ``Will you not fear (Allah)?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
``I am to you a messenger worthy of all trust.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
``So fear Allah, and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
``No reward do I ask of you for it: my reward is only from the Lord of the Worlds.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
``Will ye be left secure, in (the enjoyment of) all that ye have here?-\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
``Gardens and Springs,\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
``And corn-fields and date-palms with spathes near breaking (with the weight of fruit)?\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
``And ye carve houses out of (rocky) mountains with great skill.\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
``But fear Allah and obey me;\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
``And follow not the bidding of those who are extravagant,-\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
``Who make mischief in the land, and mend not (their ways)."\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said: ``Thou art only one of those bewitched!\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
``Thou art no more than a mortal like us: then bring us a Sign, if thou tellest the truth!"\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: ``Here is a she-camel: she has a right of watering, and ye have a right of watering, (severally) on a day appointed.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
``Touch her not with harm, lest the Penalty of a Great Day seize you."\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they ham-strung her: then did they become full of regrets.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
But the Penalty seized them. Verily in this is a Sign: but most of them do not believe.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lut rejected the messengers.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
Behold, their brother Lut said to them: ``Will ye not fear (Allah)?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
``I am to you a messenger worthy of all trust.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
``So fear Allah and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
``No reward do I ask of you for it: my reward is only from the lord of the Worlds.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
``Of all the creatures in the world, will ye approach males,\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
``And leave those whom Allah has created for you to be your mates? Nay, ye are a people transgressing (all limits)!"\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: ``If thou desist not, O Lut! thou wilt assuredly be cast out!"\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: ``I do detest your doings."\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
``O my Lord! deliver me and my family from such things as they do!"\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We delivered him and his family,- all\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except an old woman who lingered behind.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
But the rest We destroyed utterly.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
We rained down on them a shower (of brimstone): and evil was the shower on those who were admonished (but heeded not)!\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Verily in this is a Sign: but most of them do not believe.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And verily thy Lord is He, the Exalted in Might Most Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The Companions of the Wood rejected the messengers.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
Behold, Shu'aib said to them: ``Will ye not fear (Allah)?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
``I am to you a messenger worthy of all trust.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
``So fear Allah and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
``No reward do I ask of you for it: my reward is only from the Lord of the Worlds.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
``Give just measure, and cause no loss (to others by fraud).\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
``And weigh with scales true and upright.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
``And withhold not things justly due to men, nor do evil in the land, working mischief.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
``And fear Him Who created you and (who created) the generations before (you)"\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: ``Thou art only one of those bewitched!\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
``Thou art no more than a mortal like us, and indeed we think thou art a liar!\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
``Now cause a piece of the sky to fall on us, if thou art truthful!"\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said: ``My Lord knows best what ye do."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they rejected him. Then the punishment of a day of overshadowing gloom seized them, and that was the Penalty of a Great Day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Verily in that is a Sign: but most of them do not believe.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And verily thy Lord is He, the Exalted in Might, Most Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
Verily this is a Revelation from the Lord of the Worlds:\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
With it came down the spirit of Faith and Truth-\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
To thy heart and mind, that thou mayest admonish.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In the perspicuous Arabic tongue.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
Without doubt it is (announced) in the mystic Books of former peoples.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a Sign to them that the Learned of the Children of Israel knew it (as true)?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
Had We revealed it to any of the non-Arabs,\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And had he recited it to them, they would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus have We caused it to enter the hearts of the sinners.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they see the grievous Penalty;\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
But the (Penalty) will come to them of a sudden, while they perceive it not;\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say: ``Shall we be respited?"\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Do they then ask for Our Penalty to be hastened on?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Seest thou? If We do let them enjoy (this life) for a few years,\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
Yet there comes to them at length the (Punishment) which they were promised!\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
It will profit them not that they enjoyed (this life)!\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
Never did We destroy a population, but had its warners -\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
By way of reminder; and We never are unjust.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
No evil ones have brought down this (Revelation):\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
It would neither suit them nor would they be able (to produce it).\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Indeed they have been removed far from even (a chance of) hearing it.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So call not on any other god with Allah, or thou wilt be among those under the Penalty.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And admonish thy nearest kinsmen,\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And lower thy wing to the Believers who follow thee.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
Then if they disobey thee, say: ``I am free (of responsibility) for what ye do!"\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put thy trust on the Exalted in Might, the Merciful,-\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who seeth thee standing forth (in prayer),\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And thy movements among those who prostrate themselves,\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
For it is He Who heareth and knoweth all things.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you, (O people!), on whom it is that the evil ones descend?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every lying, wicked person,\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
(Into whose ears) they pour hearsay vanities, and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
And the Poets,- It is those straying in Evil, who follow them:\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Seest thou not that they wander distracted in every valley?-\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And that they say what they practise not?-\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those who believe, work righteousness, engage much in the remembrance of Allah, and defend themselves only after they are unjustly attacked. And soon will the unjust assailants know what vicissitudes their affairs will take!\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen These are verses of the Qur'an,-a book that makes (things) clear;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guide: and glad tidings for the believers,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Those who establish regular prayers and give in regular charity, and also have (full) assurance of the hereafter.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
As to those who believe not in the Hereafter, We have made their deeds pleasing in their eyes; and so they wander about in distraction.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
Such are they for whom a grievous Penalty is (waiting); and in the Hereafter theirs will be the greatest loss.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
As to thee, the Qur'an is bestowed upon thee from the presence of one who is wise and all-knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
Behold! Moses said to his family: ``I perceive a fire; soon will I bring you from there some information, or I will bring you a burning brand to light our fuel, that ye may warm yourselves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when he came to the (fire), a voice was heard: ``Blessed are those in the fire and those around: and glory to Allah, the Lord of the worlds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
``O Moses! verily, I am Allah, the exalted in might, the wise!....\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
``Now do thou throw thy rod!" But when he saw it moving (of its own accord) as if it had been a snake, he turned back in retreat, and retraced not his steps: ``O Moses!" (it was said), ``Fear not: truly, in My presence, those called as messengers have no fear,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
``But if any have done wrong and have thereafter substituted good to take the place of evil, truly, I am Oft-Forgiving, Most Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
``Now put thy hand into thy bosom, and it will come forth white without stain (or harm): (these are) among the nine Signs (thou wilt take) to Pharaoh and his people: for they are a people rebellious in transgression."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our Signs came to them, that should have opened their eyes, they said: ``This is sorcery manifest!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they rejected those Signs in iniquity and arrogance, though their souls were convinced thereof: so see what was the end of those who acted corruptly!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
We gave (in the past) knowledge to David and Solomon: And they both said: ``Praise be to Allah, Who has favoured us above many of his servants who believe!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon was David's heir. He said: ``O ye people! We have been taught the speech of birds, and on us has been bestowed (a little) of all things: this is indeed Grace manifest (from Allah.)"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And before Solomon were marshalled his hosts,- of Jinns and men and birds, and they were all kept in order and ranks.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
At length, when they came to a (lowly) valley of ants, one of the ants said: ``O ye ants, get into your habitations, lest Solomon and his hosts crush you (under foot) without knowing it."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
So he smiled, amused at her speech; and he said: ``O my Lord! so order me that I may be grateful for Thy favours, which thou hast bestowed on me and on my parents, and that I may work the righteousness that will please Thee: And admit me, by Thy Grace, to the ranks of Thy righteous Servants."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he took a muster of the Birds; and he said: ``Why is it I see not the Hoopoe? Or is he among the absentees?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
``I will certainly punish him with a severe penalty, or execute him, unless he bring me a clear reason (for absence)."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But the Hoopoe tarried not far: he (came up and) said: ``I have compassed (territory) which thou hast not compassed, and I have come to thee from Saba with tidings true.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
``I found (there) a woman ruling over them and provided with every requisite; and she has a magnificent throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
``I found her and her people worshipping the sun besides Allah: Satan has made their deeds seem pleasing in their eyes, and has kept them away from the Path,- so they receive no guidance,-\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
``(Kept them away from the Path), that they should not worship Allah, Who brings to light what is hidden in the heavens and the earth, and knows what ye hide and what ye reveal.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
``Allah!- there is no god but He!- Lord of the Throne Supreme!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
(Solomon) said: ``Soon shall we see whether thou hast told the truth or lied!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
``Go thou, with this letter of mine, and deliver it to them: then draw back from them, and (wait to) see what answer they return"...\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
(The queen) said: ``Ye chiefs! here is delivered to me - a letter worthy of respect.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
``It is from Solomon, and is (as follows): 'In the name of Allah, Most Gracious, Most Merciful:\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
``'Be ye not arrogant against me, but come to me in submission (to the true Religion).'"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: ``Ye chiefs! advise me in (this) my affair: no affair have I decided except in your presence."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: ``We are endued with strength, and given to vehement war: but the command is with thee; so consider what thou wilt command."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: ``Kings, when they enter a country, despoil it, and make the noblest of its people its meanest thus do they behave.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
``But I am going to send him a present, and (wait) to see with what (answer) return (my) ambassadors."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
Now when (the embassy) came to Solomon, he said: ``Will ye give me abundance in wealth? But that which Allah has given me is better than that which He has given you! Nay it is ye who rejoice in your gift!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
``Go back to them, and be sure we shall come to them with such hosts as they will never be able to meet: We shall expel them from there in disgrace, and they will feel humbled (indeed)."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said (to his own men): ``Ye chiefs! which of you can bring me her throne before they come to me in submission?"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
Said an 'Ifrit, of the Jinns: ``I will bring it to thee before thou rise from thy council: indeed I have full strength for the purpose, and may be trusted."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
Said one who had knowledge of the Book: ``I will bring it to thee within the twinkling of an eye!" Then when (Solomon) saw it placed firmly before him, he said: ``This is by the Grace of my Lord!- to test me whether I am grateful or ungrateful! and if any is grateful, truly his gratitude is (a gain) for his own soul; but if any is ungrateful, truly my Lord is Free of all Needs, Supreme in Honour!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said: ``Transform her throne out of all recognition by her: let us see whether she is guided (to the truth) or is one of those who receive no guidance."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So when she arrived, she was asked, ``Is this thy throne?" She said, ``It was just like this; and knowledge was bestowed on us in advance of this, and we have submitted to Allah (in Islam)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And he diverted her from the worship of others besides Allah: for she was (sprung) of a people that had no faith.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
She was asked to enter the lofty Palace: but when she saw it, she thought it was a lake of water, and she (tucked up her skirts), uncovering her legs. He said: ``This is but a palace paved smooth with slabs of glass." She said: ``O my Lord! I have indeed wronged my soul: I do (now) submit (in Islam), with Solomon, to the Lord of the Worlds."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
We sent (aforetime), to the Thamud, their brother Salih, saying, ``Serve Allah": But behold, they became two factions quarrelling with each other.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said: ``O my people! why ask ye to hasten on the evil in preference to the good? If only ye ask Allah for forgiveness, ye may hope to receive mercy.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: ``Ill omen do we augur from thee and those that are with thee". He said: ``Your ill omen is with Allah; yea, ye are a people under trial."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
There were in the city nine men of a family, who made mischief in the land, and would not reform.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: ``Swear a mutual oath by Allah that we shall make a secret night attack on him and his people, and that we shall then say to his heir (when he seeks vengeance): 'We were not present at the slaughter of his people, and we are positively telling the truth.'"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
They plotted and planned, but We too planned, even while they perceived it not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Then see what was the end of their plot!- this, that We destroyed them and their people, all (of them).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
Now such were their houses, - in utter ruin, - because they practised wrong-doing. Verily in this is a Sign for people of knowledge.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed and practised righteousness.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
(We also sent) Lut (as a messenger): behold, He said to his people, ``Do ye do what is shameful though ye see (its iniquity)?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Would ye really approach men in your lusts rather than women? Nay, ye are a people (grossly) ignorant!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
But his people gave no other answer but this: they said, ``Drive out the followers of Lut from your city: these are indeed men who want to be clean and pure!"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
But We saved him and his family, except his wife; her We destined to be of those who lagged behind.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained down on them a shower (of brimstone): and evil was the shower on those who were admonished (but heeded not)!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say: Praise be to Allah, and Peace on his servants whom He has chosen (for his Message). (Who) is better?- Allah or the false gods they associate (with Him)?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Or, Who has created the heavens and the earth, and Who sends you down rain from the sky? Yea, with it We cause to grow well-planted orchards full of beauty of delight: it is not in your power to cause the growth of the trees in them. (Can there be another) god besides Allah? Nay, they are a people who swerve from justice.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Or, Who has made the earth firm to live in; made rivers in its midst; set thereon mountains immovable; and made a separating bar between the two bodies of flowing water? (can there be another) god besides Allah? Nay, most of them know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Or, Who listens to the (soul) distressed when it calls on Him, and Who relieves its suffering, and makes you (mankind) inheritors of the earth? (Can there be another) god besides Allah? Little it is that ye heed!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Or, Who guides you through the depths of darkness on land and sea, and Who sends the winds as heralds of glad tidings, going before His Mercy? (Can there be another) god besides Allah?- High is Allah above what they associate with Him!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Or, Who originates creation, then repeats it, and who gives you sustenance from heaven and earth? (Can there be another) god besides Allah? Say, ``Bring forth your argument, if ye are telling the truth!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: None in the heavens or on earth, except Allah, knows what is hidden: nor can they perceive when they shall be raised up (for Judgment).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Still less can their knowledge comprehend the Hereafter: Nay, they are in doubt and uncertainty thereanent; nay, they are blind thereunto!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
The Unbelievers say: ``What! when we become dust,- we and our fathers,- shall we really be raised (from the dead)?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
``It is true we were promised this,- we and our fathers before (us): these are nothing but tales of the ancients."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say: ``Go ye through the earth and see what has been the end of those guilty (of sin)."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
But grieve not over them, nor distress thyself because of their plots.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
They also say: ``When will this promise (come to pass)? (Say) if ye are truthful."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: ``It may be that some of the events which ye wish to hasten on may be (close) in your pursuit!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
But verily thy Lord is full of grace to mankind: Yet most of them are ungrateful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And verily thy Lord knoweth all that their hearts do hide. As well as all that they reveal.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
Nor is there aught of the unseen, in heaven or earth, but is (recorded) in a clear record.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Verily this Qur'an doth explain to the Children of Israel most of the matters in which they disagree.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And it certainly is a Guide and a Mercy to those who believe.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Verily thy Lord will decide between them by His Decree: and He is Exalted in Might, All-Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So put thy trust in Allah: for thou art on (the path of) manifest Truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Truly thou canst not cause the dead to listen, nor canst thou cause the deaf to hear the call, (especially) when they turn back in retreat.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor canst thou be a guide to the blind, (to prevent them) from straying: only those wilt thou get to listen who believe in Our Signs, and they will bow in Islam.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word is fulfilled against them (the unjust), we shall produce from the earth a beast to (face) them: He will speak to them, for that mankind did not believe with assurance in Our Signs.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
One day We shall gather together from every people a troop of those who reject our Signs, and they shall be kept in ranks,-\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Until, when they come (before the Judgment-seat), (Allah) will say: ``Did ye reject My Signs, though ye comprehended them not in knowledge, or what was it ye did?"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word will be fulfilled against them, because of their wrong-doing, and they will be unable to speak (in plea).\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
See they not that We have made the Night for them to rest in and the Day to give them light? Verily in this are Signs for any people that believe!\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And the Day that the Trumpet will be sounded - then will be smitten with terror those who are in the heavens, and those who are on earth, except such as Allah will please (to exempt): and all shall come to His (Presence) as beings conscious of their lowliness.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
Thou seest the mountains and thinkest them firmly fixed: but they shall pass away as the clouds pass away: (such is) the artistry of Allah, who disposes of all things in perfect order: for he is well acquainted with all that ye do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
If any do good, good will (accrue) to them therefrom; and they will be secure from terror that Day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And if any do evil, their faces will be thrown headlong into the Fire: ``Do ye receive a reward other than that which ye have earned by your deeds?"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
For me, I have been commanded to serve the Lord of this city, Him Who has sanctified it and to Whom (belong) all things: and I am commanded to be of those who bow in Islam to Allah's Will,-\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And to rehearse the Qur'an: and if any accept guidance, they do it for the good of their own souls, and if any stray, say: ``I am only a Warner".\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: ``Praise be to Allah, Who will soon show you His Signs, so that ye shall know them"; and thy Lord is not unmindful of all that ye do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta. Sin. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are Verses of the Book that makes (things) clear.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We rehearse to thee some of the story of Moses and Pharaoh in Truth, for people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Truly Pharaoh elated himself in the land and broke up its people into sections, depressing a small group among them: their sons he slew, but he kept alive their females: for he was indeed a maker of mischief.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We wished to be Gracious to those who were being depressed in the land, to make them leaders (in Faith) and make them heirs,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
To establish a firm place for them in the land, and to show Pharaoh, Haman, and their hosts, at their hands, the very things against which they were taking precautions.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
So We sent this inspiration to the mother of Moses: ``Suckle (thy child), but when thou hast fears about him, cast him into the river, but fear not nor grieve: for We shall restore him to thee, and We shall make him one of Our messengers."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Then the people of Pharaoh picked him up (from the river): (It was intended) that (Moses) should be to them an adversary and a cause of sorrow: for Pharaoh and Haman and (all) their hosts were men of sin.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
The wife of Pharaoh said: ``(Here is) joy of the eye, for me and for thee: slay him not. It may be that he will be use to us, or we may adopt him as a son." And they perceived not (what they were doing)!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
But there came to be a void in the heart of the mother of Moses: She was going almost to disclose his (case), had We not strengthened her heart (with faith), so that she might remain a (firm) believer.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said to the sister of (Moses), ``Follow him" so she (the sister) watched him in the character of a stranger. And they knew not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And we ordained that he refused suck at first, until (His sister came up and) said: ``Shall I point out to you the people of a house that will nourish and bring him up for you and be sincerely attached to him?"...\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
Thus did We restore him to his mother, that her eye might be comforted, that she might not grieve, and that she might know that the promise of Allah is true: but most of them do not understand.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
When he reached full age, and was firmly established (in life), We bestowed on him wisdom and knowledge: for thus do We reward those who do good.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city at a time when its people were not watching: and he found there two men fighting,- one of his own religion, and the other, of his foes. Now the man of his own religion appealed to him against his foe, and Moses struck him with his fist and made an end of him. He said: ``This is a work of Evil (Satan): for he is an enemy that manifestly misleads!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He prayed: ``O my Lord! I have indeed wronged my soul! Do Thou then forgive me!" So (Allah) forgave him: for He is the Oft-Forgiving, Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: ``O my Lord! For that Thou hast bestowed Thy Grace on me, never shall I be a help to those who sin!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
So he saw the morning in the city, looking about, in a state of fear, when behold, the man who had, the day before, sought his help called aloud for his help (again). Moses said to him: ``Thou art truly, it is clear, a quarrelsome fellow!"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
Then, when he decided to lay hold of the man who was an enemy to both of them, that man said: ``O Moses! Is it thy intention to slay me as thou slewest a man yesterday? Thy intention is none other than to become a powerful violent man in the land, and not to be one who sets things right!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And there came a man, running, from the furthest end of the City. He said: ``O Moses! the Chiefs are taking counsel together about thee, to slay thee: so get thee away, for I do give thee sincere advice."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
He therefore got away therefrom, looking about, in a state of fear. He prayed ``O my Lord! save me from people given to wrong-doing."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
Then, when he turned his face towards (the land of) Madyan, he said: ``I do hope that my Lord will show me the smooth and straight Path."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he arrived at the watering (place) in Madyan, he found there a group of men watering (their flocks), and besides them he found two women who were keeping back (their flocks). He said: ``What is the matter with you?" They said: ``We cannot water (our flocks) until the shepherds take back (their flocks): And our father is a very old man."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he watered (their flocks) for them; then he turned back to the shade, and said:"O my Lord! truly am I in (desperate) need of any good that Thou dost send me!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Afterwards one of the (damsels) came (back) to him, walking bashfully. She said: ``My father invites thee that he may reward thee for having watered (our flocks) for us." So when he came to him and narrated the story, he said: ``Fear thou not: (well) hast thou escaped from unjust people."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
Said one of the (damsels): ``O my (dear) father! engage him on wages: truly the best of men for thee to employ is the (man) who is strong and trusty"....\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: ``I intend to wed one of these my daughters to thee, on condition that thou serve me for eight years; but if thou complete ten years, it will be (grace) from thee. But I intend not to place thee under a difficulty: thou wilt find me, indeed, if Allah wills, one of the righteous."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
He said: ``Be that (the agreement) between me and thee: whichever of the two terms I fulfil, let there be no ill-will to me. Be Allah a witness to what we say."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
Now when Moses had fulfilled the term, and was travelling with his family, he perceived a fire in the direction of Mount Tur. He said to his family: ``Tarry ye; I perceive a fire; I hope to bring you from there some information, or a burning firebrand, that ye may warm yourselves."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
But when he came to the (fire), a voice was heard from the right bank of the valley, from a tree in hallowed ground: ``O Moses! Verily I am Allah, the Lord of the Worlds....\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
``Now do thou throw thy rod!" but when he saw it moving (of its own accord) as if it had been a snake, he turned back in retreat, and retraced not his steps: O Moses!" (It was said), ``Draw near, and fear not: for thou art of those who are secure.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
``Move thy hand into thy bosom, and it will come forth white without stain (or harm), and draw thy hand close to thy side (to guard) against fear. Those are the two credentials from thy Lord to Pharaoh and his Chiefs: for truly they are a people rebellious and wicked."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said: ``O my Lord! I have slain a man among them, and I fear lest they slay me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
``And my brother Aaron - He is more eloquent in speech than I: so send him with me as a helper, to confirm (and strengthen) me: for I fear that they may accuse me of falsehood."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said: ``We will certainly strengthen thy arm through thy brother, and invest you both with authority, so they shall not be able to touch you: with Our Sign shall ye triumph,- you two as well as those who follow you."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
When Moses came to them with Our clear signs, they said: ``This is nothing but sorcery faked up: never did we head the like among our fathers of old!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Moses said: ``My Lord knows best who it is that comes with guidance from Him and whose end will be best in the Hereafter: certain it is that the wrong-doers will not prosper."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
Pharaoh said: ``O Chiefs! no god do I know for you but myself: therefore, O Haman! light me a (kiln to bake bricks) out of clay, and build me a lofty palace, that I may mount up to the god of Moses: but as far as I am concerned, I think (Moses) is a liar!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he was arrogant and insolent in the land, beyond reason,- He and his hosts: they thought that they would not have to return to Us!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
So We seized him and his hosts, and We flung them into the sea: Now behold what was the end of those who did wrong!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And we made them (but) leaders inviting to the Fire; and on the Day of Judgment no help shall they find.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
in this world We made a curse to follow them and on the Day of Judgment they will be among the loathed (and despised).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
We did reveal to Moses the Book after We had destroyed the earlier generations, (to give) Insight to men, and guidance and Mercy, that they might receive admonition.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
Thou wast not on the Western side when We decreed the Commission to Moses, nor wast thou a witness (of those events).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We raised up (new) generations, and long were the ages that passed over them; but thou wast not a dweller among the people of Madyan, rehearsing Our Signs to them; but it is We Who send messengers (with inspiration).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
Nor wast thou at the side of (the Mountain of) Tur when we called (to Moses). Yet (art thou sent) as Mercy from thy Lord, to give warning to a people to whom no warner had come before thee: in order that they may receive admonition.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
If (We had) not (sent thee to the Quraish),- in case a calamity should seize them for (the deeds) that their hands have sent forth, they might say: ``Our Lord! why didst Thou not sent us a messenger? We should then have followed Thy Signs and been amongst those who believe!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But (now), when the Truth has come to them from Ourselves, they say, ``Why are not (Signs) sent to him, like those which were sent to Moses?" Do they not then reject (the Signs) which were formerly sent to Moses? They say: ``Two kinds of sorcery, each assisting the other!" And they say: ``For us, we reject all (such things)!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say: ``Then bring ye a Book from Allah, which is a better guide than either of them, that I may follow it! (do), if ye are truthful!"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they hearken not to thee, know that they only follow their own lusts: and who is more astray than one who follow his own lusts, devoid of guidance from Allah? for Allah guides not people given to wrong-doing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
Now have We caused the Word to reach them themselves, in order that they may receive admonition.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We sent the Book before this,- they do believe in this (revelation):\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is recited to them, they say: ``We believe therein, for it is the Truth from our Lord: indeed we have been Muslims (bowing to Allah's Will) from before this.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
Twice will they be given their reward, for that they have persevered, that they avert Evil with Good, and that they spend (in charity) out of what We have given them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear vain talk, they turn away therefrom and say: ``To us our deeds, and to you yours; peace be to you: we seek not the ignorant."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
It is true thou wilt not be able to guide every one, whom thou lovest; but Allah guides those whom He will and He knows best those who receive guidance.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
They say: ``If we were to follow the guidance with thee, we should be snatched away from our land." Have We not established for them a secure sanctuary, to which are brought as tribute fruits of all kinds,- a provision from Ourselves? but most of them understand not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many populations We destroyed, which exulted in their life (of ease and plenty)! now those habitations of theirs, after them, are deserted,- All but a (miserable) few! and We are their heirs!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Nor was thy Lord the one to destroy a population until He had sent to its centre a messenger, rehearsing to them Our Signs; nor are We going to destroy a population except when its members practise iniquity.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
The (material) things which ye are given are but the conveniences of this life and the glitter thereof; but that which is with Allah is better and more enduring: will ye not then be wise?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Are (these two) alike?- one to whom We have made a goodly promise, and who is going to reach its (fulfilment), and one to whom We have given the good things of this life, but who, on the Day of Judgment, is to be among those brought up (for punishment)?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
That Day (Allah) will call to them, and say ``Where are my 'partners'?- whom ye imagined (to be such)?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the charge will be proved, will say: ``Our Lord! These are the ones whom we led astray: we led them astray, as we were astray ourselves: we free ourselves (from them) in Thy presence: it was not us they worshipped."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
It will be said (to them): ``Call upon your 'partners' (for help)": they will call upon them, but they will not listen to them; and they will see the Penalty (before them); (how they will wish) 'if only they had been open to guidance!'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
That Day (Allah) will call to them, and say: ``What was the answer ye gave to the messengers?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Then the (whole) story that Day will seem obscure to them (like light to the blind) and they will not be able (even) to question each other.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But any that (in this life) had repented, believed, and worked righteousness, will have hopes to be among those who achieve salvation.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Thy Lord does create and choose as He pleases: no choice have they (in the matter): Glory to Allah! and far is He above the partners they ascribe (to Him)!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And thy Lord knows all that their hearts conceal and all that they reveal.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah: There is no god but He. To Him be praise, at the first and at the last: for Him is the Command, and to Him shall ye (all) be brought back.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say: See ye? If Allah were to make the night perpetual over you to the Day of Judgment, what god is there other than Allah, who can give you enlightenment? Will ye not then hearken?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: See ye? If Allah were to make the day perpetual over you to the Day of Judgment, what god is there other than Allah, who can give you a night in which ye can rest? Will ye not then see?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is out of His Mercy that He has made for you Night and Day,- that ye may rest therein, and that ye may seek of his Grace;- and in order that ye may be grateful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
The Day that He will call on them, He will say: ``Where are my 'partners'? whom ye imagined (to be such)?"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And from each people shall We draw a witness, and We shall say: ``Produce your Proof": then shall they know that the Truth is in Allah (alone), and the (lies) which they invented will leave them in lurch.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Qarun was doubtless, of the people of Moses; but he acted insolently towards them: such were the treasures We had bestowed on him that their very keys would have been a burden to a body of strong men, behold, his people said to him: ``Exult not, for Allah loveth not those who exult (in riches).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
``But seek, with the (wealth) which Allah has bestowed on thee, the Home of the Hereafter, nor forget thy portion in this world: but do thou good, as Allah has been good to thee, and seek not (occasions for) mischief in the land: for Allah loves not those who do mischief."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said: ``This has been given to me because of a certain knowledge which I have." Did he not know that Allah had destroyed, before him, (whole) generations,- which were superior to him in strength and greater in the amount (of riches) they had collected? but the wicked are not called (immediately) to account for their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So he went forth among his people in the (pride of his wordly) glitter. Said those whose aim is the Life of this World: ``Oh! that we had the like of what Qarun has got! for he is truly a lord of mighty good fortune!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who had been granted (true) knowledge said: ``Alas for you! The reward of Allah (in the Hereafter) is best for those who believe and work righteousness: but this none shall attain, save those who steadfastly persevere (in good)."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
Then We caused the earth to swallow up him and his house; and he had not (the least little) party to help him against Allah, nor could he defend himself.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had envied his position the day before began to say on the morrow: ``Ah! it is indeed Allah Who enlarges the provision or restricts it, to any of His servants He pleases! had it not been that Allah was gracious to us, He could have caused the earth to swallow us up! Ah! those who reject Allah will assuredly never prosper."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That Home of the Hereafter We shall give to those who intend not high-handedness or mischief on earth: and the end is (best) for the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
If any does good, the reward to him is better than his deed; but if any does evil, the doers of evil are only punished (to the extent) of their deeds.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Verily He Who ordained the Qur'an for thee, will bring thee back to the Place of Return. Say: ``My Lord knows best who it is that brings true guidance, and who is in manifest error."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And thou hadst not expected that the Book would be sent to thee except as a Mercy from thy Lord: Therefore lend not thou support in any way to those who reject (Allah's Message).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let nothing keep thee back from the Signs of Allah after they have been revealed to thee: and invite (men) to thy Lord, and be not of the company of those who join gods with Allah.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And call not, besides Allah, on another god. There is no god but He. Everything (that exists) will perish except His own Face. To Him belongs the Command, and to Him will ye (all) be brought back.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do men think that they will be left alone on saying, ``We believe", and that they will not be tested?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
We did test those before them, and Allah will certainly know those who are true from those who are false.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Do those who practise evil think that they will get the better of Us? Evil is their judgment!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
For those whose hopes are in the meeting with Allah (in the Hereafter, let them strive); for the term (appointed) by Allah is surely coming and He hears and knows (all things).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And if any strive (with might and main), they do so for their own souls: for Allah is free of all needs from all creation.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
Those who believe and work righteous deeds,- from them shall We blot out all evil (that may be) in them, and We shall reward them according to the best of their deeds.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have enjoined on man kindness to parents: but if they (either of them) strive (to force) thee to join with Me (in worship) anything of which thou hast no knowledge, obey them not. Ye have (all) to return to me, and I will tell you (the truth) of all that ye did.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And those who believe and work righteous deeds,- them shall We admit to the company of the Righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Then there are among men such as say, ``We believe in Allah"; but when they suffer affliction in (the cause of) Allah, they treat men's oppression as if it were the Wrath of Allah! And if help comes (to thee) from thy Lord, they are sure to say, ``We have (always) been with you!" Does not Allah know best all that is in the hearts of all creation?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
And Allah most certainly knows those who believe, and as certainly those who are Hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And the Unbelievers say to those who believe: ``Follow our path, and we will bear (the consequences) of your faults." Never in the least will they bear their faults: in fact they are liars!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
They will bear their own burdens, and (other) burdens along with their own, and on the Day of Judgments they will be called to account for their falsehoods.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
We (once) sent Noah to his people, and he tarried among them a thousand years less fifty: but the Deluge overwhelmed them while they (persisted in) sin.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
But We saved him and the companions of the Ark, and We made the (Ark) a Sign for all peoples!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And (We also saved) Abraham: behold, he said to his people, ``Serve Allah and fear Him: that will be best for you- If ye understand!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
``For ye do worship idols besides Allah, and ye invent falsehood. The things that ye worship besides Allah have no power to give you sustenance: then seek ye sustenance from Allah, serve Him, and be grateful to Him: to Him will be your return.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
``And if ye reject (the Message), so did generations before you: and the duty of the messenger is only to preach publicly (and clearly)."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
See they not how Allah originates creation, then repeats it: truly that is easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: ``Travel through the earth and see how Allah did originate creation; so will Allah produce a later creation: for Allah has power over all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
``He punishes whom He pleases, and He grants Mercy to whom He pleases, and towards Him are ye turned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
``Not on earth nor in heaven will ye be able (fleeing) to frustrate (his Plan), nor have ye, besides Allah, any protector or helper."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who reject the Signs of Allah and the Meeting with Him (in the Hereafter),- it is they who shall despair of My Mercy: it is they who will (suffer) a most grievous Penalty.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
So naught was the answer of (Abraham's) people except that they said: ``Slay him or burn him." But Allah did save him from the Fire. Verily in this are Signs for people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And he said: ``For you, ye have taken (for worship) idols besides Allah, out of mutual love and regard between yourselves in this life; but on the Day of Judgment ye shall disown each other and curse each other: and your abode will be the Fire, and ye shall have none to help."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
But Lut had faith in Him: He said: ``I will leave home for the sake of my Lord: for He is Exalted in Might, and Wise."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We gave (Abraham) Isaac and Jacob, and ordained among his progeny Prophethood and Revelation, and We granted him his reward in this life; and he was in the Hereafter (of the company) of the Righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And (remember) Lut: behold, he said to his people: ``Ye do commit lewdness, such as no people in Creation (ever) committed before you.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
``Do ye indeed approach men, and cut off the highway?- and practise wickedness (even) in your councils?" But his people gave no answer but this: they said: ``Bring us the Wrath of Allah if thou tellest the truth."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said: ``O my Lord! help Thou me against people who do mischief!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
When Our Messengers came to Abraham with the good news, they said: ``We are indeed going to destroy the people of this township: for truly they are (addicted to) crime."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said: ``But there is Lut there." They said: ``Well do we know who is there: we will certainly save him and his following,- except his wife: she is of those who lag behind!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our Messengers came to Lut, he was grieved on their account, and felt himself powerless (to protect) them: but they said: ``Fear thou not, nor grieve: we are (here) to save thee and thy following, except thy wife: she is of those who lag behind.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
``For we are going to bring down on the people of this township a Punishment from heaven, because they have been wickedly rebellious."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And We have left thereof an evident Sign, for any people who (care to) understand.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
To the Madyan (people) (We sent) their brother Shu'aib. Then he said: ``O my people! serve Allah, and fear the Last Day: nor commit evil on the earth, with intent to do mischief."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they rejected him: Then the mighty Blast seized them, and they lay prostrate in their homes by the morning.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
(Remember also) the 'Ad and the Thamud (people): clearly will appear to you from (the traces) of their buildings (their fate): the Evil One made their deeds alluring to them, and kept them back from the Path, though they were gifted with intelligence and skill.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
(Remember also) Qarun, Pharaoh, and Haman: there came to them Moses with Clear Signs, but they behaved with insolence on the earth; yet they could not overreach (Us).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
Each one of them We seized for his crime: of them, against some We sent a violent tornado (with showers of stones); some were caught by a (mighty) Blast; some We caused the earth to swallow up; and some We drowned (in the waters): It was not Allah Who injured (or oppressed) them:" They injured (and oppressed) their own souls.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The parable of those who take protectors other than Allah is that of the spider, who builds (to itself) a house; but truly the flimsiest of houses is the spider's house;- if they but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Verily Allah doth know of (every thing) whatever that they call upon besides Him: and He is Exalted (in power), Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And such are the Parables We set forth for mankind, but only those understand them who have knowledge.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah created the heavens and the earth in true (proportions): verily in that is a Sign for those who believe.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite what is sent of the Book by inspiration to thee, and establish regular Prayer: for Prayer restrains from shameful and unjust deeds; and remembrance of Allah is the greatest (thing in life) without doubt. And Allah knows the (deeds) that ye do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And dispute ye not with the People of the Book, except with means better (than mere disputation), unless it be with those of them who inflict wrong (and injury): but say, ``We believe in the revelation which has come down to us and in that which came down to you; Our Allah and your Allah is one; and it is to Him we bow (in Islam)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And thus (it is) that We have sent down the Book to thee. So the People of the Book believe therein, as also do some of these (pagan Arabs): and none but Unbelievers reject our signs.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
And thou wast not (able) to recite a Book before this (Book came), nor art thou (able) to transcribe it with thy right hand: In that case, indeed, would the talkers of vanities have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Nay, here are Signs self-evident in the hearts of those endowed with knowledge: and none but the unjust reject Our Signs.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
Ye they say: ``Why are not Signs sent down to him from his Lord?" Say: ``The signs are indeed with Allah: and I am indeed a clear Warner."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
And is it not enough for them that we have sent down to thee the Book which is rehearsed to them? Verily, in it is Mercy and a Reminder to those who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say: ``Enough is Allah for a witness between me and you: He knows what is in the heavens and on earth. And it is those who believe in vanities and reject Allah, that will perish (in the end).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
They ask thee to hasten on the Punishment (for them): had it not been for a term (of respite) appointed, the Punishment would certainly have come to them: and it will certainly reach them,- of a sudden, while they perceive not!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They ask thee to hasten on the Punishment: but, of a surety, Hell will encompass the Rejecters of Faith!-\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day that the Punishment shall cover them from above them and from below them, and (a Voice) shall say: ``Taste ye (the fruits) of your deeds!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who believe! truly, spacious is My Earth: therefore serve ye Me - (and Me alone)!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul shall have a taste of death in the end to Us shall ye be brought back.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
But those who believe and work deeds of righteousness - to them shall We give a Home in Heaven,- lofty mansions beneath which flow rivers,- to dwell therein for aye;- an excellent reward for those who do (good)!-\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Those who persevere in patience, and put their trust, in their Lord and Cherisher.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
How many are the creatures that carry not their own sustenance? It is Allah who feeds (both) them and you: for He hears and knows (all things).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If indeed thou ask them who has created the heavens and the earth and subjected the sun and the moon (to his Law), they will certainly reply, ``Allah". How are they then deluded away (from the truth)?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah enlarges the sustenance (which He gives) to whichever of His servants He pleases; and He (similarly) grants by (strict) measure, (as He pleases): for Allah has full knowledge of all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if indeed thou ask them who it is that sends down rain from the sky, and gives life therewith to the earth after its death, they will certainly reply, ``Allah!" Say, ``Praise be to Allah!" But most of them understand not.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
What is the life of this world but amusement and play? but verily the Home in the Hereafter,- that is life indeed, if they but knew.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
Now, if they embark on a boat, they call on Allah, making their devotion sincerely (and exclusively) to Him; but when He has delivered them safely to (dry) land, behold, they give a share (of their worship to others)!-\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
Disdaining ungratefully Our gifts, and giving themselves up to (worldly) enjoyment! But soon will they know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Do they not then see that We have made a sanctuary secure, and that men are being snatched away from all around them? Then, do they believe in that which is vain, and reject the Grace of Allah?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does more wrong than he who invents a lie against Allah or rejects the Truth when it reaches him? Is there not a home in Hell for those who reject Faith?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
And those who strive in Our (cause),- We will certainly guide them to our Paths: For verily Allah is with those who do right.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Roman Empire has been defeated-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In a land close by; but they, (even) after (this) defeat of theirs, will soon be victorious-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
Within a few years. With Allah is the Decision, in the past and in the Future: on that Day shall the Believers rejoice-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
With the help of Allah. He helps whom He will, and He is exalted in might, most merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
(It is) the promise of Allah. Never does Allah depart from His promise: but most men understand not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know but the outer (things) in the life of this world: but of the End of things they are heedless.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Do they not reflect in their own minds? Not but for just ends and for a term appointed, did Allah create the heavens and the earth, and all between them: yet are there truly many among men who deny the meeting with their Lord (at the Resurrection)!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Do they not travel through the earth, and see what was the end of those before them? They were superior to them in strength: they tilled the soil and populated it in greater numbers than these have done: there came to them their messengers with Clear (Signs). (Which they rejected, to their own destruction): It was not Allah Who wronged them, but they wronged their own souls.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
In the long run evil in the extreme will be the End of those who do evil; for that they rejected the Signs of Allah, and held them up to ridicule.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
It is Allah Who begins (the process of) creation; then repeats it; then shall ye be brought back to Him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
On the Day that the Hour will be established, the guilty will be struck dumb with despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
No intercessor will they have among their ``Partners" and they will (themselves) reject their ``Partners".\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
On the Day that the Hour will be established,- that Day shall (all men) be sorted out.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
Then those who have believed and worked righteous deeds, shall be made happy in a Mead of Delight.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
And those who have rejected Faith and falsely denied our Signs and the meeting of the Hereafter,- such shall be brought forth to Punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So (give) glory to Allah, when ye reach eventide and when ye rise in the morning;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
Yea, to Him be praise, in the heavens and on earth; and in the late afternoon and when the day begins to decline.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
It is He Who brings out the living from the dead, and brings out the dead from the living, and Who gives life to the earth after it is dead: and thus shall ye be brought out (from the dead).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
Among His Signs in this, that He created you from dust; and then,- behold, ye are men scattered (far and wide)!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And among His Signs is this, that He created for you mates from among yourselves, that ye may dwell in tranquillity with them, and He has put love and mercy between your (hearts): verily in that are Signs for those who reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And among His Signs is the creation of the heavens and the earth, and the variations in your languages and your colours: verily in that are Signs for those who know.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And among His Signs is the sleep that ye take by night and by day, and the quest that ye (make for livelihood) out of His Bounty: verily in that are signs for those who hearken.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And among His Signs, He shows you the lightning, by way both of fear and of hope, and He sends down rain from the sky and with it gives life to the earth after it is dead: verily in that are Signs for those who are wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And among His Signs is this, that heaven and earth stand by His Command: then when He calls you, by a single call, from the earth, behold, ye (straightway) come forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs every being that is in the heavens and on earth: all are devoutly obedient to Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
It is He Who begins (the process of) creation; then repeats it; and for Him it is most easy. To Him belongs the loftiest similitude (we can think of) in the heavens and the earth: for He is Exalted in Might, full of wisdom.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He does propound to you a similitude from your own (experience): do ye have partners among those whom your right hands possess, to share as equals in the wealth We have bestowed on you? Do ye fear them as ye fear each other? Thus do we explain the Signs in detail to a people that understand.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Nay, the wrong-doers (merely) follow their own lusts, being devoid of knowledge. But who will guide those whom Allah leaves astray? To them there will be no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So set thou thy face steadily and truly to the Faith: (establish) Allah's handiwork according to the pattern on which He has made mankind: no change (let there be) in the work (wrought) by Allah: that is the standard Religion: but most among mankind understand not.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
Turn ye back in repentance to Him, and fear Him: establish regular prayers, and be not ye among those who join gods with Allah,-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Those who split up their Religion, and become (mere) Sects,- each party rejoicing in that which is with itself!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
When trouble touches men, they cry to their Lord, turning back to Him in repentance: but when He gives them a taste of Mercy as from Himself, behold, some of them pay part-worship to other god's besides their Lord,-\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
(As if) to show their ingratitude for the (favours) We have bestowed on them! Then enjoy (your brief day); but soon will ye know (your folly).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent down authority to them, which points out to them the things to which they pay part-worship?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
When We give men a taste of Mercy, they exult thereat: and when some evil afflicts them because of what their (own) hands have sent forth, behold, they are in despair!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
See they not that Allah enlarges the provision and restricts it, to whomsoever He pleases? Verily in that are Signs for those who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give what is due to kindred, the needy, and the wayfarer. That is best for those who seek the Countenance, of Allah, and it is they who will prosper.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
That which ye lay out for increase through the property of (other) people, will have no increase with Allah: but that which ye lay out for charity, seeking the Countenance of Allah, (will increase): it is these who will get a recompense multiplied.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
It is Allah Who has created you: further, He has provided for your sustenance; then He will cause you to die; and again He will give you life. Are there any of your (false) ``Partners" who can do any single one of these things? Glory to Him! and high is He above the partners they attribute (to him)!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Mischief has appeared on land and sea because of (the meed) that the hands of men have earned, that (Allah) may give them a taste of some of their deeds: in order that they may turn back (from Evil).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say: ``Travel through the earth and see what was the end of those before (you): Most of them worshipped others besides Allah."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
But set thou thy face to the right Religion before there come from Allah the Day which there is no chance of averting: on that Day shall men be divided (in two).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Those who reject Faith will suffer from that rejection: and those who work righteousness will spread their couch (of repose) for themselves (in heaven):\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
That He may reward those who believe and work righteous deeds, out of his Bounty. For He loves not those who reject Faith.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
Among His Signs is this, that He sends the Winds, as heralds of Glad Tidings, giving you a taste of His (Grace and) Mercy,- that the ships may sail (majestically) by His Command and that ye may seek of His Bounty: in order that ye may be grateful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
We did indeed send, before thee, messengers to their (respective) peoples, and they came to them with Clear Signs: then, to those who transgressed, We meted out Retribution: and it was due from Us to aid those who believed.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
It is Allah Who sends the Winds, and they raise the Clouds: then does He spread them in the sky as He wills, and break them into fragments, until thou seest rain-drops issue from the midst thereof: then when He has made them reach such of his servants as He wills behold, they do rejoice!-\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Even though, before they received (the rain) - just before this - they were dumb with despair!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Then contemplate (O man!) the memorials of Allah's Mercy!- how He gives life to the earth after its death: verily the same will give life to the men who are dead: for He has power over all things.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We (but) send a Wind from which they see (their tilth) turn yellow,- behold, they become, thereafter, Ungrateful (Unbelievers)!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
So verily thou canst not make the dead to hear, nor canst thou make the deaf to hear the call, when they show their backs and turn away.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Nor canst thou lead back the blind from their straying: only those wilt thou make to hear, who believe in Our signs and submit (their wills in Islam).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
It is Allah Who created you in a state of (helpless) weakness, then gave (you) strength after weakness, then, after strength, gave (you weakness and a hoary head: He creates as He wills, and it is He Who has all knowledge and power.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
On the Day that the Hour (of Reckoning) will be established, the transgressors will swear that they tarried not but an hour: thus were they used to being deluded!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those endued with knowledge and faith will say: ``Indeed ye did tarry, within Allah's Decree, to the Day of Resurrection, and this is the Day of Resurrection: but ye - ye were not aware!"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So on that Day no excuse of theirs will avail the transgressors, nor will they be invited (then) to seek grace (by repentance).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
verily We have propounded for men, in this Qur'an every kind of Parable: But if thou bring to them any Sign, the Unbelievers are sure to say, ``Ye do nothing but talk vanities."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus does Allah seal up the hearts of those who understand not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So patiently persevere: for verily the promise of Allah is true: nor let those shake thy firmness, who have (themselves) no certainty of faith.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are Verses of the Wise Book,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A Guide and a Mercy to the Doers of Good,-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who establish regular Prayer, and give regular Charity, and have (in their hearts) the assurance of the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
These are on (true) guidance from their Lord: and these are the ones who will prosper.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
But there are, among men, those who purchase idle tales, without knowledge (or meaning), to mislead (men) from the Path of Allah and throw ridicule (on the Path): for such there will be a Humiliating Penalty.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
When Our Signs are rehearsed to such a one, he turns away in arrogance, as if he heard them not, as if there were deafness in both his ears: announce to him a grievous Penalty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
For those who believe and work righteous deeds, there will be Gardens of Bliss,-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
To dwell therein. The promise of Allah is true: and He is Exalted in Power, Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without any pillars that ye can see; He set on the earth mountains standing firm, lest it should shake with you; and He scattered through it beasts of all kinds. We send down rain from the sky, and produce on the earth every kind of noble creature, in pairs.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
Such is the Creation of Allah: now show Me what is there that others besides Him have created: nay, but the Transgressors are in manifest error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
we bestowed (in the past) Wisdom on Luqman: ``Show (thy) gratitude to Allah." Any who is (so) grateful does so to the profit of his own soul: but if any is ungrateful, verily Allah is free of all wants, Worthy of all praise.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
Behold, Luqman said to his son by way of instruction: ``O my son! join not in worship (others) with Allah: for false worship is indeed the highest wrong-doing."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined on man (to be good) to his parents: in travail upon travail did his mother bear him, and in years twain was his weaning: (hear the command), ``Show gratitude to Me and to thy parents: to Me is (thy final) Goal.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
``But if they strive to make thee join in worship with Me things of which thou hast no knowledge, obey them not; yet bear them company in this life with justice (and consideration), and follow the way of those who turn to me (in love): in the end the return of you all is to Me, and I will tell you the truth (and meaning) of all that ye did."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
``O my son!" (said Luqman), ``If there be (but) the weight of a mustard-seed and it were (hidden) in a rock, or (anywhere) in the heavens or on earth, Allah will bring it forth: for Allah understands the finest mysteries, (and) is well-acquainted (with them).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
``O my son! establish regular prayer, enjoin what is just, and forbid what is wrong: and bear with patient constancy whatever betide thee; for this is firmness (of purpose) in (the conduct of) affairs.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
``And swell not thy cheek (for pride) at men, nor walk in insolence through the earth; for Allah loveth not any arrogant boaster.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
``And be moderate in thy pace, and lower thy voice; for the harshest of sounds without doubt is the braying of the ass."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Do ye not see that Allah has subjected to your (use) all things in the heavens and on earth, and has made his bounties flow to you in exceeding measure, (both) seen and unseen? Yet there are among men those who dispute about Allah, without knowledge and without guidance, and without a Book to enlighten them!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
When they are told to follow the (Revelation) that Allah has sent down, they say: ``Nay, we shall follow the ways that we found our fathers (following). ``What! even if it is Satan beckoning them to the Penalty of the (Blazing) Fire?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
Whoever submits his whole self to Allah, and is a doer of good, has grasped indeed the most trustworthy hand-hold: and with Allah rests the End and Decision of (all) affairs.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
But if any reject Faith, let not his rejection grieve thee: to Us is their return, and We shall tell them the truth of their deeds: for Allah knows well all that is in (men's) hearts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We grant them their pleasure for a little while: in the end shall We drive them to a chastisement unrelenting.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
If thou ask them, who it is that created the heavens and the earth. They will certainly say, ``Allah". Say: ``Praise be to Allah!" But most of them understand not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah belong all things in heaven and earth: verily Allah is He (that is) free of all wants, worthy of all praise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if all the trees on earth were pens and the ocean (were ink), with seven oceans behind it to add to its (supply), yet would not the words of Allah be exhausted (in the writing): for Allah is Exalted in Power, full of Wisdom.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
And your creation or your resurrection is in no wise but as an individual soul: for Allah is He Who hears and sees (all things).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Seest thou not that Allah merges Night into Day and he merges Day into Night; that He has subjected the sun, and the moon (to his Law), each running its course for a term appointed; and that Allah is well-acquainted with all that ye do?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because Allah is the (only) Reality, and because whatever else they invoke besides Him is Falsehood; and because Allah,- He is the Most High, Most Great.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Seest thou not that the ships sail through the ocean by the Grace of Allah?- that He may show you of His Signs? Verily in this are Signs for all who constantly persevere and give thanks.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
When a wave covers them like the canopy (of clouds), they call to Allah, offering Him sincere devotion. But when He has delivered them safely to land, there are among them those that halt between (right and wrong). But none reject Our Signs except only a perfidious ungrateful (wretch)!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind! do your duty to your Lord, and fear (the coming of) a Day when no father can avail aught for his son, nor a son avail aught for his father. Verily, the promise of Allah is true: let not then this present life deceive you, nor let the chief Deceiver deceive you about Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Verily the knowledge of the Hour is with Allah (alone). It is He Who sends down rain, and He Who knows what is in the wombs. Nor does any one know what it is that he will earn on the morrow: Nor does any one know in what land he is to die. Verily with Allah is full knowledge and He is acquainted (with all things).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen A. L. M.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
(This is) the Revelation of the Book in which there is no doubt,- from the Lord of the Worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or do they say, ``He has forged it"? Nay, it is the Truth from thy Lord, that thou mayest admonish a people to whom no warner has come before thee: in order that they may receive guidance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
It is Allah Who has created the heavens and the earth, and all between them, in six Days, and is firmly established on the Throne (of Authority): ye have none, besides Him, to protect or intercede (for you): will ye not then receive admonition?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He rules (all) affairs from the heavens to the earth: in the end will (all affairs) go up to Him, on a Day, the space whereof will be (as) a thousand years of your reckoning.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
Such is He, the Knower of all things, hidden and open, the Exalted (in power), the Merciful;-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
He Who has made everything which He has created most good: He began the creation of man with (nothing more than) clay,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
And made his progeny from a quintessence of the nature of a fluid despised:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
But He fashioned him in due proportion, and breathed into him something of His spirit. And He gave you (the faculties of) hearing and sight and feeling (and understanding): little thanks do ye give!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say: ``What! when we lie, hidden and lost, in the earth, shall we indeed be in a Creation renewed? Nay, they deny the Meeting with their Lord.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: ``The Angel of Death, put in charge of you, will (duly) take your souls: then shall ye be brought back to your Lord."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
If only thou couldst see when the guilty ones will bend low their heads before their Lord, (saying:) ``Our Lord! We have seen and we have heard: Now then send us back (to the world): we will work righteousness: for we do indeed (now) believe."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
If We had so willed, We could certainly have brought every soul its true guidance: but the Word from Me will come true, ``I will fill Hell with Jinns and men all together."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
``Taste ye then - for ye forgot the Meeting of this Day of yours, and We too will forget you - taste ye the Penalty of Eternity for your (evil) deeds!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our Signs, who, when they are recited to them, fall down in prostration, and celebrate the praises of their Lord, nor are they (ever) puffed up with pride.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their limbs do forsake their beds of sleep, the while they call on their Lord, in Fear and Hope: and they spend (in charity) out of the sustenance which We have bestowed on them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
Now no person knows what delights of the eye are kept hidden (in reserve) for them - as a reward for their (good) deeds.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Is then the man who believes no better than the man who is rebellious and wicked? Not equal are they.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
For those who believe and do righteous deeds are Gardens as hospitable homes, for their (good) deeds.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
As to those who are rebellious and wicked, their abode will be the Fire: every time they wish to get away therefrom, they will be forced thereinto, and it will be said to them: ``Taste ye the Penalty of the Fire, the which ye were wont to reject as false."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And indeed We will make them taste of the Penalty of this (life) prior to the supreme Penalty, in order that they may (repent and) return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who does more wrong than one to whom are recited the Signs of his Lord, and who then turns away therefrom? Verily from those who transgress We shall exact (due) Retribution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
We did indeed aforetime give the Book to Moses: be not then in doubt of its reaching (thee): and We made it a guide to the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We appointed, from among them, leaders, giving guidance under Our command, so long as they persevered with patience and continued to have faith in Our Signs.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Verily thy Lord will judge between them on the Day of Judgment, in the matters wherein they differ (among themselves)\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Does it not teach them a lesson, how many generations We destroyed before them, in whose dwellings they (now) go to and fro? Verily in that are Signs: Do they not then listen?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
And do they not see that We do drive rain to parched soil (bare of herbage), and produce therewith crops, providing food for their cattle and themselves? Have they not the vision?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They say: ``When will this decision be, if ye are telling the truth?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say: ``On the Day of Decision, no profit will it be to Unbelievers if they (then) believe! nor will they be granted a respite."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn away from them, and wait: they too are waiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet! Fear Allah, and hearken not to the Unbelievers and the Hypocrites: verily Allah is full of Knowledge and Wisdom.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
But follow that which comes to thee by inspiration from thy Lord: for Allah is well acquainted with (all) that ye do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put thy trust in Allah, and enough is Allah as a disposer of affairs.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has not made for any man two hearts in his (one) body: nor has He made your wives whom ye divorce by Zihar your mothers: nor has He made your adopted sons your sons. Such is (only) your (manner of) speech by your mouths. But Allah tells (you) the Truth, and He shows the (right) Way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them by (the names of) their fathers: that is juster in the sight of Allah. But if ye know not their father's (names, call them) your Brothers in faith, or your maulas. But there is no blame on you if ye make a mistake therein: (what counts is) the intention of your hearts: and Allah is Oft-Returning, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is closer to the Believers than their own selves, and his wives are their mothers. Blood-relations among each other have closer personal ties, in the Decree of Allah. Than (the Brotherhood of) Believers and Muhajirs: nevertheless do ye what is just to your closest friends: such is the writing in the Decree (of Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And remember We took from the prophets their covenant: As (We did) from thee: from Noah, Abraham, Moses, and Jesus the son of Mary: We took from them a solemn covenant:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That (Allah) may question the (custodians) of Truth concerning the Truth they (were charged with): And He has prepared for the Unbelievers a grievous Penalty.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O ye who believe! Remember the Grace of Allah, (bestowed) on you, when there came down on you hosts (to overwhelm you): But We sent against them a hurricane and forces that ye saw not: but Allah sees (clearly) all that ye do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
Behold! they came on you from above you and from below you, and behold, the eyes became dim and the hearts gaped up to the throats, and ye imagined various (vain) thoughts about Allah!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
In that situation were the Believers tried: they were shaken as by a tremendous shaking.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And behold! The Hypocrites and those in whose hearts is a disease (even) say: ``Allah and His Messenger promised us nothing but delusion!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
Behold! A party among them said: ``Ye men of Yathrib! ye cannot stand (the attack)! therefore go back!" And a band of them ask for leave of the Prophet, saying, ``Truly our houses are bare and exposed," though they were not exposed they intended nothing but to run away.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if an entry had been effected to them from the sides of the (city), and they had been incited to sedition, they would certainly have brought it to pass, with none but a brief delay!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And yet they had already covenanted with Allah not to turn their backs, and a covenant with Allah must (surely) be answered for.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say: ``Running away will not profit you if ye are running away from death or slaughter; and even if (ye do escape), no more than a brief (respite) will ye be allowed to enjoy!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: ``Who is it that can screen you from Allah if it be His wish to give you punishment or to give you Mercy?" Nor will they find for themselves, besides Allah, any protector or helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Verily Allah knows those among you who keep back (men) and those who say to their brethren, ``Come along to us", but come not to the fight except for just a little while.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Covetous over you. Then when fear comes, thou wilt see them looking to thee, their eyes revolving, like (those of) one over whom hovers death: but when the fear is past, they will smite you with sharp tongues, covetous of goods. Such men have no faith, and so Allah has made their deeds of none effect: and that is easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think that the Confederates have not withdrawn; and if the Confederates should come (again), they would wish they were in the deserts (wandering) among the Bedouins, and seeking news about you (from a safe distance); and if they were in your midst, they would fight but little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Ye have indeed in the Messenger of Allah a beautiful pattern (of conduct) for any one whose hope is in Allah and the Final Day, and who engages much in the Praise of Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
When the Believers saw the Confederate forces, they said: ``This is what Allah and his Messenger had promised us, and Allah and His Messenger told us what was true." And it only added to their faith and their zeal in obedience.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the Believers are men who have been true to their covenant with Allah: of them some have completed their vow (to the extreme), and some (still) wait: but they have never changed (their determination) in the least:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That Allah may reward the men of Truth for their Truth, and punish the Hypocrites if that be His Will, or turn to them in Mercy: for Allah is Oft-Forgiving, Most Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah turned back the Unbelievers for (all) their fury: no advantage did they gain; and enough is Allah for the believers in their fight. And Allah is full of Strength, able to enforce His Will.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And those of the People of the Book who aided them - Allah did take them down from their strongholds and cast terror into their hearts. (So that) some ye slew, and some ye made prisoners.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He made you heirs of their lands, their houses, and their goods, and of a land which ye had not frequented (before). And Allah has power over all things.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet! Say to thy Consorts: ``If it be that ye desire the life of this World, and its glitter,- then come! I will provide for your enjoyment and set you free in a handsome manner.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if ye seek Allah and His Messenger, and the Home of the Hereafter, verily Allah has prepared for the well-doers amongst you a great reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O Consorts of the Prophet! If any of you were guilty of evident unseemly conduct, the Punishment would be doubled to her, and that is easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
But any of you that is devout in the service of Allah and His Messenger, and works righteousness,- to her shall We grant her reward twice: and We have prepared for her a generous Sustenance.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O Consorts of the Prophet! Ye are not like any of the (other) women: if ye do fear (Allah), be not too complacent of speech, lest one in whose heart is a disease should be moved with desire: but speak ye a speech (that is) just.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay quietly in your houses, and make not a dazzling display, like that of the former Times of Ignorance; and establish regular Prayer, and give regular Charity; and obey Allah and His Messenger. And Allah only wishes to remove all abomination from you, ye members of the Family, and to make you pure and spotless.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And recite what is rehearsed to you in your homes, of the Signs of Allah and His Wisdom: for Allah understands the finest mysteries and is well-acquainted (with them).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
For Muslim men and women,- for believing men and women, for devout men and women, for true men and women, for men and women who are patient and constant, for men and women who humble themselves, for men and women who give in Charity, for men and women who fast (and deny themselves), for men and women who guard their chastity, and for men and women who engage much in Allah's praise,- for them has Allah prepared forgiveness and great reward.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not fitting for a Believer, man or woman, when a matter has been decided by Allah and His Messenger to have any option about their decision: if any one disobeys Allah and His Messenger, he is indeed on a clearly wrong Path.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
Behold! Thou didst say to one who had received the grace of Allah and thy favour: ``Retain thou (in wedlock) thy wife, and fear Allah." But thou didst hide in thy heart that which Allah was about to make manifest: thou didst fear the people, but it is more fitting that thou shouldst fear Allah. Then when Zaid had dissolved (his marriage) with her, with the necessary (formality), We joined her in marriage to thee: in order that (in future) there may be no difficulty to the Believers in (the matter of) marriage with the wives of their adopted sons, when the latter have dissolved with the necessary (formality) (their marriage) with them. And Allah's command must be fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There can be no difficulty to the Prophet in what Allah has indicated to him as a duty. It was the practice (approved) of Allah amongst those of old that have passed away. And the command of Allah is a decree determined.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
(It is the practice of those) who preach the Messages of Allah, and fear Him, and fear none but Allah. And enough is Allah to call (men) to account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your men, but (he is) the Messenger of Allah, and the Seal of the Prophets: and Allah has full knowledge of all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O ye who believe! Celebrate the praises of Allah, and do this often;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And glorify Him morning and evening.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
He it is Who sends blessings on you, as do His angels, that He may bring you out from the depths of Darkness into Light: and He is Full of Mercy to the Believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their salutation on the Day they meet Him will be ``Peace!"; and He has prepared for them a generous Reward.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet! Truly We have sent thee as a Witness, a Bearer of Glad Tidings, and Warner,-\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And as one who invites to Allah's (grace) by His leave, and as a lamp spreading light.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
Then give the Glad Tidings to the Believers, that they shall have from Allah a very great Bounty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And obey not (the behests) of the Unbelievers and the Hypocrites, and heed not their annoyances, but put thy Trust in Allah. For enough is Allah as a Disposer of affairs.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O ye who believe! When ye marry believing women, and then divorce them before ye have touched them, no period of 'Iddat have ye to count in respect of them: so give them a present. And set them free in a handsome manner.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet! We have made lawful to thee thy wives to whom thou hast paid their dowers; and those whom thy right hand possesses out of the prisoners of war whom Allah has assigned to thee; and daughters of thy paternal uncles and aunts, and daughters of thy maternal uncles and aunts, who migrated (from Makka) with thee; and any believing woman who dedicates her soul to the Prophet if the Prophet wishes to wed her;- this only for thee, and not for the Believers (at large); We know what We have appointed for them as to their wives and the captives whom their right hands possess;- in order that there should be no difficulty for thee. And Allah is Oft-Forgiving, Most Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Thou mayest defer (the turn of) any of them that thou pleasest, and thou mayest receive any thou pleasest: and there is no blame on thee if thou invite one whose (turn) thou hadst set aside. This were nigher to the cooling of their eyes, the prevention of their grief, and their satisfaction - that of all of them - with that which thou hast to give them: and Allah knows (all) that is in your hearts: and Allah is All-Knowing, Most Forbearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
It is not lawful for thee (to marry more) women after this, nor to change them for (other) wives, even though their beauty attract thee, except any thy right hand should possess (as handmaidens): and Allah doth watch over all things.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O ye who believe! Enter not the Prophet's houses,- until leave is given you,- for a meal, (and then) not (so early as) to wait for its preparation: but when ye are invited, enter; and when ye have taken your meal, disperse, without seeking familiar talk. Such (behaviour) annoys the Prophet: he is ashamed to dismiss you, but Allah is not ashamed (to tell you) the truth. And when ye ask (his ladies) for anything ye want, ask them from before a screen: that makes for greater purity for your hearts and for theirs. Nor is it right for you that ye should annoy Allah's Messenger, or that ye should marry his widows after him at any time. Truly such a thing is in Allah's sight an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether ye reveal anything or conceal it, verily Allah has full knowledge of all things.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
There is no blame (on these ladies if they appear) before their fathers or their sons, their brothers, or their brother's sons, or their sisters' sons, or their women, or the (slaves) whom their right hands possess. And, (ladies), fear Allah; for Allah is Witness to all things.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Allah and His angels send blessings on the Prophet: O ye that believe! Send ye blessings on him, and salute him with all respect.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Those who annoy Allah and His Messenger - Allah has cursed them in this World and in the Hereafter, and has prepared for them a humiliating Punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who annoy believing men and women undeservedly, bear (on themselves) a calumny and a glaring sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Tell thy wives and daughters, and the believing women, that they should cast their outer garments over their persons (when abroad): that is most convenient, that they should be known (as such) and not molested. And Allah is Oft-Forgiving, Most Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
Truly, if the Hypocrites, and those in whose hearts is a disease, and those who stir up sedition in the City, desist not, We shall certainly stir thee up against them: Then will they not be able to stay in it as thy neighbours for any length of time:\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
They shall have a curse on them: whenever they are found, they shall be seized and slain (without mercy).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
(Such was) the practice (approved) of Allah among those who lived aforetime: No change wilt thou find in the practice (approved) of Allah.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
Men ask thee concerning the Hour: Say, ``The knowledge thereof is with Allah (alone)": and what will make thee understand?- perchance the Hour is nigh!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Verily Allah has cursed the Unbelievers and prepared for them a Blazing Fire,-\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
To dwell therein for ever: no protector will they find, nor helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
The Day that their faces will be turned upside down in the Fire, they will say: ``Woe to us! Would that we had obeyed Allah and obeyed the Messenger!"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they would say: ``Our Lord! We obeyed our chiefs and our great ones, and they misled us as to the (right) Path.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
``Our Lord! Give them double Penalty and curse them with a very great Curse!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O ye who believe! Be ye not like those who vexed and insulted Moses, but Allah cleared him of the (calumnies) they had uttered: and he was honourable in Allah's sight.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O ye who believe! Fear Allah, and (always) say a word directed to the Right:\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
That He may make your conduct whole and sound and forgive you your sins: He that obeys Allah and His Messenger, has already attained the highest achievement.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We did indeed offer the Trust to the Heavens and the Earth and the Mountains; but they refused to undertake it, being afraid thereof: but man undertook it;- He was indeed unjust and foolish;-\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
(With the result) that Allah has to punish the Hypocrites, men and women, and the Unbelievers, men and women, and Allah turns in Mercy to the Believers, men and women: for Allah is Oft-Forgiving, Most Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen Praise be to Allah, to Whom belong all things in the heavens and on earth: to Him be Praise in the Hereafter: and He is Full of Wisdom, acquainted with all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows all that goes into the earth, and all that comes out thereof; all that comes down from the sky and all that ascends thereto and He is the Most Merciful, the Oft-Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
The Unbelievers say, ``Never to us will come the Hour": Say, ``Nay! but most surely, by my Lord, it will come upon you;- by Him Who knows the unseen,- from Whom is not hidden the least little atom in the heavens or on earth: Nor is there anything less than that, or greater, but is in the Record Perspicuous:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may reward those who believe and work deeds of righteousness: for such is Forgiveness and a Sustenance Most Generous."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who strive against Our Signs, to frustrate them,- for such will be a Penalty,- a Punishment most humiliating.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And those to whom knowledge has come see that the (Revelation) sent down to thee from thy Lord - that is the Truth, and that it guides to the Path of the Exalted (in might), Worthy of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
The Unbelievers say (in ridicule): ``Shall we point out to you a man that will tell you, when ye are all scattered to pieces in disintegration, that ye shall (then be raised) in a New Creation?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
``Has he invented a falsehood against Allah, or has a spirit (seized) him?"- Nay, it is those who believe not in the Hereafter, that are in (real) Penalty, and in farthest error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
See they not what is before them and behind them, of the sky and the earth? If We wished, We could cause the earth to swallow them up, or cause a piece of the sky to fall upon them. Verily in this is a Sign for every devotee that turns to Allah (in repentance).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
We bestowed Grace aforetime on David from ourselves: ``O ye Mountains! Sing ye back the Praises of Allah with him! and ye birds (also)! And We made the iron soft for him;-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
(Commanding), ``Make thou coast of mail, balancing well the rings of chain armour, and work ye righteousness; for be sure I see (clearly) all that ye do."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And to Solomon (We made) the Wind (obedient): Its early morning (stride) was a month's (journey), and its evening (stride) was a month's (journey); and We made a Font of molten brass to flow for him; and there were Jinns that worked in front of him, by the leave of his Lord, and if any of them turned aside from our command, We made him taste of the Penalty of the Blazing Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They worked for him as he desired, (making) arches, images, basons as large as reservoirs, and (cooking) cauldrons fixed (in their places): ``Work ye, sons of David, with thanks! but few of My servants are grateful!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
Then, when We decreed (Solomon's) death, nothing showed them his death except a little worm of the earth, which kept (slowly) gnawing away at his staff: so when he fell down, the Jinns saw plainly that if they had known the unseen, they would not have tarried in the humiliating Penalty (of their Task).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
There was, for Saba, aforetime, a Sign in their home-land - two Gardens to the right and to the left. ``Eat of the Sustenance (provided) by your Lord, and be grateful to Him: a territory fair and happy, and a Lord Oft-Forgiving!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away (from Allah), and We sent against them the Flood (released) from the dams, and We converted their two garden (rows) into ``gardens" producing bitter fruit, and tamarisks, and some few (stunted) Lote-trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
That was the Requital We gave them because they ungratefully rejected Faith: and never do We give (such) requital except to such as are ungrateful rejecters.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
Between them and the Cities on which We had poured our blessings, We had placed Cities in prominent positions, and between them We had appointed stages of journey in due proportion: ``Travel therein, secure, by night and by day."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: ``Our Lord! Place longer distances between our journey-stages": but they wronged themselves (therein). At length We made them as a tale (that is told), and We dispersed them all in scattered fragments. Verily in this are Signs for every (soul that is) patiently constant and grateful.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And on them did Satan prove true his idea, and they followed him, all but a party that believed.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
But he had no authority over them,- except that We might test the man who believes in the Hereafter from him who is in doubt concerning it: and thy Lord doth watch over all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say: ``Call upon other (gods) whom ye fancy, besides Allah: They have no power,- not the weight of an atom,- in the heavens or on earth: No (sort of) share have they therein, nor is any of them a helper to Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
``No intercession can avail in His Presence, except for those for whom He has granted permission. So far (is this the case) that, when terror is removed from their hearts (at the Day of Judgment, then) will they say, 'what is it that your Lord commanded?' they will say, 'That which is true and just; and He is the Most High Most Great'."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say: ``Who gives you sustenance, from the heavens and the earth?" Say: ``It is Allah; and certain it is that either we or ye are on right guidance or in manifest error!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say: ``Ye shall not be questioned as to our sins, nor shall we be questioned as to what ye do."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: ``Our Lord will gather us together and will in the end decide the matter between us (and you) in truth and justice: and He is the one to decide, the One Who knows all."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: ``Show me those whom ye have joined with Him as partners: by no means (can ye). Nay, He is Allah, the Exalted in Power, the Wise."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
We have not sent thee but as a universal (Messenger) to men, giving them glad tidings, and warning them (against sin), but most men understand not.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
They say: ``When will this promise (come to pass) if ye are telling the truth?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say: ``The appointment to you is for a Day, which ye cannot put back for an hour nor put forward."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
The Unbelievers say: ``We shall neither believe in this scripture nor in (any) that (came) before it." Couldst thou but see when the wrong-doers will be made to stand before their Lord, throwing back the word (of blame) on one another! Those who had been despised will say to the arrogant ones: ``Had it not been for you, we should certainly have been believers!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
The arrogant ones will say to those who had been despised: ``Was it we who kept you back from Guidance after it reached you? Nay, rather, it was ye who transgressed.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who had been despised will say to the arrogant ones: ``Nay! it was a plot (of yours) by day and by night: Behold! Ye (constantly) ordered us to be ungrateful to Allah and to attribute equals to Him!" They will declare (their) repentance when they see the Penalty: We shall put yokes on the necks of the Unbelievers: It would only be a requital for their (ill) Deeds.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
Never did We send a warner to a population, but the wealthy ones among them said: ``We believe not in the (Message) with which ye have been sent."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
They said: ``We have more in wealth and in sons, and we cannot be punished."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say: ``Verily my Lord enlarges and restricts the Provision to whom He pleases, but most men understand not."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
It is not your wealth nor your sons, that will bring you nearer to Us in degree: but only those who believe and work righteousness - these are the ones for whom there is a multiplied Reward for their deeds, while secure they (reside) in the dwellings on high!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
Those who strive against Our Signs, to frustrate them, will be given over into Punishment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: ``Verily my Lord enlarges and restricts the Sustenance to such of his servants as He pleases: and nothing do ye spend in the least (in His cause) but He replaces it: for He is the Best of those who grant Sustenance.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
One Day He will gather them all together, and say to the angels, ``Was it you that these men used to worship?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say, ``Glory to Thee! our (tie) is with Thee - as Protector - not with them. Nay, but they worshipped the Jinns: most of them believed in them."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
So on that Day no power shall they have over each other, for profit or harm: and We shall say to the wrong-doers, ``Taste ye the Penalty of the Fire,- the which ye were wont to deny!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
When Our Clear Signs are rehearsed to them, they say, ``This is only a man who wishes to hinder you from the (worship) which your fathers practised." And they say, ``This is only a falsehood invented!" and the Unbelievers say of the Truth when it comes to them, ``This is nothing but evident magic!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
But We had not given them Books which they could study, nor sent messengers to them before thee as Warners.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And their predecessors rejected (the Truth); these have not received a tenth of what We had granted to those: yet when they rejected My messengers, how (terrible) was My rejection (of them)!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say: ``I do admonish you on one point: that ye do stand up before Allah,- (It may be) in pairs, or (it may be) singly,- and reflect (within yourselves): your Companion is not possessed: he is no less than a warner to you, in face of a terrible Penalty."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say: ``No reward do I ask of you: it is (all) in your interest: my reward is only due from Allah: And He is witness to all things."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say: ``Verily my Lord doth cast the (mantle of) Truth (over His servants),- He that has full knowledge of (all) that is hidden."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say: ``The Truth has arrived, and Falsehood neither creates anything new, nor restores anything."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: ``If I am astray, I only stray to the loss of my own soul: but if I receive guidance, it is because of the inspiration of my Lord to me: it is He Who hears all things, and is (ever) near."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
If thou couldst but see when they will quake with terror; but then there will be no escape (for them), and they will be seized from a position (quite) near.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they will say, ``We do believe (now) in the (Truth)"; but how could they receive (Faith) from a position (so far off,-\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
Seeing that they did reject Faith (entirely) before, and that they (continually) cast (slanders) on the unseen from a position far off?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And between them and their desires, is placed a barrier, as was done in the past with their partisans: for they were indeed in suspicious (disquieting) doubt.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen Praise be to Allah, Who created (out of nothing) the heavens and the earth, Who made the angels, messengers with wings,- two, or three, or four (pairs): He adds to Creation as He pleases: for Allah has power over all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
What Allah out of his Mercy doth bestow on mankind there is none can withhold: what He doth withhold, there is none can grant, apart from Him: and He is the Exalted in Power, full of Wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O men! Call to mind the grace of Allah unto you! is there a creator, other than Allah, to give you sustenance from heaven or earth? There is no god but He: how then are ye deluded away from the Truth?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they reject thee, so were messengers rejected before thee: to Allah back for decision all affairs.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O men! Certainly the promise of Allah is true. Let not then this present life deceive you, nor let the Chief Deceiver deceive you about Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Verily Satan is an enemy to you: so treat him as an enemy. He only invites his adherents, that they may become Companions of the Blazing Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
For those who reject Allah, is a terrible Penalty: but for those who believe and work righteous deeds, is Forgiveness, and a magnificent Reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Is he, then, to whom the evil of his conduct is made alluring, so that he looks upon it as good, (equal to one who is rightly guided)? For Allah leaves to stray whom He wills, and guides whom He wills. So let not thy soul go out in (vainly) sighing after them: for Allah knows well all that they do!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
It is Allah Who sends forth the Winds, so that they raise up the Clouds, and We drive them to a land that is dead, and revive the earth therewith after its death: even so (will be) the Resurrection!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
If any do seek for glory and power,- to Allah belong all glory and power. To Him mount up (all) Words of Purity: It is He Who exalts each Deed of Righteousness. Those that lay Plots of Evil,- for them is a Penalty terrible; and the plotting of such will be void (of result).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah did create you from dust; then from a sperm-drop; then He made you in pairs. And no female conceives, or lays down (her load), but with His knowledge. Nor is a man long-lived granted length of days, nor is a part cut off from his life, but is in a Decree (ordained). All this is easy to Allah.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
Nor are the two bodies of flowing water alike,- the one palatable, sweet, and pleasant to drink, and the other, salt and bitter. Yet from each (kind of water) do ye eat flesh fresh and tender, and ye extract ornaments to wear; and thou seest the ships therein that plough the waves, that ye may seek (thus) of the Bounty of Allah that ye may be grateful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He merges Night into Day, and he merges Day into Night, and he has subjected the sun and the moon (to his Law): each one runs its course for a term appointed. Such is Allah your Lord: to Him belongs all Dominion. And those whom ye invoke besides Him have not the least power.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If ye invoke them, they will not listen to your call, and if they were to listen, they cannot answer your (prayer). On the Day of Judgment they will reject your ``Partnership". and none, (O man!) can tell thee (the Truth) like the One Who is acquainted with all things.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O ye men! It is ye that have need of Allah: but Allah is the One Free of all wants, worthy of all praise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He so pleased, He could blot you out and bring in a New Creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
Nor is that (at all) difficult for Allah.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
Nor can a bearer of burdens bear another's burdens if one heavily laden should call another to (bear) his load. Not the least portion of it can be carried (by the other). Even though he be nearly related. Thou canst but admonish such as fear their Lord unseen and establish regular Prayer. And whoever purifies himself does so for the benefit of his own soul; and the destination (of all) is to Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
The blind and the seeing are not alike;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor are the depths of Darkness and the Light;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor are the (chilly) shade and the (genial) heat of the sun:\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor are alike those that are living and those that are dead. Allah can make any that He wills to hear; but thou canst not make those to hear who are (buried) in graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
Thou art no other than a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Verily We have sent thee in truth, as a bearer of glad tidings, and as a warner: and there never was a people, without a warner having lived among them (in the past).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they reject thee, so did their predecessors, to whom came their messengers with Clear Signs, Books of dark prophecies, and the Book of Enlightenment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
In the end did I punish those who rejected Faith: and how (terrible) was My rejection (of them)!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Seest thou not that Allah sends down rain from the sky? With it We then bring out produce of various colours. And in the mountains are tracts white and red, of various shades of colour, and black intense in hue.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And so amongst men and crawling creatures and cattle, are they of various colours. Those truly fear Allah, among His Servants, who have knowledge: for Allah is Exalted in Might, Oft-Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Those who rehearse the Book of Allah, establish regular Prayer, and spend (in Charity) out of what We have provided for them, secretly and openly, hope for a commerce that will never fail:\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
For He will pay them their meed, nay, He will give them (even) more out of His Bounty: for He is Oft-Forgiving, Most Ready to appreciate (service).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
That which We have revealed to thee of the Book is the Truth,- confirming what was (revealed) before it: for Allah is assuredly- with respect to His Servants - well acquainted and Fully Observant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We have given the Book for inheritance to such of Our Servants as We have chosen: but there are among them some who wrong their own souls; some who follow a middle course; and some who are, by Allah's leave, foremost in good deeds; that is the highest Grace.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
Gardens of Eternity will they enter: therein will they be adorned with bracelets of gold and pearls; and their garments there will be of silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say: ``Praise be to Allah, Who has removed from us (all) sorrow: for our Lord is indeed Oft-Forgiving Ready to appreciate (service):\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
``Who has, out of His Bounty, settled us in a Home that will last: no toil nor sense of weariness shall touch us therein."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
But those who reject (Allah) - for them will be the Fire of Hell: No term shall be determined for them, so they should die, nor shall its Penalty be lightened for them. Thus do We reward every ungrateful one!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
Therein will they cry aloud (for assistance): ``Our Lord! Bring us out: we shall work righteousness, not the (deeds) we used to do!" - ``Did We not give you long enough life so that he that would should receive admonition? and (moreover) the warner came to you. So taste ye (the fruits of your deeds): for the wrong-doers there is no helper."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Verily Allah knows (all) the hidden things of the heavens and the earth: verily He has full knowledge of all that is in (men's) hearts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
He it is That has made you inheritors in the earth: if, then, any do reject (Allah), their rejection (works) against themselves: their rejection but adds to the odium for the Unbelievers in the sight of their Lord: their rejection but adds to (their own) undoing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say: ``Have ye seen (these) 'Partners' of yours whom ye call upon besides Allah? Show Me what it is they have created in the (wide) earth. Or have they a share in the heavens? Or have We given them a Book from which they (can derive) clear (evidence)?- Nay, the wrong-doers promise each other nothing but delusions.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
It is Allah Who sustains the heavens and the earth, lest they cease (to function): and if they should fail, there is none - not one - can sustain them thereafter: Verily He is Most Forbearing, Oft-Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
They swore their strongest oaths by Allah that if a warner came to them, they would follow his guidance better than any (other) of the Peoples: But when a warner came to them, it has only increased their flight (from righteousness),-\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
On account of their arrogance in the land and their plotting of Evil, but the plotting of Evil will hem in only the authors thereof. Now are they but looking for the way the ancients were dealt with? But no change wilt thou find in Allah's way (of dealing): no turning off wilt thou find in Allah's way (of dealing).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Do they not travel through the earth, and see what was the End of those before them,- though they were superior to them in strength? Nor is Allah to be frustrated by anything whatever in the heavens or on earth: for He is All-Knowing. All-Powerful.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If Allah were to punish men according to what they deserve. He would not leave on the back of the (earth) a single living creature: but He gives them respite for a stated Term: when their Term expires, verily Allah has in His sight all His Servants.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya Sin.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Qur'an, full of Wisdom,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Thou art indeed one of the messengers,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On a Straight Way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
It is a Revelation sent down by (Him), the Exalted in Might, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
In order that thou mayest admonish a people, whose fathers had received no admonition, and who therefore remain heedless (of the Signs of Allah).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
The Word is proved true against the greater part of them: for they do not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
We have put yokes round their necks right up to their chins, so that their heads are forced up (and they cannot see).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have put a bar in front of them and a bar behind them, and further, We have covered them up; so that they cannot see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
The same is it to them whether thou admonish them or thou do not admonish them: they will not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
Thou canst but admonish such a one as follows the Message and fears the (Lord) Most Gracious, unseen: give such a one, therefore, good tidings, of Forgiveness and a Reward most generous.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Verily We shall give life to the dead, and We record that which they send before and that which they leave behind, and of all things have We taken account in a clear Book (of evidence).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
Set forth to them, by way of a parable, the (story of) the Companions of the City. Behold!, there came messengers to it.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We (first) sent to them two messengers, they rejected them: But We strengthened them with a third: they said, ``Truly, we have been sent on a mission to you."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
The (people) said: ``Ye are only men like ourselves; and (Allah) Most Gracious sends no sort of revelation: ye do nothing but lie."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said: ``Our Lord doth know that we have been sent on a mission to you:\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
``And our duty is only to proclaim the clear Message."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
The (people) said: ``for us, we augur an evil omen from you: if ye desist not, we will certainly stone you. And a grievous punishment indeed will be inflicted on you by us."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said: ``Your evil omens are with yourselves: (deem ye this an evil omen). If ye are admonished? Nay, but ye are a people transgressing all bounds!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
Then there came running, from the farthest part of the City, a man, saying, ``O my people! Obey the messengers:\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
``Obey those who ask no reward of you (for themselves), and who have themselves received Guidance.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
``It would not be reasonable in me if I did not serve Him Who created me, and to Whom ye shall (all) be brought back.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
``Shall I take (other) gods besides Him? If (Allah) Most Gracious should intend some adversity for me, of no use whatever will be their intercession for me, nor can they deliver me.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
``I would indeed, if I were to do so, be in manifest Error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
``For me, I have faith in the Lord of you (all): listen, then, to me!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said: ``Enter thou the Garden." He said: ``Ah me! Would that my People knew (what I know)!-\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
``For that my Lord has granted me Forgiveness and has enrolled me among those held in honour!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We sent not down against his People, after him, any hosts from heaven, nor was it needful for Us so to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was no more than a single mighty Blast, and behold! they were (like ashes) quenched and silent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Ah! Alas for (My) Servants! There comes not a messenger to them but they mock him!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
See they not how many generations before them we destroyed? Not to them will they return:\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
But each one of them all - will be brought before Us (for judgment).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
A Sign for them is the earth that is dead: We do give it life, and produce grain therefrom, of which ye do eat.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We produce therein orchard with date-palms and vines, and We cause springs to gush forth therein:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
That they may enjoy the fruits of this (artistry): It was not their hands that made this: will they not then give thanks?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory to Allah, Who created in pairs all things that the earth produces, as well as their own (human) kind and (other) things of which they have no knowledge.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a Sign for them is the Night: We withdraw therefrom the Day, and behold they are plunged in darkness;\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs his course for a period determined for him: that is the decree of (Him), the Exalted in Might, the All-Knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the Moon,- We have measured for her mansions (to traverse) till she returns like the old (and withered) lower part of a date-stalk.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not permitted to the Sun to catch up the Moon, nor can the Night outstrip the Day: Each (just) swims along in (its own) orbit (according to Law).\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a Sign for them is that We bore their race (through the Flood) in the loaded Ark;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them similar (vessels) on which they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
If it were Our Will, We could drown them: then would there be no helper (to hear their cry), nor could they be delivered,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Except by way of Mercy from Us, and by way of (world) convenience (to serve them) for a time.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
When they are told, ``Fear ye that which is before you and that which will be after you, in order that ye may receive Mercy," (they turn back).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
Not a Sign comes to them from among the Signs of their Lord, but they turn away therefrom.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when they are told, ``Spend ye of (the bounties) with which Allah has provided you," the Unbelievers say to those who believe: ``Shall we then feed those whom, if Allah had so willed, He would have fed, (Himself)?- Ye are in nothing but manifest error."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
Further, they say, ``When will this promise (come to pass), if what ye say is true?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They will not (have to) wait for aught but a single Blast: it will seize them while they are yet disputing among themselves!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
No (chance) will they then have, by will, to dispose (of their affairs), nor to return to their own people!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
The trumpet shall be sounded, when behold! from the sepulchres (men) will rush forth to their Lord!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say: ``Ah! Woe unto us! Who hath raised us up from our beds of repose?"... (A voice will say:) ``This is what (Allah) Most Gracious had promised. And true was the word of the messengers!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It will be no more than a single Blast, when lo! they will all be brought up before Us!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
Then, on that Day, not a soul will be wronged in the least, and ye shall but be repaid the meeds of your past Deeds.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Verily the Companions of the Garden shall that Day have joy in all that they do;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their associates will be in groves of (cool) shade, reclining on Thrones (of dignity);\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
(Every) fruit (enjoyment) will be there for them; they shall have whatever they call for;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
``Peace!" - a word (of salutation) from a Lord Most Merciful!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
``And O ye in sin! Get ye apart this Day!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
``Did I not enjoin on you, O ye Children of Adam, that ye should not worship Satan; for that he was to you an enemy avowed?-\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
``And that ye should worship Me, (for that) this was the Straight Way?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
``But he did lead astray a great multitude of you. Did ye not, then, understand?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
``This is the Hell of which ye were (repeatedly) warned!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
``Embrace ye the (fire) this Day, for that ye (persistently) rejected (Truth)."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
That Day shall We set a seal on their mouths. But their hands will speak to us, and their feet bear witness, to all that they did.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
If it had been our Will, We could surely have blotted out their eyes; then should they have run about groping for the Path, but how could they have seen?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if it had been Our Will, We could have transformed them (to remain) in their places; then should they have been unable to move about, nor could they have returned (after error).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
If We grant long life to any, We cause him to be reversed in nature: Will they not then understand?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
We have not instructed the (Prophet) in Poetry, nor is it meet for him: this is no less than a Message and a Qur'an making things clear:\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
That it may give admonition to any (who are) alive, and that the charge may be proved against those who reject (Truth).\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
See they not that it is We Who have created for them - among the things which Our hands have fashioned - cattle, which are under their dominion?-\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And that We have subjected them to their (use)? of them some do carry them and some they eat:\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And they have (other) profits from them (besides), and they get (milk) to drink. Will they not then be grateful?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
Yet they take (for worship) gods other than Allah, (hoping) that they might be helped!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They have not the power to help them: but they will be brought up (before Our Judgment-seat) as a troop (to be condemned).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
Let not their speech, then, grieve thee. Verily We know what they hide as well as what they disclose.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Doth not man see that it is We Who created him from sperm? yet behold! he (stands forth) as an open adversary!\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he makes comparisons for Us, and forgets his own (origin and) Creation: He says, ``Who can give life to (dry) bones and decomposed ones (at that)?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say, ``He will give them life Who created them for the first time! for He is Well-versed in every kind of creation!-\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
``The same Who produces for you fire out of the green tree, when behold! ye kindle therewith (your own fires)!\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
``Is not He Who created the heavens and the earth able to create the like thereof?" - Yea, indeed! for He is the Creator Supreme, of skill and knowledge (infinite)!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
Verily, when He intends a thing, His Command is, ``be", and it is!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So glory to Him in Whose hands is the dominion of all things: and to Him will ye be all brought back.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those who range themselves in ranks,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
And so are strong in repelling (evil),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
And thus proclaim the Message (of Allah)!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Verily, verily, your Allah is one!-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and of the earth and all between them, and Lord of every point at the rising of the sun!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have indeed decked the lower heaven with beauty (in) the stars,-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
(For beauty) and for guard against all obstinate rebellious evil spirits,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
(So) they should not strain their ears in the direction of the Exalted Assembly but be cast away from every side,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Repulsed, for they are under a perpetual penalty,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except such as snatch away something by stealth, and they are pursued by a flaming fire, of piercing brightness.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Just ask their opinion: are they the more difficult to create, or the (other) beings We have created? Them have We created out of a sticky clay!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Truly dost thou marvel, while they ridicule,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And, when they are admonished, pay no heed,-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And, when they see a Sign, turn it to mockery,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And say, ``This is nothing but evident sorcery!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
``What! when we die, and become dust and bones, shall we (then) be raised up (again)\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
``And also our fathers of old?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say thou: ``Yea, and ye shall then be humiliated (on account of your evil)."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
Then it will be a single (compelling) cry; and behold, they will begin to see!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will say, ``Ah! Woe to us! This is the Day of Judgment!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
(A voice will say,) ``This is the Day of Sorting Out, whose truth ye (once) denied!"\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
``Bring ye up", it shall be said, ``The wrong-doers and their wives, and the things they worshipped-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
``Besides Allah, and lead them to the Way to the (Fierce) Fire!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
``But stop them, for they must be asked:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
``'What is the matter with you that ye help not each other?'"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Nay, but that day they shall submit (to Judgment);\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And they will turn to one another, and question one another.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say: ``It was ye who used to come to us from the right hand (of power and authority)!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will reply: ``Nay, ye yourselves had no Faith!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
``Nor had we any authority over you. Nay, it was ye who were a people in obstinate rebellion!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
``So now has been proved true, against us, the word of our Lord that we shall indeed (have to) taste (the punishment of our sins).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
``We led you astray: for truly we were ourselves astray."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
Truly, that Day, they will (all) share in the Penalty.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Verily that is how We shall deal with Sinners.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
For they, when they were told that there is no god except Allah, would puff themselves up with Pride,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And say: ``What! shall we give up our gods for the sake of a Poet possessed?"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Nay! he has come with the (very) Truth, and he confirms (the Message of) the messengers (before him).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Ye shall indeed taste of the Grievous Penalty;-\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
But it will be no more than the retribution of (the Evil) that ye have wrought;-\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
But the sincere (and devoted) Servants of Allah,-\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them is a Sustenance determined,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits (Delights); and they (shall enjoy) honour and dignity,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In Gardens of Felicity,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
Facing each other on Thrones (of Dignity):\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
Round will be passed to them a Cup from a clear-flowing fountain,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
Crystal-white, of a taste delicious to those who drink (thereof),\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Free from headiness; nor will they suffer intoxication therefrom.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And besides them will be chaste women, restraining their glances, with big eyes (of wonder and beauty).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
As if they were (delicate) eggs closely guarded.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then they will turn to one another and question one another.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
One of them will start the talk and say: ``I had an intimate companion (on the earth),\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
``Who used to say, 'what! art thou amongst those who bear witness to the Truth (of the Message)?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
``'When we die and become dust and bones, shall we indeed receive rewards and punishments?'"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
(A voice) said: ``Would ye like to look down?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
He looked down and saw him in the midst of the Fire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He said: ``By Allah! thou wast little short of bringing me to perdition!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
``Had it not been for the Grace of my Lord, I should certainly have been among those brought (there)!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
``Is it (the case) that we shall not die,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
``Except our first death, and that we shall not be punished?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Verily this is the supreme achievement!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this let all strive, who wish to strive.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is that the better entertainment or the Tree of Zaqqum?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
For We have truly made it (as) a trial for the wrong-doers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
For it is a tree that springs out of the bottom of Hell-Fire:\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
The shoots of its fruit-stalks are like the heads of devils:\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
Truly they will eat thereof and fill their bellies therewith.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then on top of that they will be given a mixture made of boiling water.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then shall their return be to the (Blazing) Fire.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
Truly they found their fathers on the wrong Path;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they (too) were rushed down on their footsteps!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And truly before them, many of the ancients went astray;-\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
But We sent aforetime, among them, (messengers) to admonish them;-\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Then see what was the end of those who were admonished (but heeded not),-\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Except the sincere (and devoted) Servants of Allah.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
(In the days of old), Noah cried to Us, and We are the best to hear prayer.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We delivered him and his people from the Great Calamity,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And made his progeny to endure (on this earth);\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And We left (this blessing) for him among generations to come in later times:\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
``Peace and salutation to Noah among the nations!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Thus indeed do we reward those who do right.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
For he was one of our believing Servants.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then the rest we overwhelmed in the Flood.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
Verily among those who followed his Way was Abraham.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
Behold! he approached his Lord with a sound heart.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
Behold! he said to his father and to his people, ``What is that which ye worship?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
``Is it a falsehood- gods other than Allah- that ye desire?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
``Then what is your idea about the Lord of the worlds?"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then did he cast a glance at the Stars.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And he said, ``I am indeed sick (at heart)!"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So they turned away from him, and departed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then did he turn to their gods and said, ``will ye not eat (of the offerings before you)?...\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
``What is the matter with you that ye speak not (intelligently)?"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then did he turn upon them, striking (them) with the right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then came (the worshippers) with hurried steps, and faced (him).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: ``Worship ye that which ye have (yourselves) carved?\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
``But Allah has created you and your handwork!"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said, ``Build him a furnace, and throw him into the blazing fire!"\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
(This failing), they then sought a stratagem against him, but We made them the ones most humiliated!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
He said: ``I will go to my Lord! He will surely guide me!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
``O my Lord! Grant me a righteous (son)!"\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So We gave him the good news of a boy ready to suffer and forbear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
Then, when (the son) reached (the age of) (serious) work with him, he said: ``O my son! I see in vision that I offer thee in sacrifice: Now see what is thy view!" (The son) said: ``O my father! Do as thou art commanded: thou will find me, if Allah so wills one practising Patience and Constancy!"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
So when they had both submitted their wills (to Allah), and he had laid him prostrate on his forehead (for sacrifice),\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called out to him ``O Abraham!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
``Thou hast already fulfilled the vision!" - thus indeed do We reward those who do right.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
For this was obviously a trial-\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a momentous sacrifice:\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left (this blessing) for him among generations (to come) in later times:\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
``Peace and salutation to Abraham!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus indeed do We reward those who do right.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
For he was one of our believing Servants.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the good news of Isaac - a prophet,- one of the Righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
We blessed him and Isaac: but of their progeny are (some) that do right, and (some) that obviously do wrong, to their own souls.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
Again (of old) We bestowed Our favour on Moses and Aaron,\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And We delivered them and their people from (their) Great Calamity;\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We helped them, so they overcame (their troubles);\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the Book which helps to make things clear;\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And We guided them to the Straight Way.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left (this blessing) for them among generations (to come) in later times:\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
``Peace and salutation to Moses and Aaron!"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Thus indeed do We reward those who do right.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
For they were two of our believing Servants.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
So also was Elias among those sent (by Us).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
Behold, he said to his people, ``Will ye not fear (Allah)?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
``Will ye call upon Baal and forsake the Best of Creators,-\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
``Allah, your Lord and Cherisher and the Lord and Cherisher of your fathers of old?"\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they rejected him, and they will certainly be called up (for punishment),-\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except the sincere and devoted Servants of Allah (among them).\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left (this blessing) for him among generations (to come) in later times:\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
``Peace and salutation to such as Elias!"\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Thus indeed do We reward those who do right.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
For he was one of our believing Servants.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
So also was Lut among those sent (by Us).\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
Behold, We delivered him and his adherents, all\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except an old woman who was among those who lagged behind:\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We destroyed the rest.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
Verily, ye pass by their (sites), by day-\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And by night: will ye not understand?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
So also was Jonah among those sent (by Us).\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he ran away (like a slave from captivity) to the ship (fully) laden,\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
He (agreed to) cast lots, and he was condemned:\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then the big Fish did swallow him, and he had done acts worthy of blame.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Had it not been that he (repented and) glorified Allah,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would certainly have remained inside the Fish till the Day of Resurrection.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We cast him forth on the naked shore in a state of sickness,\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused to grow, over him, a spreading plant of the gourd kind.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him (on a mission) to a hundred thousand (men) or more.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed; so We permitted them to enjoy (their life) for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now ask them their opinion: Is it that thy Lord has (only) daughters, and they have sons?-\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or that We created the angels female, and they are witnesses (thereto)?\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Is it not that they say, from their own invention,\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
``Allah has begotten children"? but they are liars!\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Did He (then) choose daughters rather than sons?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you? How judge ye?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will ye not then receive admonition?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or have ye an authority manifest?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then bring ye your Book (of authority) if ye be truthful!\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have invented a blood-relationship between Him and the Jinns: but the Jinns know (quite well) that they have indeed to appear (before his Judgment-Seat)!\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Glory to Allah! (He is free) from the things they ascribe (to Him)!\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Not (so do) the Servants of Allah, sincere and devoted.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
For, verily, neither ye nor those ye worship-\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Can lead (any) into temptation concerning Allah,\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except such as are (themselves) going to the blazing Fire!\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
(Those ranged in ranks say): ``Not one of us but has a place appointed;\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
``And we are verily ranged in ranks (for service);\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
``And we are verily those who declare (Allah's) glory!"\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And there were those who said,\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
``If only we had had before us a Message from those of old,\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
``We should certainly have been Servants of Allah, sincere (and devoted)!"\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But (now that the Qur'an has come), they reject it: But soon will they know!\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
Already has Our Word been passed before (this) to our Servants sent (by Us),\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That they would certainly be assisted,\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And that Our forces,- they surely must conquer.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So turn thou away from them for a little while,\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch them (how they fare), and they soon shall see (how thou farest)!\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Do they wish (indeed) to hurry on our Punishment?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
But when it descends into the open space before them, evil will be the morning for those who were warned (and heeded not)!\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So turn thou away from them for a little while,\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And watch (how they fare) and they soon shall see (how thou farest)!\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Glory to thy Lord, the Lord of Honour and Power! (He is free) from what they ascribe (to Him)!\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And Peace on the messengers!\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And Praise to Allah, the Lord and Cherisher of the Worlds.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad: By the Qur'an, Full of Admonition: (This is the Truth).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
But the Unbelievers (are steeped) in self-glory and Separatism.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many generations before them did We destroy? In the end they cried (for mercy)- when there was no longer time for being saved!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
So they wonder that a Warner has come to them from among themselves! and the Unbelievers say, ``This is a sorcerer telling lies!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
``Has he made the gods (all) into one Allah? Truly this is a wonderful thing!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the leader among them go away (impatiently), (saying), ``Walk ye away, and remain constant to your gods! For this is truly a thing designed (against you)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
``We never heard (the like) of this among the people of these latter days: this is nothing but a made-up tale!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
``What! has the Message been sent to him - (Of all persons) among us?"... but they are in doubt concerning My (Own) Message! Nay, they have not yet tasted My Punishment!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or have they the treasures of the mercy of thy Lord,- the Exalted in Power, the Grantor of Bounties without measure?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or have they the dominion of the heavens and the earth and all between? If so, let them mount up with the ropes and means (to reach that end)!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
But there - will be put to flight even a host of confederates.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them (were many who) rejected messengers,- the people of Noah, and 'Ad, and Pharaoh, the Lord of Stakes,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And Thamud, and the people of Lut, and the Companions of the Wood; - such were the Confederates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Not one (of them) but rejected the messengers, but My punishment came justly and inevitably (on them).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
These (today) only wait for a single mighty Blast, which (when it comes) will brook no delay.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: ``Our Lord! hasten to us our sentence (even) before the Day of Account!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Have patience at what they say, and remember our servant David, the man of strength: for he ever turned (to Allah).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
It was We that made the hills declare, in unison with him, Our Praises, at eventide and at break of day,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And the birds gathered (in assemblies): all with him did turn (to Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We strengthened his kingdom, and gave him wisdom and sound judgment in speech and decision.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
Has the Story of the Disputants reached thee? Behold, they climbed over the wall of the private chamber;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered the presence of David, and he was terrified of them, they said: ``Fear not: we are two disputants, one of whom has wronged the other: Decide now between us with truth, and treat us not with injustice, but guide us to the even Path..\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
``This man is my brother: He has nine and ninety ewes, and I have (but) one: Yet he says, 'commit her to my care,' and is (moreover) harsh to me in speech."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
(David) said: ``He has undoubtedly wronged thee in demanding thy (single) ewe to be added to his (flock of) ewes: truly many are the partners (in business) who wrong each other: Not so do those who believe and work deeds of righteousness, and how few are they?"... and David gathered that We had tried him: he asked forgiveness of his Lord, fell down, bowing (in prostration), and turned (to Allah in repentance).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him this (lapse): he enjoyed, indeed, a Near Approach to Us, and a beautiful place of (Final) Return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
O David! We did indeed make thee a vicegerent on earth: so judge thou between men in truth (and justice): Nor follow thou the lusts (of thy heart), for they will mislead thee from the Path of Allah: for those who wander astray from the Path of Allah, is a Penalty Grievous, for that they forget the Day of Account.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
Not without purpose did We create heaven and earth and all between! that were the thought of Unbelievers! but woe to the Unbelievers because of the Fire (of Hell)!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We treat those who believe and work deeds of righteousness, the same as those who do mischief on earth? Shall We treat those who guard against evil, the same as those who turn aside from the right?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
(Here is) a Book which We have sent down unto thee, full of blessings, that they may mediate on its Signs, and that men of understanding may receive admonition.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
To David We gave Solomon (for a son),- How excellent in Our service! Ever did he turn (to Us)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
Behold, there were brought before him, at eventide coursers of the highest breeding, and swift of foot;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
And he said, ``Truly do I love the love of good, with a view to the glory of my Lord,"- until (the sun) was hidden in the veil (of night):\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
``Bring them back to me." then began he to pass his hand over (their) legs and their necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And We did try Solomon: We placed on his throne a body (without life); but he did turn (to Us in true devotion):\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said, ``O my Lord! Forgive me, and grant me a kingdom which, (it may be), suits not another after me: for Thou art the Grantor of Bounties (without measure).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
Then We subjected the wind to his power, to flow gently to his order, Whithersoever he willed,-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
As also the evil ones, (including) every kind of builder and diver,-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
As also others bound together in fetters.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
``Such are Our Bounties: whether thou bestow them (on others) or withhold them, no account will be asked."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And he enjoyed, indeed, a Near Approach to Us, and a beautiful Place of (Final) Return.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
Commemorate Our Servant Job. Behold he cried to his Lord: ``The Evil One has afflicted me with distress and suffering!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(The command was given:) ``Strike with thy foot: here is (water) wherein to wash, cool and refreshing, and (water) to drink."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We gave him (back) his people, and doubled their number,- as a Grace from Ourselves, and a thing for commemoration, for all who have Understanding.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
``And take in thy hand a little grass, and strike therewith: and break not (thy oath)." Truly We found him full of patience and constancy. How excellent in Our service! ever did he turn (to Us)!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And commemorate Our Servants Abraham, Isaac, and Jacob, possessors of Power and Vision.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Verily We did choose them for a special (purpose)- proclaiming the Message of the Hereafter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
They were, in Our sight, truly, of the company of the Elect and the Good.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And commemorate Isma'il, Elisha, and Zul-Kifl: Each of them was of the Company of the Good.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a Message (of admonition): and verily, for the righteous, is a beautiful Place of (Final) Return,-\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Gardens of Eternity, whose doors will (ever) be open to them;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Therein will they recline (at ease): Therein can they call (at pleasure) for fruit in abundance, and (delicious) drink;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And beside them will be chaste women restraining their glances, (companions) of equal age.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
Such is the Promise made, to you for the Day of Account!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Truly such will be Our Bounty (to you); it will never fail;-\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
Yea, such! but - for the wrong-doers will be an evil place of (Final) Return!-\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell!- they will burn therein, - an evil bed (indeed, to lie on)!-\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
Yea, such! - then shall they taste it,- a boiling fluid, and a fluid dark, murky, intensely cold!-\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other Penalties of a similar kind, to match them!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
Here is a troop rushing headlong with you! No welcome for them! truly, they shall burn in the Fire!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
(The followers shall cry to the misleaders:) ``Nay, ye (too)! No welcome for you! It is ye who have brought this upon us! Now evil is (this) place to stay in!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say: ``Our Lord! whoever brought this upon us,- Add to him a double Penalty in the Fire!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say: ``What has happened to us that we see not men whom we used to number among the bad ones?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
``Did we treat them (as such) in ridicule, or have (our) eyes failed to perceive them?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Truly that is just and fitting,- the mutual recriminations of the People of the Fire!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say: ``Truly am I a Warner: no god is there but the one Allah, Supreme and Irresistible,-\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
``The Lord of the heavens and the earth, and all between,- Exalted in Might, able to enforce His Will, forgiving again and again."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: ``That is a Message Supreme (above all),-\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
``From which ye do turn away!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
``No knowledge have I of the Chiefs on high, when they discuss (matters) among themselves.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
'Only this has been revealed to me: that I am to give warning plainly and publicly."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
Behold, thy Lord said to the angels: ``I am about to create man from clay:\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
``When I have fashioned him (in due proportion) and breathed into him of My spirit, fall ye down in obeisance unto him."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So the angels prostrated themselves, all of them together:\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Not so Iblis: he was haughty, and became one of those who reject Faith.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
(Allah) said: ``O Iblis! What prevents thee from prostrating thyself to one whom I have created with my hands? Art thou haughty? Or art thou one of the high (and mighty) ones?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
(Iblis) said: ``I am better than he: thou createdst me from fire, and him thou createdst from clay."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
(Allah) said: ``Then get thee out from here: for thou art rejected, accursed.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
``And My curse shall be on thee till the Day of Judgment."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
(Iblis) said: ``O my Lord! Give me then respite till the Day the (dead) are raised."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
(Allah) said: ``Respite then is granted thee-\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
``Till the Day of the Time Appointed."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
(Iblis) said: ``Then, by Thy power, I will put them all in the wrong,-\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
``Except Thy Servants amongst them, sincere and purified (by Thy Grace)."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
(Allah) said: ``Then it is just and fitting- and I say what is just and fitting-\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
``That I will certainly fill Hell with thee and those that follow thee,- every one."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say: ``No reward do I ask of you for this (Qur'an), nor am I a pretender.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
``This is no less than a Message to (all) the Worlds.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
``And ye shall certainly know the truth of it (all) after a while."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of this Book is from Allah, the Exalted in Power, full of Wisdom.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Verily it is We Who have revealed the Book to thee in Truth: so serve Allah, offering Him sincere devotion.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Is it not to Allah that sincere devotion is due? But those who take for protectors other than Allah (say): ``We only serve them in order that they may bring us nearer to Allah." Truly Allah will judge between them in that wherein they differ. But Allah guides not such as are false and ungrateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Had Allah wished to take to Himself a son, He could have chosen whom He pleased out of those whom He doth create: but Glory be to Him! (He is above such things.) He is Allah, the One, the Irresistible.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and the earth in true (proportions): He makes the Night overlap the Day, and the Day overlap the Night: He has subjected the sun and the moon (to His law): Each one follows a course for a time appointed. Is not He the Exalted in Power - He Who forgives again and again?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you (all) from a single person: then created, of like nature, his mate; and he sent down for you eight head of cattle in pairs: He makes you, in the wombs of your mothers, in stages, one after another, in three veils of darkness. such is Allah, your Lord and Cherisher: to Him belongs (all) dominion. There is no god but He: then how are ye turned away (from your true Centre)?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If ye reject (Allah), Truly Allah hath no need of you; but He liketh not ingratitude from His servants: if ye are grateful, He is pleased with you. No bearer of burdens can bear the burden of another. In the end, to your Lord is your Return, when He will tell you the truth of all that ye did (in this life). for He knoweth well all that is in (men's) hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
When some trouble toucheth man, he crieth unto his Lord, turning to Him in repentance: but when He bestoweth a favour upon him as from Himself, (man) doth forget what he cried and prayed for before, and he doth set up rivals unto Allah, thus misleading others from Allah's Path. Say, ``Enjoy thy blasphemy for a little while: verily thou art (one) of the Companions of the Fire!"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is one who worships devoutly during the hour of the night prostrating himself or standing (in adoration), who takes heed of the Hereafter, and who places his hope in the Mercy of his Lord - (like one who does not)? Say: ``Are those equal, those who know and those who do not know? It is those who are endued with understanding that receive admonition.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say: ``O ye my servants who believe! Fear your Lord, good is (the reward) for those who do good in this world. Spacious is Allah's earth! those who patiently persevere will truly receive a reward without measure!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say: ``Verily, I am commanded to serve Allah with sincere devotion;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
``And I am commanded to be the first of those who bow to Allah in Islam."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: ``I would, if I disobeyed my Lord, indeed have fear of the Penalty of a Mighty Day."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: ``It is Allah I serve, with my sincere (and exclusive) devotion:\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
``Serve ye what ye will besides him." Say: ``Truly, those in loss are those who lose their own souls and their People on the Day of Judgment: Ah! that is indeed the (real and) evident Loss!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They shall have Layers of Fire above them, and Layers (of Fire) below them: with this doth Allah warn off his servants: ``O My Servants! then fear ye Me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
Those who eschew Evil,- and fall not into its worship,- and turn to Allah (in repentance),- for them is Good News: so announce the Good News to My Servants,-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Those who listen to the Word, and follow the best (meaning) in it: those are the ones whom Allah has guided, and those are the ones endued with understanding.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Is, then, one against whom the decree of Punishment is justly due (equal to one who eschews Evil)? Wouldst thou, then, deliver one (who is) in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But it is for those who fear their Lord. That lofty mansions, one above another, have been built: beneath them flow rivers (of delight): (such is) the Promise of Allah: never doth Allah fail in (His) promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Seest thou not that Allah sends down rain from the sky, and leads it through springs in the earth? Then He causes to grow, therewith, produce of various colours: then it withers; thou wilt see it grow yellow; then He makes it dry up and crumble away. Truly, in this, is a Message of remembrance to men of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is one whose heart Allah has opened to Islam, so that he has received Enlightenment from Allah, (no better than one hard-hearted)? Woe to those whose hearts are hardened against celebrating the praises of Allah! they are manifestly wandering (in error)!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has revealed (from time to time) the most beautiful Message in the form of a Book, consistent with itself, (yet) repeating (its teaching in various aspects): the skins of those who fear their Lord tremble thereat; then their skins and their hearts do soften to the celebration of Allah's praises. Such is the guidance of Allah: He guides therewith whom He pleases, but such as Allah leaves to stray, can have none to guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is, then, one who has to fear the brunt of the Penalty on the Day of Judgment (and receive it) on his face, (like one guarded therefrom)? It will be said to the wrong-doers: ``Taste ye (the fruits of) what ye earned!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them (also) rejected (revelation), and so the Punishment came to them from directions they did not perceive.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah gave them a taste of humiliation in the present life, but greater is the punishment of the Hereafter, if they only knew!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
We have put forth for men, in this Qur'an every kind of Parable, in order that they may receive admonition.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
(It is) a Qur'an in Arabic, without any crookedness (therein): in order that they may guard against Evil.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah puts forth a Parable a man belonging to many partners at variance with each other, and a man belonging entirely to one master: are those two equal in comparison? Praise be to Allah! but most of them have no knowledge.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Truly thou wilt die (one day), and truly they (too) will die (one day).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
In the end will ye (all), on the Day of Judgment, settle your disputes in the presence of your Lord.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Who, then, doth more wrong than one who utters a lie concerning Allah, and rejects the Truth when it comes to him; is there not in Hell an abode for blasphemers?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And he who brings the Truth and he who confirms (and supports) it - such are the men who do right.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have all that they wish for, in the presence of their Lord: such is the reward of those who do good:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
So that Allah will turn off from them (even) the worst in their deeds and give them their reward according to the best of what they have done.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah enough for his Servant? But they try to frighten thee with other (gods) besides Him! for such as Allah leaves to stray, there can be no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And such as Allah doth guide there can be none to lead astray. Is not Allah Exalted in Power, (Able to enforce His Will), Lord of Retribution?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
If indeed thou ask them who it is that created the heavens and the earth, they would be sure to say, ``Allah". Say: ``See ye then? the things that ye invoke besides Allah,- can they, if Allah wills some Penalty for me, remove His Penalty?- Or if He wills some Grace for me, can they keep back his Grace?" Say: ``Sufficient is Allah for me! In Him trust those who put their trust."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: ``O my People! Do whatever ye can: I will do (my part): but soon will ye know-\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
``Who it is to whom comes a Penalty of ignominy, and on whom descends a Penalty that abides."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Verily We have revealed the Book to thee in Truth, for (instructing) mankind. He, then, that receives guidance benefits his own soul: but he that strays injures his own soul. Nor art thou set over them to dispose of their affairs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
It is Allah that takes the souls (of men) at death; and those that die not (He takes) during their sleep: those on whom He has passed the decree of death, He keeps back (from returning to life), but the rest He sends (to their bodies) for a term appointed verily in this are Signs for those who reflect.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
What! Do they take for intercessors others besides Allah? Say: ``Even if they have no power whatever and no intelligence?"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: ``To Allah belongs exclusively (the right to grant) intercession: to Him belongs the dominion of the heavens and the earth: In the End, it is to Him that ye shall be brought back."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
When Allah, the One and Only, is mentioned, the hearts of those who believe not in the Hereafter are filled with disgust and horror; but when (gods) other than He are mentioned, behold, they are filled with joy!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: ``O Allah! Creator of the heavens and the earth! Knower of all that is hidden and open! it is Thou that wilt judge between Thy Servants in those matters about which they have differed."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
Even if the wrong-doers had all that there is on earth, and as much more, (in vain) would they offer it for ransom from the pain of the Penalty on the Day of Judgment: but something will confront them from Allah, which they could never have counted upon!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
For the evils of their Deeds will confront them, and they will be (completely) encircled by that which they used to mock at!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
Now, when trouble touches man, he cries to Us: But when We bestow a favour upon him as from Ourselves, he says, ``This has been given to me because of a certain knowledge (I have)!" Nay, but this is but a trial, but most of them understand not!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Thus did the (generations) before them say! But all that they did was of no profit to them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
Nay, the evil results of their Deeds overtook them. And the wrong-doers of this (generation)- the evil results of their Deeds will soon overtake them (too), and they will never be able to frustrate (Our Plan)!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Know they not that Allah enlarges the provision or restricts it, for any He pleases? Verily, in this are Signs for those who believe!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: ``O my Servants who have transgressed against their souls! Despair not of the Mercy of Allah: for Allah forgives all sins: for He is Oft-Forgiving, Most Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
``Turn ye to our Lord (in repentance) and bow to His (Will), before the Penalty comes on you: after that ye shall not be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
``And follow the best of (the courses) revealed to you from your Lord, before the Penalty comes on you - of a sudden while ye perceive not!-\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
``Lest the soul should (then) say: 'Ah! Woe is me!- In that I neglected (my duty) towards Allah, and was but among those who mocked!'-\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
``Or (lest) it should say: 'If only Allah had guided me, I should certainly have been among the righteous!'-\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
``Or (lest) it should say when it (actually) sees the penalty: 'If only I had another chance, I should certainly be among those who do good!'\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
``(The reply will be:) 'Nay, but there came to thee my Signs, and thou didst reject them: thou wast Haughty, and became one of those who reject faith!'"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
On the Day of Judgment wilt thou see those who told lies against Allah;- their faces will be turned black; Is there not in Hell an abode for the Haughty?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
But Allah will deliver the righteous to their place of salvation: no evil shall touch them, nor shall they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of all things, and He is the Guardian and Disposer of all affairs.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the keys of the heavens and the earth: and those who reject the Signs of Allah,- it is they who will be in loss.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say: ``Is it some one other than Allah that ye order me to worship, O ye ignorant ones?"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
But it has already been revealed to thee,- as it was to those before thee,- ``If thou wert to join (gods with Allah), truly fruitless will be thy work (in life), and thou wilt surely be in the ranks of those who lose (all spiritual good)".\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Nay, but worship Allah, and be of those who give thanks.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
No just estimate have they made of Allah, such as is due to Him: On the Day of Judgment the whole of the earth will be but His handful, and the heavens will be rolled up in His right hand: Glory to Him! High is He above the Partners they attribute to Him!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
The Trumpet will (just) be sounded, when all that are in the heavens and on earth will swoon, except such as it will please Allah (to exempt). Then will a second one be sounded, when, behold, they will be standing and looking on!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the Earth will shine with the Glory of its Lord: the Record (of Deeds) will be placed (open); the prophets and the witnesses will be brought forward and a just decision pronounced between them; and they will not be wronged (in the least).\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And to every soul will be paid in full (the fruit) of its Deeds; and (Allah) knoweth best all that they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
The Unbelievers will be led to Hell in crowd: until, when they arrive, there, its gates will be opened. And its keepers will say, ``Did not messengers come to you from among yourselves, rehearsing to you the Signs of your Lord, and warning you of the Meeting of This Day of yours?" The answer will be: ``True: but the Decree of Punishment has been proved true against the Unbelievers!"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
(To them) will be said: ``Enter ye the gates of Hell, to dwell therein: and evil is (this) Abode of the Arrogant!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who feared their Lord will be led to the Garden in crowds: until behold, they arrive there; its gates will be opened; and its keepers will say: ``Peace be upon you! well have ye done! enter ye here, to dwell therein."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
They will say: ``Praise be to Allah, Who has truly fulfilled His Promise to us, and has given us (this) land in heritage: We can dwell in the Garden as we will: how excellent a reward for those who work (righteousness)!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And thou wilt see the angels surrounding the Throne (Divine) on all sides, singing Glory and Praise to their Lord. The Decision between them (at Judgment) will be in (perfect) justice, and the cry (on all sides) will be, ``Praise be to Allah, the Lord of the Worlds!"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of this Book is from Allah, Exalted in Power, Full of Knowledge,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
Who forgiveth sin, accepteth repentance, is strict in punishment, and hath a long reach (in all things). there is no god but He: to Him is the final goal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None can dispute about the Signs of Allah but the Unbelievers. Let not, then, their strutting about through the land deceive thee!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
But (there were people) before them, who denied (the Signs),- the People of Noah, and the Confederates (of Evil) after them; and every People plotted against their prophet, to seize him, and disputed by means of vanities, therewith to condemn the Truth; but it was I that seized them! and how (terrible) was My Requital!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus was the Decree of thy Lord proved true against the Unbelievers; that truly they are Companions of the Fire!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who sustain the Throne (of Allah) and those around it Sing Glory and Praise to their Lord; believe in Him; and implore Forgiveness for those who believe: ``Our Lord! Thy Reach is over all things, in Mercy and Knowledge. Forgive, then, those who turn in Repentance, and follow Thy Path; and preserve them from the Penalty of the Blazing Fire!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
``And grant, our Lord! that they enter the Gardens of Eternity, which Thou hast promised to them, and to the righteous among their fathers, their wives, and their posterity! For Thou art (He), the Exalted in Might, Full of Wisdom.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
``And preserve them from (all) ills; and any whom Thou dost preserve from ills that Day,- on them wilt Thou have bestowed Mercy indeed: and that will be truly (for them) the highest Achievement".\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
The Unbelievers will be addressed: ``Greater was the aversion of Allah to you than (is) your aversion to yourselves, seeing that ye were called to the Faith and ye used to refuse."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say: ``Our Lord! twice hast Thou made us without life, and twice hast Thou given us Life! Now have we recognised our sins: Is there any way out (of this)?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(The answer will be:) ``This is because, when Allah was invoked as the Only (object of worship), ye did reject Faith, but when partners were joined to Him, ye believed! the Command is with Allah, Most High, Most Great!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
He it is Who showeth you his Signs, and sendeth down sustenance for you from the sky: but only those receive admonition who turn (to Allah).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
Call ye, then, upon Allah with sincere devotion to Him, even though the Unbelievers may detest it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Raised high above ranks (or degrees), (He is) the Lord of the Throne (of Authority): by His Command doth He send the Spirit (of inspiration) to any of His servants he pleases, that it may warn (men) of the Day of Mutual Meeting,-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day whereon they will (all) come forth: not a single thing concerning them is hidden from Allah. Whose will be the dominion that Day?" That of Allah, the One the Irresistible!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
That Day will every soul be requited for what it earned; no injustice will there be that Day, for Allah is Swift in taking account.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
Warn them of the Day that is (ever) drawing near, when the hearts will (come) right up to the throats to choke (them); No intimate friend nor intercessor will the wrong-doers have, who could be listened to.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
(Allah) knows of (the tricks) that deceive with the eyes, and all that the hearts (of men) conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
And Allah will judge with (justice and) Truth: but those whom (men) invoke besides Him, will not (be in a position) to judge at all. Verily it is Allah (alone) Who hears and sees (all things).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Do they not travel through the earth and see what was the End of those before them? They were even superior to them in strength, and in the traces (they have left) in the land: but Allah did call them to account for their sins, and none had they to defend them against Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because there came to them their messengers with Clear (Signs), but they rejected them: So Allah called them to account: for He is Full of Strength, Strict in Punishment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
Of old We sent Moses, with Our Signs and an authority manifest,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
To Pharaoh, Haman, and Qarun; but they called (him)" a sorcerer telling lies!"...\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
Now, when he came to them in Truth, from Us, they said, ``Slay the sons of those who believe with him, and keep alive their females," but the plots of Unbelievers (end) in nothing but errors (and delusions)!...\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
Said Pharaoh: ``Leave me to slay Moses; and let him call on his Lord! What I fear is lest he should change your religion, or lest he should cause mischief to appear in the land!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Moses said: ``I have indeed called upon my Lord and your Lord (for protection) from every arrogant one who believes not in the Day of Account!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
A believer, a man from among the people of Pharaoh, who had concealed his faith, said: ``Will ye slay a man because he says, 'My Lord is Allah'?- when he has indeed come to you with Clear (Signs) from your Lord? and if he be a liar, on him is (the sin of) his lie: but, if he is telling the Truth, then will fall on you something of the (calamity) of which he warns you: Truly Allah guides not one who transgresses and lies!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
``O my People! Yours is the dominion this day: Ye have the upper hand in the land: but who will help us from the Punishment of Allah, should it befall us?" Pharaoh said: ``I but point out to you that which I see (myself); Nor do I guide you but to the Path of Right!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
Then said the man who believed: ``O my people! Truly I do fear for you something like the Day (of disaster) of the Confederates (in sin)!-\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
``Something like the fate of the People of Noah, the 'Ad, and the Thamud, and those who came after them: but Allah never wishes injustice to his Servants.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
``And O my people! I fear for you a Day when there will be Mutual calling (and wailing),-\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
``A Day when ye shall turn your backs and flee: No defender shall ye have from Allah: Any whom Allah leaves to stray, there is none to guide...\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
``And to you there came Joseph in times gone by, with Clear Signs, but ye ceased not to doubt of the (Mission) for which he had come: At length, when he died, ye said: 'No messenger will Allah send after him.' thus doth Allah leave to stray such as transgress and live in doubt,-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
``(Such) as dispute about the Signs of Allah, without any authority that hath reached them, grievous and odious (is such conduct) in the sight of Allah and of the Believers. Thus doth Allah, seal up every heart - of arrogant and obstinate Transgressors."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
Pharaoh said: ``O Haman! Build me a lofty palace, that I may attain the ways and means-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
``The ways and means of (reaching) the heavens, and that I may mount up to the god of Moses: But as far as I am concerned, I think (Moses) is a liar!" Thus was made alluring, in Pharaoh's eyes, the evil of his deeds, and he was hindered from the Path; and the plot of Pharaoh led to nothing but perdition (for him).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
The man who believed said further: ``O my people! Follow me: I will lead you to the Path of Right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
``O my people! This life of the present is nothing but (temporary) convenience: It is the Hereafter that is the Home that will last.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
``He that works evil will not be requited but by the like thereof: and he that works a righteous deed - whether man or woman - and is a Believer- such will enter the Garden (of Bliss): Therein will they have abundance without measure.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
``And O my people! How (strange) it is for me to call you to Salvation while ye call me to the Fire!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
``Ye do call upon me to blaspheme against Allah, and to join with Him partners of whom I have no knowledge; and I call you to the Exalted in Power, Who forgives again and again!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
``Without doubt ye do call me to one who is not fit to be called to, whether in this world, or in the Hereafter; our return will be to Allah; and the Transgressors will be Companions of the Fire!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
``Soon will ye remember what I say to you (now), My (own) affair I commit to Allah: for Allah (ever) watches over His Servants."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
Then Allah saved him from (every) ill that they plotted (against him), but the burnt of the Penalty encompassed on all sides the People of Pharaoh.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
In front of the Fire will they be brought, morning and evening: And (the sentence will be) on the Day that Judgment will be established: ``Cast ye the People of Pharaoh into the severest Penalty!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
Behold, they will dispute with each other in the Fire! The weak ones (who followed) will say to those who had been arrogant, ``We but followed you: Can ye then take (on yourselves) from us some share of the Fire?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who had been arrogant will say: ``We are all in this (Fire)! Truly, Allah has judged between (his) Servants!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
Those in the Fire will say to the Keepers of Hell: ``Pray to your Lord to lighten us the Penalty for a day (at least)!"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say: ``Did there not come to you your messengers with Clear Signs?" They will say, ``Yes". They will reply, ``Then pray (as ye like)! But the prayer of those without Faith is nothing but (futile wandering) in (mazes of) error!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
We will, without doubt, help our messengers and those who believe, (both) in this world's life and on the Day when the Witnesses will stand forth,-\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The Day when no profit will it be to Wrong-doers to present their excuses, but they will (only) have the Curse and the Home of Misery.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
We did aforetime give Moses the (Book of) Guidance, and We gave the book in inheritance to the Children of Israel,-\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A Guide and a Message to men of Understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Patiently, then, persevere: for the Promise of Allah is true: and ask forgiveness for thy fault, and celebrate the Praises of thy Lord in the evening and in the morning.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Those who dispute about the signs of Allah without any authority bestowed on them,- there is nothing in their breasts but (the quest of) greatness, which they shall never attain to: seek refuge, then, in Allah: It is He Who hears and sees (all things).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Assuredly the creation of the heavens and the earth is a greater (matter) than the creation of men: Yet most men understand not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
Not equal are the blind and those who (clearly) see: Nor are (equal) those who believe and work deeds of righteousness, and those who do evil. Little do ye learn by admonition!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
The Hour will certainly come: Therein is no doubt: Yet most men believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord says: ``Call on Me; I will answer your (Prayer): but those who are too arrogant to serve Me will surely find themselves in Hell - in humiliation!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is Allah Who has made the Night for you, that ye may rest therein, and the days as that which helps (you) to see. Verily Allah is full of Grace and Bounty to men: yet most men give no thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is Allah, your Lord, the Creator of all things, there is no god but He: Then how ye are deluded away from the Truth!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus are deluded those who are wont to reject the Signs of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is Allah Who has made for you the earth as a resting place, and the sky as a canopy, and has given you shape- and made your shapes beautiful,- and has provided for you Sustenance, of things pure and good;- such is Allah your Lord. So Glory to Allah, the Lord of the Worlds!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living (One): There is no god but He: Call upon Him, giving Him sincere devotion. Praise be to Allah, Lord of the Worlds!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say: ``I have been forbidden to invoke those whom ye invoke besides Allah,- seeing that the Clear Signs have come to me from my Lord; and I have been commanded to bow (in Islam) to the Lord of the Worlds."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He Who has created you from dust then from a sperm-drop, then from a leech-like clot; then does he get you out (into the light) as a child: then lets you (grow and) reach your age of full strength; then lets you become old,- though of you there are some who die before;- and lets you reach a Term appointed; in order that ye may learn wisdom.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He Who gives Life and Death; and when He decides upon an affair, He says to it, ``Be", and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Seest thou not those that dispute concerning the Signs of Allah? How are they turned away (from Reality)?-\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who reject the Book and the (revelations) with which We sent our messengers: but soon shall they know,-\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When the yokes (shall be) round their necks, and the chains; they shall be dragged along-\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
In the boiling fetid fluid: then in the Fire shall they be burned;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then shall it be said to them: ``Where are the (deities) to which ye gave part-worship-\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
``In derogation of Allah?" They will reply: ``They have left us in the lurch: Nay, we invoked not, of old, anything (that had real existence)." Thus does Allah leave the Unbelievers to stray.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
``That was because ye were wont to rejoice on the earth in things other than the Truth, and that ye were wont to be insolent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
``Enter ye the gates of Hell, to dwell therein: and evil is (this) abode of the arrogant!"\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So persevere in patience; for the Promise of Allah is true: and whether We show thee (in this life) some part of what We promise them,- or We take thy soul (to Our Mercy) (before that),-(in any case) it is to Us that they shall (all) return.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
We did aforetime send messengers before thee: of them there are some whose story We have related to thee, and some whose story We have not related to thee. It was not (possible) for any messenger to bring a sign except by the leave of Allah: but when the Command of Allah issued, the matter was decided in truth and justice, and there perished, there and then those who stood on Falsehoods.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
It is Allah Who made cattle for you, that ye may use some for riding and some for food;\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And there are (other) advantages in them for you (besides); that ye may through them attain to any need (there may be) in your hearts; and on them and on ships ye are carried.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you (always) His Signs: then which of the Signs of Allah will ye deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Do they not travel through the earth and see what was the End of those before them? They were more numerous than these and superior in strength and in the traces (they have left) in the land: Yet all that they accomplished was of no profit to them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
For when their messengers came to them with Clear Signs, they exulted in such knowledge (and skill) as they had; but that very (Wrath) at which they were wont to scoff hemmed them in.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
But when they saw Our Punishment, they said: ``We believe in Allah,- the one Allah - and we reject the partners we used to join with Him."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their professing the Faith when they (actually) saw Our Punishment was not going to profit them. (Such has been) Allah's Way of dealing with His Servants (from the most ancient times). And even thus did the Rejecters of Allah perish (utterly)!\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha Mim:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A Revelation from (Allah), Most Gracious, Most Merciful;-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book, whereof the verses are explained in detail;- a Qur'an in Arabic, for people who understand;-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Giving good news and admonition: yet most of them turn away, and so they hear not.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
They say: ``Our hearts are under veils, (concealed) from that to which thou dost invite us, and in our ears in a deafness, and between us and thee is a screen: so do thou (what thou wilt); for us, we shall do (what we will!)"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say thou: ``I am but a man like you: It is revealed to me by Inspiration, that your Allah is one Allah: so stand true to Him, and ask for His Forgiveness." And woe to those who join gods with Allah,-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who practise not regular Charity, and who even deny the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
For those who believe and work deeds of righteousness is a reward that will never fail.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say: Is it that ye deny Him Who created the earth in two Days? And do ye join equals with Him? He is the Lord of (all) the Worlds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He set on the (earth), mountains standing firm, high above it, and bestowed blessings on the earth, and measure therein all things to give them nourishment in due proportion, in four Days, in accordance with (the needs of) those who seek (Sustenance).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Moreover He comprehended in His design the sky, and it had been (as) smoke: He said to it and to the earth: ``Come ye together, willingly or unwillingly." They said: ``We do come (together), in willing obedience."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
So He completed them as seven firmaments in two Days, and He assigned to each heaven its duty and command. And We adorned the lower heaven with lights, and (provided it) with guard. Such is the Decree of (Him) the Exalted in Might, Full of Knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, say thou: ``I have warned you of a stunning Punishment (as of thunder and lightning) like that which (overtook) the 'Ad and the Thamud!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
Behold, the messengers came to them, from before them and behind them, (preaching): ``Serve none but Allah." They said, ``If our Lord had so pleased, He would certainly have sent down angels (to preach). Now we reject your mission (altogether)."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
Now the 'Ad behaved arrogantly through the land, against (all) truth and reason, and said: ``Who is superior to us in strength?" What! did they not see that Allah, Who created them, was superior to them in strength? But they continued to reject Our Signs!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
So We sent against them a furious Wind through days of disaster, that We might give them a taste of a Penalty of humiliation in this life; but the Penalty of a Hereafter will be more humiliating still: and they will find no help.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
As to the Thamud, We gave them Guidance, but they preferred blindness (of heart) to Guidance: so the stunning Punishment of humiliation seized them, because of what they had earned.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
But We delivered those who believed and practised righteousness.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
On the Day that the enemies of Allah will be gathered together to the Fire, they will be marched in ranks.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
At length, when they reach the (Fire), their hearing, their sight, and their skins will bear witness against them, as to (all) their deeds.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
They will say to their skins: ``Why bear ye witness against us?" They will say: ``Allah hath given us speech,- (He) Who giveth speech to everything: He created you for the first time, and unto Him were ye to return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
``Ye did not seek to hide yourselves, lest your hearing, your sight, and your skins should bear witness against you! But ye did think that Allah knew not many of the things that ye used to do!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
``But this thought of yours which ye did entertain concerning your Lord, hath brought you to destruction, and (now) have ye become of those utterly lost!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
If, then, they have patience, the Fire will be a home for them! and if they beg to be received into favour, into favour will they not (then) be received.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We have destined for them intimate companions (of like nature), who made alluring to them what was before them and behind them; and the sentence among the previous generations of Jinns and men, who have passed away, is proved against them; for they are utterly lost.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
The Unbelievers say: ``Listen not to this Qur'an, but talk at random in the midst of its (reading), that ye may gain the upper hand!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
But We will certainly give the Unbelievers a taste of a severe Penalty, and We will requite them for the worst of their deeds.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
Such is the requital of the enemies of Allah,- the Fire: therein will be for them the Eternal Home: a (fit) requital, for that they were wont to reject Our Signs.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And the Unbelievers will say: ``Our Lord! Show us those, among Jinns and men, who misled us: We shall crush them beneath our feet, so that they become the vilest (before all)."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
In the case of those who say, ``Our Lord is Allah", and, further, stand straight and steadfast, the angels descend on them (from time to time): ``Fear ye not!" (they suggest), ``Nor grieve! but receive the Glad Tidings of the Garden (of Bliss), the which ye were promised!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
``We are your protectors in this life and in the Hereafter: therein shall ye have all that your souls shall desire; therein shall ye have all that ye ask for!-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
``A hospitable gift from one Oft-Forgiving, Most Merciful!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
Who is better in speech than one who calls (men) to Allah, works righteousness, and says, ``I am of those who bow in Islam"?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
Nor can goodness and Evil be equal. Repel (Evil) with what is better: Then will he between whom and thee was hatred become as it were thy friend and intimate!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
And no one will be granted such goodness except those who exercise patience and self-restraint,- none but persons of the greatest good fortune.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if (at any time) an incitement to discord is made to thee by the Evil One, seek refuge in Allah. He is the One Who hears and knows all things.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
Among His Signs are the Night and the Day, and the Sun and the Moon. Do not prostrate to the sun and the moon, but prostrate to Allah, Who created them, if it is Him ye wish to serve.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But is the (Unbelievers) are arrogant, (no matter): for in the presence of thy Lord are those who celebrate His praises by night and by day. And they never flag (nor feel themselves above it).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And among His Signs in this: thou seest the earth barren and desolate; but when We send down rain to it, it is stirred to life and yields increase. Truly, He Who gives life to the (dead) earth can surely give life to (men) who are dead. For He has power over all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Those who pervert the Truth in Our Signs are not hidden from Us. Which is better?- he that is cast into the Fire, or he that comes safe through, on the Day of Judgment? Do what ye will: verily He seeth (clearly) all that ye do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Those who reject the Message when it comes to them (are not hidden from Us). And indeed it is a Book of exalted power.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
No falsehood can approach it from before or behind it: It is sent down by One Full of Wisdom, Worthy of all Praise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing is said to thee that was not said to the messengers before thee: that thy lord has at his Command (all) forgiveness as well as a most Grievous Penalty.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
Had We sent this as a Qur'an (in the language) other than Arabic, they would have said: ``Why are not its verses explained in detail? What! (a Book) not in Arabic and (a Messenger an Arab?" Say: ``It is a Guide and a Healing to those who believe; and for those who believe not, there is a deafness in their ears, and it is blindness in their (eyes): They are (as it were) being called from a place far distant!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
We certainly gave Moses the Book aforetime: but disputes arose therein. Had it not been for a Word that went forth before from thy Lord, (their differences) would have been settled between them: but they remained in suspicious disquieting doubt thereon.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoever works righteousness benefits his own soul; whoever works evil, it is against his own soul: nor is thy Lord ever unjust (in the least) to His Servants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To Him is referred the Knowledge of the Hour (of Judgment: He knows all): No date-fruit comes out of its sheath, nor does a female conceive (within her womb) nor bring forth the Day that (Allah) will propound to them the (question), ``Where are the partners (ye attributed to Me?" They will say, ``We do assure thee not one of us can bear witness!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
The (deities) they used to invoke aforetime will leave them in the lurch, and they will perceive that they have no way of escape.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man does not weary of asking for good (things), but if ill touches him, he gives up all hope (and) is lost in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
When we give him a taste of some Mercy from Ourselves, after some adversity has touched him, he is sure to say, ``This is due to my (merit): I think not that the Hour (of Judgment) will (ever) be established; but if I am brought back to my Lord, I have (much) good (stored) in His sight!" But We will show the Unbelievers the truth of all that they did, and We shall give them the taste of a severe Penalty.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
When We bestow favours on man, he turns away, and gets himself remote on his side (instead of coming to Us); and when evil seizes him, (he comes) full of prolonged prayer!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say: ``See ye if the (Revelation) is (really) from Allah, and yet do ye reject it? Who is more astray than one who is in a schism far (from any purpose)?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
Soon will We show them our Signs in the (furthest) regions (of the earth), and in their own souls, until it becomes manifest to them that this is the Truth. Is it not enough that thy Lord doth witness all things?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Ah indeed! Are they in doubt concerning the Meeting with their Lord? Ah indeed! It is He that doth encompass all things!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha-Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
'Ain. Sin. Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Thus doth (He) send inspiration to thee as (He did) to those before thee,- Allah, Exalted in Power, Full of Wisdom.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs all that is in the heavens and on earth: and He is Most High, Most Great.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens are almost rent asunder from above them (by Him Glory): and the angels celebrate the Praises of their Lord, and pray for forgiveness for (all) beings on earth: Behold! Verily Allah is He, the Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And those who take as protectors others besides Him,- Allah doth watch over them; and thou art not the disposer of their affairs.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
Thus have We sent by inspiration to thee an Arabic Qur'an: that thou mayest warn the Mother of Cities and all around her,- and warn (them) of the Day of Assembly, of which there is no doubt: (when) some will be in the Garden, and some in the Blazing Fire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
If Allah had so willed, He could have made them a single people; but He admits whom He will to His Mercy; and the Wrong-doers will have no protector nor helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
What! Have they taken (for worship) protectors besides Him? But it is Allah,- He is the Protector, and it is He Who gives life to the dead: It is He Who has power over all things,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
Whatever it be wherein ye differ, the decision thereof is with Allah: such is Allah my Lord: In Him I trust, and to Him I turn.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
(He is) the Creator of the heavens and the earth: He has made for you pairs from among yourselves, and pairs among cattle: by this means does He multiply you: there is nothing whatever like unto Him, and He is the One that hears and sees (all things).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belong the keys of the heavens and the earth: He enlarges and restricts. The Sustenance to whom He will: for He knows full well all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
The same religion has He established for you as that which He enjoined on Noah - the which We have sent by inspiration to thee - and that which We enjoined on Abraham, Moses, and Jesus: Namely, that ye should remain steadfast in religion, and make no divisions therein: to those who worship other things than Allah, hard is the (way) to which thou callest them. Allah chooses to Himself those whom He pleases, and guides to Himself those who turn (to Him).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they became divided only after Knowledge reached them,- through selfish envy as between themselves. Had it not been for a Word that went forth before from thy Lord, (tending) to a Term appointed, the matter would have been settled between them: But truly those who have inherited the Book after them are in suspicious (disquieting) doubt concerning it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
Now then, for that (reason), call (them to the Faith), and stand steadfast as thou art commanded, nor follow thou their vain desires; but say: ``I believe in the Book which Allah has sent down; and I am commanded to judge justly between you. Allah is our Lord and your Lord: for us (is the responsibility for) our deeds, and for you for your deeds. There is no contention between us and you. Allah will bring us together, and to Him is (our) Final Goal.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
But those who dispute concerning Allah after He has been accepted,- futile is their dispute in the Sight of their Lord: on them will be a Penalty terrible.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah Who has sent down the Book in Truth, and the Balance (by which to weigh conduct). And what will make thee realise that perhaps the Hour is close at hand?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Only those wish to hasten it who believe not in it: those who believe hold it in awe, and know that it is the Truth. Behold, verily those that dispute concerning the Hour are far astray.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Gracious is Allah to His servants: He gives Sustenance to whom He pleases: and He has power and can carry out His Will.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
To any that desires the tilth of the Hereafter, We give increase in his tilth, and to any that desires the tilth of this world, We grant somewhat thereof, but he has no share or lot in the Hereafter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
What! have they partners (in godhead), who have established for them some religion without the permission of Allah? Had it not been for the Decree of Judgment, the matter would have been decided between them (at once). But verily the Wrong-doers will have a grievous Penalty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
Thou wilt see the Wrong-doers in fear on account of what they have earned, and (the burden of) that must (necessarily) fall on them. But those who believe and work righteous deeds will be in the luxuriant meads of the Gardens: they shall have, before their Lord, all that they wish for. That will indeed be the magnificent Bounty (of Allah).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is (the Bounty) whereof Allah gives Glad Tidings to His Servants who believe and do righteous deeds. Say: ``No reward do I ask of you for this except the love of those near of kin." And if any one earns any good, We shall give him an increase of good in respect thereof: for Allah is Oft-Forgiving, Most Ready to appreciate (service).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
What! Do they say, ``He has forged a falsehood against Allah"? But if Allah willed, He could seal up thy heart. And Allah blots out Vanity, and proves the Truth by His Words. For He knows well the secrets of all hearts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
He is the One that accepts repentance from His Servants and forgives sins: and He knows all that ye do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He listens to those who believe and do deeds of righteousness, and gives them increase of His Bounty: but for the Unbelievers their is a terrible Penalty.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
If Allah were to enlarge the provision for His Servants, they would indeed transgress beyond all bounds through the earth; but he sends (it) down in due measure as He pleases. For He is with His Servants Well-acquainted, Watchful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
He is the One that sends down rain (even) after (men) have given up all hope, and scatters His Mercy (far and wide). And He is the Protector, Worthy of all Praise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And among His Signs is the creation of the heavens and the earth, and the living creatures that He has scattered through them: and He has power to gather them together when He wills.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
Whatever misfortune happens to you, is because on the things your hands have wrought, and for many (of them) He grants forgiveness.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
Nor can ye frustrate (aught), (fleeing) through the earth; nor have ye, besides Allah, any one to protect or to help.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And among His Signs are the ships, smooth-running through the ocean, (tall) as mountains.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If it be His Will He can still the Wind: then would they become motionless on the back of the (ocean). Verily in this are Signs for everyone who patiently perseveres and is grateful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He can cause them to perish because of the (evil) which (the men) have earned; but much doth He forgive.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
But let those know, who dispute about Our Signs, that there is for them no way of escape.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
Whatever ye are given (here) is (but) a convenience of this life: but that which is with Allah is better and more lasting: (it is) for those who believe and put their trust in their Lord:\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
Those who avoid the greater crimes and shameful deeds, and, when they are angry even then forgive;\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
Those who hearken to their Lord, and establish regular Prayer; who (conduct) their affairs by mutual Consultation; who spend out of what We bestow on them for Sustenance;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when an oppressive wrong is inflicted on them, (are not cowed but) help and defend themselves.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The recompense for an injury is an injury equal thereto (in degree): but if a person forgives and makes reconciliation, his reward is due from Allah: for (Allah) loveth not those who do wrong.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
But indeed if any do help and defend themselves after a wrong (done) to them, against such there is no cause of blame.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The blame is only against those who oppress men and wrong-doing and insolently transgress beyond bounds through the land, defying right and justice: for such there will be a penalty grievous.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
But indeed if any show patience and forgive, that would truly be an exercise of courageous will and resolution in the conduct of affairs.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
For any whom Allah leaves astray, there is no protector thereafter. And thou wilt see the Wrong-doers, when in sight of the Penalty, Say: ``Is there any way (to effect) a return?"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And thou wilt see them brought forward to the (Penalty), in a humble frame of mind because of (their) disgrace, (and) looking with a stealthy glance. And the Believers will say: ``Those are indeed in loss, who have given to perdition their own selves and those belonging to them on the Day of Judgment. Behold! Truly the Wrong-doers are in a lasting Penalty!"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And no protectors have they to help them, other than Allah. And for any whom Allah leaves to stray, there is no way (to the Goal).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Hearken ye to your Lord, before there come a Day which there will be no putting back, because of (the Ordainment of) Allah! that Day there will be for you no place of refuge nor will there be for you any room for denial (of your sins)!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
If then they run away, We have not sent thee as a guard over them. Thy duty is but to convey (the Message). And truly, when We give man a taste of a Mercy from Ourselves, he doth exult thereat, but when some ill happens to him, on account of the deeds which his hands have sent forth, truly then is man ungrateful!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To Allah belongs the dominion of the heavens and the earth. He creates what He wills (and plans). He bestows (children) male or female according to His Will (and Plan),\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He bestows both males and females, and He leaves barren whom He will: for He is full of Knowledge and Power.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It is not fitting for a man that Allah should speak to him except by inspiration, or from behind a veil, or by the sending of a messenger to reveal, with Allah's permission, what Allah wills: for He is Most High, Most Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And thus have We, by Our Command, sent inspiration to thee: thou knewest not (before) what was Revelation, and what was Faith; but We have made the (Qur'an) a Light, wherewith We guide such of Our servants as We will; and verily thou dost guide (men) to the Straight Way,-\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The Way of Allah, to Whom belongs whatever is in the heavens and whatever is on earth. Behold (how) all affairs tend towards Allah!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha-Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Book that makes things clear,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
We have made it a Qur'an in Arabic, that ye may be able to understand (and learn wisdom).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And verily, it is in the Mother of the Book, in Our Presence, high (in dignity), full of wisdom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We then take away the Message from you and repel (you), for that ye are a people transgressing beyond bounds?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
But how many were the prophets We sent amongst the peoples of old?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And never came there a prophet to them but they mocked him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
So We destroyed (them)- stronger in power than these;- and (thus) has passed on the Parable of the peoples of old.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
If thou wert to question them, 'Who created the heavens and the earth?' They would be sure to reply, 'they were created by (Him), the Exalted in Power, Full of Knowledge';-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
(Yea, the same that) has made for you the earth (like a carpet) spread out, and has made for you roads (and channels) therein, in order that ye may find guidance (on the way);\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
That sends down (from time to time) rain from the sky in due measure;- and We raise to life therewith a land that is dead; even so will ye be raised (from the dead);-\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
That has created pairs in all things, and has made for you ships and cattle on which ye ride,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
In order that ye may sit firm and square on their backs, and when so seated, ye may celebrate the (kind) favour of your Lord, and say, ``Glory to Him Who has subjected these to our (use), for we could never have accomplished this (by ourselves),\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
``And to our Lord, surely, must we turn back!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they attribute to some of His servants a share with Him (in his godhead)! truly is man a blasphemous ingrate avowed!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
What! has He taken daughters out of what He himself creates, and granted to you sons for choice?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
When news is brought to one of them of (the birth of) what he sets up as a likeness to (Allah) Most Gracious, his face darkens, and he is filled with inward grief!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
Is then one brought up among trinkets, and unable to give a clear account in a dispute (to be associated with Allah)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they make into females angels who themselves serve Allah. Did they witness their creation? Their evidence will be recorded, and they will be called to account!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
("Ah!") they say, ``If it had been the will of (Allah) Most Gracious, we should not have worshipped such (deities)!" Of that they have no knowledge! they do nothing but lie!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
What! have We given them a Book before this, to which they are holding fast?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay! they say: ``We found our fathers following a certain religion, and we do guide ourselves by their footsteps."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
Just in the same way, whenever We sent a Warner before thee to any people, the wealthy ones among them said: ``We found our fathers following a certain religion, and we will certainly follow in their footsteps."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
He said: ``What! Even if I brought you better guidance than that which ye found your fathers following?" They said: ``For us, we deny that ye (prophets) are sent (on a mission at all)."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We exacted retribution from them: now see what was the end of those who rejected (Truth)!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
Behold! Abraham said to his father and his people: ``I do indeed clear myself of what ye worship:\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
``(I worship) only Him Who made me, and He will certainly guide me."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he left it as a Word to endure among those who came after him, that they may turn back (to Allah).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Yea, I have given the good things of this life to these (men) and their fathers, until the Truth has come to them, and a messenger making things clear.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
But when the Truth came to them, they said: ``This is sorcery, and we do reject it."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
Also, they say: ``Why is not this Qur'an sent down to some leading man in either of the two (chief) cities?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who would portion out the Mercy of thy Lord? It is We Who portion out between them their livelihood in the life of this world: and We raise some of them above others in ranks, so that some may command work from others. But the Mercy of thy Lord is better than the (wealth) which they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that (all) men might become of one (evil) way of life, We would provide, for everyone that blasphemes against (Allah) Most Gracious, silver roofs for their houses and (silver) stair-ways on which to go up,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And (silver) doors to their houses, and thrones (of silver) on which they could recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And also adornments of gold. But all this were nothing but conveniences of the present life: The Hereafter, in the sight of thy Lord is for the Righteous.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
If anyone withdraws himself from remembrance of (Allah) Most Gracious, We appoint for him an evil one, to be an intimate companion to him.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
Such (evil ones) really hinder them from the Path, but they think that they are being guided aright!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
At length, when (such a one) comes to Us, he says (to his evil companion): ``Would that between me and thee were the distance of East and West!" Ah! evil is the companion (indeed)!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
When ye have done wrong, it will avail you nothing, that Day, that ye shall be partners in Punishment!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Canst thou then make the deaf to hear, or give direction to the blind or to such as (wander) in manifest error?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
Even if We take thee away, We shall be sure to exact retribution from them,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or We shall show thee that (accomplished) which We have promised them: for verily We shall prevail over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold thou fast to the Revelation sent down to thee; verily thou art on a Straight Way.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
The (Qur'an) is indeed the message, for thee and for thy people; and soon shall ye (all) be brought to account.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And question thou our messengers whom We sent before thee; did We appoint any deities other than (Allah) Most Gracious, to be worshipped?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
We did send Moses aforetime, with Our Signs, to Pharaoh and his Chiefs: He said, ``I am a messenger of the Lord of the Worlds."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he came to them with Our Signs, behold they ridiculed them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
We showed them Sign after Sign, each greater than its fellow, and We seized them with Punishment, in order that they might turn (to Us).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said, ``O thou sorcerer! Invoke thy Lord for us according to His covenant with thee; for we shall truly accept guidance."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We removed the Penalty from them, behold, they broke their word.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Pharaoh proclaimed among his people, saying: ``O my people! Does not the dominion of Egypt belong to me, (witness) these streams flowing underneath my (palace)? What! see ye not then?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
``Am I not better than this (Moses), who is a contemptible wretch and can scarcely express himself clearly?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
``Then why are not gold bracelets bestowed on him, or (why) come (not) with him angels accompanying him in procession?"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Thus did he make fools of his people, and they obeyed him: truly were they a people rebellious (against Allah).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
When at length they provoked Us, We exacted retribution from them, and We drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them (a people) of the Past and an Example to later ages.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
When (Jesus) the son of Mary is held up as an example, behold, thy people raise a clamour thereat (in ridicule)!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And they say, ``Are our gods best, or he?" This they set forth to thee, only by way of disputation: yea, they are a contentious people.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He was no more than a servant: We granted Our favour to him, and We made him an example to the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And if it were Our Will, We could make angels from amongst you, succeeding each other on the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And (Jesus) shall be a Sign (for the coming of) the Hour (of Judgment): therefore have no doubt about the (Hour), but follow ye Me: this is a Straight Way.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
Let not the Evil One hinder you: for he is to you an enemy avowed.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
When Jesus came with Clear Signs, he said: ``Now have I come to you with Wisdom, and in order to make clear to you some of the (points) on which ye dispute: therefore fear Allah and obey me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
``For Allah, He is my Lord and your Lord: so worship ye Him: this is a Straight Way."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But sects from among themselves fell into disagreement: then woe to the wrong-doers, from the Penalty of a Grievous Day!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Do they only wait for the Hour - that it should come on them all of a sudden, while they perceive not?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Friends on that day will be foes, one to another,- except the Righteous.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
My devotees! no fear shall be on you that Day, nor shall ye grieve,-\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
(Being) those who have believed in Our Signs and bowed (their wills to Ours) in Islam.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter ye the Garden, ye and your wives, in (beauty and) rejoicing.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
To them will be passed round, dishes and goblets of gold: there will be there all that the souls could desire, all that their eyes could delight in: and ye shall abide therein (for eye).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
Such will be the Garden of which ye are made heirs for your (good) deeds (in life).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Ye shall have therein abundance of fruit, from which ye shall have satisfaction.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
The sinners will be in the Punishment of Hell, to dwell therein (for aye):\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
Nowise will the (Punishment) be lightened for them, and in despair will they be there overwhelmed.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
Nowise shall We be unjust to them: but it is they who have been unjust themselves.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
They will cry: ``O Malik! would that thy Lord put an end to us!" He will say, ``Nay, but ye shall abide!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
Verily We have brought the Truth to you: but most of you have a hatred for Truth.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
What! have they settled some plan (among themselves)? But it is We Who settle things.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We hear not their secrets and their private counsels? Indeed (We do), and Our messengers are by them, to record.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say: ``If (Allah) Most Gracious had a son, I would be the first to worship."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glory to the Lord of the heavens and the earth, the Lord of the Throne (of Authority)! (He is free) from the things they attribute (to him)!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them to babble and play (with vanities) until they meet that Day of theirs, which they have been promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
It is He Who is Allah in heaven and Allah on earth; and He is full of Wisdom and Knowledge.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blessed is He to Whom belongs the dominion of the heavens and the earth, and all between them: with Him is the Knowledge of the Hour (of Judgment): and to Him shall ye be brought back.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those whom they invoke besides Allah have no power of intercession;- only he who bears witness to the Truth, and they know (him).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
If thou ask them, who created them, they will certainly say, Allah: How then are they deluded away (from the Truth)?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
(Allah has knowledge) of the (Prophet's) cry, ``O my Lord! Truly these are people who will not believe!"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
But turn away from them, and say ``Peace!" But soon shall they know!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Book that makes things clear;-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We sent it down during a Blessed Night: for We (ever) wish to warn (against Evil).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
In the (Night) is made distinct every affair of wisdom,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
By command, from Our Presence. For We (ever) send (revelations),\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
As Mercy from thy Lord: for He hears and knows (all things);\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
The Lord of the heavens and the earth and all between them, if ye (but) have an assured faith.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god but He: It is He Who gives life and gives death,- The Lord and Cherisher to you and your earliest ancestors.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Yet they play about in doubt.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
Then watch thou for the Day that the sky will bring forth a kind of smoke (or mist) plainly visible,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Enveloping the people: this will be a Penalty Grievous.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
(They will say:) ``Our Lord! remove the Penalty from us, for we do really believe!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How shall the message be (effectual) for them, seeing that an Messenger explaining things clearly has (already) come to them,-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Yet they turn away from him and say: ``Tutored (by others), a man possessed!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
We shall indeed remove the Penalty for a while, (but) truly ye will revert (to your ways).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
One day We shall seize you with a mighty onslaught: We will indeed (then) exact Retribution!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
We did, before them, try the people of Pharaoh: there came to them a messenger most honourable,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying: ``Restore to me the Servants of Allah: I am to you an messenger worthy of all trust;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
``And be not arrogant as against Allah: for I come to you with authority manifest.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
``For me, I have sought safety with my Lord and your Lord, against your injuring me.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
``If ye believe me not, at least keep yourselves away from me."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
(But they were aggressive:) then he cried to his Lord: ``These are indeed a people given to sin."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
(The reply came:) ``March forth with My Servants by night: for ye are sure to be pursued.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
``And leave the sea as a furrow (divided): for they are a host (destined) to be drowned."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many were the gardens and springs they left behind,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And corn-fields and noble buildings,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And wealth (and conveniences of life), wherein they had taken such delight!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Thus (was their end)! And We made other people inherit (those things)!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And neither heaven nor earth shed a tear over them: nor were they given a respite (again).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
We did deliver aforetime the Children of Israel from humiliating Punishment,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
Inflicted by Pharaoh, for he was arrogant (even) among inordinate transgressors.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We chose them aforetime above the nations, knowingly,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And granted them Signs in which there was a manifest trial\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
As to these (Quraish), they say forsooth:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
``There is nothing beyond our first death, and we shall not be raised again.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
``Then bring (back) our forefathers, if what ye say is true!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
What! Are they better than the people of Tubba and those who were before them? We destroyed them because they were guilty of sin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
We created not the heavens, the earth, and all between them, merely in (idle) sport:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not except for just ends: but most of them do not understand.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Verily the Day of sorting out is the time appointed for all of them,-\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The Day when no protector can avail his client in aught, and no help can they receive,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except such as receive Allah's Mercy: for He is Exalted in Might, Most Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Verily the tree of Zaqqum\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Will be the food of the Sinful,-\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like molten brass; it will boil in their insides.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the boiling of scalding water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
(A voice will cry: ``Seize ye him and drag him into the midst of the Blazing Fire!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
``Then pour over his head the Penalty of Boiling Water,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
``Taste thou (this)! Truly wast thou mighty, full of honour!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
``Truly this is what ye used to doubt!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
As to the Righteous (they will be) in a position of Security,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Among Gardens and Springs;\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Dressed in fine silk and in rich brocade, they will face each other;\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
So; and We shall join them to fair women with beautiful, big, and lustrous eyes.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
There can they call for every kind of fruit in peace and security;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
Nor will they there taste Death, except the first death; and He will preserve them from the Penalty of the Blazing Fire,-\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
As a Bounty from thy Lord! that will be the supreme achievement!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
Verily, We have made this (Qur'an) easy, in thy tongue, in order that they may give heed.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
So wait thou and watch; for they (too) are waiting.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book is from Allah the Exalted in Power, Full of Wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Verily in the heavens and the earth, are Signs for those who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in the creation of yourselves and the fact that animals are scattered (through the earth), are Signs for those of assured Faith.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of Night and Day, and the fact that Allah sends down Sustenance from the sky, and revives therewith the earth after its death, and in the change of the winds,- are Signs for those that are wise.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
Such are the Signs of Allah, which We rehearse to thee in Truth; then in what exposition will they believe after (rejecting) Allah and His Signs?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to each sinful dealer in Falsehoods:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
He hears the Signs of Allah rehearsed to him, yet is obstinate and lofty, as if he had not heard them: then announce to him a Penalty Grievous!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he learns something of Our Signs, he takes them in jest: for such there will be a humiliating Penalty.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
In front of them is Hell: and of no profit to them is anything they may have earned, nor any protectors they may have taken to themselves besides Allah: for them is a tremendous Penalty.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is (true) Guidance and for those who reject the Signs of their Lord, is a grievous Penalty of abomination.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
It is Allah Who has subjected the sea to you, that ships may sail through it by His command, that ye may seek of his Bounty, and that ye may be grateful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And He has subjected to you, as from Him, all that is in the heavens and on earth: Behold, in that are Signs indeed for those who reflect.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Tell those who believe, to forgive those who do not look forward to the Days of Allah: It is for Him to recompense (for good or ill) each People according to what they have earned.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
If any one does a righteous deed, it ensures to the benefit of his own soul; if he does evil, it works against (his own soul). In the end will ye (all) be brought back to your Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
We did aforetime grant to the Children of Israel the Book the Power of Command, and Prophethood; We gave them, for Sustenance, things good and pure; and We favoured them above the nations.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And We granted them Clear Signs in affairs (of Religion): it was only after knowledge had been granted to them that they fell into schisms, through insolent envy among themselves. Verily thy Lord will judge between them on the Day of Judgment as to those matters in which they set up differences.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We put thee on the (right) Way of Religion: so follow thou that (Way), and follow not the desires of those who know not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
They will be of no use to thee in the sight of Allah: it is only Wrong-doers (that stand as) protectors, one to another: but Allah is the Protector of the Righteous.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
These are clear evidences to men and a Guidance and Mercy to those of assured Faith.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
What! Do those who seek after evil ways think that We shall hold them equal with those who believe and do righteous deeds,- that equal will be their life and their death? Ill is the judgment that they make.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
Allah created the heavens and the earth for just ends, and in order that each soul may find the recompense of what it has earned, and none of them be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Then seest thou such a one as takes as his god his own vain desire? Allah has, knowing (him as such), left him astray, and sealed his hearing and his heart (and understanding), and put a cover on his sight. Who, then, will guide him after Allah (has withdrawn Guidance)? Will ye not then receive admonition?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say: ``What is there but our life in this world? We shall die and we live, and nothing but time can destroy us." But of that they have no knowledge: they merely conjecture:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our Clear Signs are rehearsed to them their argument is nothing but this: They say, ``Bring (back) our forefathers, if what ye say is true!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say: ``It is Allah Who gives you life, then gives you death; then He will gather you together for the Day of Judgment about which there is no doubt": But most men do not understand.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
To Allah belongs the dominion of the heavens and the earth, and the Day that the Hour of Judgment is established,- that Day will the dealers in Falsehood perish!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And thou wilt see every sect bowing the knee: Every sect will be called to its Record: ``This Day shall ye be recompensed for all that ye did!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
``This Our Record speaks about you with truth: For We were wont to put on Record all that ye did."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
Then, as to those who believed and did righteous deeds, their Lord will admit them to His Mercy that will be the achievement for all to see.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as to those who rejected Allah, (to them will be said): ``Were not Our Signs rehearsed to you? But ye were arrogant, and were a people given to sin!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
``And when it was said that the promise of Allah was true, and that the Hour- there was no doubt about its (coming), ye used to say, 'We know not what is the hour: we only think it is an idea, and we have no firm assurance.'"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
Then will appear to them the evil (fruits) of what they did, and they will be completely encircled by that which they used to mock at!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
It will also be said: ``This Day We will forget you as ye forgot the meeting of this Day of yours! and your abode is the Fire, and no helpers have ye!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
``This, because ye used to take the Signs of Allah in jest, and the life of the world deceived you:" (From) that Day, therefore, they shall not be taken out thence, nor shall they be received into Grace.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
Then Praise be to Allah, Lord of the heavens and Lord of the earth,- Lord and Cherisher of all the Worlds!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
To Him be glory throughout the heavens and the earth: and He is Exalted in Power, Full of Wisdom!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The Revelation of the Book is from Allah the Exalted in Power, Full of Wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We created not the heavens and the earth and all between them but for just ends, and for a Term Appointed: But those who reject Faith turn away from that whereof they are warned.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say: ``Do ye see what it is ye invoke besides Allah? Show me what it is they have created on earth, or have they a share in the heavens bring me a book (revealed) before this, or any remnant of knowledge (ye may have), if ye are telling the truth!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than one who invokes besides Allah, such as will not answer him to the Day of Judgment, and who (in fact) are unconscious of their call (to them)?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when mankind are gathered together (at the Resurrection), they will be hostile to them and reject their worship (altogether)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
When Our Clear Signs are rehearsed to them, the Unbelievers say, of the Truth when it comes to them: ``This is evident sorcery!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or do they say, ``He has forged it"? Say: ``Had I forged it, then can ye obtain no single (blessing) for me from Allah. He knows best of that whereof ye talk (so glibly)! Enough is He for a witness between me and you! And he is Oft-Forgiving, Most Merciful."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say: ``I am no bringer of new-fangled doctrine among the messengers, nor do I know what will be done with me or with you. I follow but that which is revealed to me by inspiration; I am but a Warner open and clear."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say: ``See ye? If (this teaching) be from Allah, and ye reject it, and a witness from among the Children of Israel testifies to its similarity (with earlier scripture), and has believed while ye are arrogant, (how unjust ye are!) truly, Allah guides not a people unjust."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
The Unbelievers say of those who believe: ``If (this Message) were a good thing, (such men) would not have gone to it first, before us!" And seeing that they guide not themselves thereby, they will say, ``this is an (old,) falsehood!"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before this, was the Book of Moses as a guide and a mercy: And this Book confirms (it) in the Arabic tongue; to admonish the unjust, and as Glad Tidings to those who do right.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Verily those who say, ``Our Lord is Allah," and remain firm (on that Path),- on them shall be no fear, nor shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Such shall be Companions of the Gardens, dwelling therein (for aye): a recompense for their (good) deeds.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
We have enjoined on man kindness to his parents: In pain did his mother bear him, and in pain did she give him birth. The carrying of the (child) to his weaning is (a period of) thirty months. At length, when he reaches the age of full strength and attains forty years, he says, ``O my Lord! Grant me that I may be grateful for Thy favour which Thou has bestowed upon me, and upon both my parents, and that I may work righteousness such as Thou mayest approve; and be gracious to me in my issue. Truly have I turned to Thee and truly do I bow (to Thee) in Islam."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Such are they from whom We shall accept the best of their deeds and pass by their ill deeds: (They shall be) among the Companions of the Garden: a promise! of truth, which was made to them (in this life).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But (there is one) who says to his parents, ``Fie on you! Do ye hold out the promise to me that I shall be raised up, even though generations have passed before me (without rising again)?" And they two seek Allah's aid, (and rebuke the son): ``Woe to thee! Have faith! for the promise of Allah is true." But he says, ``This is nothing but tales of the ancients!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Such are they against whom is proved the sentence among the previous generations of Jinns and men, that have passed away; for they will be (utterly) lost.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And to all are (assigned) degrees according to the deeds which they (have done), and in order that (Allah) may recompense their deeds, and no injustice be done to them.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And on the Day that the Unbelievers will be placed before the Fire, (It will be said to them): ``Ye received your good things in the life of the world, and ye took your pleasure out of them: but today shall ye be recompensed with a Penalty of humiliation: for that ye were arrogant on earth without just cause, and that ye (ever) transgressed."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
Mention (Hud) one of 'Ad's (own) brethren: Behold, he warned his people about the winding Sand-tracts: but there have been warners before him and after him: ``Worship ye none other than Allah: Truly I fear for you the Penalty of a Mighty Day."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: ``Hast thou come in order to turn us aside from our gods? Then bring upon us the (calamity) with which thou dost threaten us, if thou art telling the truth?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said: ``The Knowledge (of when it will come) is only with Allah: I proclaim to you the mission on which I have been sent: But I see that ye are a people in ignorance!"..\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they saw the (Penalty in the shape of) a cloud traversing the sky, coming to meet their valleys, they said, ``This cloud will give us rain!" ``Nay, it is the (Calamity) ye were asking to be hastened!- A wind wherein is a Grievous Penalty!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
``Everything will it destroy by the command of its Lord!" Then by the morning they - nothing was to be seen but (the ruins of) their houses! thus do We recompense those given to sin!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And We had firmly established them in a (prosperity and) power which We have not given to you (ye Quraish!) and We had endowed them with (faculties of) hearing, seeing, heart and intellect: but of no profit to them were their (faculties of) hearing, sight, and heart and intellect, when they went on rejecting the Signs of Allah; and they were (completely) encircled by that which they used to mock at!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
We destroyed aforetime populations round about you; and We have shown the Signs in various ways, that they may turn (to Us).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Why then was no help forthcoming to them from those whom they worshipped as gods, besides Allah, as a means of access (to Allah)? Nay, they left them in the lurch: but that was their falsehood and their invention.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
Behold, We turned towards thee a company of Jinns (quietly) listening to the Qur'an: when they stood in the presence thereof, they said, ``Listen in silence!" When the (reading) was finished, they returned to their people, to warn (them of their sins).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said, ``O our people! We have heard a Book revealed after Moses, confirming what came before it: it guides (men) to the Truth and to a Straight Path.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
``O our people, hearken to the one who invites (you) to Allah, and believe in him: He will forgive you your faults, and deliver you from a Penalty Grievous.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
``If any does not hearken to the one who invites (us) to Allah, he cannot frustrate (Allah's Plan) on earth, and no protectors can he have besides Allah: such men (wander) in manifest error."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
See they not that Allah, Who created the heavens and the earth, and never wearied with their creation, is able to give life to the dead? Yea, verily He has power over all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the Day that the Unbelievers will be placed before the Fire, (they will be asked,) ``Is this not the Truth?" they will say, ``Yea, by our Lord!" (One will say:) ``Then taste ye the Penalty, for that ye were wont to deny (Truth)!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Therefore patiently persevere, as did (all) messengers of inflexible purpose; and be in no haste about the (Unbelievers). On the Day that they see the (Punishment) promised them, (it will be) as if they had not tarried more than an hour in a single day. (Thine but) to proclaim the Message: but shall any be destroyed except those who transgress?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who reject Allah and hinder (men) from the Path of Allah,- their deeds will Allah render astray (from their mark).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
But those who believe and work deeds of righteousness, and believe in the (Revelation) sent down to Muhammad - for it is the Truth from their Lord,- He will remove from them their ills and improve their condition.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
This because those who reject Allah follow vanities, while those who believe follow the Truth from their Lord: Thus does Allah set forth for men their lessons by similitudes.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
Therefore, when ye meet the Unbelievers (in fight), smite at their necks; At length, when ye have thoroughly subdued them, bind a bond firmly (on them): thereafter (is the time for) either generosity or ransom: Until the war lays down its burdens. Thus (are ye commanded): but if it had been Allah's Will, He could certainly have exacted retribution from them (Himself); but (He lets you fight) in order to test you, some with others. But those who are slain in the Way of Allah,- He will never let their deeds be lost.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
Soon will He guide them and improve their condition,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And admit them to the Garden which He has announced for them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O ye who believe! If ye will aid (the cause of) Allah, He will aid you, and plant your feet firmly.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But those who reject (Allah),- for them is destruction, and (Allah) will render their deeds astray (from their mark).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they hate the Revelation of Allah; so He has made their deeds fruitless.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Do they not travel through the earth, and see what was the End of those before them (who did evil)? Allah brought utter destruction on them, and similar (fates await) those who reject Allah.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the Protector of those who believe, but those who reject Allah have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Verily Allah will admit those who believe and do righteous deeds, to Gardens beneath which rivers flow; while those who reject Allah will enjoy (this world) and eat as cattle eat; and the Fire will be their abode.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And how many cities, with more power than thy city which has driven thee out, have We destroyed (for their sins)? and there was none to aid them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is then one who is on a clear (Path) from his Lord, no better than one to whom the evil of his conduct seems pleasing, and such as follow their own lusts?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
(Here is) a Parable of the Garden which the righteous are promised: in it are rivers of water incorruptible; rivers of milk of which the taste never changes; rivers of wine, a joy to those who drink; and rivers of honey pure and clear. In it there are for them all kinds of fruits; and Grace from their Lord. (Can those in such Bliss) be compared to such as shall dwell for ever in the Fire, and be given, to drink, boiling water, so that it cuts up their bowels (to pieces)?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And among them are men who listen to thee, but in the end, when they go out from thee, they say to those who have received Knowledge, ``What is it he said just then?" Such are men whose hearts Allah has sealed, and who follow their own lusts.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
But to those who receive Guidance, He increases the (light of) Guidance, and bestows on them their Piety and Restraint (from evil).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Do they then only wait for the Hour,- that it should come on them of a sudden? But already have come some tokens thereof, and when it (actually) is on them, how can they benefit then by their admonition?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Know, therefore, that there is no god but Allah, and ask forgiveness for thy fault, and for the men and women who believe: for Allah knows how ye move about and how ye dwell in your homes.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say, ``Why is not a sura sent down (for us)?" But when a sura of basic or categorical meaning is revealed, and fighting is mentioned therein, thou wilt see those in whose hearts is a disease looking at thee with a look of one in swoon at the approach of death. But more fitting for them-\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Were it to obey and say what is just, and when a matter is resolved on, it were best for them if they were true to Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Then, is it to be expected of you, if ye were put in authority, that ye will do mischief in the land, and break your ties of kith and kin?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Such are the men whom Allah has cursed for He has made them deaf and blinded their sight.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Do they not then earnestly seek to understand the Qur'an, or are their hearts locked up by them?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Those who turn back as apostates after Guidance was clearly shown to them,- the Evil One has instigated them and busied them up with false hopes.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
This, because they said to those who hate what Allah has revealed, ``We will obey you in part of (this) matter"; but Allah knows their (inner) secrets.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
But how (will it be) when the angels take their souls at death, and smite their faces and their backs?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
This because they followed that which called forth the Wrath of Allah, and they hated Allah's good pleasure; so He made their deeds of no effect.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do those in whose hearts is a disease, think that Allah will not bring to light all their rancour?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
Had We so wiled, We could have shown them up to thee, and thou shouldst have known them by their marks: but surely thou wilt know them by the tone of their speech! And Allah knows all that ye do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And We shall try you until We test those among you who strive their utmost and persevere in patience; and We shall try your reported (mettle).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Those who reject Allah, hinder (men) from the Path of Allah, and resist the Messenger, after Guidance has been clearly shown to them, will not injure Allah in the least, but He will make their deeds of no effect.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O ye who believe! Obey Allah, and obey the messenger, and make not vain your deeds!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Those who reject Allah, and hinder (men) from the Path of Allah, then die rejecting Allah,- Allah will not forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
Be not weary and faint-hearted, crying for peace, when ye should be uppermost: for Allah is with you, and will never put you in loss for your (good) deeds.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of this world is but play and amusement: and if ye believe and guard against Evil, He will grant you your recompense, and will not ask you (to give up) your possessions.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He were to ask you for all of them, and press you, ye would covetously withhold, and He would bring out all your ill-feeling.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Behold, ye are those invited to spend (of your substance) in the Way of Allah: But among you are some that are niggardly. But any who are niggardly are so at the expense of their own souls. But Allah is free of all wants, and it is ye that are needy. If ye turn back (from the Path), He will substitute in your stead another people; then they would not be like you!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Verily We have granted thee a manifest Victory:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive thee thy faults of the past and those to follow; fulfil His favour to thee; and guide thee on the Straight Way;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And that Allah may help thee with powerful help.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It is He Who sent down tranquillity into the hearts of the Believers, that they may add faith to their faith;- for to Allah belong the Forces of the heavens and the earth; and Allah is Full of Knowledge and Wisdom;-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
That He may admit the men and women who believe, to Gardens beneath which rivers flow, to dwell therein for aye, and remove their ills from them;- and that is, in the sight of Allah, the highest achievement (for man),-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And that He may punish the Hypocrites, men and women, and the Polytheists men and women, who imagine an evil opinion of Allah. On them is a round of Evil: the Wrath of Allah is on them: He has cursed them and got Hell ready for them: and evil is it for a destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
For to Allah belong the Forces of the heavens and the earth; and Allah is Exalted in Power, Full of Wisdom.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
We have truly sent thee as a witness, as a bringer of Glad Tidings, and as a Warner:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
In order that ye (O men) may believe in Allah and His Messenger, that ye may assist and honour Him, and celebrate His praise morning and evening.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Verily those who plight their fealty to thee do no less than plight their fealty to Allah: the Hand of Allah is over their hands: then any one who violates his oath, does so to the harm of his own soul, and any one who fulfils what he has covenanted with Allah,- Allah will soon grant him a great Reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
The desert Arabs who lagged behind will say to thee: ``We were engaged in (looking after) our flocks and herds, and our families: do thou then ask forgiveness for us." They say with their tongues what is not in their hearts. Say: ``Who then has any power at all (to intervene) on your behalf with Allah, if His Will is to give you some loss or to give you some profit? But Allah is well acquainted with all that ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
``Nay, ye thought that the Messenger and the Believers would never return to their families; this seemed pleasing in your hearts, and ye conceived an evil thought, for ye are a people lost (in wickedness)."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And if any believe not in Allah and His Messenger, We have prepared, for those who reject Allah, a Blazing Fire!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
To Allah belongs the dominion of the heavens and the earth: He forgives whom He wills, and He punishes whom He wills: but Allah is Oft-Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who lagged behind (will say), when ye (are free to) march and take booty (in war): ``Permit us to follow you." They wish to change Allah's decree: Say: ``Not thus will ye follow us: Allah has already declared (this) beforehand": then they will say, ``But ye are jealous of us." Nay, but little do they understand (such things).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the desert Arabs who lagged behind: ``Ye shall be summoned (to fight) against a people given to vehement war: then shall ye fight, or they shall submit. Then if ye show obedience, Allah will grant you a goodly reward, but if ye turn back as ye did before, He will punish you with a grievous Penalty."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
No blame is there on the blind, nor is there blame on the lame, nor on one ill (if he joins not the war): But he that obeys Allah and his Messenger,- (Allah) will admit him to Gardens beneath which rivers flow; and he who turns back, (Allah) will punish him with a grievous Penalty.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Allah's Good Pleasure was on the Believers when they swore Fealty to thee under the Tree: He knew what was in their hearts, and He sent down Tranquillity to them; and He rewarded them with a speedy Victory;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And many gains will they acquire (besides): and Allah is Exalted in Power, Full of Wisdom.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you many gains that ye shall acquire, and He has given you these beforehand; and He has restrained the hands of men from you; that it may be a Sign for the Believers, and that He may guide you to a Straight Path;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And other gains (there are), which are not within your power, but which Allah has compassed: and Allah has power over all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
If the Unbelievers should fight you, they would certainly turn their backs; then would they find neither protector nor helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
(Such has been) the practice (approved) of Allah already in the past: no change wilt thou find in the practice (approved) of Allah.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And it is He Who has restrained their hands from you and your hands from them in the midst of Makka, after that He gave you the victory over them. And Allah sees well all that ye do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are the ones who denied Revelation and hindered you from the Sacred Mosque and the sacrificial animals, detained from reaching their place of sacrifice. Had there not been believing men and believing women whom ye did not know that ye were trampling down and on whose account a crime would have accrued to you without (your) knowledge, (Allah would have allowed you to force your way, but He held back your hands) that He may admit to His Mercy whom He will. If they had been apart, We should certainly have punished the Unbelievers among them with a grievous Punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
While the Unbelievers got up in their hearts heat and cant - the heat and cant of ignorance,- Allah sent down His Tranquillity to his Messenger and to the Believers, and made them stick close to the command of self-restraint; and well were they entitled to it and worthy of it. And Allah has full knowledge of all things.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Truly did Allah fulfil the vision for His Messenger: ye shall enter the Sacred Mosque, if Allah wills, with minds secure, heads shaved, hair cut short, and without fear. For He knew what ye knew not, and He granted, besides this, a speedy victory.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He Who has sent His Messenger with Guidance and the Religion of Truth, to proclaim it over all religion: and enough is Allah for a Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the messenger of Allah; and those who are with him are strong against Unbelievers, (but) compassionate amongst each other. Thou wilt see them bow and prostrate themselves (in prayer), seeking Grace from Allah and (His) Good Pleasure. On their faces are their marks, (being) the traces of their prostration. This is their similitude in the Taurat; and their similitude in the Gospel is: like a seed which sends forth its blade, then makes it strong; it then becomes thick, and it stands on its own stem, (filling) the sowers with wonder and delight. As a result, it fills the Unbelievers with rage at them. Allah has promised those among them who believe and do righteous deeds forgiveness, and a great Reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O Ye who believe! Put not yourselves forward before Allah and His Messenger; but fear Allah: for Allah is He Who hears and knows all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O ye who believe! Raise not your voices above the voice of the Prophet, nor speak aloud to him in talk, as ye may speak aloud to one another, lest your deeds become vain and ye perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Those that lower their voices in the presence of Allah's Messenger,- their hearts has Allah tested for piety: for them is Forgiveness and a great Reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Those who shout out to thee from without the inner apartments - most of them lack understanding.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
If only they had patience until thou couldst come out to them, it would be best for them: but Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O ye who believe! If a wicked person comes to you with any news, ascertain the truth, lest ye harm people unwittingly, and afterwards become full of repentance for what ye have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that among you is Allah's Messenger: were he, in many matters, to follow your (wishes), ye would certainly fall into misfortune: But Allah has endeared the Faith to you, and has made it beautiful in your hearts, and He has made hateful to you Unbelief, wickedness, and rebellion: such indeed are those who walk in righteousness;-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
A Grace and Favour from Allah; and Allah is full of Knowledge and Wisdom.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
If two parties among the Believers fall into a quarrel, make ye peace between them: but if one of them transgresses beyond bounds against the other, then fight ye (all) against the one that transgresses until it complies with the command of Allah; but if it complies, then make peace between them with justice, and be fair: for Allah loves those who are fair (and just).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The Believers are but a single Brotherhood: So make peace and reconciliation between your two (contending) brothers; and fear Allah, that ye may receive Mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O ye who believe! Let not some men among you laugh at others: It may be that the (latter) are better than the (former): Nor let some women laugh at others: It may be that the (latter are better than the (former): Nor defame nor be sarcastic to each other, nor call each other by (offensive) nicknames: Ill-seeming is a name connoting wickedness, (to be used of one) after he has believed: And those who do not desist are (indeed) doing wrong.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O ye who believe! Avoid suspicion as much (as possible): for suspicion in some cases is a sin: And spy not on each other behind their backs. Would any of you like to eat the flesh of his dead brother? Nay, ye would abhor it... But fear Allah: For Allah is Oft-Returning, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind! We created you from a single (pair) of a male and a female, and made you into nations and tribes, that ye may know each other (not that ye may despise (each other). Verily the most honoured of you in the sight of Allah is (he who is) the most righteous of you. And Allah has full knowledge and is well acquainted (with all things).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The desert Arabs say, ``We believe." Say, ``Ye have no faith; but ye (only) say, 'We have submitted our wills to Allah,' For not yet has Faith entered your hearts. But if ye obey Allah and His Messenger, He will not belittle aught of your deeds: for Allah is Oft-Forgiving, Most Merciful."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
Only those are Believers who have believed in Allah and His Messenger, and have never since doubted, but have striven with their belongings and their persons in the Cause of Allah: Such are the sincere ones.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say: ``What! Will ye instruct Allah about your religion? But Allah knows all that is in the heavens and on earth: He has full knowledge of all things.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They impress on thee as a favour that they have embraced Islam. Say, ``Count not your Islam as a favour upon me: Nay, Allah has conferred a favour upon you that He has guided you to the faith, if ye be true and sincere.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
``Verily Allah knows the secrets of the heavens and the earth: and Allah Sees well all that ye do."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf: By the Glorious Qur'an (Thou art Allah's Messenger).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
But they wonder that there has come to them a Warner from among themselves. So the Unbelievers say: ``This is a wonderful thing!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
``What! When we die and become dust, (shall we live again?) That is a (sort of) return far (from our understanding)."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We already know how much of them the earth takes away: With Us is a record guarding (the full account).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
But they deny the Truth when it comes to them: so they are in a confused state.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Do they not look at the sky above them?- How We have made it and adorned it, and there are no flaws in it?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth- We have spread it out, and set thereon mountains standing firm, and produced therein every kind of beautiful growth (in pairs)-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
To be observed and commemorated by every devotee turning (to Allah).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We send down from the sky rain charted with blessing, and We produce therewith gardens and Grain for harvests;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And tall (and stately) palm-trees, with shoots of fruit-stalks, piled one over another;-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
As sustenance for (Allah's) Servants;- and We give (new) life therewith to land that is dead: Thus will be the Resurrection.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Before them was denied (the Hereafter) by the People of Noah, the Companions of the Rass, the Thamud,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
The 'Ad, Pharaoh, the brethren of Lut,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
The Companions of the Wood, and the People of Tubba'; each one (of them) rejected the messengers, and My warning was duly fulfilled (in them).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Were We then weary with the first Creation, that they should be in confused doubt about a new Creation?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
It was We Who created man, and We know what dark suggestions his soul makes to him: for We are nearer to him than (his) jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
Behold, two (guardian angels) appointed to learn (his doings) learn (and noted them), one sitting on the right and one on the left.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Not a word does he utter but there is a sentinel by him, ready (to note it).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the stupor of death will bring Truth (before his eyes): ``This was the thing which thou wast trying to escape!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet shall be blown: that will be the Day whereof Warning (had been given).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And there will come forth every soul: with each will be an (angel) to drive, and an (angel) to bear witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
(It will be said:) ``Thou wast heedless of this; now have We removed thy veil, and sharp is thy sight this Day!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his Companion will say: ``Here is (his Record) ready with me!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
(The sentence will be:) ``Throw, throw into Hell every contumacious Rejecter (of Allah)!-\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
``Who forbade what was good, transgressed all bounds, cast doubts and suspicions;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
``Who set up another god beside Allah: Throw him into a severe penalty."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His Companion will say: ``Our Lord! I did not make him transgress, but he was (himself) far astray."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He will say: ``Dispute not with each other in My Presence: I had already in advance sent you Warning.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
``The Word changes not before Me, and I do not the least injustice to My Servants."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
One Day We will ask Hell, ``Art thou filled to the full?" It will say, ``Are there any more (to come)?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And the Garden will be brought nigh to the Righteous,- no more a thing distant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
(A voice will say:) ``This is what was promised for you,- for every one who turned (to Allah) in sincere repentance, who kept (His Law),\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
``Who feared (Allah) Most Gracious Unseen, and brought a heart turned in devotion (to Him):\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
``Enter ye therein in Peace and Security; this is a Day of Eternal Life!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
There will be for them therein all that they wish,- and more besides in Our Presence.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
But how many generations before them did We destroy (for their sins),- stronger in power than they? Then did they wander through the land: was there any place of escape (for them)?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Verily in this is a Message for any that has a heart and understanding or who gives ear and earnestly witnesses (the truth).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
We created the heavens and the earth and all between them in Six Days, nor did any sense of weariness touch Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
Bear, then, with patience, all that they say, and celebrate the praises of thy Lord, before the rising of the sun and before (its) setting.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And during part of the night, (also,) celebrate His praises, and (so likewise) after the postures of adoration.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen for the Day when the Caller will call out from a place quiet near,-\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day when they will hear a (mighty) Blast in (very) truth: that will be the Day of Resurrection.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Verily it is We Who give Life and Death; and to Us is the Final Goal-\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
The Day when the Earth will be rent asunder, from (men) hurrying out: that will be a gathering together,- quite easy for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We know best what they say; and thou art not one to overawe them by force. So admonish with the Qur'an such as fear My Warning!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the (Winds) that scatter broadcast;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And those that lift and bear away heavy weights;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And those that flow with ease and gentleness;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And those that distribute and apportion by Command;-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Verily that which ye are promised is true;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And verily Judgment and Justice must indeed come to pass.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the Sky with (its) numerous Paths,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Truly ye are in a doctrine discordant,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Through which are deluded (away from the Truth) such as would be deluded.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Woe to the falsehood-mongers,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Those who (flounder) heedless in a flood of confusion:\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask, ``When will be the Day of Judgment and Justice?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
(It will be) a Day when they will be tried (and tested) over the Fire!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
``Taste ye your trial! This is what ye used to ask to be hastened!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
As to the Righteous, they will be in the midst of Gardens and Springs,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Taking joy in the things which their Lord gives them, because, before then, they lived a good life.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They were in the habit of sleeping but little by night,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And in the hour of early dawn, they (were found) praying for Forgiveness;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their wealth and possessions (was remembered) the right of the (needy,) him who asked, and him who (for some reason) was prevented (from asking).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
On the earth are signs for those of assured Faith,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
As also in your own selves: Will ye not then see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in heaven is your Sustenance, as (also) that which ye are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
Then, by the Lord of heaven and earth, this is the very Truth, as much as the fact that ye can speak intelligently to each other.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Has the story reached thee, of the honoured guests of Abraham?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
Behold, they entered his presence, and said: ``Peace!" He said, ``Peace!" (and thought, ``These seem) unusual people."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he turned quickly to his household, brought out a fatted calf,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And placed it before them.. he said, ``Will ye not eat?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
(When they did not eat), He conceived a fear of them. They said, ``Fear not," and they gave him glad tidings of a son endowed with knowledge.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
But his wife came forward (laughing) aloud: she smote her forehead and said: ``A barren old woman!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said, ``Even so has thy Lord spoken: and He is full of Wisdom and Knowledge."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
(Abraham) said: ``And what, O ye Messengers, is your errand (now)?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said, ``We have been sent to a people (deep) in sin;-\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
``To bring on, on them, (a shower of) stones of clay (brimstone),\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
``Marked as from thy Lord for those who trespass beyond bounds."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
Then We evacuated those of the Believers who were there,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But We found not there any just (Muslim) persons except in one house:\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We left there a Sign for such as fear the Grievous Penalty.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Moses (was another Sign): Behold, We sent him to Pharaoh, with authority manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But (Pharaoh) turned back with his Chiefs, and said, ``A sorcerer, or one possessed!"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We took him and his forces, and threw them into the sea; and his was the blame.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in the 'Ad (people) (was another Sign): Behold, We sent against them the devastating Wind:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It left nothing whatever that it came up against, but reduced it to ruin and rottenness.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in the Thamud (was another Sign): Behold, they were told, ``Enjoy (your brief day) for a little while!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they insolently defied the Command of their Lord: So the stunning noise (of an earthquake) seized them, even while they were looking on.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
Then they could not even stand (on their feet), nor could they help themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
So were the People of Noah before them for they wickedly transgressed.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
With power and skill did We construct the Firmament: for it is We Who create the vastness of pace.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And We have spread out the (spacious) earth: How excellently We do spread out!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of every thing We have created pairs: That ye may receive instruction.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Hasten ye then (at once) to Allah: I am from Him a Warner to you, clear and open!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And make not another an object of worship with Allah: I am from Him a Warner to you, clear and open!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Similarly, no messenger came to the Peoples before them, but they said (of him) in like manner, ``A sorcerer, or one possessed"!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Is this the legacy they have transmitted, one to another? Nay, they are themselves a people transgressing beyond bounds!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away from them: not thine is the blame.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
But teach (thy Message) for teaching benefits the Believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I have only created Jinns and men, that they may serve Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
No Sustenance do I require of them, nor do I require that they should feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
For Allah is He Who gives (all) Sustenance,- Lord of Power,- Steadfast (for ever).\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
For the Wrong-doers, their portion is like unto the portion of their fellows (of earlier generations): then let them not ask Me to hasten (that portion)!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Woe, then, to the Unbelievers, on account of that Day of theirs which they have been promised!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount (of Revelation);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
By a Decree inscribed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In a Scroll unfolded;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
By the much-frequented Fane;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
By the Canopy Raised High;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And by the Ocean filled with Swell;-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Verily, the Doom of thy Lord will indeed come to pass;-\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
There is none can avert it;-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day when the firmament will be in dreadful commotion.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains will fly hither and thither.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Then woe that Day to those that treat (Truth) as Falsehood;-\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
That play (and paddle) in shallow trifles.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
That Day shall they be thrust down to the Fire of Hell, irresistibly.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
``This:, it will be said, ``Is the Fire,- which ye were wont to deny!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
``Is this then a fake, or is it ye that do not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
``Burn ye therein: the same is it to you whether ye bear it with patience, or not: Ye but receive the recompense of your (own) deeds."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
As to the Righteous, they will be in Gardens, and in Happiness,-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Enjoying the (Bliss) which their Lord hath bestowed on them, and their Lord shall deliver them from the Penalty of the Fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
(To them will be said:) ``Eat and drink ye, with profit and health, because of your (good) deeds."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
They will recline (with ease) on Thrones (of dignity) arranged in ranks; and We shall join them to Companions, with beautiful big and lustrous eyes.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believe and whose families follow them in Faith,- to them shall We join their families: Nor shall We deprive them (of the fruit) of aught of their works: (Yet) is each individual in pledge for his deeds.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We shall bestow on them, of fruit and meat, anything they shall desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
They shall there exchange, one with another, a (loving) cup free of frivolity, free of all taint of ill.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
Round about them will serve, (devoted) to them, young male servants (handsome) as Pearls well-guarded.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
They will advance to each other, engaging in mutual enquiry.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They will say: ``Aforetime, we were not without fear for the sake of our people.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
``But Allah has been good to us, and has delivered us from the Penalty of the Scorching Wind.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
``Truly, we did call unto Him from of old: truly it is He, the Beneficent, the Merciful!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore proclaim thou the praises (of thy Lord): for by the Grace of thy Lord, thou art no (vulgar) soothsayer, nor art thou one possessed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say:- ``A Poet! we await for him some calamity (hatched) by Time!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say thou: ``Await ye!- I too will wait along with you!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Is it that their faculties of understanding urge them to this, or are they but a people transgressing beyond bounds?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say, ``He fabricated the (Message)"? Nay, they have no faith!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Let them then produce a recital like unto it,- If (it be) they speak the truth!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Were they created of nothing, or were they themselves the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? Nay, they have no firm belief.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or are the Treasures of thy Lord with them, or are they the managers (of affairs)?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they a ladder, by which they can (climb up to heaven and) listen (to its secrets)? Then let (such a) listener of theirs produce a manifest proof.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or has He only daughters and ye have sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or is it that thou dost ask for a reward, so that they are burdened with a load of debt?-\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or that the Unseen in it their hands, and they write it down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or do they intend a plot (against thee)? But those who defy Allah are themselves involved in a Plot!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they a god other than Allah? Exalted is Allah far above the things they associate with Him!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
Were they to see a piece of the sky falling (on them), they would (only) say: ``Clouds gathered in heaps!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them alone until they encounter that Day of theirs, wherein they shall (perforce) swoon (with terror),-\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day when their plotting will avail them nothing and no help shall be given them.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And verily, for those who do wrong, there is another punishment besides this: But most of them understand not.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
Now await in patience the command of thy Lord: for verily thou art in Our eyes: and celebrate the praises of thy Lord the while thou standest forth,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And for part of the night also praise thou Him,- and at the retreat of the stars!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the Star when it goes down,-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your Companion is neither astray nor being misled.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor does he say (aught) of (his own) Desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is no less than inspiration sent down to him:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
He was taught by one Mighty in Power,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
Endued with Wisdom: for he appeared (in stately form);\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he was in the highest part of the horizon:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he approached and came closer,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
And was at a distance of but two bow-lengths or (even) nearer;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
So did (Allah) convey the inspiration to His Servant- (conveyed) what He (meant) to convey.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The (Prophet's) (mind and) heart in no way falsified that which he saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will ye then dispute with him concerning what he saw?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
For indeed he saw him at a second descent,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
Near the Lote-tree beyond which none may pass:\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Near it is the Garden of Abode.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
Behold, the Lote-tree was shrouded (in mystery unspeakable!)\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
(His) sight never swerved, nor did it go wrong!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
For truly did he see, of the Signs of his Lord, the Greatest!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have ye seen Lat. and 'Uzza,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And another, the third (goddess), Manat?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
What! for you the male sex, and for Him, the female?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
Behold, such would be indeed a division most unfair!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
These are nothing but names which ye have devised,- ye and your fathers,- for which Allah has sent down no authority (whatever). They follow nothing but conjecture and what their own souls desire!- Even though there has already come to them Guidance from their Lord!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Nay, shall man have (just) anything he hankers after?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
But it is to Allah that the End and the Beginning (of all things) belong.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
How many-so-ever be the angels in the heavens, their intercession will avail nothing except after Allah has given leave for whom He pleases and that he is acceptable to Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Those who believe not in the Hereafter, name the angels with female names.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
But they have no knowledge therein. They follow nothing but conjecture; and conjecture avails nothing against Truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Therefore shun those who turn away from Our Message and desire nothing but the life of this world.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is as far as knowledge will reach them. Verily thy Lord knoweth best those who stray from His Path, and He knoweth best those who receive guidance.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
Yea, to Allah belongs all that is in the heavens and on earth: so that He rewards those who do evil, according to their deeds, and He rewards those who do good, with what is best.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid great sins and shameful deeds, only (falling into) small faults,- verily thy Lord is ample in forgiveness. He knows you well when He brings you out of the earth, And when ye are hidden in your mothers' wombs. Therefore justify not yourselves: He knows best who it is that guards against evil.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Seest thou one who turns back,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
Gives a little, then hardens (his heart)?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
What! Has he knowledge of the Unseen so that he can see?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Nay, is he not acquainted with what is in the Books of Moses-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Abraham who fulfilled his engagements?-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
Namely, that no bearer of burdens can bear the burden of another;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
That man can have nothing but what he strives for;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
That (the fruit of) his striving will soon come in sight:\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then will he be rewarded with a reward complete;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
That to thy Lord is the final Goal;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
That it is He Who granteth Laughter and Tears;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
That it is He Who granteth Death and Life;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
That He did create in pairs,- male and female,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From a seed when lodged (in its place);\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
That He hath promised a Second Creation (Raising of the Dead);\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
That it is He Who giveth wealth and satisfaction;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
That He is the Lord of Sirius (the Mighty Star);\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that it is He Who destroyed the (powerful) ancient 'Ad (people),\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And the Thamud nor gave them a lease of perpetual life.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And before them, the people of Noah, for that they were (all) most unjust and most insolent transgressors,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And He destroyed the Overthrown Cities (of Sodom and Gomorrah).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
So that (ruins unknown) have covered them up.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Then which of the gifts of thy Lord, (O man,) wilt thou dispute about?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a Warner, of the (series of) Warners of old!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The (Judgment) ever approaching draws nigh:\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
No (soul) but Allah can lay it bare.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do ye then wonder at this recital?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And will ye laugh and not weep,-\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
Wasting your time in vanities?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
But fall ye down in prostration to Allah, and adore (Him)!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour (of Judgment) is nigh, and the moon is cleft asunder.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
But if they see a Sign, they turn away, and say, ``This is (but) transient magic."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They reject (the warning) and follow their (own) lusts but every matter has its appointed time.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
There have already come to them Recitals wherein there is (enough) to check (them),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Mature wisdom;- but (the preaching of) Warners profits them not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
Therefore, (O Prophet,) turn away from them. The Day that the Caller will call (them) to a terrible affair,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
They will come forth,- their eyes humbled - from (their) graves, (torpid) like locusts scattered abroad,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Hastening, with eyes transfixed, towards the Caller!- ``Hard is this Day!", the Unbelievers will say.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
Before them the People of Noah rejected (their messenger): they rejected Our servant, and said, ``Here is one possessed!", and he was driven out.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Then he called on his Lord: ``I am one overcome: do Thou then help (me)!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
So We opened the gates of heaven, with water pouring forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And We caused the earth to gush forth with springs, so the waters met (and rose) to the extent decreed.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
But We bore him on an (Ark) made of broad planks and caulked with palm-fibre:\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
She floats under our eyes (and care): a recompense to one who had been rejected (with scorn)!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We have left this as a Sign (for all time): then is there any that will receive admonition?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
But how (terrible) was My Penalty and My Warning?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And We have indeed made the Qur'an easy to understand and remember: then is there any that will receive admonition?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
The 'Ad (people) (too) rejected (Truth): then how terrible was My Penalty and My Warning?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
For We sent against them a furious wind, on a Day of violent Disaster,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Plucking out men as if they were roots of palm-trees torn up (from the ground).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
Yea, how (terrible) was My Penalty and My Warning!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
But We have indeed made the Qur'an easy to understand and remember: then is there any that will receive admonition?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
The Thamud (also) rejected (their) Warners.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
For they said: ``What! a man! a Solitary one from among ourselves! shall we follow such a one? Truly should we then be straying in mind, and mad!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
``Is it that the Message is sent to him, of all people amongst us? Nay, he is a liar, an insolent one!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
Ah! they will know on the morrow, which is the liar, the insolent one!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
For We will send the she-camel by way of trial for them. So watch them, (O Salih), and possess thyself in patience!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And tell them that the water is to be divided between them: Each one's right to drink being brought forward (by suitable turns).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called to their companion, and he took a sword in hand, and hamstrung (her).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
Ah! how (terrible) was My Penalty and My Warning!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
For We sent against them a single Mighty Blast, and they became like the dry stubble used by one who pens cattle.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And We have indeed made the Qur'an easy to understand and remember: then is there any that will receive admonition?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lut rejected (his) warning.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
We sent against them a violent Tornado with showers of stones, (which destroyed them), except Lut's household: them We delivered by early Dawn,-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As a Grace from Us: thus do We reward those who give thanks.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And (Lut) did warn them of Our Punishment, but they disputed about the Warning.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And they even sought to snatch away his guests from him, but We blinded their eyes. (They heard:) ``Now taste ye My Wrath and My Warning."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
Early on the morrow an abiding Punishment seized them:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
``So taste ye My Wrath and My Warning."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And We have indeed made the Qur'an easy to understand and remember: then is there any that will receive admonition?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
To the People of Pharaoh, too, aforetime, came Warners (from Allah).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
The (people) rejected all Our Signs; but We seized them with such Penalty (as comes) from One Exalted in Power, able to carry out His Will.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your Unbelievers, (O Quraish), better than they? Or have ye an immunity in the Sacred Books?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say: ``We acting together can defend ourselves"?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Soon will their multitude be put to flight, and they will show their backs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay, the Hour (of Judgment) is the time promised them (for their full recompense): And that Hour will be most grievous and most bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Truly those in sin are the ones straying in mind, and mad.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The Day they will be dragged through the Fire on their faces, (they will hear:) ``Taste ye the touch of Hell!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Verily, all things have We created in proportion and measure.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our Command is but a single (Act),- like the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And (oft) in the past, have We destroyed gangs like unto you: then is there any that will receive admonition?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
All that they do is noted in (their) Books (of Deeds):\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
Every matter, small and great, is on record.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
As to the Righteous, they will be in the midst of Gardens and Rivers,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In an Assembly of Truth, in the Presence of a Sovereign Omnipotent.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen (Allah) Most Gracious!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
It is He Who has taught the Qur'an.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He has created man:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
He has taught him speech (and intelligence).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon follow courses (exactly) computed;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the herbs and the trees - both (alike) prostrate in adoration.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the Firmament has He raised high, and He has set up the Balance (of Justice),\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
In order that ye may not transgress (due) balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
So establish weight with justice and fall not short in the balance.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
It is He Who has spread out the earth for (His) creatures:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein is fruit and date-palms, producing spathes (enclosing dates);\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
Also corn, with (its) leaves and stalk for fodder, and sweet-smelling plants.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Then which of the favours of your Lord will ye deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man from sounding clay like unto pottery,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And He created Jinns from fire free of smoke:\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Then which of the favours of your Lord will ye deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
(He is) Lord of the two Easts and Lord of the two Wests:\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Then which of the favours of your Lord will ye deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He has let free the two bodies of flowing water, meeting together:\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Between them is a Barrier which they do not transgress:\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Then which of the favours of your Lord will ye deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
Out of them come Pearls and Coral:\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Then which of the favours of your Lord will ye deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
And His are the Ships sailing smoothly through the seas, lofty as mountains:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Then which of the favours of your Lord will ye deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
All that is on earth will perish:\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
But will abide (for ever) the Face of thy Lord,- full of Majesty, Bounty and Honour.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Then which of the favours of your Lord will ye deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Of Him seeks (its need) every creature in the heavens and on earth: every day in (new) Splendour doth He (shine)!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Then which of the favours of your Lord will ye deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
Soon shall We settle your affairs, O both ye worlds!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Then which of the favours of your Lord will ye deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O ye assembly of Jinns and men! If it be ye can pass beyond the zones of the heavens and the earth, pass ye! not without authority shall ye be able to pass!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Then which of the favours of your Lord will ye deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
On you will be sent (O ye evil ones twain!) a flame of fire (to burn) and a smoke (to choke): no defence will ye have:\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Then which of the favours of your Lord will ye deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
When the sky is rent asunder, and it becomes red like ointment:\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Then which of the favours of your Lord will ye deny?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that Day no question will be asked of man or Jinn as to his sin.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Then which of the favours of your Lord will ye deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
(For) the sinners will be known by their marks: and they will be seized by their forelocks and their feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Then which of the favours of your Lord will ye deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is the Hell which the Sinners deny:\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
In its midst and in the midst of boiling hot water will they wander round!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Then which of the favours of your Lord will ye deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for such as fear the time when they will stand before (the Judgment Seat of) their Lord, there will be two Gardens-\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Then which of the favours of your Lord will ye deny?-\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
Containing all kinds (of trees and delights);-\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Then which of the favours of your Lord will ye deny?-\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In them (each) will be two Springs flowing (free);\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Then which of the favours of your Lord will ye deny?-\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In them will be Fruits of every kind, two and two.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Then which of the favours of your Lord will ye deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
They will recline on Carpets, whose inner linings will be of rich brocade: the Fruit of the Gardens will be near (and easy of reach).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Then which of the favours of your Lord will ye deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
In them will be (Maidens), chaste, restraining their glances, whom no man or Jinn before them has touched;-\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Then which of the favours of your Lord will ye deny?-\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
Like unto Rubies and coral.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Then which of the favours of your Lord will ye deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is there any Reward for Good - other than Good?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Then which of the favours of your Lord will ye deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And besides these two, there are two other Gardens,-\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Then which of the favours of your Lord will ye deny?-\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Dark-green in colour (from plentiful watering).\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Then which of the favours of your Lord will ye deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In them (each) will be two Springs pouring forth water in continuous abundance:\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Then which of the favours of your Lord will ye deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them will be Fruits, and dates and pomegranates:\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Then which of the favours of your Lord will ye deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In them will be fair (Companions), good, beautiful;-\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Then which of the favours of your Lord will ye deny?-\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Companions restrained (as to their glances), in (goodly) pavilions;-\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Then which of the favours of your Lord will ye deny?-\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Whom no man or Jinn before them has touched;-\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Then which of the favours of your Lord will ye deny?-\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green Cushions and rich Carpets of beauty.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Then which of the favours of your Lord will ye deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the name of thy Lord, full of Majesty, Bounty and Honour.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Event inevitable cometh to pass,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
Then will no (soul) entertain falsehood concerning its coming.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
(Many) will it bring low; (many) will it exalt;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth shall be shaken to its depths,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains shall be crumbled to atoms,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
Becoming dust scattered abroad,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And ye shall be sorted out into three classes.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Then (there will be) the Companions of the Right Hand;- What will be the Companions of the Right Hand?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And the Companions of the Left Hand,- what will be the Companions of the Left Hand?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And those Foremost (in Faith) will be Foremost (in the Hereafter).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
These will be those Nearest to Allah:\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In Gardens of Bliss:\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A number of people from those of old,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few from those of later times.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
(They will be) on Thrones encrusted (with gold and precious stones),\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining on them, facing each other.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
Round about them will (serve) youths of perpetual (freshness),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With goblets, (shining) beakers, and cups (filled) out of clear-flowing fountains:\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
No after-ache will they receive therefrom, nor will they suffer intoxication:\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And with fruits, any that they may select:\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And the flesh of fowls, any that they may desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And (there will be) Companions with beautiful, big, and lustrous eyes,-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
Like unto Pearls well-guarded.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
A Reward for the deeds of their past (life).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
Not frivolity will they hear therein, nor any taint of ill,-\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
Only the saying, ``Peace! Peace".\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
The Companions of the Right Hand,- what will be the Companions of the Right Hand?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
(They will be) among Lote-trees without thorns,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
Among Talh trees with flowers (or fruits) piled one above another,-\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
In shade long-extended,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
By water flowing constantly,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit in abundance.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Whose season is not limited, nor (supply) forbidden,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And on Thrones (of Dignity), raised high.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
We have created (their Companions) of special creation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgin - pure (and undefiled), -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Beloved (by nature), equal in age,-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For the Companions of the Right Hand.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A (goodly) number from those of old,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a (goodly) number from those of later times.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
The Companions of the Left Hand,- what will be the Companions of the Left Hand?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
(They will be) in the midst of a Fierce Blast of Fire and in Boiling Water,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And in the shades of Black Smoke:\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Nothing (will there be) to refresh, nor to please:\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
For that they were wont to be indulged, before that, in wealth (and luxury),\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And persisted obstinately in wickedness supreme!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say, ``What! when we die and become dust and bones, shall we then indeed be raised up again?-\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
``(We) and our fathers of old?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say: ``Yea, those of old and those of later times,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
``All will certainly be gathered together for the meeting appointed for a Day well-known.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
``Then will ye truly,- O ye that go wrong, and treat (Truth) as Falsehood!-\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
``Ye will surely taste of the Tree of Zaqqum.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
``Then will ye fill your insides therewith,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
``And drink Boiling Water on top of it:\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
``Indeed ye shall drink like diseased camels raging with thirst!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
Such will be their entertainment on the Day of Requital!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
It is We Who have created you: why will ye not witness the Truth?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Do ye then see?- The (human Seed) that ye throw out,-\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Is it ye who create it, or are We the Creators?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed Death to be your common lot, and We are not to be frustrated\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
from changing your Forms and creating you (again) in (forms) that ye know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And ye certainly know already the first form of creation: why then do ye not celebrate His praises?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
See ye the seed that ye sow in the ground?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it ye that cause it to grow, or are We the Cause?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
Were it Our Will, We could crumble it to dry powder, and ye would be left in wonderment,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
(Saying), ``We are indeed left with debts (for nothing):\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
``Indeed are we shut out (of the fruits of our labour)"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
See ye the water which ye drink?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Do ye bring it down (in rain) from the cloud or do We?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
Were it Our Will, We could make it salt (and unpalatable): then why do ye not give thanks?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
See ye the Fire which ye kindle?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it ye who grow the tree which feeds the fire, or do We grow it?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a memorial (of Our handiwork), and an article of comfort and convenience for the denizens of deserts.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Then celebrate with praises the name of thy Lord, the Supreme!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
Furthermore I call to witness the setting of the Stars,-\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And that is indeed a mighty adjuration if ye but knew,-\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
That this is indeed a qur'an Most Honourable,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In Book well-guarded,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
Which none shall touch but those who are clean:\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
A Revelation from the Lord of the Worlds.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it such a Message that ye would hold in light esteem?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And have ye made it your livelihood that ye should declare it false?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Then why do ye not (intervene) when (the soul of the dying man) reaches the throat,-\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And ye the while (sit) looking on,-\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
But We are nearer to him than ye, and yet see not,-\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Then why do ye not,- If you are exempt from (future) account,-\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Call back the soul, if ye are true (in the claim of independence)?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Thus, then, if he be of those Nearest to Allah,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
(There is for him) Rest and Satisfaction, and a Garden of Delights.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he be of the Companions of the Right Hand,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
(For him is the salutation), ``Peace be unto thee", from the Companions of the Right Hand.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
And if he be of those who treat (Truth) as Falsehood, who go wrong,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
For him is Entertainment with Boiling Water.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And burning in Hell-Fire.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Verily, this is the Very Truth and Certainly.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So celebrate with praises the name of thy Lord, the Supreme.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Whatever is in the heavens and on earth,- let it declare the Praises and Glory of Allah: for He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
To Him belongs the dominion of the heavens and the earth: It is He Who gives Life and Death; and He has Power over all things.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, the Evident and the Immanent: and He has full knowledge of all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in Six Days, and is moreover firmly established on the Throne (of Authority). He knows what enters within the earth and what comes forth out of it, what comes down from heaven and what mounts up to it. And He is with you wheresoever ye may be. And Allah sees well all that ye do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
To Him belongs the dominion of the heavens and the earth: and all affairs are referred back to Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He merges Night into Day, and He merges Day into Night; and He has full knowledge of the secrets of (all) hearts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His messenger, and spend (in charity) out of the (substance) whereof He has made you heirs. For, those of you who believe and spend (in charity),- for them is a great Reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
What cause have ye why ye should not believe in Allah?- and the Messenger invites you to believe in your Lord, and has indeed taken your Covenant, if ye are men of Faith.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
He is the One Who sends to His Servant Manifest Signs, that He may lead you from the depths of Darkness into the Light and verily Allah is to you most kind and Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what cause have ye why ye should not spend in the cause of Allah?- For to Allah belongs the heritage of the heavens and the earth. Not equal among you are those who spent (freely) and fought, before the Victory, (with those who did so later). Those are higher in rank than those who spent (freely) and fought afterwards. But to all has Allah promised a goodly (reward). And Allah is well acquainted with all that ye do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will Loan to Allah a beautiful loan? for (Allah) will increase it manifold to his credit, and he will have (besides) a liberal Reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
One Day shalt thou see the believing men and the believing women- how their Light runs forward before them and by their right hands: (their greeting will be): ``Good News for you this Day! Gardens beneath which flow rivers! to dwell therein for aye! This is indeed the highest Achievement!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
One Day will the Hypocrites- men and women - say to the Believers: ``Wait for us! Let us borrow (a Light) from your Light!" It will be said: ``Turn ye back to your rear! then seek a Light (where ye can)!" So a wall will be put up betwixt them, with a gate therein. Within it will be Mercy throughout, and without it, all alongside, will be (Wrath and) Punishment!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
(Those without) will call out, ``Were we not with you?" (The others) will reply, ``True! but ye led yourselves into temptation; ye looked forward (to our ruin); ye doubted (Allah's Promise); and (your false) desires deceived you; until there issued the Command of Allah. And the Deceiver deceived you in respect of Allah.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
``This Day shall no ransom be accepted of you, nor of those who rejected Allah." Your abode is the Fire: that is the proper place to claim you: and an evil refuge it is!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Has not the Time arrived for the Believers that their hearts in all humility should engage in the remembrance of Allah and of the Truth which has been revealed (to them), and that they should not become like those to whom was given Revelation aforetime, but long ages passed over them and their hearts grew hard? For many among them are rebellious transgressors.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know ye (all) that Allah giveth life to the earth after its death! already have We shown the Signs plainly to you, that ye may learn wisdom.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
For those who give in Charity, men and women, and loan to Allah a Beautiful Loan, it shall be increased manifold (to their credit), and they shall have (besides) a liberal reward.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in Allah and His messengers- they are the Sincere (lovers of Truth), and the witnesses (who testify), in the eyes of their Lord: They shall have their Reward and their Light. But those who reject Allah and deny Our Signs,- they are the Companions of Hell-Fire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know ye (all), that the life of this world is but play and amusement, pomp and mutual boasting and multiplying, (in rivalry) among yourselves, riches and children. Here is a similitude: How rain and the growth which it brings forth, delight (the hearts of) the tillers; soon it withers; thou wilt see it grow yellow; then it becomes dry and crumbles away. But in the Hereafter is a Penalty severe (for the devotees of wrong). And Forgiveness from Allah and (His) Good Pleasure (for the devotees of Allah). And what is the life of this world, but goods and chattels of deception?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Be ye foremost (in seeking) Forgiveness from your Lord, and a Garden (of Bliss), the width whereof is as the width of heaven and earth, prepared for those who believe in Allah and His messengers: that is the Grace of Allah, which He bestows on whom he pleases: and Allah is the Lord of Grace abounding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No misfortune can happen on earth or in your souls but is recorded in a decree before We bring it into existence: That is truly easy for Allah:\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
In order that ye may not despair over matters that pass you by, nor exult over favours bestowed upon you. For Allah loveth not any vainglorious boaster,-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Such persons as are covetous and commend covetousness to men. And if any turn back (from Allah's Way), verily Allah is Free of all Needs, Worthy of all Praise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
We sent aforetime our messengers with Clear Signs and sent down with them the Book and the Balance (of Right and Wrong), that men may stand forth in justice; and We sent down Iron, in which is (material for) mighty war, as well as many benefits for mankind, that Allah may test who it is that will help, Unseen, Him and His messengers: For Allah is Full of Strength, Exalted in Might (and able to enforce His Will).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And We sent Noah and Abraham, and established in their line Prophethood and Revelation: and some of them were on right guidance. But many of them became rebellious transgressors.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then, in their wake, We followed them up with (others of) Our messengers: We sent after them Jesus the son of Mary, and bestowed on him the Gospel; and We ordained in the hearts of those who followed him Compassion and Mercy. But the Monasticism which they invented for themselves, We did not prescribe for them: (We commanded) only the seeking for the Good Pleasure of Allah; but that they did not foster as they should have done. Yet We bestowed, on those among them who believed, their (due) reward, but many of them are rebellious transgressors.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O ye that believe! Fear Allah, and believe in His Messenger, and He will bestow on you a double portion of His Mercy: He will provide for you a Light by which ye shall walk (straight in your path), and He will forgive you (your past): for Allah is Oft-Forgiving, Most Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
That the People of the Book may know that they have no power whatever over the Grace of Allah, that (His) Grace is (entirely) in His Hand, to bestow it on whomsoever He wills. For Allah is the Lord of Grace abounding.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Allah has indeed heard (and accepted) the statement of the woman who pleads with thee concerning her husband and carries her complaint (in prayer) to Allah: and Allah (always) hears the arguments between both sides among you: for Allah hears and sees (all things).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
If any men among you divorce their wives by Zihar (calling them mothers), they cannot be their mothers: None can be their mothers except those who gave them birth. And in fact they use words (both) iniquitous and false: but truly Allah is one that blots out (sins), and forgives (again and again).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
But those who divorce their wives by Zihar, then wish to go back on the words they uttered,- (It is ordained that such a one) should free a slave before they touch each other: Thus are ye admonished to perform: and Allah is well-acquainted with (all) that ye do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And if any has not (the wherewithal), he should fast for two months consecutively before they touch each other. But if any is unable to do so, he should feed sixty indigent ones, this, that ye may show your faith in Allah and His Messenger. Those are limits (set by) Allah. For those who reject (Him), there is a grievous Penalty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Those who resist Allah and His Messenger will be humbled to dust, as were those before them: for We have already sent down Clear Signs. And the Unbelievers (will have) a humiliating Penalty,-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day that Allah will raise them all up (again) and show them the Truth (and meaning) of their conduct. Allah has reckoned its (value), though they may have forgotten it, for Allah is Witness to all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Seest thou not that Allah doth know (all) that is in the heavens and on earth? There is not a secret consultation between three, but He makes the fourth among them, - Nor between five but He makes the sixth,- nor between fewer nor more, but He is in their midst, wheresoever they be: In the end will He tell them the truth of their conduct, on the Day of Judgment. For Allah has full knowledge of all things.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Turnest thou not thy sight towards those who were forbidden secret counsels yet revert to that which they were forbidden (to do)? And they hold secret counsels among themselves for iniquity and hostility, and disobedience to the Messenger. And when they come to thee, they salute thee, not as Allah salutes thee, (but in crooked ways): And they say to themselves, ``Why does not Allah punish us for our words?" Enough for them is Hell: In it will they burn, and evil is that destination!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O ye who believe! When ye hold secret counsel, do it not for iniquity and hostility, and disobedience to the Prophet; but do it for righteousness and self-restraint; and fear Allah, to Whom ye shall be brought back.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Secret counsels are only (inspired) by the Evil One, in order that he may cause grief to the Believers; but he cannot harm them in the least, except as Allah permits; and on Allah let the Believers put their trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O ye who believe! When ye are told to make room in the assemblies, (spread out and) make room: (ample) room will Allah provide for you. And when ye are told to rise up, rise up Allah will rise up, to (suitable) ranks (and degrees), those of you who believe and who have been granted (mystic) Knowledge. And Allah is well-acquainted with all ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O ye who believe! When ye consult the Messenger in private, spend something in charity before your private consultation. That will be best for you, and most conducive to purity (of conduct). But if ye find not (the wherewithal), Allah is Oft-Forgiving, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Is it that ye are afraid of spending sums in charity before your private consultation (with him)? If, then, ye do not so, and Allah forgives you, then (at least) establish regular prayer; practise regular charity; and obey Allah and His Messenger. And Allah is well-acquainted with all that ye do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Turnest thou not thy attention to those who turn (in friendship) to such as have the Wrath of Allah upon them? They are neither of you nor of them, and they swear to falsehood knowingly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a severe Penalty: evil indeed are their deeds.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have made their oaths a screen (for their misdeeds): thus they obstruct (men) from the Path of Allah: therefore shall they have a humiliating Penalty.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Of no profit whatever to them, against Allah, will be their riches nor their sons: they will be Companions of the Fire, to dwell therein (for aye)!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
One day will Allah raise them all up (for Judgment): then will they swear to Him as they swear to you: And they think that they have something (to stand upon). No, indeed! they are but liars!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
The Evil One has got the better of them: so he has made them lose the remembrance of Allah. They are the Party of the Evil One. Truly, it is the Party of the Evil One that will perish!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Those who resist Allah and His Messenger will be among those most humiliated.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has decreed: ``It is I and My messengers who must prevail": For Allah is One full of strength, able to enforce His Will.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
Thou wilt not find any people who believe in Allah and the Last Day, loving those who resist Allah and His Messenger, even though they were their fathers or their sons, or their brothers, or their kindred. For such He has written Faith in their hearts, and strengthened them with a spirit from Himself. And He will admit them to Gardens beneath which Rivers flow, to dwell therein (for ever). Allah will be well pleased with them, and they with Him. They are the Party of Allah. Truly it is the Party of Allah that will achieve Felicity.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Whatever is in the heavens and on earth, let it declare the Praises and Glory of Allah: for He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It is He Who got out the Unbelievers among the People of the Book from their homes at the first gathering (of the forces). Little did ye think that they would get out: And they thought that their fortresses would defend them from Allah! But the (Wrath of) Allah came to them from quarters from which they little expected (it), and cast terror into their hearts, so that they destroyed their dwellings by their own hands and the hands of the Believers, take warning, then, O ye with eyes (to see)!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And had it not been that Allah had decreed banishment for them, He would certainly have punished them in this world: And in the Hereafter they shall (certainly) have the Punishment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they resisted Allah and His Messenger: and if any one resists Allah, verily Allah is severe in Punishment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whether ye cut down (O ye Muslim!) The tender palm-trees, or ye left them standing on their roots, it was by leave of Allah, and in order that He might cover with shame the rebellious transgresses.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
What Allah has bestowed on His Messenger (and taken away) from them - for this ye made no expedition with either cavalry or camelry: but Allah gives power to His messengers over any He pleases: and Allah has power over all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
What Allah has bestowed on His Messenger (and taken away) from the people of the townships,- belongs to Allah,- to His Messenger and to kindred and orphans, the needy and the wayfarer; In order that it may not (merely) make a circuit between the wealthy among you. So take what the Messenger assigns to you, and deny yourselves that which he withholds from you. And fear Allah; for Allah is strict in Punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
(Some part is due) to the indigent Muhajirs, those who were expelled from their homes and their property, while seeking Grace from Allah and (His) Good Pleasure, and aiding Allah and His Messenger: such are indeed the sincere ones:-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
But those who before them, had homes (in Medina) and had adopted the Faith,- show their affection to such as came to them for refuge, and entertain no desire in their hearts for things given to the (latter), but give them preference over themselves, even though poverty was their (own lot). And those saved from the covetousness of their own souls,- they are the ones that achieve prosperity.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came after them say: ``Our Lord! Forgive us, and our brethren who came before us into the Faith, and leave not, in our hearts, rancour (or sense of injury) against those who have believed. Our Lord! Thou art indeed Full of Kindness, Most Merciful."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Hast thou not observed the Hypocrites say to their misbelieving brethren among the People of the Book? - ``If ye are expelled, we too will go out with you, and we will never hearken to any one in your affair; and if ye are attacked (in fight) we will help you". But Allah is witness that they are indeed liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If they are expelled, never will they go out with them; and if they are attacked (in fight), they will never help them; and if they do help them, they will turn their backs; so they will receive no help.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Of a truth ye are stronger (than they) because of the terror in their hearts, (sent) by Allah. This is because they are men devoid of understanding.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight you (even) together, except in fortified townships, or from behind walls. Strong is their fighting (spirit) amongst themselves: thou wouldst think they were united, but their hearts are divided: that is because they are a people devoid of wisdom.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
Like those who lately preceded them, they have tasted the evil result of their conduct; and (in the Hereafter there is) for them a grievous Penalty;-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
(Their allies deceived them), like the Evil One, when he says to man, ``Deny Allah": but when (man) denies Allah, (the Evil One) says, ``I am free of thee: I do fear Allah, the Lord of the Worlds!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
The end of both will be that they will go into the Fire, dwelling therein for ever. Such is the reward of the wrong-doers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O ye who believe! Fear Allah, and let every soul look to what (provision) He has sent forth for the morrow. Yea, fear Allah: for Allah is well-acquainted with (all) that ye do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be ye not like those who forgot Allah; and He made them forget their own souls! Such are the rebellious transgressors!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the Companions of the Fire and the Companions of the Garden: it is the Companions of the Garden, that will achieve Felicity.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Qur'an on a mountain, verily, thou wouldst have seen it humble itself and cleave asunder for fear of Allah. Such are the similitudes which We propound to men, that they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
Allah is He, than Whom there is no other god;- Who knows (all things) both secret and open; He, Most Gracious, Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
Allah is He, than Whom there is no other god;- the Sovereign, the Holy One, the Source of Peace (and Perfection), the Guardian of Faith, the Preserver of Safety, the Exalted in Might, the Irresistible, the Supreme: Glory to Allah! (High is He) above the partners they attribute to Him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Evolver, the Bestower of Forms (or Colours). To Him belong the Most Beautiful Names: whatever is in the heavens and on earth, doth declare His Praises and Glory: and He is the Exalted in Might, the Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O ye who believe! Take not my enemies and yours as friends (or protectors),- offering them (your) love, even though they have rejected the Truth that has come to you, and have (on the contrary) driven out the Prophet and yourselves (from your homes), (simply) because ye believe in Allah your Lord! If ye have come out to strive in My Way and to seek My Good Pleasure, (take them not as friends), holding secret converse of love (and friendship) with them: for I know full well all that ye conceal and all that ye reveal. And any of you that does this has strayed from the Straight Path.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they were to get the better of you, they would behave to you as enemies, and stretch forth their hands and their tongues against you for evil: and they desire that ye should reject the Truth.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Of no profit to you will be your relatives and your children on the Day of Judgment: He will judge between you: for Allah sees well all that ye do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
There is for you an excellent example (to follow) in Abraham and those with him, when they said to their people: ``We are clear of you and of whatever ye worship besides Allah: we have rejected you, and there has arisen, between us and you, enmity and hatred for ever,- unless ye believe in Allah and Him alone": But not when Abraham said to his father: ``I will pray for forgiveness for thee, though I have no power (to get) aught on thy behalf from Allah." (They prayed): ``Our Lord! in Thee do we trust, and to Thee do we turn in repentance: to Thee is (our) Final Goal.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
``Our Lord! Make us not a (test and) trial for the Unbelievers, but forgive us, our Lord! for Thou art the Exalted in Might, the Wise."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
There was indeed in them an excellent example for you to follow,- for those whose hope is in Allah and in the Last Day. But if any turn away, truly Allah is Free of all Wants, Worthy of all Praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It may be that Allah will grant love (and friendship) between you and those whom ye (now) hold as enemies. For Allah has power (over all things); And Allah is Oft-Forgiving, Most Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah forbids you not, with regard to those who fight you not for (your) Faith nor drive you out of your homes, from dealing kindly and justly with them: for Allah loveth those who are just.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah only forbids you, with regard to those who fight you for (your) Faith, and drive you out of your homes, and support (others) in driving you out, from turning to them (for friendship and protection). It is such as turn to them (in these circumstances), that do wrong.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O ye who believe! When there come to you believing women refugees, examine (and test) them: Allah knows best as to their Faith: if ye ascertain that they are Believers, then send them not back to the Unbelievers. They are not lawful (wives) for the Unbelievers, nor are the (Unbelievers) lawful (husbands) for them. But pay the Unbelievers what they have spent (on their dower), and there will be no blame on you if ye marry them on payment of their dower to them. But hold not to the guardianship of unbelieving women: ask for what ye have spent on their dowers, and let the (Unbelievers) ask for what they have spent (on the dowers of women who come over to you). Such is the command of Allah: He judges (with justice) between you. And Allah is Full of Knowledge and Wisdom.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives deserts you to the Unbelievers, and ye have an accession (by the coming over of a woman from the other side), then pay to those whose wives have deserted the equivalent of what they had spent (on their dower). And fear Allah, in Whom ye believe.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet! When believing women come to thee to take the oath of fealty to thee, that they will not associate in worship any other thing whatever with Allah, that they will not steal, that they will not commit adultery (or fornication), that they will not kill their children, that they will not utter slander, intentionally forging falsehood, and that they will not disobey thee in any just matter,- then do thou receive their fealty, and pray to Allah for the forgiveness (of their sins): for Allah is Oft-Forgiving, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O ye who believe! Turn not (for friendship) to people on whom is the Wrath of Allah, of the Hereafter they are already in despair, just as the Unbelievers are in despair about those (buried) in graves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Whatever is in the heavens and on earth, let it declare the Praises and Glory of Allah: for He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O ye who believe! Why say ye that which ye do not?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Grievously odious is it in the sight of Allah that ye say that which ye do not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Truly Allah loves those who fight in His Cause in battle array, as if they were a solid cemented structure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And remember, Moses said to his people: ``O my people! why do ye vex and insult me, though ye know that I am the messenger of Allah (sent) to you?" Then when they went wrong, Allah let their hearts go wrong. For Allah guides not those who are rebellious transgressors.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And remember, Jesus, the son of Mary, said: ``O Children of Israel! I am the messenger of Allah (sent) to you, confirming the Law (which came) before me, and giving Glad Tidings of a Messenger to come after me, whose name shall be Ahmad." But when he came to them with Clear Signs, they said, ``this is evident sorcery!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
Who doth greater wrong than one who invents falsehood against Allah, even as he is being invited to Islam? And Allah guides not those who do wrong.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
Their intention is to extinguish Allah's Light (by blowing) with their mouths: But Allah will complete (the revelation of) His Light, even though the Unbelievers may detest (it).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He Who has sent His Messenger with Guidance and the Religion of Truth, that he may proclaim it over all religion, even though the Pagans may detest (it).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O ye who believe! Shall I lead you to a bargain that will save you from a grievous Penalty?-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
That ye believe in Allah and His Messenger, and that ye strive (your utmost) in the Cause of Allah, with your property and your persons: That will be best for you, if ye but knew!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins, and admit you to Gardens beneath which Rivers flow, and to beautiful mansions in Gardens of Eternity: that is indeed the Supreme Achievement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And another (favour will He bestow,) which ye do love,- help from Allah and a speedy victory. So give the Glad Tidings to the Believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O ye who believe! Be ye helpers of Allah: As said Jesus the son of Mary to the Disciples, ``Who will be my helpers to (the work of) Allah?" Said the disciples, ``We are Allah's helpers!" then a portion of the Children of Israel believed, and a portion disbelieved: But We gave power to those who believed, against their enemies, and they became the ones that prevailed.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Whatever is in the heavens and on earth, doth declare the Praises and Glory of Allah,- the Sovereign, the Holy One, the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He Who has sent amongst the Unlettered a messenger from among themselves, to rehearse to them His Signs, to sanctify them, and to instruct them in Scripture and Wisdom,- although they had been, before, in manifest error;-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
As well as (to confer all these benefits upon) others of them, who have not already joined them: And He is exalted in Might, Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
Such is the Bounty of Allah, which He bestows on whom He will: and Allah is the Lord of the highest bounty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The similitude of those who were charged with the (obligations of the) Mosaic Law, but who subsequently failed in those (obligations), is that of a donkey which carries huge tomes (but understands them not). Evil is the similitude of people who falsify the Signs of Allah: and Allah guides not people who do wrong.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say: ``O ye that stand on Judaism! If ye think that ye are friends to Allah, to the exclusion of (other) men, then express your desire for Death, if ye are truthful!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But never will they express their desire (for Death), because of the (deeds) their hands have sent on before them! and Allah knows well those that do wrong!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say: ``The Death from which ye flee will truly overtake you: then will ye be sent back to the Knower of things secret and open: and He will tell you (the truth of) the things that ye did!"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O ye who believe! When the call is proclaimed to prayer on Friday (the Day of Assembly), hasten earnestly to the Remembrance of Allah, and leave off business (and traffic): That is best for you if ye but knew!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
And when the Prayer is finished, then may ye disperse through the land, and seek of the Bounty of Allah: and celebrate the Praises of Allah often (and without stint): that ye may prosper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
But when they see some bargain or some amusement, they disperse headlong to it, and leave thee standing. Say: ``The (blessing) from the Presence of Allah is better than any amusement or bargain! and Allah is the Best to provide (for all needs)."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the Hypocrites come to thee, they say, ``We bear witness that thou art indeed the Messenger of Allah." Yea, Allah knoweth that thou art indeed His Messenger, and Allah beareth witness that the Hypocrites are indeed liars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have made their oaths a screen (for their misdeeds): thus they obstruct (men) from the Path of Allah: truly evil are their deeds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, then they rejected Faith: So a seal was set on their hearts: therefore they understand not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
When thou lookest at them, their exteriors please thee; and when they speak, thou listenest to their words. They are as (worthless as hollow) pieces of timber propped up, (unable to stand on their own). They think that every cry is against them. They are the enemies; so beware of them. The curse of Allah be on them! How are they deluded (away from the Truth)!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them, ``Come, the Messenger of Allah will pray for your forgiveness", they turn aside their heads, and thou wouldst see them turning away their faces in arrogance.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is equal to them whether thou pray for their forgiveness or not. Allah will not forgive them. Truly Allah guides not rebellious transgressors.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They are the ones who say, ``Spend nothing on those who are with Allah's Messenger, to the end that they may disperse (and quit Medina)." But to Allah belong the treasures of the heavens and the earth; but the Hypocrites understand not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say, ``If we return to Medina, surely the more honourable (element) will expel therefrom the meaner." But honour belongs to Allah and His Messenger, and to the Believers; but the Hypocrites know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O ye who believe! Let not your riches or your children divert you from the remembrance of Allah. If any act thus, the loss is their own.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
and spend something (in charity) out of the substance which We have bestowed on you, before Death should come to any of you and he should say, ``O my Lord! why didst Thou not give me respite for a little while? I should then have given (largely) in charity, and I should have been one of the doers of good".\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But to no soul will Allah grant respite when the time appointed (for it) has come; and Allah is well acquainted with (all) that ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Whatever is in the heavens and on earth, doth declare the Praises and Glory of Allah: to Him belongs dominion, and to Him belongs praise: and He has power over all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He Who has created you; and of you are some that are Unbelievers, and some that are Believers: and Allah sees well all that ye do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He has created the heavens and the earth in just proportions, and has given you shape, and made your shapes beautiful: and to Him is the final Goal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows what is in the heavens and on earth; and He knows what ye conceal and what ye reveal: yea, Allah knows well the (secrets) of (all) hearts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has not the story reached you, of those who rejected Faith aforetime? So they tasted the evil result of their conduct; and they had a grievous Penalty.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That was because there came to them messengers with Clear Signs, but they said: ``Shall (mere) human beings direct us?" So they rejected (the Message) and turned away. But Allah can do without (them): and Allah is free of all needs, worthy of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The Unbelievers think that they will not be raised up (for Judgment). Say: ``Yea, By my Lord, Ye shall surely be raised up: then shall ye be told (the truth) of all that ye did. And that is easy for Allah."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Believe, therefore, in Allah and His Messenger, and in the Light which we have sent down. And Allah is well acquainted with all that ye do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The Day that He assembles you (all) for a Day of Assembly,- that will be a Day of mutual loss and gain (among you), and those who believe in Allah and work righteousness,- He will remove from them their ills, and He will admit them to Gardens beneath which Rivers flow, to dwell therein for ever: that will be the Supreme Achievement.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But those who reject Faith and treat Our Signs as falsehoods, they will be Companions of the Fire, to dwell therein for aye: and evil is that Goal.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No kind of calamity can occur, except by the leave of Allah: and if any one believes in Allah, (Allah) guides his heart (aright): for Allah knows all things.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
So obey Allah, and obey His Messenger: but if ye turn back, the duty of Our Messenger is but to proclaim (the Message) clearly and openly.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah! There is no god but He: and on Allah, therefore, let the Believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O ye who believe! Truly, among your wives and your children are (some that are) enemies to yourselves: so beware of them! But if ye forgive and overlook, and cover up (their faults), verily Allah is Oft-Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your riches and your children may be but a trial: but in the Presence of Allah, is the highest, Reward.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So fear Allah as much as ye can; listen and obey and spend in charity for the benefit of your own soul and those saved from the covetousness of their own souls,- they are the ones that achieve prosperity.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If ye loan to Allah, a beautiful loan, He will double it to your (credit), and He will grant you Forgiveness: for Allah is most Ready to appreciate (service), Most Forbearing,-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
Knower of what is open, Exalted in Might, Full of Wisdom.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet! When ye do divorce women, divorce them at their prescribed periods, and count (accurately), their prescribed periods: And fear Allah your Lord: and turn them not out of their houses, nor shall they (themselves) leave, except in case they are guilty of some open lewdness, those are limits set by Allah: and any who transgresses the limits of Allah, does verily wrong his (own) soul: thou knowest not if perchance Allah will bring about thereafter some new situation.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Thus when they fulfil their term appointed, either take them back on equitable terms or part with them on equitable terms; and take for witness two persons from among you, endued with justice, and establish the evidence (as) before Allah. Such is the admonition given to him who believes in Allah and the Last Day. And for those who fear Allah, He (ever) prepares a way out,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And He provides for him from (sources) he never could imagine. And if any one puts his trust in Allah, sufficient is (Allah) for him. For Allah will surely accomplish his purpose: verily, for all things has Allah appointed a due proportion.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
Such of your women as have passed the age of monthly courses, for them the prescribed period, if ye have any doubts, is three months, and for those who have no courses (it is the same): for those who carry (life within their wombs), their period is until they deliver their burdens: and for those who fear Allah, He will make their path easy.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the Command of Allah, which He has sent down to you: and if any one fears Allah, He will remove his ills, from him, and will enlarge his reward.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Let the women live (in 'iddat) in the same style as ye live, according to your means: Annoy them not, so as to restrict them. And if they carry (life in their wombs), then spend (your substance) on them until they deliver their burden: and if they suckle your (offspring), give them their recompense: and take mutual counsel together, according to what is just and reasonable. And if ye find yourselves in difficulties, let another woman suckle (the child) on the (father's) behalf.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the man of means spend according to his means: and the man whose resources are restricted, let him spend according to what Allah has given him. Allah puts no burden on any person beyond what He has given him. After a difficulty, Allah will soon grant relief.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
How many populations that insolently opposed the Command of their Lord and of His messengers, did We not then call to account,- to severe account?- and We imposed on them an exemplary Punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
Then did they taste the evil result of their conduct, and the End of their conduct was Perdition.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has prepared for them a severe Punishment (in the Hereafter). Therefore fear Allah, O ye men of understanding - who have believed!- for Allah hath indeed sent down to you a Message,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
An Messenger, who rehearses to you the Signs of Allah containing clear explanations, that he may lead forth those who believe and do righteous deeds from the depths of Darkness into Light. And those who believe in Allah and work righteousness, He will admit to Gardens beneath which Rivers flow, to dwell therein for ever: Allah has indeed granted for them a most excellent Provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
Allah is He Who created seven Firmaments and of the earth a similar number. Through the midst of them (all) descends His Command: that ye may know that Allah has power over all things, and that Allah comprehends, all things in (His) Knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet! Why holdest thou to be forbidden that which Allah has made lawful to thee? Thou seekest to please thy consorts. But Allah is Oft-Forgiving, Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has already ordained for you, (O men), the dissolution of your oaths (in some cases): and Allah is your Protector, and He is Full of Knowledge and Wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
When the Prophet disclosed a matter in confidence to one of his consorts, and she then divulged it (to another), and Allah made it known to him, he confirmed part thereof and repudiated a part. Then when he told her thereof, she said, ``Who told thee this? ``He said, ``He told me Who knows and is well-acquainted (with all things)."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If ye two turn in repentance to Him, your hearts are indeed so inclined; But if ye back up each other against him, truly Allah is his Protector, and Gabriel, and (every) righteous one among those who believe,- and furthermore, the angels - will back (him) up.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It may be, if he divorced you (all), that Allah will give him in exchange consorts better than you,- who submit (their wills), who believe, who are devout, who turn to Allah in repentance, who worship (in humility), who travel (for Faith) and fast,- previously married or virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O ye who believe! save yourselves and your families from a Fire whose fuel is Men and Stones, over which are (appointed) angels stern (and) severe, who flinch not (from executing) the Commands they receive from Allah, but do (precisely) what they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
(They will say), ``O ye Unbelievers! Make no excuses this Day! Ye are being but requited for all that ye did!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O ye who believe! Turn to Allah with sincere repentance: In the hope that your Lord will remove from you your ills and admit you to Gardens beneath which Rivers flow,- the Day that Allah will not permit to be humiliated the Prophet and those who believe with him. Their Light will run forward before them and by their right hands, while they say, ``Our Lord! Perfect our Light for us, and grant us Forgiveness: for Thou hast power over all things."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet! Strive hard against the Unbelievers and the Hypocrites, and be firm against them. Their abode is Hell,- an evil refuge (indeed).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah sets forth, for an example to the Unbelievers, the wife of Noah and the wife of Lut: they were (respectively) under two of our righteous servants, but they were false to their (husbands), and they profited nothing before Allah on their account, but were told: ``Enter ye the Fire along with (others) that enter!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah sets forth, as an example to those who believe the wife of Pharaoh: Behold she said: ``O my Lord! Build for me, in nearness to Thee, a mansion in the Garden, and save me from Pharaoh and his doings, and save me from those that do wrong";\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Mary the daughter of 'Imran, who guarded her chastity; and We breathed into (her body) of Our spirit; and she testified to the truth of the words of her Lord and of His Revelations, and was one of the devout (servants).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed be He in Whose hands is Dominion; and He over all things hath Power;-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
He Who created Death and Life, that He may try which of you is best in deed: and He is the Exalted in Might, Oft-Forgiving;-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
He Who created the seven heavens one above another: No want of proportion wilt thou see in the Creation of (Allah) Most Gracious. So turn thy vision again: seest thou any flaw?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Again turn thy vision a second time: (thy) vision will come back to thee dull and discomfited, in a state worn out.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And we have, (from of old), adorned the lowest heaven with Lamps, and We have made such (Lamps) (as) missiles to drive away the Evil Ones, and have prepared for them the Penalty of the Blazing Fire.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
For those who reject their Lord (and Cherisher) is the Penalty of Hell: and evil is (such), Destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are cast therein, they will hear the (terrible) drawing in of its breath even as it blazes forth,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
Almost bursting with fury: Every time a Group is cast therein, its Keepers will ask, ``Did no Warner come to you?"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say: ``Yes indeed; a Warner did come to us, but we rejected him and said, 'Allah never sent down any (Message): ye are nothing but an egregious delusion!'"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
They will further say: ``Had we but listened or used our intelligence, we should not (now) be among the Companions of the Blazing Fire!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
They will then confess their sins: but far will be (Forgiveness) from the Companions of the Blazing Fire!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
As for those who fear their Lord unseen, for them is Forgiveness and a great Reward.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And whether ye hide your word or publish it, He certainly has (full) knowledge, of the secrets of (all) hearts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Should He not know,- He that created? and He is the One that understands the finest mysteries (and) is well-acquainted (with them).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He Who has made the earth manageable for you, so traverse ye through its tracts and enjoy of the Sustenance which He furnishes: but unto Him is the Resurrection.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do ye feel secure that He Who is in heaven will not cause you to be swallowed up by the earth when it shakes (as in an earthquake)?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or do ye feel secure that He Who is in Heaven will not send against you a violent tornado (with showers of stones), so that ye shall know how (terrible) was My warning?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
But indeed men before them rejected (My warning): then how (terrible) was My rejection (of them)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Do they not observe the birds above them, spreading their wings and folding them in? None can uphold them except (Allah) Most Gracious: Truly (Allah) Most Gracious: Truly it is He that watches over all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Nay, who is there that can help you, (even as) an army, besides (Allah) Most Merciful? In nothing but delusion are the Unbelievers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is there that can provide you with Sustenance if He were to withhold His provision? Nay, they obstinately persist in insolent impiety and flight (from the Truth).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is then one who walks headlong, with his face grovelling, better guided,- or one who walks evenly on a Straight Way?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say: ``It is He Who has created you (and made you grow), and made for you the faculties of hearing, seeing, feeling and understanding: little thanks it is ye give.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: ``It is He Who has multiplied you through the earth, and to Him shall ye be gathered together."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They ask: When will this promise be (fulfilled)? - If ye are telling the truth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: ``As to the knowledge of the time, it is with Allah alone: I am (sent) only to warn plainly in public."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
At length, when they see it close at hand, grieved will be the faces of the Unbelievers, and it will be said (to them): ``This is (the promise fulfilled), which ye were calling for!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say: ``See ye?- If Allah were to destroy me, and those with me, or if He bestows His Mercy on us,- yet who can deliver the Unbelievers from a grievous Penalty?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: ``He is (Allah) Most Gracious: We have believed in Him, and on Him have we put our trust: So, soon will ye know which (of us) it is that is in manifest error."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say: ``See ye?- If your stream be some morning lost (in the underground earth), who then can supply you with clear-flowing water?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the Pen and the (Record) which (men) write,-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
Thou art not, by the Grace of thy Lord, mad or possessed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
Nay, verily for thee is a Reward unfailing:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And thou (standest) on an exalted standard of character.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
Soon wilt thou see, and they will see,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is afflicted with madness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Verily it is thy Lord that knoweth best, which (among men) hath strayed from His Path: and He knoweth best those who receive (true) Guidance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
So hearken not to those who deny (the Truth).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
Their desire is that thou shouldst be pliant: so would they be pliant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
Heed not the type of despicable men,- ready with oaths,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
A slanderer, going about with calumnies,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
(Habitually) hindering (all) good, transgressing beyond bounds, deep in sin,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Violent (and cruel),- with all that, base-born,-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
Because he possesses wealth and (numerous) sons.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When to him are rehearsed Our Signs, ``Tales of the ancients", he cries!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
Soon shall We brand (the beast) on the snout!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Verily We have tried them as We tried the People of the Garden, when they resolved to gather the fruits of the (garden) in the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
But made no reservation, ("If it be Allah's Will").\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then there came on the (garden) a visitation from thy Lord, (which swept away) all around, while they were asleep.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
So the (garden) became, by the morning, like a dark and desolate spot, (whose fruit had been gathered).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
As the morning broke, they called out, one to another,-\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
``Go ye to your tilth (betimes) in the morning, if ye would gather the fruits."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they departed, conversing in secret low tones, (saying)-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
``Let not a single indigent person break in upon you into the (garden) this day."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they opened the morning, strong in an (unjust) resolve.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw the (garden), they said: ``We have surely lost our way:\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
``Indeed we are shut out (of the fruits of our labour)!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
Said one of them, more just (than the rest): ``Did I not say to you, 'Why not glorify (Allah)?'"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said: ``Glory to our Lord! Verily we have been doing wrong!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they turned, one against another, in reproach.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: ``Alas for us! We have indeed transgressed!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
``It may be that our Lord will give us in exchange a better (garden) than this: for we do turn to Him (in repentance)!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the Punishment (in this life); but greater is the Punishment in the Hereafter,- if only they knew!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Verily, for the Righteous, are Gardens of Delight, in the Presence of their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We then treat the People of Faith like the People of Sin?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you? How judge ye?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or have ye a book through which ye learn-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That ye shall have, through it whatever ye choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have ye Covenants with Us to oath, reaching to the Day of Judgment, (providing) that ye shall have whatever ye shall demand?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask thou of them, which of them will stand surety for that!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or have they some ``Partners" (in Allahhead)? Then let them produce their ``partners", if they are truthful!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
The Day that the shin shall be laid bare, and they shall be summoned to bow in adoration, but they shall not be able,-\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes will be cast down,- ignominy will cover them; seeing that they had been summoned aforetime to bow in adoration, while they were whole, (and had refused).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Then leave Me alone with such as reject this Message: by degrees shall We punish them from directions they perceive not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
A (long) respite will I grant them: truly powerful is My Plan.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or is it that thou dost ask them for a reward, so that they are burdened with a load of debt?-\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or that the Unseen is in their hands, so that they can write it down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So wait with patience for the Command of thy Lord, and be not like the Companion of the Fish,- when he cried out in agony.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had not Grace from his Lord reached him, he would indeed have been cast off on the naked shore, in disgrace.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
Thus did his Lord choose him and make him of the Company of the Righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And the Unbelievers would almost trip thee up with their eyes when they hear the Message; and they say: ``Surely he is possessed!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is nothing less than a Message to all the worlds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Sure Reality!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Sure Reality?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what will make thee realise what the Sure Reality is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
The Thamud and the 'Ad People (branded) as false the Stunning Calamity!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
But the Thamud,- they were destroyed by a terrible Storm of thunder and lightning!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And the 'Ad, they were destroyed by a furious Wind, exceedingly violent;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
He made it rage against them seven nights and eight days in succession: so that thou couldst see the (whole) people lying prostrate in its (path), as they had been roots of hollow palm-trees tumbled down!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Then seest thou any of them left surviving?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Pharaoh, and those before him, and the Cities Overthrown, committed habitual Sin.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And disobeyed (each) the messenger of their Lord; so He punished them with an abundant Penalty.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
We, when the water (of Noah's Flood) overflowed beyond its limits, carried you (mankind), in the floating (Ark),\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it a Message unto you, and that ears (that should hear the tale and) retain its memory should bear its (lessons) in remembrance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
Then, when one blast is sounded on the Trumpet,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth is moved, and its mountains, and they are crushed to powder at one stroke,-\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
On that Day shall the (Great) Event come to pass.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the sky will be rent asunder, for it will that Day be flimsy,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be on its sides, and eight will, that Day, bear the Throne of thy Lord above them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
That Day shall ye be brought to Judgment: not an act of yours that ye hide will be hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then he that will be given his Record in his right hand will say: ``Ah here! Read ye my Record!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
``I did really understand that my Account would (One Day) reach me!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
And he will be in a life of Bliss,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a Garden on high,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
The Fruits whereof (will hang in bunches) low and near.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
``Eat ye and drink ye, with full satisfaction; because of the (good) that ye sent before you, in the days that are gone!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
And he that will be given his Record in his left hand, will say: ``Ah! Would that my Record had not been given to me!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
``And that I had never realised how my account (stood)!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
``Ah! Would that (Death) had made an end of me!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
``Of no profit to me has been my wealth!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
``My power has perished from me!"...\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(The stern command will say): ``Seize ye him, and bind ye him,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
``And burn ye him in the Blazing Fire.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
``Further, make him march in a chain, whereof the length is seventy cubits!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
``This was he that would not believe in Allah Most High.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
``And would not encourage the feeding of the indigent!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
``So no friend hath he here this Day.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
``Nor hath he any food except the corruption from the washing of wounds,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
``Which none do eat but those in sin."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
So I do call to witness what ye see,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And what ye see not,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
That this is verily the word of an honoured messenger;\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not the word of a poet: little it is ye believe!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the word of a soothsayer: little admonition it is ye receive.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
(This is) a Message sent down from the Lord of the Worlds.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if the messenger were to invent any sayings in Our name,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We should certainly seize him by his right hand,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
And We should certainly then cut off the artery of his heart:\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
Nor could any of you withhold him (from Our wrath).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
But verily this is a Message for the Allah-fearing.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And We certainly know that there are amongst you those that reject (it).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
But truly (Revelation) is a cause of sorrow for the Unbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
But verily it is Truth of assured certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So glorify the name of thy Lord Most High.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner asked about a Penalty to befall-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
The Unbelievers, the which there is none to ward off,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
(A Penalty) from Allah, Lord of the Ways of Ascent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
The angels and the spirit ascend unto him in a Day the measure whereof is (as) fifty thousand years:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
Therefore do thou hold Patience,- a Patience of beautiful (contentment).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
They see the (Day) indeed as a far-off (event):\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
But We see it (quite) near.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
The Day that the sky will be like molten brass,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the mountains will be like wool,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no friend will ask after a friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
Though they will be put in sight of each other,- the sinner's desire will be: Would that he could redeem himself from the Penalty of that Day by (sacrificing) his children,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
His wife and his brother,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
His kindred who sheltered him,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all, all that is on earth,- so it could deliver him:\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! for it would be the Fire of Hell!-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
Plucking out (his being) right to the skull!-\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
Inviting (all) such as turn their backs and turn away their faces (from the Right).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And collect (wealth) and hide it (from use)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Truly man was created very impatient;-\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Fretful when evil touches him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And niggardly when good reaches him;-\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Not so those devoted to Prayer;-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who remain steadfast to their prayer;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose wealth is a recognised right.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the (needy) who asks and him who is prevented (for some reason from asking);\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who hold to the truth of the Day of Judgment;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who fear the displeasure of their Lord,-\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
For their Lord's displeasure is the opposite of Peace and Tranquillity;-\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who guard their chastity,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except with their wives and the (captives) whom their right hands possess,- for (then) they are not to be blamed,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But those who trespass beyond this are transgressors;-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who respect their trusts and covenants;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand firm in their testimonies;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who guard (the sacredness) of their worship;-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Such will be the honoured ones in the Gardens (of Bliss).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
Now what is the matter with the Unbelievers that they rush madly before thee-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
From the right and from the left, in crowds?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does every man of them long to enter the Garden of Bliss?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
By no means! For We have created them out of the (base matter) they know!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
Now I do call to witness the Lord of all points in the East and the West that We can certainly-\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
Substitute for them better (men) than they; And We are not to be defeated (in Our Plan).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them to plunge in vain talk and play about, until they encounter that Day of theirs which they have been promised!-\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day whereon they will issue from their sepulchres in sudden haste as if they were rushing to a goal-post (fixed for them),-\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
Their eyes lowered in dejection,- ignominy covering them (all over)! such is the Day the which they are promised!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen We sent Noah to his People (with the Command): ``Do thou warn thy People before there comes to them a grievous Penalty."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: ``O my People! I am to you a Warner, clear and open:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
``That ye should worship Allah, fear Him and obey me:\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
``So He may forgive you your sins and give you respite for a stated Term: for when the Term given by Allah is accomplished, it cannot be put forward: if ye only knew."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: ``O my Lord! I have called to my People night and day:\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
``But my call only increases (their) flight (from the Right).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
``And every time I have called to them, that Thou mightest forgive them, they have (only) thrust their fingers into their ears, covered themselves up with their garments, grown obstinate, and given themselves up to arrogance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
``So I have called to them aloud;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
``Further I have spoken to them in public and secretly in private,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
``Saying, 'Ask forgiveness from your Lord; for He is Oft-Forgiving;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
``'He will send rain to you in abundance;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
``'Give you increase in wealth and sons; and bestow on you gardens and bestow on you rivers (of flowing water).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
``'What is the matter with you, that ye place not your hope for kindness and long-suffering in Allah,-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
``'Seeing that it is He that has created you in diverse stages?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
``'See ye not how Allah has created the seven heavens one above another,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
``'And made the moon a light in their midst, and made the sun as a (Glorious) Lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
``'And Allah has produced you from the earth growing (gradually),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
``'And in the End He will return you into the (earth), and raise you forth (again at the Resurrection)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
``'And Allah has made the earth for you as a carpet (spread out),\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
``'That ye may go about therein, in spacious roads.'"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said: ``O my Lord! They have disobeyed me, but they follow (men) whose wealth and children give them no increase but only Loss.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
``And they have devised a tremendous Plot.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
``And they have said (to each other), 'Abandon not your gods: Abandon neither Wadd nor Suwa', neither Yaguth nor Ya'uq, nor Nasr';-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
``They have already misled many; and grant Thou no increase to the wrong-doers but in straying (from their mark)."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned (in the flood), and were made to enter the Fire (of Punishment): and they found- in lieu of Allah- none to help them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Noah, said: ``O my Lord! Leave not of the Unbelievers, a single one on earth!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
``For, if Thou dost leave (any of) them, they will but mislead Thy devotees, and they will breed none but wicked ungrateful ones.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
``O my Lord! Forgive me, my parents, all who enter my house in Faith, and (all) believing men and believing women: and to the wrong-doers grant Thou no increase but in perdition!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say: It has been revealed to me that a company of Jinns listened (to the Qur'an). They said, 'We have really heard a wonderful Recital!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
'It gives guidance to the Right, and we have believed therein: we shall not join (in worship) any (gods) with our Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
'And Exalted is the Majesty of our Lord: He has taken neither a wife nor a son.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
'There were some foolish ones among us, who used to utter extravagant lies against Allah;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
'But we do think that no man or spirit should say aught that untrue against Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
'True, there were persons among mankind who took shelter with persons among the Jinns, but they increased them in folly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
'And they (came to) think as ye thought, that Allah would not raise up any one (to Judgment).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
'And we pried into the secrets of heaven; but we found it filled with stern guards and flaming fires.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
'We used, indeed, to sit there in (hidden) stations, to (steal) a hearing; but any who listen now will find a flaming fire watching him in ambush.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
'And we understand not whether ill is intended to those on earth, or whether their Lord (really) intends to guide them to right conduct.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
'There are among us some that are righteous, and some the contrary: we follow divergent paths.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
'But we think that we can by no means frustrate Allah throughout the earth, nor can we frustrate Him by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
'And as for us, since we have listened to the Guidance, we have accepted it: and any who believes in his Lord has no fear, either of a short (account) or of any injustice.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
'Amongst us are some that submit their wills (to Allah), and some that swerve from justice. Now those who submit their wills - they have sought out (the path) of right conduct:\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
'But those who swerve,- they are (but) fuel for Hell-fire'-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
(And Allah's Message is): ``If they (the Pagans) had (only) remained on the (right) Way, We should certainly have bestowed on them Rain in abundance.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
``That We might try them by that (means). But if any turns away from the remembrance of his Lord, He will cause him to undergo a severe Penalty.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
``And the places of worship are for Allah (alone): So invoke not any one along with Allah;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
``Yet when the Devotee of Allah stands forth to invoke Him, they just make round him a dense crowd."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say: ``I do no more than invoke my Lord, and I join not with Him any (false god)."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: ``It is not in my power to cause you harm, or to bring you to right conduct."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: ``No one can deliver me from Allah (If I were to disobey Him), nor should I find refuge except in Him,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
``Unless I proclaim what I receive from Allah and His Messages: for any that disobey Allah and His Messenger,- for them is Hell: they shall dwell therein for ever."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
At length, when they see (with their own eyes) that which they are promised,- then will they know who it is that is weakest in (his) helper and least important in point of numbers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say: ``I know not whether the (Punishment) which ye are promised is near, or whether my Lord will appoint for it a distant term.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
``He (alone) knows the Unseen, nor does He make any one acquainted with His Mysteries,-\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
``Except a messenger whom He has chosen: and then He makes a band of watchers march before him and behind him,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
``That He may know that they have (truly) brought and delivered the Messages of their Lord: and He surrounds (all the mysteries) that are with them, and takes account of every single thing."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O thou folded in garments!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stand (to prayer) by night, but not all night,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
Half of it,- or a little less,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or a little more; and recite the Qur'an in slow, measured rhythmic tones.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Soon shall We send down to thee a weighty Message.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Truly the rising by night is most potent for governing (the soul), and most suitable for (framing) the Word (of Prayer and Praise).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
True, there is for thee by day prolonged occupation with ordinary duties:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
But keep in remembrance the name of thy Lord and devote thyself to Him whole-heartedly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
(He is) Lord of the East and the West: there is no god but He: take Him therefore for (thy) Disposer of Affairs.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And have patience with what they say, and leave them with noble (dignity).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave Me (alone to deal with) those in possession of the good things of life, who (yet) deny the Truth; and bear with them for a little while.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
With Us are Fetters (to bind them), and a Fire (to burn them),\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And a Food that chokes, and a Penalty Grievous.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
One Day the earth and the mountains will be in violent commotion. And the mountains will be as a heap of sand poured out and flowing down.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
We have sent to you, (O men!) a messenger, to be a witness concerning you, even as We sent a messenger to Pharaoh.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Pharaoh disobeyed the messenger; so We seized him with a heavy Punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
Then how shall ye, if ye deny (Allah), guard yourselves against a Day that will make children hoary-headed?-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
Whereon the sky will be cleft asunder? His Promise needs must be accomplished.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Verily this is an Admonition: therefore, whoso will, let him take a (straight) path to his Lord!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Thy Lord doth know that thou standest forth (to prayer) nigh two-thirds of the night, or half the night, or a third of the night, and so doth a party of those with thee. But Allah doth appoint night and day in due measure He knoweth that ye are unable to keep count thereof. So He hath turned to you (in mercy): read ye, therefore, of the Qur'an as much as may be easy for you. He knoweth that there may be (some) among you in ill-health; others travelling through the land, seeking of Allah's bounty; yet others fighting in Allah's Cause, read ye, therefore, as much of the Qur'an as may be easy (for you); and establish regular Prayer and give regular Charity; and loan to Allah a Beautiful Loan. And whatever good ye send forth for your souls ye shall find it in Allah's Presence,- yea, better and greater, in Reward and seek ye the Grace of Allah: for Allah is Oft-Forgiving, Most Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O thou wrapped up (in the mantle)!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and deliver thy warning!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And thy Lord do thou magnify!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And thy garments keep free from stain!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And all abomination shun!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
Nor expect, in giving, any increase (for thyself)!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
But, for thy Lord's (Cause), be patient and constant!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
Finally, when the Trumpet is sounded,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
That will be- that Day - a Day of Distress,-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
Far from easy for those without Faith.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me alone, (to deal) with the (creature) whom I created (bare and) alone!-\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
To whom I granted resources in abundance,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And sons to be by his side!-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
To whom I made (life) smooth and comfortable!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
Yet is he greedy-that I should add (yet more);-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
By no means! For to Our Signs he has been refractory!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
Soon will I visit him with a mount of calamities!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
For he thought and he plotted;-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
And woe to him! How he plotted!-\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Yea, Woe to him; How he plotted!-\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he looked round;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then he frowned and he scowled;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned back and was haughty;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
Then said he: ``This is nothing but magic, derived from of old;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
``This is nothing but the word of a mortal!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
Soon will I cast him into Hell-Fire!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what will explain to thee what Hell-Fire is?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
Naught doth it permit to endure, and naught doth it leave alone!-\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
Darkening and changing the colour of man!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are Nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
And We have set none but angels as Guardians of the Fire; and We have fixed their number only as a trial for Unbelievers,- in order that the People of the Book may arrive at certainty, and the Believers may increase in Faith,- and that no doubts may be left for the People of the Book and the Believers, and that those in whose hearts is a disease and the Unbelievers may say, ``What symbol doth Allah intend by this?" Thus doth Allah leave to stray whom He pleaseth, and guide whom He pleaseth: and none can know the forces of thy Lord, except He and this is no other than a warning to mankind.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay, verily: By the Moon,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And by the Night as it retreateth,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And by the Dawn as it shineth forth,-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
This is but one of the mighty (portents),\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
A warning to mankind,-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
To any of you that chooses to press forward, or to follow behind;-\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul will be (held) in pledge for its deeds.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except the Companions of the Right Hand.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
(They will be) in Gardens (of Delight): they will question each other,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
And (ask) of the Sinners:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
``What led you into Hell Fire?"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say: ``We were not of those who prayed;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
``Nor were we of those who fed the indigent;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
``But we used to talk vanities with vain talkers;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
``And we used to deny the Day of Judgment,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
``Until there came to us (the Hour) that is certain."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
Then will no intercession of (any) intercessors profit them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Then what is the matter with them that they turn away from admonition?-\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As if they were affrighted asses,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a lion!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Forsooth, each one of them wants to be given scrolls (of revelation) spread out!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
By no means! But they fear not the Hereafter,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nay, this surely is an admonition:\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
Let any who will, keep it in remembrance!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
But none will keep it in remembrance except as Allah wills: He is the Lord of Righteousness, and the Lord of Forgiveness.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I do call to witness the Resurrection Day;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And I do call to witness the self-reproaching spirit: (Eschew Evil).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man think that We cannot assemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Nay, We are able to put together in perfect order the very tips of his fingers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
But man wishes to do wrong (even) in the time in front of him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He questions: ``When is the Day of Resurrection?"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
At length, when the sight is dazed,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon is buried in darkness.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and moon are joined together,-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
That Day will Man say: ``Where is the refuge?"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
By no means! No place of safety!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Before thy Lord (alone), that Day will be the place of rest.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
That Day will Man be told (all) that he put forward, and all that he put back.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Nay, man will be evidence against himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Even though he were to put up his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not thy tongue concerning the (Qur'an) to make haste therewith.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
It is for Us to collect it and to promulgate it:\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
But when We have promulgated it, follow thou its recital (as promulgated):\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Nay more, it is for Us to explain it (and make it clear):\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Nay, (ye men!) but ye love the fleeting life,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And leave alone the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Some faces, that Day, will beam (in brightness and beauty);-\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking towards their Lord;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And some faces, that Day, will be sad and dismal,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
In the thought that some back-breaking calamity was about to be inflicted on them;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Yea, when (the soul) reaches to the collar-bone (in its exit),\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And there will be a cry, ``Who is a magician (to restore him)?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he will conclude that it was (the Time) of Parting;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And one leg will be joined with another:\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
That Day the Drive will be (all) to thy Lord!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
So he gave nothing in charity, nor did he pray!-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But on the contrary, he rejected Truth and turned away!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then did he stalk to his family in full conceit!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe to thee, (O men!), yea, woe!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again, Woe to thee, (O men!), yea, woe!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left uncontrolled, (without purpose)?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a drop of sperm emitted (in lowly form)?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then did he become a leech-like clot; then did (Allah) make and fashion (him) in due proportion.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And of him He made two sexes, male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Has not He, (the same), the power to give life to the dead?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there not been over Man a long period of Time, when he was nothing - (not even) mentioned?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Verily We created Man from a drop of mingled sperm, in order to try him: So We gave him (the gifts), of Hearing and Sight.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
We showed him the Way: whether he be grateful or ungrateful (rests on his will).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
For the Rejecters we have prepared chains, yokes, and a blazing Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
As to the Righteous, they shall drink of a Cup (of Wine) mixed with Kafur,-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A Fountain where the Devotees of Allah do drink, making it flow in unstinted abundance.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They perform (their) vows, and they fear a Day whose evil flies far and wide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they feed, for the love of Allah, the indigent, the orphan, and the captive,-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(Saying),"We feed you for the sake of Allah alone: no reward do we desire from you, nor thanks.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
``We only fear a Day of distressful Wrath from the side of our Lord."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
But Allah will deliver them from the evil of that Day, and will shed over them a Light of Beauty and (blissful) Joy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And because they were patient and constant, He will reward them with a Garden and (garments of) silk.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining in the (Garden) on raised thrones, they will see there neither the sun's (excessive heat) nor (the moon's) excessive cold.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And the shades of the (Garden) will come low over them, and the bunches (of fruit), there, will hang low in humility.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
And amongst them will be passed round vessels of silver and goblets of crystal,-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Crystal-clear, made of silver: they will determine the measure thereof (according to their wishes).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And they will be given to drink there of a Cup (of Wine) mixed with Zanjabil,-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
A fountain there, called Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
And round about them will (serve) youths of perpetual (freshness): If thou seest them, thou wouldst think them scattered Pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when thou lookest, it is there thou wilt see a Bliss and a Realm Magnificent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon them will be green Garments of fine silk and heavy brocade, and they will be adorned with Bracelets of silver; and their Lord will give to them to drink of a Wine Pure and Holy.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
``Verily this is a Reward for you, and your Endeavour is accepted and recognised."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
It is We Who have sent down the Qur'an to thee by stages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
Therefore be patient with constancy to the Command of thy Lord, and hearken not to the sinner or the ingrate among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And celebrate the name of thy Lord morning and evening,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And part of the night, prostrate thyself to Him; and glorify Him a long night through.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
As to these, they love the fleeting life, and put away behind them a Day (that will be) hard.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
It is We Who created them, and We have made their joints strong; but, when We will, We can substitute the like of them by a complete change.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
This is an admonition: Whosoever will, let him take a (straight) Path to his Lord.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
But ye will not, except as Allah wills; for Allah is full of Knowledge and Wisdom.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He will admit to His Mercy whom He will; But the wrong-doers,- for them has He prepared a grievous Penalty.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the (Winds) sent forth one after another (to man's profit);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
Which then blow violently in tempestuous Gusts,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
And scatter (things) far and wide;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
Then separate them, one from another,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
Then spread abroad a Message,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
Whether of Justification or of Warning;-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Assuredly, what ye are promised must come to pass.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
Then when the stars become dim;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
When the heaven is cleft asunder;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
When the mountains are scattered (to the winds) as dust;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the messengers are (all) appointed a time (to collect);-\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what Day are these (portents) deferred?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Sorting out.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what will explain to thee what is the Day of Sorting out?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the men of old (for their evil)?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
So shall We make later (generations) follow them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus do We deal with men of sin.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Have We not created you from a fluid (held) despicable?-\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
The which We placed in a place of rest, firmly fixed,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a period (of gestation), determined (according to need)?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
For We do determine (according to need); for We are the best to determine (things).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Ah woe, that Day! to the Rejecters of Truth!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth (as a place) to draw together.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
The living and the dead,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And made therein mountains standing firm, lofty (in stature); and provided for you water sweet (and wholesome)?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
(It will be said:) ``Depart ye to that which ye used to reject as false!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
``Depart ye to a Shadow (of smoke ascending) in three columns,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
``(Which yields) no shade of coolness, and is of no use against the fierce Blaze.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
``Indeed it throws about sparks (huge) as Forts,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
``As if there were (a string of) yellow camels (marching swiftly)."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
That will be a Day when they shall not be able to speak.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
Nor will it be open to them to put forth pleas.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
That will be a Day of Sorting out! We shall gather you together and those before (you)!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
Now, if ye have a trick (or plot), use it against Me!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
As to the Righteous, they shall be amidst (cool) shades and springs (of water).\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And (they shall have) fruits,- all they desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
``Eat ye and drink ye to your heart's content: for that ye worked (Righteousness).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Thus do We certainly reward the Doers of Good.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
(O ye unjust!) Eat ye and enjoy yourselves (but) a little while, for that ye are Sinners.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them, ``Prostrate yourselves!" they do not so.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Ah woe, that Day, to the Rejecters of Truth!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
Then what Message, after that, will they believe in?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen Concerning what are they disputing?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
Concerning the Great News,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
About which they cannot agree.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Verily, they shall soon (come to) know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Verily, verily they shall soon (come to) know!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth as a wide expanse,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as pegs?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And (have We not) created you in pairs,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And made your sleep for rest,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And made the night as a covering,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And made the day as a means of subsistence?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And (have We not) built over you the seven firmaments,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And placed (therein) a Light of Splendour?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And do We not send down from the clouds water in abundance,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
That We may produce therewith corn and vegetables,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens of luxurious growth?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Verily the Day of Sorting out is a thing appointed,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The Day that the Trumpet shall be sounded, and ye shall come forth in crowds;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heavens shall be opened as if there were doors,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains shall vanish, as if they were a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Truly Hell is as a place of ambush,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
For the transgressors a place of destination:\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will dwell therein for ages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
Nothing cool shall they taste therein, nor any drink,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Save a boiling fluid and a fluid, dark, murky, intensely cold,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
A fitting recompense (for them).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For that they used not to fear any account (for their deeds),\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
But they (impudently) treated Our Signs as false.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And all things have We preserved on record.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
``So taste ye (the fruits of your deeds); for no increase shall We grant you, except in Punishment."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Verily for the Righteous there will be a fulfilment of (the heart's) desires;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens enclosed, and grapevines;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And voluptuous women of equal age;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a cup full (to the brim).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
No vanity shall they hear therein, nor Untruth:-\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
Recompense from thy Lord, a gift, (amply) sufficient,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
(From) the Lord of the heavens and the earth, and all between, (Allah) Most Gracious: None shall have power to argue with Him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The Day that the Spirit and the angels will stand forth in ranks, none shall speak except any who is permitted by (Allah) Most Gracious, and He will say what is right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That Day will be the sure Reality: Therefore, whoso will, let him take a (straight) return to his Lord!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Verily, We have warned you of a Penalty near, the Day when man will see (the deeds) which his hands have sent forth, and the Unbeliever will say, ``Woe unto me! Would that I were (metre) dust!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By the (angels) who tear out (the souls of the wicked) with violence;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
By those who gently draw out (the souls of the blessed);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And by those who glide along (on errands of mercy),\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
Then press forward as in a race,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
Then arrange to do (the Commands of their Lord),\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
One Day everything that can be in commotion will be in violent commotion,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
Followed by oft-repeated (commotions):\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Hearts that Day will be in agitation;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Cast down will be (their owners') eyes.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say (now): ``What! shall we indeed be returned to (our) former state?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
``What! - when we shall have become rotten bones?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: ``It would, in that case, be a return with loss!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But verily, it will be but a single (Compelling) Cry,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
When, behold, they will be in the (full) awakening (to Judgment).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has the story of Moses reached thee?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
Behold, thy Lord did call to him in the sacred valley of Tuwa:-\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
``Go thou to Pharaoh for he has indeed transgressed all bounds:\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
``And say to him, 'Wouldst thou that thou shouldst be purified (from sin)?-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
``'And that I guide thee to thy Lord, so thou shouldst fear Him?'"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
Then did (Moses) show him the Great Sign.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But (Pharaoh) rejected it and disobeyed (guidance);\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Further, he turned his back, striving hard (against Allah).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
Then he collected (his men) and made a proclamation,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
Saying, ``I am your Lord, Most High".\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
But Allah did punish him, (and made an) example of him, - in the Hereafter, as in this life.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Verily in this is an instructive warning for whosoever feareth (Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
What! Are ye the more difficult to create or the heaven (above)? (Allah) hath constructed it:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
On high hath He raised its canopy, and He hath given it order and perfection.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
Its night doth He endow with darkness, and its splendour doth He bring out (with light).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And the earth, moreover, hath He extended (to a wide expanse);\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
He draweth out therefrom its moisture and its pasture;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains hath He firmly fixed;-\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
For use and convenience to you and your cattle.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
Therefore, when there comes the great, overwhelming (Event),-\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The Day when man shall remember (all) that he strove for,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And Hell-Fire shall be placed in full view for (all) to see,-\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
Then, for such as had transgressed all bounds,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And had preferred the life of this world,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
The Abode will be Hell-Fire;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
And for such as had entertained the fear of standing before their Lord's (tribunal) and had restrained (their) soul from lower desires,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Their abode will be the Garden.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask thee about the Hour,-'When will be its appointed time?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
Wherein art thou (concerned) with the declaration thereof?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
With thy Lord in the Limit fixed therefor.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
Thou art but a Warner for such as fear it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
The Day they see it, (It will be) as if they had tarried but a single evening, or (at most till) the following morn!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen (The Prophet) frowned and turned away,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because there came to him the blind man (interrupting).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
But what could tell thee but that perchance he might grow (in spiritual understanding)?-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or that he might receive admonition, and the teaching might profit him?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As to one who regards Himself as self-sufficient,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
To him dost thou attend;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
Though it is no blame to thee if he grow not (in spiritual understanding).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as to him who came to thee striving earnestly,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And with fear (in his heart),\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
Of him wast thou unmindful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
By no means (should it be so)! For it is indeed a Message of instruction:\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
Therefore let whoso will, keep it in remembrance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
(It is) in Books held (greatly) in honour,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted (in dignity), kept pure and holy,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
(Written) by the hands of scribes-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Honourable and Pious and Just.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Woe to man! What hath made him reject Allah;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what stuff hath He created him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a sperm-drop: He hath created him, and then mouldeth him in due proportions;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then doth He make His path smooth for him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He causeth him to die, and putteth him in his grave;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then, when it is His Will, He will raise him up (again).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
By no means hath he fulfilled what Allah hath commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Then let man look at his food, (and how We provide it):\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
For that We pour forth water in abundance,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
And We split the earth in fragments,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And produce therein corn,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And Grapes and nutritious plants,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And Olives and Dates,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And enclosed Gardens, dense with lofty trees,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and fodder,-\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
For use and convenience to you and your cattle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
At length, when there comes the Deafening Noise,-\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
That Day shall a man flee from his own brother,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And from his mother and his father,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And from his wife and his children.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Each one of them, that Day, will have enough concern (of his own) to make him indifferent to the others.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces that Day will be beaming,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And other faces that Day will be dust-stained,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Blackness will cover them:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Such will be the Rejecters of Allah, the doers of iniquity.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun (with its spacious light) is folded up;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
When the stars fall, losing their lustre;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
When the mountains vanish (like a mirage);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
When the she-camels, ten months with young, are left untended;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
When the wild beasts are herded together (in the human habitations);\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
When the oceans boil over with a swell;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
When the souls are sorted out, (being joined, like with like);\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
When the female (infant), buried alive, is questioned -\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what crime she was killed;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
When the scrolls are laid open;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
When the world on High is unveiled;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
When the Blazing Fire is kindled to fierce heat;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when the Garden is brought near;-\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
(Then) shall each soul know what it has put forward.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
So verily I call to witness the planets - that recede,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Go straight, or hide;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And the Night as it dissipates;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And the Dawn as it breathes away the darkness;-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
Verily this is the word of a most honourable Messenger,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Endued with Power, with rank before the Lord of the Throne,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
With authority there, (and) faithful to his trust.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And (O people!) your companion is not one possessed;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
And without doubt he saw him in the clear horizon.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
Neither doth he withhold grudgingly a knowledge of the Unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
Nor is it the word of an evil spirit accursed.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
When whither go ye?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
Verily this is no less than a Message to (all) the Worlds:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
(With profit) to whoever among you wills to go straight:\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
But ye shall not will except as Allah wills,- the Cherisher of the Worlds.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the Sky is cleft asunder;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
When the Stars are scattered;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
When the Oceans are suffered to burst forth;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the Graves are turned upside down;-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
(Then) shall each soul know what it hath sent forward and (what it hath) kept back.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What has seduced thee from thy Lord Most Beneficent?-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Him Who created thee. Fashioned thee in due proportion, and gave thee a just bias;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever Form He wills, does He put thee together.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Nay! But ye do reject Right and Judgment!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
But verily over you (are appointed angels) to protect you,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Kind and honourable,- Writing down (your deeds):\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know (and understand) all that ye do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
As for the Righteous, they will be in bliss;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And the Wicked - they will be in the Fire,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
Which they will enter on the Day of Judgment,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And they will not be able to keep away therefrom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what will explain to thee what the Day of Judgment is?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what will explain to thee what the Day of Judgment is?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
(It will be) the Day when no soul shall have power (to do) aught for another: For the command, that Day, will be (wholly) with Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to those that deal in fraud,-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who, when they have to receive by measure from men, exact full measure,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
But when they have to give by measure or weight to men, give less than due.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do they not think that they will be called to account?-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
On a Mighty Day,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
A Day when (all) mankind will stand before the Lord of the Worlds?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Nay! Surely the record of the wicked is (preserved) in Sijjin.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what will explain to thee what Sijjin is?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
(There is) a Register (fully) inscribed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe, that Day, to those that deny-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those that deny the Day of Judgment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none can deny it but the Transgressor beyond bounds the Sinner!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our Signs are rehearsed to him, he says, ``Tales of the ancients!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
By no means! but on their hearts is the stain of the (ill) which they do!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Verily, from (the Light of) their Lord, that Day, will they be veiled.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Further, they will enter the Fire of Hell.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Further, it will be said to them: ``This is the (reality) which ye rejected as false!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
Nay, verily the record of the Righteous is (preserved) in 'Illiyin.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what will explain to thee what 'Illiyun is?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
(There is) a Register (fully) inscribed,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
To which bear witness those Nearest (to Allah).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Truly the Righteous will be in Bliss:\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On Thrones (of Dignity) will they command a sight (of all things):\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
Thou wilt recognise in their faces the beaming brightness of Bliss.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
Their thirst will be slaked with Pure Wine sealed:\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
The seal thereof will be Musk: And for this let those aspire, who have aspirations:\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
With it will be (given) a mixture of Tasnim:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring, from (the waters) whereof drink those Nearest to Allah.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Those in sin used to laugh at those who believed,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And whenever they passed by them, used to wink at each other (in mockery);\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their own people, they would return jesting;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And whenever they saw them, they would say, ``Behold! These are the people truly astray!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
But they had not been sent as keepers over them!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But on this Day the Believers will laugh at the Unbelievers:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On Thrones (of Dignity) they will command (a sight) (of all things).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Will not the Unbelievers have been paid back for what they did?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the sky is rent asunder,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And hearkens to (the Command of) its Lord, and it must needs (do so);-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is flattened out,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And casts forth what is within it and becomes (clean) empty,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And hearkens to (the Command of) its Lord,- and it must needs (do so);- (then will come Home the full reality).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O thou man! Verily thou art ever toiling on towards thy Lord- painfully toiling,- but thou shalt meet Him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then he who is given his Record in his right hand,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
Soon will his account be taken by an easy reckoning,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And he will turn to his people, rejoicing!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But he who is given his Record behind his back,-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
Soon will he cry for perdition,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And he will enter a Blazing Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Truly, did he go about among his people, rejoicing!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
Truly, did he think that he would not have to return (to Us)!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Nay, nay! for his Lord was (ever) watchful of him!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
So I do call to witness the ruddy glow of Sunset;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
The Night and its Homing;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And the Moon in her fullness:\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
Ye shall surely travel from stage to stage.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What then is the matter with them, that they believe not?-\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Qur'an is read to them, they fall not prostrate,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
But on the contrary the Unbelievers reject (it).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
But Allah has full knowledge of what they secrete (in their breasts)\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So announce to them a Penalty Grievous,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Except to those who believe and work righteous deeds: For them is a Reward that will never fail.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the sky, (displaying) the Zodiacal Signs;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
By the promised Day (of Judgment);\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
By one that witnesses, and the subject of the witness;-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Woe to the makers of the pit (of fire),\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
Fire supplied (abundantly) with fuel:\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
Behold! they sat over against the (fire),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And they witnessed (all) that they were doing against the Believers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
And they ill-treated them for no other reason than that they believed in Allah, Exalted in Power, Worthy of all Praise!-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
Him to Whom belongs the dominion of the heavens and the earth! And Allah is Witness to all things.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Those who persecute (or draw into temptation) the Believers, men and women, and do not turn in repentance, will have the Penalty of Hell: They will have the Penalty of the Burning Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
For those who believe and do righteous deeds, will be Gardens; beneath which rivers flow: That is the great Salvation, (the fulfilment of all desires),\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Truly strong is the Grip (and Power) of thy Lord.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
It is He Who creates from the very beginning, and He can restore (life).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Oft-Forgiving, Full of Loving-Kindness,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Lord of the Throne of Glory,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Doer (without let) of all that He intends.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has the story reached thee, of the forces-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of Pharaoh and the Thamud?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
And yet the Unbelievers (persist) in rejecting (the Truth)!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
But Allah doth encompass them from behind!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay, this is a Glorious Qur'an,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
(Inscribed) in a Tablet Preserved!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the Sky and the Night-Visitant (therein);-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what will explain to thee what the Night-Visitant is?-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
(It is) the Star of piercing brightness;-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no soul but has a protector over it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
Now let man but think from what he is created!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He is created from a drop emitted-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
Proceeding from between the backbone and the ribs:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Surely (Allah) is able to bring him back (to life)!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
The Day that (all) things secret will be tested,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
(Man) will have no power, and no helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the Firmament which returns (in its round),\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And by the Earth which opens out (for the gushing of springs or the sprouting of vegetation),-\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Behold this is the Word that distinguishes (Good from Evil):\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
It is not a thing for amusement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
As for them, they are but plotting a scheme,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I am planning a scheme.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
Therefore grant a delay to the Unbelievers: Give respite to them gently (for awhile).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Glorify the name of thy Guardian-Lord Most High,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who hath created, and further, given order and proportion;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
Who hath ordained laws. And granted guidance;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
And Who bringeth out the (green and luscious) pasture,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
And then doth make it (but) swarthy stubble.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
By degrees shall We teach thee to declare (the Message), so thou shalt not forget,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except as Allah wills: For He knoweth what is manifest and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We will make it easy for thee (to follow) the simple (Path).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore give admonition in case the admonition profits (the hearer).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
The admonition will be received by those who fear (Allah):\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But it will be avoided by those most unfortunate ones,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
Who will enter the Great Fire,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
In which they will then neither die nor live.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
But those will prosper who purify themselves,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And glorify the name of their Guardian-Lord, and (lift their hearts) in prayer.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
Nay (behold), ye prefer the life of this world;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
But the Hereafter is better and more enduring.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
And this is in the Books of the earliest (Revelation),-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The Books of Abraham and Moses.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has the story reached thee of the overwhelming (Event)?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Some faces, that Day, will be humiliated,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Labouring (hard), weary,-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
The while they enter the Blazing Fire,-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
The while they are given, to drink, of a boiling hot spring,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
No food will there be for them but a bitter Dhari'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which will neither nourish nor satisfy hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
(Other) faces that Day will be joyful,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Pleased with their striving,-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a Garden on high,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
Where they shall hear no (word) of vanity:\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Therein will be a bubbling spring:\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Therein will be Thrones (of dignity), raised on high,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
Goblets placed (ready),\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions set in rows,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And rich carpets (all) spread out.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Do they not look at the Camels, how they are made?-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the Sky, how it is raised high?-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the Mountains, how they are fixed firm?-\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the Earth, how it is spread out?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Therefore do thou give admonition, for thou art one to admonish.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
Thou art not one to manage (men's) affairs.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But if any turn away and reject Allah,-\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Allah will punish him with a mighty Punishment,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
For to Us will be their return;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then it will be for Us to call them to account.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the break of Day\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
By the Nights twice five;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
By the even and odd (contrasted);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And by the Night when it passeth away;-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there (not) in these an adjuration (or evidence) for those who understand?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Seest thou not how thy Lord dealt with the 'Ad (people),-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
Of the (city of) Iram, with lofty pillars,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which were not produced in (all) the land?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And with the Thamud (people), who cut out (huge) rocks in the valley?-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And with Pharaoh, lord of stakes?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
(All) these transgressed beyond bounds in the lands,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And heaped therein mischief (on mischief).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Therefore did thy Lord pour on them a scourge of diverse chastisements:\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
For thy Lord is (as a Guardian) on a watch-tower.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
Now, as for man, when his Lord trieth him, giving him honour and gifts, then saith he, (puffed up), ``My Lord hath honoured me."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He trieth him, restricting his subsistence for him, then saith he (in despair), ``My Lord hath humiliated me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
Nay, nay! but ye honour not the orphans!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
Nor do ye encourage one another to feed the poor!-\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And ye devour inheritance - all with greed,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And ye love wealth with inordinate love!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
Nay! When the earth is pounded to powder,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And thy Lord cometh, and His angels, rank upon rank,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And Hell, that Day, is brought (face to face),- on that Day will man remember, but how will that remembrance profit him?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: ``Ah! Would that I had sent forth (good deeds) for (this) my (Future) Life!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
For, that Day, His Chastisement will be such as none (else) can inflict,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And His bonds will be such as none (other) can bind.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
(To the righteous soul will be said:) ``O (thou) soul, in (complete) rest and satisfaction!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
``Come back thou to thy Lord,- well pleased (thyself), and well-pleasing unto Him!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
``Enter thou, then, among My devotees!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
``Yea, enter thou My Heaven!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I do call to witness this City;-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And thou art a freeman of this City;-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And (the mystic ties of) parent and child;-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
Verily We have created man into toil and struggle.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Thinketh he, that none hath power over him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He may say (boastfully); Wealth have I squandered in abundance!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Thinketh he that none beholdeth him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not made for him a pair of eyes?-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue, and a pair of lips?-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And shown him the two highways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he hath made no haste on the path that is steep.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what will explain to thee the path that is steep?-\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
(It is:) freeing the bondman;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or the giving of food in a day of privation\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
To the orphan with claims of relationship,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or to the indigent (down) in the dust.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
Then will he be of those who believe, and enjoin patience, (constancy, and self-restraint), and enjoin deeds of kindness and compassion.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
Such are the Companions of the Right Hand.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But those who reject Our Signs, they are the (unhappy) Companions of the Left Hand.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
On them will be Fire vaulted over (all round).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the Sun and his (glorious) splendour;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
By the Moon as she follows him;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
By the Day as it shows up (the Sun's) glory;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
By the Night as it conceals it;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
By the Firmament and its (wonderful) structure;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
By the Earth and its (wide) expanse:\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
By the Soul, and the proportion and order given to it;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And its enlightenment as to its wrong and its right;-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Truly he succeeds that purifies it,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And he fails that corrupts it!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
The Thamud (people) rejected (their prophet) through their inordinate wrong-doing,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
Behold, the most wicked man among them was deputed (for impiety).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
But the Messenger of Allah said to them: ``It is a She-camel of Allah! And (bar her not from) having her drink!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
Then they rejected him (as a false prophet), and they hamstrung her. So their Lord, on account of their crime, obliterated their traces and made them equal (in destruction, high and low)!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And for Him is no fear of its consequences.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the Night as it conceals (the light);\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
By the Day as it appears in glory;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
By (the mystery of) the creation of male and female;-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Verily, (the ends) ye strive for are diverse.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
So he who gives (in charity) and fears (Allah),\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And (in all sincerity) testifies to the best,-\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We will indeed make smooth for him the path to Bliss.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But he who is a greedy miser and thinks himself self-sufficient,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And gives the lie to the best,-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We will indeed make smooth for him the path to Misery;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
Nor will his wealth profit him when he falls headlong (into the Pit).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Verily We take upon Ourselves to guide,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And verily unto Us (belong) the End and the Beginning.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Therefore do I warn you of a Fire blazing fiercely;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None shall reach it but those most unfortunate ones\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
Who give the lie to Truth and turn their backs.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
But those most devoted to Allah shall be removed far from it,-\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
Those who spend their wealth for increase in self-purification,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And have in their minds no favour from anyone for which a reward is expected in return,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
But only the desire to seek for the Countenance of their Lord Most High;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
And soon will they attain (complete) satisfaction.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the Glorious Morning Light,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And by the Night when it is still,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Thy Guardian-Lord hath not forsaken thee, nor is He displeased.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And verily the Hereafter will be better for thee than the present.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And soon will thy Guardian-Lord give thee (that wherewith) thou shalt be well-pleased.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find thee an orphan and give thee shelter (and care)?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And He found thee wandering, and He gave thee guidance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And He found thee in need, and made thee independent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore, treat not the orphan with harshness,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
Nor repulse the petitioner (unheard);\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
But the bounty of the Lord - rehearse and proclaim!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not expanded thee thy breast?-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And removed from thee thy burden\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
The which did gall thy back?-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And raised high the esteem (in which) thou (art held)?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
So, verily, with every difficulty, there is relief:\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Verily, with every difficulty there is relief.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
Therefore, when thou art free (from thine immediate task), still labour hard,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And to thy Lord turn (all) thy attention.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the Fig and the Olive,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
And the Mount of Sinai,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And this City of security,-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
We have indeed created man in the best of moulds,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then do We abase him (to be) the lowest of the low,-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Except such as believe and do righteous deeds: For they shall have a reward unfailing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
Then what can, after this, contradict thee, as to the judgment (to come)?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the wisest of judges?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Proclaim! (or read!) in the name of thy Lord and Cherisher, Who created-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Created man, out of a (mere) clot of congealed blood:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Proclaim! And thy Lord is Most Bountiful,-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
He Who taught (the use of) the pen,-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Taught man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Nay, but man doth transgress all bounds,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
In that he looketh upon himself as self-sufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Verily, to thy Lord is the return (of all).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Seest thou one who forbids-\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A votary when he (turns) to pray?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Seest thou if he is on (the road of) Guidance?-\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or enjoins Righteousness?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Seest thou if he denies (Truth) and turns away?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Knoweth he not that Allah doth see?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Let him beware! If he desist not, We will drag him by the forelock,-\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A lying, sinful forelock!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then, let him call (for help) to his council (of comrades):\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call on the angels of punishment (to deal with him)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
Nay, heed him not: But bow down in adoration, and bring thyself the closer (to Allah)!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen We have indeed revealed this (Message) in the Night of Power:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what will explain to thee what the night of power is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Power is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
Therein come down the angels and the Spirit by Allah's permission, on every errand:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace!... This until the rise of morn!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who reject (Truth), among the People of the Book and among the Polytheists, were not going to depart (from their ways) until there should come to them Clear Evidence,-\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
An messenger from Allah, rehearsing scriptures kept pure and holy:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Wherein are laws (or decrees) right and straight.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Nor did the People of the Book make schisms, until after there came to them Clear Evidence.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they have been commanded no more than this: To worship Allah, offering Him sincere devotion, being true (in faith); to establish regular prayer; and to practise regular charity; and that is the Religion Right and Straight.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Those who reject (Truth), among the People of the Book and among the Polytheists, will be in Hell-Fire, to dwell therein (for aye). They are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Those who have faith and do righteous deeds,- they are the best of creatures.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward is with Allah: Gardens of Eternity, beneath which rivers flow; they will dwell therein for ever; Allah well pleased with them, and they with Him: all this for such as fear their Lord and Cherisher.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken to her (utmost) convulsion,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And the earth throws up her burdens (from within),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man cries (distressed): 'What is the matter with her?'-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that Day will she declare her tidings:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
For that thy Lord will have given her inspiration.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that Day will men proceed in companies sorted out, to be shown the deeds that they (had done).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
Then shall anyone who has done an atom's weight of good, see it!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And anyone who has done an atom's weight of evil, shall see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the (Steeds) that run, with panting (breath),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
And strike sparks of fire,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And push home the charge in the morning,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
And raise the dust in clouds the while,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
And penetrate forthwith into the midst (of the foe) en masse;-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Truly man is, to his Lord, ungrateful;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And to that (fact) he bears witness (by his deeds);\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And violent is he in his love of wealth.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Does he not know,- when that which is in the graves is scattered abroad\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And that which is (locked up) in (human) breasts is made manifest-\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
That their Lord had been Well-acquainted with them, (even to) that Day?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The (Day) of Noise and Clamour:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the (Day) of Noise and Clamour?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what will explain to thee what the (Day) of Noise and Clamour is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
(It is) a Day whereon men will be like moths scattered about,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will be like carded wool.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then, he whose balance (of good deeds) will be (found) heavy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
Will be in a life of good pleasure and satisfaction.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But he whose balance (of good deeds) will be (found) light,-\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
Will have his home in a (bottomless) Pit.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what will explain to thee what this is?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
(It is) a Fire Blazing fiercely!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The mutual rivalry for piling up (the good things of this world) diverts you (from the more serious things),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until ye visit the graves.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
But nay, ye soon shall know (the reality).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again, ye soon shall know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Nay, were ye to know with certainty of mind, (ye would beware!)\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
Ye shall certainly see Hell-Fire!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Again, ye shall see it with certainty of sight!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, shall ye be questioned that Day about the joy (ye indulged in!).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By (the Token of) Time (through the ages),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Verily Man is in loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except such as have Faith, and do righteous deeds, and (join together) in the mutual teaching of Truth, and of Patience and Constancy.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every (kind of) scandal-monger and-backbiter,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who pileth up wealth and layeth it by,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
Thinking that his wealth would make him last for ever!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
By no means! He will be sure to be thrown into That which Breaks to Pieces,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what will explain to thee That which Breaks to Pieces?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
(It is) the Fire of (the Wrath of) Allah kindled (to a blaze),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
The which doth mount (Right) to the Hearts:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
It shall be made into a vault over them,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In columns outstretched.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Seest thou not how thy Lord dealt with the Companions of the Elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their treacherous plan go astray?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them Flights of Birds,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Striking them with stones of baked clay.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
Then did He make them like an empty field of stalks and straw, (of which the corn) has been eaten up.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the covenants (of security and safeguard enjoyed) by the Quraish,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
Their covenants (covering) journeys by winter and summer,-\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
Let them adore the Lord of this House,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who provides them with food against hunger, and with security against fear (of danger).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Seest thou one who denies the Judgment (to come)?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
Then such is the (man) who repulses the orphan (with harshness),\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And encourages not the feeding of the indigent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So woe to the worshippers\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Who are neglectful of their prayers,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who (want but) to be seen (of men),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
But refuse (to supply) (even) neighbourly needs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen To thee have We granted the Fount (of Abundance).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
Therefore to thy Lord turn in Prayer and Sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
For he who hateth thee, he will be cut off (from Future Hope).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: O ye that reject Faith!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I worship not that which ye worship,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor will ye worship that which I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
And I will not worship that which ye have been wont to worship,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor will ye worship that which I worship.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
To you be your Way, and to me mine.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When comes the Help of Allah, and Victory,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And thou dost see the people enter Allah's Religion in crowds,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Celebrate the praises of thy Lord, and pray for His Forgiveness: For He is Oft-Returning (in Grace and Mercy).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the hands of the Father of Flame! Perish he!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
No profit to him from all his wealth, and all his gains!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
Burnt soon will he be in a Fire of Blazing Flame!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
His wife shall carry the (crackling) wood - As fuel!-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
A twisted rope of palm-leaf fibre round her (own) neck!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: He is Allah, the One and Only;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
Allah, the Eternal, Absolute;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He begetteth not, nor is He begotten;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
And there is none like unto Him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: I seek refuge with the Lord of the Dawn\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
From the mischief of created things;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
From the mischief of Darkness as it overspreads;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
From the mischief of those who practise secret arts;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
And from the mischief of the envious one as he practises envy.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: I seek refuge with the Lord and Cherisher of Mankind,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
The King (or Ruler) of Mankind,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
The god (or judge) of Mankind,-\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
From the mischief of the Whisperer (of Evil), who withdraws (after his whisper),-\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
(The same) who whispers into the hearts of Mankind,-\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
Among Jinns and among men.\qt@no{6}}%
%% End of file `qurantext-enxvi.translation.def'
